
#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 1865
 * transforms:
 *    ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul', 'a@8', 128) => ('ishl', 'a', 7)
 *    ('imul', 'a@16', 32768) => ('ishl', 'a', 15)
 *    ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31)
 *    ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63)
 *    ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b'))
 *    ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b')))
 *    ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b'))
 *    ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b'))
 *    ('udiv', 'a', 1) => a
 *    ('idiv', 'a', 1) => a
 *    ('umod', 'a', 1) => 0
 *    ('imod', 'a', 1) => 0
 *    ('imod', 'a', -1) => 0
 *    ('irem', 'a', 1) => 0
 *    ('irem', 'a', -1) => 0
 *    ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b'))
 *    ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b')))
 *    ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b')))))
 *    ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b'))
 *    ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b')))
 *    ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b'))
 *    ('~fneg', ('fneg', 'a')) => a
 *    ('ineg', ('ineg', 'a')) => a
 *    ('fabs', ('fneg', 'a')) => ('fabs', 'a')
 *    ('fabs', ('u2f', 'a')) => ('u2f', 'a')
 *    ('iabs', ('iabs', 'a')) => ('iabs', 'a')
 *    ('iabs', ('ineg', 'a')) => ('iabs', 'a')
 *    ('f2b', ('fneg', 'a')) => ('f2b', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('~fadd', 'a', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a
 *    ('iadd', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', -1) => -1
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c'))
 *    ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a'))
 *    ('~fmul', 'a', 0.0) => 0.0
 *    ('fmul', 'a@16', 0.0) => 0.0
 *    ('fmul', 'a@32', 0.0) => 0.0
 *    ('imul', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', -1) => a
 *    ('~fmul', 'a', 1.0) => a
 *    ('fmul(is_only_used_as_float)', 'a', 1.0) => a
 *    ('imul', 'a', 1) => a
 *    ('fmul', 'a', -1.0) => ('fneg', 'a')
 *    ('imul', 'a', -1) => ('ineg', 'a')
 *    ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a')
 *    ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a')
 *    ('~ffma', 0.0, 'a', 'b') => b
 *    ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~flrp', 'a', 'b', 0.0) => a
 *    ('~flrp', 'a', 'b', 1.0) => b
 *    ('~flrp', 'a', 'a', 'b') => a
 *    ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b')
 *    ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('sdot_4x8_iadd', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd', 'a', 0, 'b') => b
 *    ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd_sat', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 0, 'a', 'b') => b
 *    ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b
 *    ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c')
 *    ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a')
 *    ('ftrunc', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ffloor', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('fadd', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('ffract', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a')))
 *    ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e'))
 *    ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y')
 *    ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b'))
 *    ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b'))
 *    ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b'))
 *    ('fsum2', 'a') => ('fadd', 'a.x', 'a.y')
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd'))
 *    ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c'))
 *    ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 7))
 *    ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 15))
 *    ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 31))
 *    ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 63))
 *    ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b'))
 *    ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b'))
 *    ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b'))
 *    ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b'))
 *    ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b')
 *    ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b')
 *    ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1)
 *    ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1)
 *    ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2)
 *    ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2)
 *    ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16)
 *    ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16)
 *    ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16)
 *    ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24)
 *    ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24)
 *    ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd'))
 *    ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd'))
 *    ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b')
 *    ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b')
 *    ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b')
 *    ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b')
 *    ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b')
 *    ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b')
 *    ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b')
 *    ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b')
 *    ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b')
 *    ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False
 *    ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False
 *    ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False
 *    ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False
 *    ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a')
 *    ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a')
 *    ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b')
 *    ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b')
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b')
 *    ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b')
 *    ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b')
 *    ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b')
 *    ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0)
 *    ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0)
 *    ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b'))
 *    ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0)
 *    ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0)
 *    ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0)
 *    ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0)
 *    ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0)
 *    ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0)
 *    ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a')
 *    ('fneu', ('b2f', 'a@1'), 0.0) => a
 *    ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a')
 *    ('ine', ('b2i', 'a@1'), 0) => a
 *    ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('u2f', 'a'), 0.0) => True
 *    ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a')
 *    ('flt', ('u2f', 'a'), 0.0) => False
 *    ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a')
 *    ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0)
 *    ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a')
 *    ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0)
 *    ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a')
 *    ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0)
 *    ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0)
 *    ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0)
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a'))
 *    ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b'))
 *    ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b')))
 *    ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b')))
 *    ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0))
 *    ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b')
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c')
 *    ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b')
 *    ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b')
 *    ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b')
 *    ('~fmin', 'a', 'a') => a
 *    ('~fmax', 'a', 'a') => a
 *    ('imin', 'a', 'a') => a
 *    ('imax', 'a', 'a') => a
 *    ('umin', 'a', 'a') => a
 *    ('umin', 'a', 0) => 0
 *    ('umin', 'a', -1) => a
 *    ('umax', 'a', 'a') => a
 *    ('umax', 'a', 0) => a
 *    ('umax', 'a', -1) => -1
 *    ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b')
 *    ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b')
 *    ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b')
 *    ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b')
 *    ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b')
 *    ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b')
 *    ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c')
 *    ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c')
 *    ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c')
 *    ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c')
 *    ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c')
 *    ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c')
 *    ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b')
 *    ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0)
 *    ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0)
 *    ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0)
 *    ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0)
 *    ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a'))
 *    ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a'))
 *    ('~fmin', 'a', ('fabs', 'a')) => a
 *    ('imin', 'a', ('iabs', 'a')) => a
 *    ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a
 *    ('imax', 'a', ('ineg', ('iabs', 'a'))) => a
 *    ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a')
 *    ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a')
 *    ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a')
 *    ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a')
 *    ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a')
 *    ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a'))
 *    ('fsat', ('b2f', 'a')) => ('b2f', 'a')
 *    ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0)
 *    ('fsat', ('fsat', 'a')) => ('fsat', 'a')
 *    ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b')))
 *    ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b')))
 *    ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c')
 *    ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c')
 *    ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c')
 *    ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b'))
 *    ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b'))
 *    ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a'))
 *    ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a'))
 *    ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b'))
 *    ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255)
 *    ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c'))
 *    ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c')
 *    ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c'))
 *    ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c')
 *    ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c'))
 *    ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c'))
 *    ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c'))
 *    ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c')
 *    ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c'))
 *    ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c')
 *    ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c'))
 *    ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c'))
 *    ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a')
 *    ('~f2i16', ('i2f', 'a@16')) => a
 *    ('~f2i16', ('u2f', 'a@16')) => a
 *    ('~f2u16', ('i2f', 'a@16')) => a
 *    ('~f2u16', ('u2f', 'a@16')) => a
 *    ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a'))
 *    ('f2f16', ('f2f32', 'a@16')) => a
 *    ('i2i16', ('i2i32', 'a@16')) => a
 *    ('u2u16', ('u2u32', 'a@16')) => a
 *    ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a')
 *    ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a')
 *    ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a')
 *    ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a')
 *    ('f2f16', ('f2f64', 'a@16')) => a
 *    ('i2i16', ('i2i64', 'a@16')) => a
 *    ('u2u16', ('u2u64', 'a@16')) => a
 *    ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a')
 *    ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a')
 *    ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a')
 *    ('~f2i32', ('i2f', 'a@32')) => a
 *    ('~f2i32', ('u2f', 'a@32')) => a
 *    ('~f2u32', ('i2f', 'a@32')) => a
 *    ('~f2u32', ('u2f', 'a@32')) => a
 *    ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a'))
 *    ('f2f32', ('f2f64', 'a@32')) => a
 *    ('i2i32', ('i2i64', 'a@32')) => a
 *    ('u2u32', ('u2u64', 'a@32')) => a
 *    ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a')
 *    ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a')
 *    ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a')
 *    ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a')
 *    ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a')
 *    ('~f2i64', ('i2f', 'a@64')) => a
 *    ('~f2i64', ('u2f', 'a@64')) => a
 *    ('~f2u64', ('i2f', 'a@64')) => a
 *    ('~f2u64', ('u2f', 'a@64')) => a
 *    ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a'))
 *    ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a')
 *    ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a')
 *    ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a')
 *    ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a')
 *    ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a')
 *    ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a')
 *    ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a')
 *    ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a')
 *    ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b')
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b')
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b')
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i8', 'a@8')) => a
 *    ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i16', 'a@16')) => a
 *    ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i32', 'a@32')) => a
 *    ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i64', 'a@64')) => a
 *    ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b')
 *    ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a')
 *    ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a')
 *    ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a')
 *    ('ior', 'a', ('ieq', 'a', False)) => True
 *    ('ior', 'a', ('inot', 'a')) => -1
 *    ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b')
 *    ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b'))
 *    ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0))
 *    ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0))
 *    ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b')
 *    ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a')
 *    ('~fge', 'a', ('fmin', 'b', 'a')) => True
 *    ('~fge', ('fmax', 'a', 'b'), 'a') => True
 *    ('flt', 'a', ('fmin', 'b', 'a')) => False
 *    ('flt', ('fmax', 'a', 'b'), 'a') => False
 *    ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b')
 *    ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a')
 *    ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b')
 *    ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a')
 *    ('ige', 'a', ('imin', 'b', 'a')) => True
 *    ('ige', ('imax', 'a', 'b'), 'a') => True
 *    ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b')
 *    ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a')
 *    ('uge', 'a', ('umin', 'b', 'a')) => True
 *    ('uge', ('umax', 'a', 'b'), 'a') => True
 *    ('ilt', 'a', ('imin', 'b', 'a')) => False
 *    ('ilt', ('imax', 'a', 'b'), 'a') => False
 *    ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b')
 *    ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a')
 *    ('ult', 'a', ('umin', 'b', 'a')) => False
 *    ('ult', ('umax', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b')
 *    ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a')
 *    ('ult', 'a', ('iand', 'b', 'a')) => False
 *    ('ult', ('ior', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('iand', 'b', 'a')) => True
 *    ('uge', ('ior', 'a', 'b'), 'a') => True
 *    ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b'))
 *    ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b')
 *    ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b')
 *    ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b')
 *    ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b')
 *    ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b')
 *    ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b'))
 *    ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b'))
 *    ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b'))
 *    ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b'))
 *    ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y'))
 *    ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0)
 *    ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0)
 *    ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y'))
 *    ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y'))
 *    ('ball_iequal3', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('ieq', 'a.z', 'b.z'))
 *    ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w')))
 *    ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y'))
 *    ('bany_inequal3', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ine', 'a.z', 'b.z'))
 *    ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w')))
 *    ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y'))
 *    ('ball_fequal3', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('feq', 'a.z', 'b.z'))
 *    ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w')))
 *    ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y'))
 *    ('bany_fnequal3', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('fneu', 'a.z', 'b.z'))
 *    ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w')))
 *    ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0)
 *    ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0)
 *    ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b'))
 *    ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b'))
 *    ('iand', 'a@bool16', 1.0) => ('b2f', 'a')
 *    ('iand', 'a@bool32', 1.0) => ('b2f', 'a')
 *    ('flt', ('fneg', ('b2f', 'a@1')), 0) => a
 *    ('ilt', 'a', 'a') => False
 *    ('ige', 'a', 'a') => True
 *    ('ieq', 'a', 'a') => True
 *    ('ine', 'a', 'a') => False
 *    ('ult', 'a', 'a') => False
 *    ('uge', 'a', 'a') => True
 *    ('flt', 'a', 'a') => False
 *    ('fge', 'a(is_a_number)', 'a') => True
 *    ('feq', 'a(is_a_number)', 'a') => True
 *    ('fneu', 'a(is_a_number)', 'a') => False
 *    ('iand', 'a', 'a') => a
 *    ('iand', 'a', -1) => a
 *    ('iand', 'a', 0) => 0
 *    ('ior', 'a', 'a') => a
 *    ('ior', 'a', 0) => a
 *    ('ior', 'a', True) => True
 *    ('ixor', 'a', 'a') => 0
 *    ('ixor', 'a', 0) => a
 *    ('inot', ('inot', 'a')) => a
 *    ('ior', ('iand', 'a', 'b'), 'b') => b
 *    ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b')
 *    ('iand', ('ior', 'a', 'b'), 'b') => b
 *    ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b')
 *    ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b'))
 *    ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b'))
 *    ('ishl', 0, 'a') => 0
 *    ('ishl', 'a', 0) => a
 *    ('ishr', 0, 'a') => 0
 *    ('ishr', 'a', 0) => a
 *    ('ushr', 0, 'a') => 0
 *    ('ushr', 'a', 0) => a
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b')
 *    ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b')))
 *    ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b')))
 *    ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b')))
 *    ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b')))
 *    ('~fexp2', ('flog2', 'a')) => a
 *    ('~flog2', ('fexp2', 'a')) => a
 *    ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b')
 *    ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 'a', 1.0) => a
 *    ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a')
 *    ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 2.0, 'a') => ('fexp2', 'a')
 *    ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a
 *    ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a')
 *    ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a'))
 *    ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a'))
 *    ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a'))
 *    ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a'))
 *    ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a'))
 *    ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a'))
 *    ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a'))
 *    ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b'))
 *    ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0))
 *    ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fdiv', 1.0, 'a') => ('frcp', 'a')
 *    ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b'))
 *    ('~frcp', ('frcp', 'a')) => a
 *    ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a')
 *    ('fsqrt', 'a') => ('frcp', ('frsq', 'a'))
 *    ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a')
 *    ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))
 *    ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))
 *    ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0)
 *    ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0)
 *    ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0)
 *    ('ieq', 'a', True) => a
 *    ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a')
 *    ('ine', 'a', False) => a
 *    ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a')
 *    ('bcsel', 'a', True, False) => a
 *    ('bcsel', 'a', False, True) => ('inot', 'a')
 *    ('bcsel', True, 'b', 'c') => b
 *    ('bcsel', False, 'b', 'c') => c
 *    ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel', 'a', 'b', 'b') => b
 *    ('~fcsel', 'a', 'b', 'b') => b
 *    ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1'))
 *    ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a')))
 *    ('bcsel', 'a', 1, 0) => ('b2i', 'a@1')
 *    ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a'))
 *    ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a')
 *    ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a
 *    ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a')
 *    ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a')
 *    ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2i', ('ftrunc', 'a')) => ('f2i', 'a')
 *    ('f2u', ('ftrunc', 'a')) => ('f2u', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('i2b', ('iabs', 'a')) => ('i2b', 'a')
 *    ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0)
 *    ('f2fmp', ('f2f32', 'a@16')) => a
 *    ('i2imp', ('i2i32', 'a@16')) => a
 *    ('i2imp', ('u2u32', 'a@16')) => a
 *    ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a')
 *    ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a')
 *    ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a')
 *    ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a')
 *    ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('f2f32', ('f2fmp', 'a@32')) => a
 *    ('i2i32', ('i2imp', 'a@32')) => a
 *    ('u2u32', ('i2imp', 'a@32')) => a
 *    ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a')
 *    ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a')
 *    ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a')
 *    ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a')
 *    ('~f2f32', ('f2f64', 'a@32')) => a
 *    ('ffloor', 'a(is_integral)') => a
 *    ('fceil', 'a(is_integral)') => a
 *    ('ftrunc', 'a(is_integral)') => a
 *    ('~ffract', 'a(is_integral)') => 0.0
 *    ('fabs', 'a(is_not_negative)') => a
 *    ('iabs', 'a(is_not_negative)') => a
 *    ('fsat', 'a(is_not_positive)') => 0.0
 *    ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a')
 *    ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0)
 *    ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0)
 *    ('fneu', 'a(is_not_zero)', 0.0) => True
 *    ('feq', 'a(is_not_zero)', 0.0) => False
 *    ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True
 *    ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True
 *    ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True
 *    ('ine', 'a(is_not_zero)', 0) => True
 *    ('ieq', 'a(is_not_zero)', 0) => False
 *    ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True
 *    ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True
 *    ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True
 *    ('ult', 0, 'a(is_gt_zero)') => True
 *    ('ult', 'a', 0) => False
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b
 *    ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b')
 *    ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a
 *    ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a
 *    ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a
 *    ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a
 *    ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a
 *    ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a
 *    ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c'))
 *    ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1)
 *    ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3)
 *    ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7)
 *    ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1)
 *    ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3)
 *    ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7)
 *    ('iand', 255, 'a') => ('extract_u8', 'a', 0)
 *    ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2))
 *    ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1))
 *    ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b'))
 *    ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b'))
 *    ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0)
 *    ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1)
 *    ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2)
 *    ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3)
 *    ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0)
 *    ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1)
 *    ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2)
 *    ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3)
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0)
 *    ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1)
 *    ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0)
 *    ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1)
 *    ('iand', 65535, 'a') => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1)
 *    ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0)
 *    ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1)
 *    ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a'))
 *    ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32))
 *    ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16))
 *    ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a')
 *    ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32))
 *    ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16))
 *    ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a')
 *    ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a')
 *    ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a')
 *    ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a'))
 *    ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0))
 *    ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a')
 *    ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0)
 *    ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0)
 *    ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd')
 *    ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6)
 *    ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5)
 *    ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4)
 *    ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3)
 *    ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0)
 *    ('ussub_4x8_vc4', 'a', 0) => a
 *    ('ussub_4x8_vc4', 'a', -1) => 0
 *    ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b'))
 *    ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b'))
 *    ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b'))
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b'))
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b'))
 *    ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b')
 *    ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b')
 *    ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b')
 *    ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a
 *    ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd')
 *    ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b'))))
 *    ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b'))))
 *    ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a'))
 *    ('usub_borrow@32', 'a', 'b') => ('b2i', ('ult', 'a', 'b'))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base'))
 *    ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807))
 *    ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base'))
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits'))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits'))
 *    ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b')
 *    ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c')
 *    ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits')
 *    ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits')
 *    ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset')
 *    ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset')
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b')))
 *    ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits')))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1)))
 *    ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value'))
 *    ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value'))
 *    ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value'))
 *    ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value')))
 *    ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24)
 *    ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255)
 *    ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16)
 *    ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535)
 *    ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0))))
 *    ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0))))
 *    ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0))))
 *    ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0))))
 *    ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0)
 *    ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0)
 *    ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0)))
 *    ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0)))
 *    ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a')))
 *    ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a'))
 *    ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16)))
 *    ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a'))
 *    ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16))
 *    ('isign', 'a') => ('imin', ('imax', 'a', -1), 1)
 *    ('imin', ('imax', 'a', -1), 1) => ('isign', 'a')
 *    ('imax', ('imin', 'a', 1), -1) => ('isign', 'a')
 *    ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0)))
 *    ('amul', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215))
 *    ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c')
 *    ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b')
 *    ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c')
 *    ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b')
 *    ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b')
 *    ('imad24_ir3', 'a', 0, 'c') => c
 *    ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c')
 *    ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c')
 *    ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('imul24', 'a', 0) => 0
 *    ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'c', 'b')
 *    ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'c', 'b')
 *    ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b')
 *    ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b')
 *    ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'c', 'b')
 *    ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'c', 'b')
 *    ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b')))
 *    ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b')))
 *    ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b')))
 *    ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b')))
 *    ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b')))
 *    ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b')))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b')))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b')))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('f2b1', ('b2f', 'a@1')) => a
 *    ('i2b1', ('b2i', 'a@1')) => a
 *    ('f2b8', ('b2f', 'a@8')) => a
 *    ('i2b8', ('b2i', 'a@8')) => a
 *    ('f2b16', ('b2f', 'a@16')) => a
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('f2b32', ('b2f', 'a@32')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2f', ('b2f', 'a')) => ('b2f', 'a')
 *    ('f2u', ('b2f', 'a')) => ('b2i', 'a')
 *    ('f2i', ('b2f', 'a')) => ('b2i', 'a')
 *    ('u2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('u2u', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('i2i', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2i1', 'a@1') => a
 *    ('i2i8', 'a@8') => a
 *    ('i2i16', 'a@16') => a
 *    ('i2i32', 'a@32') => a
 *    ('i2i64', 'a@64') => a
 *    ('u2u1', 'a@1') => a
 *    ('u2u8', 'a@8') => a
 *    ('u2u16', 'a@16') => a
 *    ('u2u32', 'a@32') => a
 *    ('u2u64', 'a@64') => a
 *    ('f2f16', 'a@16') => a
 *    ('f2f32', 'a@32') => a
 *    ('f2f64', 'a@64') => a
 *    ('b2b1', 'a@1') => a
 *    ('b2b8', 'a@8') => a
 *    ('b2b16', 'a@16') => a
 *    ('b2b32', 'a@32') => a
 *    ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b')))
 *    ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b')))
 *    ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a')
 *    ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a')
 *    ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a')
 *    ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a')
 *    ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10)))
 *    ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23))
 *    ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20)))
 *    ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x')
 *    ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x')
 *    ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b')
 *    ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b')
 *    ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b')
 *    ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b')
 *    ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b')
 *    ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b')
 *    ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b')
 *    ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b')
 *    ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b')
 *    ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b')
 *    ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b')
 *    ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b')
 *    ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b')
 *    ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b')
 *    ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b')
 *    ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b')
 *    ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b')
 *    ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b')
 *    ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b')
 *    ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a')
 *    ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd'))
 *    ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd'))
 *    ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd'))
 *    ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd'))
 *    ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd'))
 *    ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c'))
 *    ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd'))
 *    ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c'))
 *    ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd'))
 *    ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c'))
 *    ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd'))
 *    ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c'))
 *    ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd'))
 *    ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c'))
 *    ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd'))
 *    ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c'))
 *    ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd'))
 *    ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd'))
 *    ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd'))
 *    ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd'))
 *    ('fddx', 'a') => 0.0
 *    ('fddx_fine', 'a') => 0.0
 *    ('fddx_coarse', 'a') => 0.0
 *    ('fddy', 'a') => 0.0
 *    ('fddy_fine', 'a') => 0.0
 *    ('fddy_coarse', 'a') => 0.0
 *    ('umul_low', '#a(is_lower_half_zero)', 'b') => 0
 *    ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c
 *    ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b'))
 *    ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b'))
 *    ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b'))
 *    ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b'))
 *    ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216))
 *    ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b'))
 *    ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b'))
 *    ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b'))
 *    ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b'))
 *    ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b'))
 *    ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'))
 *    ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))
 *    ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'))
 *    ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'))
 *    ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'))
 *    ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd'))
 *    ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd'))
 *    ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd'))
 *    ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd'))
 *    ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd'))
 */


static const nir_search_value_union nir_opt_algebraic_values[] = {
   /* ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imul,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_find_lsb,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('imul', 'a@8', 128) => ('ishl', 'a', 7) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x80 /* 128 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_imul,
      0, 1,
      { 6, 7 },
      -1,
   } },

   /* replace1_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 6, 9 },
      -1,
   } },

   /* ('imul', 'a@16', 32768) => ('ishl', 'a', 15) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x8000 /* 32768 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_imul,
      0, 1,
      { 11, 12 },
      -1,
   } },

   /* replace2_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf /* 15 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 11, 14 },
      -1,
   } },

   /* ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x80000000 /* 2147483648 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 16, 17 },
      -1,
   } },

   /* replace3_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1f /* 31 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 19 },
      -1,
   } },

   /* ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x8000000000000000 /* 9223372036854775808 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_imul,
      0, 1,
      { 21, 22 },
      -1,
   } },

   /* replace4_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3f /* 63 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 24 },
      -1,
   } },

   /* ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search5_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imul,
      0, 1,
      { 0, 26 },
      -1,
   } },

   /* replace5_0_0 -> 0 in the cache */
   /* replace5_0_1_0_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_find_lsb,
      -1, 0,
      { 28 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 0, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 30 },
      -1,
   } },

   /* ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 32, 33 },
      -1,
   } },

   /* replace6_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imul,
      0, 1,
      { 32, 37 },
      -1,
   } },

   /* ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b'))) */
   /* search7_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_imul,
      0, 1,
      { 21, 39 },
      -1,
   } },

   /* replace7_0_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ufind_msb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 42 },
      -1,
   } },
   /* replace7_1_0 -> 21 in the cache */
   /* replace7_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_find_lsb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 44 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 43, 45 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search8_0_0 -> 16 in the cache */
   /* search8_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 47 },
      -1,
   } },

   /* replace8_0 -> 16 in the cache */
   /* replace8_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search9_0_0 -> 16 in the cache */
   /* search9_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 50 },
      -1,
   } },

   /* replace9_0 -> 16 in the cache */
   /* replace9_1 -> 36 in the cache */
   /* replace9 -> 49 in the cache */

   /* ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b')) */
   /* search10_0 -> 16 in the cache */
   /* search10_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace10_0_0 -> 16 in the cache */
   /* replace10_0_1 -> 36 in the cache */
   /* replace10_0 -> 49 in the cache */
   /* replace10_1_0 -> 16 in the cache */
   /* replace10_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 53 },
      -1,
   } },

   /* ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b')) */
   /* search11_0 -> 16 in the cache */
   /* search11_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace11_0_0 -> 16 in the cache */
   /* replace11_0_1 -> 36 in the cache */
   /* replace11_0 -> 49 in the cache */
   /* replace11_1_0 -> 16 in the cache */
   /* replace11_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 56 },
      -1,
   } },

   /* ('udiv', 'a', 1) => a */
   /* search12_0 -> 32 in the cache */
   /* search12_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_udiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace12 -> 32 in the cache */

   /* ('idiv', 'a', 1) => a */
   /* search13_0 -> 32 in the cache */
   /* search13_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_idiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace13 -> 32 in the cache */

   /* ('umod', 'a', 1) => 0 */
   /* search14_0 -> 32 in the cache */
   /* search14_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_umod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('imod', 'a', 1) => 0 */
   /* search15_0 -> 32 in the cache */
   /* search15_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace15 -> 61 in the cache */

   /* ('imod', 'a', -1) => 0 */
   /* search16_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imod,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace16 -> 61 in the cache */

   /* ('irem', 'a', 1) => 0 */
   /* search17_0 -> 32 in the cache */
   /* search17_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_irem,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace17 -> 61 in the cache */

   /* ('irem', 'a', -1) => 0 */
   /* search18_0 -> 32 in the cache */
   /* search18_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_irem,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace18 -> 61 in the cache */

   /* ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b')) */
   /* search19_0 -> 0 in the cache */
   /* search19_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_udiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace19_0 -> 0 in the cache */
   /* replace19_1_0 -> 3 in the cache */
   /* replace19_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b'))) */
   /* search20_0 -> 0 in the cache */
   /* search20_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_idiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace20_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_isign,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_1_0 -> 3 in the cache */
   /* replace20_1_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 71, 4 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imul,
      0, 1,
      { 70, 72 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b'))))) */
   /* search21_0 -> 0 in the cache */
   /* search21_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_idiv,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace21_0_0_0 -> 0 in the cache */
   /* replace21_0_0 -> 70 in the cache */
   /* replace21_0_1_0_0 -> 0 in the cache */
   /* replace21_0_1_0 -> 71 in the cache */
   /* replace21_0_1_1_0_0 -> 3 in the cache */
   /* replace21_0_1_1_0 -> 28 in the cache */
   /* replace21_0_1_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 71, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imul,
      0, 1,
      { 70, 75 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ineg,
      -1, 1,
      { 76 },
      -1,
   } },

   /* ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search22_0 -> 0 in the cache */
   /* search22_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_umod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace22_0 -> 0 in the cache */
   /* replace22_1_0 -> 3 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 3, 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 1,
      { 0, 80 },
      -1,
   } },

   /* ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search23_0 -> 0 in the cache */
   /* search23_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace23_0 -> 0 in the cache */
   /* replace23_1_0 -> 3 in the cache */
   /* replace23_1_1 -> 79 in the cache */
   /* replace23_1 -> 80 in the cache */
   /* replace23 -> 81 in the cache */

   /* ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b')) */
   /* search24_0 -> 0 in the cache */
   /* search24_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imod,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace24_0_0_0 -> 0 in the cache */
   /* replace24_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ior,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace24_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 84, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace24_2_0 -> 0 in the cache */
   /* replace24_2_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ior,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 3,
      { 85, 86, 87 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b'))) */
   /* search25_0 -> 0 in the cache */
   /* search25_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_irem,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace25_0 -> 0 in the cache */
   /* replace25_1_0_0_0 -> 0 in the cache */
   /* replace25_1_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 0, 86 },
      -1,
   } },
   /* replace25_1_0_1_0 -> 0 in the cache */
   /* replace25_1_0_1_1_0 -> 3 in the cache */
   /* replace25_1_0_1_1_1 -> 79 in the cache */
   /* replace25_1_0_1_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 0, 80 },
      -1,
   } },
   /* replace25_1_0_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 90, 91, 0 },
      -1,
   } },
   /* replace25_1_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 2,
      { 92, 93 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_isub,
      -1, 2,
      { 0, 94 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b')) */
   /* search26_0 -> 0 in the cache */
   /* search26_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_irem,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace26_0 -> 0 in the cache */
   /* replace26_1_0 -> 3 in the cache */
   /* replace26_1 -> 28 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_irem,
      -1, 0,
      { 0, 28 },
      -1,
   } },

   /* ('~fneg', ('fneg', 'a')) => a */
   /* search27_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fneg,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace27 -> 32 in the cache */

   /* ('ineg', ('ineg', 'a')) => a */
   /* search28_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace28 -> 32 in the cache */

   /* ('fabs', ('fneg', 'a')) => ('fabs', 'a') */
   /* search29_0_0 -> 32 in the cache */
   /* search29_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace29_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('fabs', ('u2f', 'a')) => ('u2f', 'a') */
   /* search30_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_u2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 104 },
      -1,
   } },

   /* replace30_0 -> 32 in the cache */
   /* replace30 -> 104 in the cache */

   /* ('iabs', ('iabs', 'a')) => ('iabs', 'a') */
   /* search31_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace31_0 -> 32 in the cache */
   /* replace31 -> 106 in the cache */

   /* ('iabs', ('ineg', 'a')) => ('iabs', 'a') */
   /* search32_0_0 -> 32 in the cache */
   /* search32_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace32_0 -> 32 in the cache */
   /* replace32 -> 106 in the cache */

   /* ('f2b', ('fneg', 'a')) => ('f2b', 'a') */
   /* search33_0_0 -> 32 in the cache */
   /* search33_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2b,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace33_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search34_0_0 -> 32 in the cache */
   /* search34_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_i2b,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace34_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fadd', 'a', 0.0) => a */
   /* search35_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fadd,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace35 -> 32 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a */
   /* search36_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 11, 115 },
      1,
   } },

   /* replace36 -> 11 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a */
   /* search37_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 16, 117 },
      1,
   } },

   /* replace37 -> 16 in the cache */

   /* ('iadd', 'a', 0) => a */
   /* search38_0 -> 32 in the cache */
   /* search38_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace38 -> 32 in the cache */

   /* ('usadd_4x8_vc4', 'a', 0) => a */
   /* search39_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace39 -> 16 in the cache */

   /* ('usadd_4x8_vc4', 'a', -1) => -1 */
   /* search40_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* replace40 -> 122 in the cache */

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search41_1_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 126, 128 },
      -1,
   } },

   /* replace41_0 -> 124 in the cache */
   /* replace41_1_0 -> 125 in the cache */
   /* replace41_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      0, 2,
      { 124, 130 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search42_0 -> 0 in the cache */
   /* search42_1 -> 3 in the cache */
   /* search42_2_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 0, 132, 133 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 134 },
      -1,
   } },

   /* replace42_0 -> 0 in the cache */
   /* replace42_1_0 -> 3 in the cache */
   /* replace42_1_1 -> 132 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 3, 132 },
      -1,
   } },
   /* replace42_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ffma,
      0, 2,
      { 0, 136, 133 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search43_0 -> 0 in the cache */
   /* search43_1 -> 3 in the cache */
   /* search43_2_0 -> 0 in the cache */
   /* search43_2_1 -> 132 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 0, 132 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 138 },
      -1,
   } },

   /* replace43_0 -> 0 in the cache */
   /* replace43_1_0 -> 3 in the cache */
   /* replace43_1_1 -> 132 in the cache */
   /* replace43_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 2,
      { 0, 136 },
      -1,
   } },

   /* ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 141, 142 },
      0,
   } },
   /* search44_1_0 -> 141 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ffma,
      2, 1,
      { 141, 144, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 143, 146 },
      -1,
   } },

   /* replace44_0 -> 141 in the cache */
   /* replace44_1_0 -> 142 in the cache */
   /* replace44_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 142, 144 },
      -1,
   } },
   /* replace44_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ffma,
      0, 2,
      { 141, 148, 145 },
      -1,
   } },

   /* ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd')) */
   /* search45_0 -> 141 in the cache */
   /* search45_1_0 -> 142 in the cache */
   /* search45_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 142, 144 },
      0,
   } },
   /* search45_2_0 -> 142 in the cache */
   /* search45_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_ffma,
      0, 3,
      { 141, 150, 151 },
      -1,
   } },

   /* replace45_0 -> 142 in the cache */
   /* replace45_1_0 -> 141 in the cache */
   /* replace45_1_1 -> 144 in the cache */
   /* replace45_1_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 141, 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      0, 2,
      { 142, 153 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search46_0_0 -> 124 in the cache */
   /* search46_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search46_1_0 -> 124 in the cache */
   /* search46_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 3,
      { 155, 156 },
      -1,
   } },

   /* replace46_0 -> 124 in the cache */
   /* replace46_1_0 -> 125 in the cache */
   /* replace46_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      0, 2,
      { 124, 158 },
      -1,
   } },

   /* ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c')) */
   /* search47_0_0 -> 124 in the cache */
   /* search47_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search47_1_0 -> 124 in the cache */
   /* search47_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      0, 3,
      { 160, 161 },
      -1,
   } },

   /* replace47_0 -> 124 in the cache */
   /* replace47_1_0 -> 125 in the cache */
   /* replace47_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      0, 2,
      { 124, 163 },
      -1,
   } },

   /* ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c')) */
   /* search48_0_0 -> 124 in the cache */
   /* search48_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search48_1_0 -> 124 in the cache */
   /* search48_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      0, 3,
      { 165, 166 },
      -1,
   } },

   /* replace48_0 -> 124 in the cache */
   /* replace48_1_0 -> 125 in the cache */
   /* replace48_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      0, 2,
      { 124, 168 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   /* search49_0_0 -> 32 in the cache */
   /* search49_0 -> 98 in the cache */
   /* search49_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fadd,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace49 -> 113 in the cache */

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search50_0_0 -> 32 in the cache */
   /* search50_0 -> 100 in the cache */
   /* search50_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 100, 32 },
      -1,
   } },

   /* replace50 -> 61 in the cache */

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   /* search51_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search51_1_0 -> 0 in the cache */
   /* search51_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 172, 173 },
      -1,
   } },

   /* replace51 -> 3 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search52_0 -> 0 in the cache */
   /* search52_1_0_0 -> 0 in the cache */
   /* search52_1_0 -> 172 in the cache */
   /* search52_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 172, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 0, 175 },
      -1,
   } },

   /* replace52 -> 3 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search53_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search53_1_0 -> 0 in the cache */
   /* search53_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 177, 178 },
      -1,
   } },

   /* replace53 -> 3 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search54_0 -> 0 in the cache */
   /* search54_1_0_0 -> 0 in the cache */
   /* search54_1_0 -> 177 in the cache */
   /* search54_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 177, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 0, 180 },
      -1,
   } },

   /* replace54 -> 3 in the cache */

   /* ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a')) */
   /* search55_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search55_1_0_0 -> 32 in the cache */
   /* search55_1_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 182, 183 },
      -1,
   } },

   /* replace55_0_0 -> 32 in the cache */
   /* replace55_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 103 },
      -1,
   } },

   /* ('~fmul', 'a', 0.0) => 0.0 */
   /* search56_0 -> 32 in the cache */
   /* search56_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmul,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace56 -> 113 in the cache */

   /* ('fmul', 'a@16', 0.0) => 0.0 */
   /* search57_0 -> 11 in the cache */
   /* search57_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 11, 115 },
      -1,
   } },

   /* replace57 -> 115 in the cache */

   /* ('fmul', 'a@32', 0.0) => 0.0 */
   /* search58_0 -> 16 in the cache */
   /* search58_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 16, 117 },
      -1,
   } },

   /* replace58 -> 117 in the cache */

   /* ('imul', 'a', 0) => 0 */
   /* search59_0 -> 32 in the cache */
   /* search59_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imul,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace59 -> 61 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', 0) => 0 */
   /* search60_0 -> 16 in the cache */
   /* search60_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace60 -> 120 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', -1) => a */
   /* search61_0 -> 16 in the cache */
   /* search61_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* replace61 -> 16 in the cache */

   /* ('~fmul', 'a', 1.0) => a */
   /* search62_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmul,
      0, 1,
      { 32, 192 },
      -1,
   } },

   /* replace62 -> 32 in the cache */

   /* ('fmul(is_only_used_as_float)', 'a', 1.0) => a */
   /* search63_0 -> 32 in the cache */
   /* search63_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 32, 192 },
      1,
   } },

   /* replace63 -> 32 in the cache */

   /* ('imul', 'a', 1) => a */
   /* search64_0 -> 32 in the cache */
   /* search64_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imul,
      0, 1,
      { 32, 35 },
      -1,
   } },

   /* replace64 -> 32 in the cache */

   /* ('fmul', 'a', -1.0) => ('fneg', 'a') */
   /* search65_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 32, 196 },
      -1,
   } },

   /* replace65_0 -> 32 in the cache */
   /* replace65 -> 98 in the cache */

   /* ('imul', 'a', -1) => ('ineg', 'a') */
   /* search66_0 -> 32 in the cache */
   /* search66_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imul,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace66_0 -> 32 in the cache */
   /* replace66 -> 100 in the cache */

   /* ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a') */
   /* search67_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search67_1_0 -> 32 in the cache */
   /* search67_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 199, 200 },
      -1,
   } },

   /* replace67_0_0 -> 32 in the cache */
   /* replace67_0 -> 103 in the cache */
   /* replace67_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 103, 32 },
      -1,
   } },

   /* ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a') */
   /* search68_0_0_0 -> 32 in the cache */
   /* search68_0_0 -> 199 in the cache */
   /* search68_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 199, 32 },
      -1,
   } },
   /* search68_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 2,
      { 203, 32 },
      -1,
   } },

   /* replace68_0_0 -> 32 in the cache */
   /* replace68_0 -> 103 in the cache */
   /* replace68_1 -> 32 in the cache */
   /* replace68 -> 202 in the cache */

   /* ('~ffma', 0.0, 'a', 'b') => b */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search69_1 -> 0 in the cache */
   /* search69_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_ffma,
      0, 1,
      { 205, 0, 3 },
      -1,
   } },

   /* replace69 -> 3 in the cache */

   /* ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search70_0 -> 115 in the cache */
   /* search70_1 -> 11 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 115, 11, 207 },
      1,
   } },

   /* replace70 -> 207 in the cache */

   /* ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search71_0 -> 117 in the cache */
   /* search71_1 -> 16 in the cache */
   /* search71_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 117, 16, 36 },
      1,
   } },

   /* replace71 -> 36 in the cache */

   /* ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search72_0 -> 0 in the cache */
   /* search72_1 -> 3 in the cache */
   /* search72_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_ffma,
      0, 1,
      { 0, 3, 205 },
      -1,
   } },

   /* replace72_0 -> 0 in the cache */
   /* replace72_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search73_0 -> 11 in the cache */
   /* search73_1 -> 207 in the cache */
   /* search73_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 11, 207, 115 },
      -1,
   } },

   /* replace73_0 -> 11 in the cache */
   /* replace73_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 11, 207 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search74_0 -> 16 in the cache */
   /* search74_1 -> 36 in the cache */
   /* search74_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 117 },
      -1,
   } },

   /* replace74_0 -> 16 in the cache */
   /* replace74_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search75_1 -> 0 in the cache */
   /* search75_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 216, 0, 3 },
      -1,
   } },

   /* replace75_0 -> 0 in the cache */
   /* replace75_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search76_1 -> 0 in the cache */
   /* search76_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 219, 0, 3 },
      -1,
   } },

   /* replace76_0_0 -> 0 in the cache */
   /* replace76_0 -> 177 in the cache */
   /* replace76_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 177, 3 },
      -1,
   } },

   /* ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search77_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_ffma,
      0, 1,
      { 222, 223, 127 },
      -1,
   } },

   /* replace77_0_0 -> 124 in the cache */
   /* replace77_0_1 -> 125 in the cache */
   /* replace77_0 -> 126 in the cache */
   /* replace77_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 126, 127 },
      -1,
   } },

   /* ('~flrp', 'a', 'b', 0.0) => a */
   /* search78_0 -> 0 in the cache */
   /* search78_1 -> 3 in the cache */
   /* search78_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 205 },
      -1,
   } },

   /* replace78 -> 0 in the cache */

   /* ('~flrp', 'a', 'b', 1.0) => b */
   /* search79_0 -> 0 in the cache */
   /* search79_1 -> 3 in the cache */
   /* search79_2 -> 216 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 216 },
      -1,
   } },

   /* replace79 -> 3 in the cache */

   /* ('~flrp', 'a', 'a', 'b') => a */
   /* search80_0 -> 0 in the cache */
   /* search80_1 -> 0 in the cache */
   /* search80_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_flrp,
      -1, 0,
      { 0, 0, 3 },
      -1,
   } },

   /* replace80 -> 0 in the cache */

   /* ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b') */
   /* search81_0 -> 205 in the cache */
   /* search81_1 -> 0 in the cache */
   /* search81_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_flrp,
      -1, 0,
      { 205, 0, 3 },
      -1,
   } },

   /* replace81_0 -> 0 in the cache */
   /* replace81_1 -> 3 in the cache */
   /* replace81 -> 211 in the cache */

   /* ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search82_0 -> 124 in the cache */
   /* search82_1_0 -> 124 in the cache */
   /* search82_1_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 124, 125 },
      0,
   } },
   /* search82_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_flrp,
      -1, 1,
      { 124, 230, 127 },
      -1,
   } },

   /* replace82_0_0 -> 125 in the cache */
   /* replace82_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 125, 127 },
      -1,
   } },
   /* replace82_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 232, 124 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 0, 'b') => b */
   /* search83_0 -> 16 in the cache */
   /* search83_1 -> 120 in the cache */
   /* search83_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace83 -> 36 in the cache */

   /* ('udot_4x8_uadd', 'a', 0, 'b') => b */
   /* search84_0 -> 16 in the cache */
   /* search84_1 -> 120 in the cache */
   /* search84_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace84 -> 36 in the cache */

   /* ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search85_0 -> 16 in the cache */
   /* search85_1 -> 120 in the cache */
   /* search85_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace85 -> 36 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 0, 'b') => b */
   /* search86_0 -> 16 in the cache */
   /* search86_1 -> 120 in the cache */
   /* search86_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace86 -> 36 in the cache */

   /* ('sdot_2x16_iadd', 'a', 0, 'b') => b */
   /* search87_0 -> 16 in the cache */
   /* search87_1 -> 120 in the cache */
   /* search87_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace87 -> 36 in the cache */

   /* ('udot_2x16_uadd', 'a', 0, 'b') => b */
   /* search88_0 -> 16 in the cache */
   /* search88_1 -> 120 in the cache */
   /* search88_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace88 -> 36 in the cache */

   /* ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b */
   /* search89_0 -> 16 in the cache */
   /* search89_1 -> 120 in the cache */
   /* search89_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace89 -> 36 in the cache */

   /* ('udot_2x16_uadd_sat', 'a', 0, 'b') => b */
   /* search90_0 -> 16 in the cache */
   /* search90_1 -> 120 in the cache */
   /* search90_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace90 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 'a', 0, 'b') => b */
   /* search91_0 -> 16 in the cache */
   /* search91_1 -> 120 in the cache */
   /* search91_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 120, 36 },
      -1,
   } },

   /* replace91 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 0, 'a', 'b') => b */
   /* search92_0 -> 120 in the cache */
   /* search92_1 -> 16 in the cache */
   /* search92_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 120, 16, 36 },
      -1,
   } },

   /* replace92 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search93_0 -> 16 in the cache */
   /* search93_1 -> 120 in the cache */
   /* search93_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 120, 36 },
      -1,
   } },

   /* replace93 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b */
   /* search94_0 -> 120 in the cache */
   /* search94_1 -> 16 in the cache */
   /* search94_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 120, 16, 36 },
      -1,
   } },

   /* replace94 -> 36 in the cache */

   /* ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search95_0_0 -> 16 in the cache */
   /* search95_0_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 246 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 247, 248 },
      -1,
   } },

   /* replace95_0 -> 16 in the cache */
   /* replace95_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 250, 251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_4x8_iadd,
      0, 2,
      { 16, 36, 252 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search96_0_0 -> 16 in the cache */
   /* search96_0_1 -> 36 in the cache */
   /* search96_0_2 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 246 },
      0,
   } },
   /* search96_1 -> 248 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 254, 248 },
      -1,
   } },

   /* replace96_0 -> 16 in the cache */
   /* replace96_1 -> 36 in the cache */
   /* replace96_2_0 -> 250 in the cache */
   /* replace96_2_1 -> 251 in the cache */
   /* replace96_2 -> 252 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_4x8_uadd,
      0, 2,
      { 16, 36, 252 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search97_0_0 -> 16 in the cache */
   /* search97_0_1 -> 36 in the cache */
   /* search97_0_2 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 246 },
      0,
   } },
   /* search97_1 -> 248 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 257, 248 },
      -1,
   } },

   /* replace97_0 -> 16 in the cache */
   /* replace97_1 -> 36 in the cache */
   /* replace97_2_0 -> 250 in the cache */
   /* replace97_2_1 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 250, 251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd,
      -1, 1,
      { 16, 36, 259 },
      -1,
   } },

   /* ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search98_0_0 -> 16 in the cache */
   /* search98_0_1 -> 36 in the cache */
   /* search98_0_2 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 246 },
      0,
   } },
   /* search98_1 -> 248 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 261, 248 },
      -1,
   } },

   /* replace98_0 -> 16 in the cache */
   /* replace98_1 -> 36 in the cache */
   /* replace98_2_0 -> 250 in the cache */
   /* replace98_2_1 -> 251 in the cache */
   /* replace98_2 -> 252 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_2x16_iadd,
      0, 2,
      { 16, 36, 252 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search99_0_0 -> 16 in the cache */
   /* search99_0_1 -> 36 in the cache */
   /* search99_0_2 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 246 },
      0,
   } },
   /* search99_1 -> 248 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 264, 248 },
      -1,
   } },

   /* replace99_0 -> 16 in the cache */
   /* replace99_1 -> 36 in the cache */
   /* replace99_2_0 -> 250 in the cache */
   /* replace99_2_1 -> 251 in the cache */
   /* replace99_2 -> 252 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_2x16_uadd,
      0, 2,
      { 16, 36, 252 },
      -1,
   } },

   /* ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search100_0_1 -> 36 in the cache */
   /* search100_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 267, 36, 120 },
      -1,
   } },
   /* search100_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 268, 250 },
      -1,
   } },

   /* replace100_0 -> 16 in the cache */
   /* replace100_1 -> 36 in the cache */
   /* replace100_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search101_0_0 -> 267 in the cache */
   /* search101_0_1 -> 36 in the cache */
   /* search101_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 267, 36, 120 },
      -1,
   } },
   /* search101_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 271, 250 },
      -1,
   } },

   /* replace101_0 -> 16 in the cache */
   /* replace101_1 -> 36 in the cache */
   /* replace101_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search102_0_0 -> 267 in the cache */
   /* search102_0_1 -> 36 in the cache */
   /* search102_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 267, 36, 120 },
      -1,
   } },
   /* search102_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 274, 250 },
      -1,
   } },

   /* replace102_0 -> 16 in the cache */
   /* replace102_1 -> 36 in the cache */
   /* replace102_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 250 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search103_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search103_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 277, 120 },
      -1,
   } },
   /* search103_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 278, 250 },
      -1,
   } },

   /* replace103_0 -> 16 in the cache */
   /* replace103_1 -> 36 in the cache */
   /* replace103_2 -> 250 in the cache */
   /* replace103 -> 276 in the cache */

   /* ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c') */
   /* search104_0_0 -> 267 in the cache */
   /* search104_0_1 -> 36 in the cache */
   /* search104_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 267, 36, 120 },
      -1,
   } },
   /* search104_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 280, 250 },
      -1,
   } },

   /* replace104_0 -> 16 in the cache */
   /* replace104_1 -> 36 in the cache */
   /* replace104_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c') */
   /* search105_0_0 -> 267 in the cache */
   /* search105_0_1 -> 36 in the cache */
   /* search105_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 267, 36, 120 },
      -1,
   } },
   /* search105_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 283, 250 },
      -1,
   } },

   /* replace105_0 -> 16 in the cache */
   /* replace105_1 -> 36 in the cache */
   /* replace105_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search106_1 -> 33 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 286, 33, 287 },
      -1,
   } },

   /* replace106_0_0 -> 16 in the cache */
   /* replace106_0_1 -> 36 in the cache */
   /* replace106_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace106_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 289, 250 },
      -1,
   } },

   /* ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search107_0 -> 286 in the cache */
   /* search107_1 -> 33 in the cache */
   /* search107_2 -> 287 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 286, 33, 287 },
      -1,
   } },

   /* replace107_0_0 -> 16 in the cache */
   /* replace107_0_1 -> 36 in the cache */
   /* replace107_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace107_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 292, 250 },
      -1,
   } },

   /* ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search108_0 -> 286 in the cache */
   /* search108_1 -> 33 in the cache */
   /* search108_2 -> 287 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 286, 33, 287 },
      -1,
   } },

   /* replace108_0_0 -> 16 in the cache */
   /* replace108_0_1 -> 36 in the cache */
   /* replace108_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },
   /* replace108_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 295, 250 },
      -1,
   } },

   /* ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search109_0 -> 286 in the cache */
   /* search109_1 -> 33 in the cache */
   /* search109_2 -> 287 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 286, 33, 287 },
      -1,
   } },

   /* replace109_0_0 -> 16 in the cache */
   /* replace109_0_1 -> 36 in the cache */
   /* replace109_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace109_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 298, 250 },
      -1,
   } },

   /* ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search110_0 -> 286 in the cache */
   /* search110_1 -> 33 in the cache */
   /* search110_2 -> 287 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 286, 33, 287 },
      -1,
   } },

   /* replace110_0_0 -> 16 in the cache */
   /* replace110_0_1 -> 36 in the cache */
   /* replace110_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace110_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 301, 250 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search111_0 -> 286 in the cache */
   /* search111_1 -> 33 in the cache */
   /* search111_2 -> 287 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 286, 33, 287 },
      -1,
   } },

   /* replace111_0_0 -> 16 in the cache */
   /* replace111_0_1 -> 36 in the cache */
   /* replace111_0_2 -> 120 in the cache */
   /* replace111_0 -> 289 in the cache */
   /* replace111_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd_sat,
      0, 2,
      { 289, 250 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search112_0 -> 286 in the cache */
   /* search112_1 -> 33 in the cache */
   /* search112_2 -> 287 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 286, 33, 287 },
      -1,
   } },

   /* replace112_0_0 -> 16 in the cache */
   /* replace112_0_1 -> 36 in the cache */
   /* replace112_0_2 -> 120 in the cache */
   /* replace112_0 -> 292 in the cache */
   /* replace112_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_uadd_sat,
      0, 2,
      { 292, 250 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search113_0 -> 286 in the cache */
   /* search113_1 -> 33 in the cache */
   /* search113_2 -> 287 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 286, 33, 287 },
      -1,
   } },

   /* replace113_0_0 -> 16 in the cache */
   /* replace113_0_1 -> 36 in the cache */
   /* replace113_0_2 -> 120 in the cache */
   /* replace113_0 -> 295 in the cache */
   /* replace113_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd_sat,
      0, 1,
      { 295, 250 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search114_0 -> 286 in the cache */
   /* search114_1 -> 33 in the cache */
   /* search114_2 -> 287 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 286, 33, 287 },
      -1,
   } },

   /* replace114_0_0 -> 16 in the cache */
   /* replace114_0_1 -> 36 in the cache */
   /* replace114_0_2 -> 120 in the cache */
   /* replace114_0 -> 298 in the cache */
   /* replace114_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd_sat,
      0, 2,
      { 298, 250 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search115_0 -> 286 in the cache */
   /* search115_1 -> 33 in the cache */
   /* search115_2 -> 287 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 286, 33, 287 },
      -1,
   } },

   /* replace115_0_0 -> 16 in the cache */
   /* replace115_0_1 -> 36 in the cache */
   /* replace115_0_2 -> 120 in the cache */
   /* replace115_0 -> 301 in the cache */
   /* replace115_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_uadd_sat,
      0, 2,
      { 301, 250 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search116_0 -> 16 in the cache */
   /* search116_1 -> 36 in the cache */
   /* search116_2 -> 250 in the cache */
   /* search116 -> 270 in the cache */

   /* replace116_0_0_0_0_0 -> 16 in the cache */
   /* replace116_0_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace116_0_0_0_1_0 -> 36 in the cache */
   /* replace116_0_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      3, 1,
      { 313, 314 },
      -1,
   } },
   /* replace116_0_0_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 316 },
      -1,
   } },
   /* replace116_0_0_1_1_0 -> 36 in the cache */
   /* replace116_0_0_1_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      4, 1,
      { 317, 318 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      2, 3,
      { 315, 319 },
      -1,
   } },
   /* replace116_0_1_0_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 321 },
      -1,
   } },
   /* replace116_0_1_0_1_0 -> 36 in the cache */
   /* replace116_0_1_0_1_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 321 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      6, 1,
      { 322, 323 },
      -1,
   } },
   /* replace116_0_1_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 325 },
      -1,
   } },
   /* replace116_0_1_1_1_0 -> 36 in the cache */
   /* replace116_0_1_1_1_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 325 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      7, 1,
      { 326, 327 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      5, 3,
      { 324, 328 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 7,
      { 320, 329 },
      -1,
   } },
   /* replace116_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 8,
      { 330, 250 },
      -1,
   } },

   /* ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search117_0 -> 16 in the cache */
   /* search117_1 -> 36 in the cache */
   /* search117_2 -> 250 in the cache */
   /* search117 -> 273 in the cache */

   /* replace117_0_0_0_0_0 -> 16 in the cache */
   /* replace117_0_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace117_0_0_0_1_0 -> 36 in the cache */
   /* replace117_0_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      3, 1,
      { 332, 333 },
      -1,
   } },
   /* replace117_0_0_1_0_0 -> 16 in the cache */
   /* replace117_0_0_1_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 316 },
      -1,
   } },
   /* replace117_0_0_1_1_0 -> 36 in the cache */
   /* replace117_0_0_1_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      4, 1,
      { 335, 336 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      2, 3,
      { 334, 337 },
      -1,
   } },
   /* replace117_0_1_0_0_0 -> 16 in the cache */
   /* replace117_0_1_0_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 321 },
      -1,
   } },
   /* replace117_0_1_0_1_0 -> 36 in the cache */
   /* replace117_0_1_0_1_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 321 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      6, 1,
      { 339, 340 },
      -1,
   } },
   /* replace117_0_1_1_0_0 -> 16 in the cache */
   /* replace117_0_1_1_0_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 325 },
      -1,
   } },
   /* replace117_0_1_1_1_0 -> 36 in the cache */
   /* replace117_0_1_1_1_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 325 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      7, 1,
      { 342, 343 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      5, 3,
      { 341, 344 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 7,
      { 338, 345 },
      -1,
   } },
   /* replace117_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 8,
      { 346, 250 },
      -1,
   } },

   /* ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search118_0 -> 16 in the cache */
   /* search118_1 -> 36 in the cache */
   /* search118_2 -> 250 in the cache */
   /* search118 -> 276 in the cache */

   /* replace118_0_0_0_0_0 -> 16 in the cache */
   /* replace118_0_0_0_0_1 -> 120 in the cache */
   /* replace118_0_0_0_0 -> 313 in the cache */
   /* replace118_0_0_0_1_0 -> 36 in the cache */
   /* replace118_0_0_0_1_1 -> 120 in the cache */
   /* replace118_0_0_0_1 -> 333 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      3, 1,
      { 313, 333 },
      -1,
   } },
   /* replace118_0_0_1_0_0 -> 16 in the cache */
   /* replace118_0_0_1_0_1 -> 316 in the cache */
   /* replace118_0_0_1_0 -> 317 in the cache */
   /* replace118_0_0_1_1_0 -> 36 in the cache */
   /* replace118_0_0_1_1_1 -> 316 in the cache */
   /* replace118_0_0_1_1 -> 336 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      4, 1,
      { 317, 336 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      2, 3,
      { 348, 349 },
      -1,
   } },
   /* replace118_0_1_0_0_0 -> 16 in the cache */
   /* replace118_0_1_0_0_1 -> 321 in the cache */
   /* replace118_0_1_0_0 -> 322 in the cache */
   /* replace118_0_1_0_1_0 -> 36 in the cache */
   /* replace118_0_1_0_1_1 -> 321 in the cache */
   /* replace118_0_1_0_1 -> 340 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      6, 1,
      { 322, 340 },
      -1,
   } },
   /* replace118_0_1_1_0_0 -> 16 in the cache */
   /* replace118_0_1_1_0_1 -> 325 in the cache */
   /* replace118_0_1_1_0 -> 326 in the cache */
   /* replace118_0_1_1_1_0 -> 36 in the cache */
   /* replace118_0_1_1_1_1 -> 325 in the cache */
   /* replace118_0_1_1_1 -> 343 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      7, 1,
      { 326, 343 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      5, 3,
      { 351, 352 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 7,
      { 350, 353 },
      -1,
   } },
   /* replace118_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 8,
      { 354, 250 },
      -1,
   } },

   /* ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search119_0 -> 16 in the cache */
   /* search119_1 -> 36 in the cache */
   /* search119_2 -> 250 in the cache */
   /* search119 -> 282 in the cache */

   /* replace119_0_0_0_0 -> 16 in the cache */
   /* replace119_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace119_0_0_1_0 -> 36 in the cache */
   /* replace119_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      2, 1,
      { 356, 357 },
      -1,
   } },
   /* replace119_0_1_0_0 -> 16 in the cache */
   /* replace119_0_1_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 316 },
      -1,
   } },
   /* replace119_0_1_1_0 -> 36 in the cache */
   /* replace119_0_1_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      3, 1,
      { 359, 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 3,
      { 358, 361 },
      -1,
   } },
   /* replace119_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 4,
      { 362, 250 },
      -1,
   } },

   /* ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search120_0 -> 16 in the cache */
   /* search120_1 -> 36 in the cache */
   /* search120_2 -> 250 in the cache */
   /* search120 -> 285 in the cache */

   /* replace120_0_0_0_0 -> 16 in the cache */
   /* replace120_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace120_0_0_1_0 -> 36 in the cache */
   /* replace120_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      2, 1,
      { 364, 365 },
      -1,
   } },
   /* replace120_0_1_0_0 -> 16 in the cache */
   /* replace120_0_1_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 316 },
      -1,
   } },
   /* replace120_0_1_1_0 -> 36 in the cache */
   /* replace120_0_1_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      3, 1,
      { 367, 368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 3,
      { 366, 369 },
      -1,
   } },
   /* replace120_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 4,
      { 370, 250 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search121_0 -> 16 in the cache */
   /* search121_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 372 },
      -1,
   } },

   /* replace121_0 -> 16 in the cache */
   /* replace121_1 -> 36 in the cache */
   /* replace121_2 -> 250 in the cache */
   /* replace121 -> 273 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search122_0 -> 16 in the cache */
   /* search122_1 -> 36 in the cache */
   /* search122_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* replace122_0_0_0_0_0 -> 16 in the cache */
   /* replace122_0_0_0_0_1 -> 120 in the cache */
   /* replace122_0_0_0_0 -> 332 in the cache */
   /* replace122_0_0_0_1_0 -> 36 in the cache */
   /* replace122_0_0_0_1_1 -> 120 in the cache */
   /* replace122_0_0_0_1 -> 333 in the cache */
   /* replace122_0_0_0 -> 334 in the cache */
   /* replace122_0_0_1_0_0 -> 16 in the cache */
   /* replace122_0_0_1_0_1 -> 316 in the cache */
   /* replace122_0_0_1_0 -> 335 in the cache */
   /* replace122_0_0_1_1_0 -> 36 in the cache */
   /* replace122_0_0_1_1_1 -> 316 in the cache */
   /* replace122_0_0_1_1 -> 336 in the cache */
   /* replace122_0_0_1 -> 337 in the cache */
   /* replace122_0_0 -> 338 in the cache */
   /* replace122_0_1_0_0_0 -> 16 in the cache */
   /* replace122_0_1_0_0_1 -> 321 in the cache */
   /* replace122_0_1_0_0 -> 339 in the cache */
   /* replace122_0_1_0_1_0 -> 36 in the cache */
   /* replace122_0_1_0_1_1 -> 321 in the cache */
   /* replace122_0_1_0_1 -> 340 in the cache */
   /* replace122_0_1_0 -> 341 in the cache */
   /* replace122_0_1_1_0_0 -> 16 in the cache */
   /* replace122_0_1_1_0_1 -> 325 in the cache */
   /* replace122_0_1_1_0 -> 342 in the cache */
   /* replace122_0_1_1_1_0 -> 36 in the cache */
   /* replace122_0_1_1_1_1 -> 325 in the cache */
   /* replace122_0_1_1_1 -> 343 in the cache */
   /* replace122_0_1_1 -> 344 in the cache */
   /* replace122_0_1 -> 345 in the cache */
   /* replace122_0 -> 346 in the cache */
   /* replace122_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_uadd_sat,
      0, 8,
      { 346, 250 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search123_0 -> 16 in the cache */
   /* search123_1 -> 36 in the cache */
   /* search123_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* replace123_0_0_0_0_0 -> 16 in the cache */
   /* replace123_0_0_0_0_1 -> 120 in the cache */
   /* replace123_0_0_0_0 -> 313 in the cache */
   /* replace123_0_0_0_1_0 -> 36 in the cache */
   /* replace123_0_0_0_1_1 -> 120 in the cache */
   /* replace123_0_0_0_1 -> 314 in the cache */
   /* replace123_0_0_0 -> 315 in the cache */
   /* replace123_0_0_1_0_0 -> 16 in the cache */
   /* replace123_0_0_1_0_1 -> 316 in the cache */
   /* replace123_0_0_1_0 -> 317 in the cache */
   /* replace123_0_0_1_1_0 -> 36 in the cache */
   /* replace123_0_0_1_1_1 -> 316 in the cache */
   /* replace123_0_0_1_1 -> 318 in the cache */
   /* replace123_0_0_1 -> 319 in the cache */
   /* replace123_0_0 -> 320 in the cache */
   /* replace123_0_1_0_0_0 -> 16 in the cache */
   /* replace123_0_1_0_0_1 -> 321 in the cache */
   /* replace123_0_1_0_0 -> 322 in the cache */
   /* replace123_0_1_0_1_0 -> 36 in the cache */
   /* replace123_0_1_0_1_1 -> 321 in the cache */
   /* replace123_0_1_0_1 -> 323 in the cache */
   /* replace123_0_1_0 -> 324 in the cache */
   /* replace123_0_1_1_0_0 -> 16 in the cache */
   /* replace123_0_1_1_0_1 -> 325 in the cache */
   /* replace123_0_1_1_0 -> 326 in the cache */
   /* replace123_0_1_1_1_0 -> 36 in the cache */
   /* replace123_0_1_1_1_1 -> 325 in the cache */
   /* replace123_0_1_1_1 -> 327 in the cache */
   /* replace123_0_1_1 -> 328 in the cache */
   /* replace123_0_1 -> 329 in the cache */
   /* replace123_0 -> 330 in the cache */
   /* replace123_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd_sat,
      0, 8,
      { 330, 250 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search124_0 -> 16 in the cache */
   /* search124_1 -> 36 in the cache */
   /* search124_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 36, 250 },
      -1,
   } },

   /* replace124_0_0_0_0_0 -> 16 in the cache */
   /* replace124_0_0_0_0_1 -> 120 in the cache */
   /* replace124_0_0_0_0 -> 313 in the cache */
   /* replace124_0_0_0_1_0 -> 36 in the cache */
   /* replace124_0_0_0_1_1 -> 120 in the cache */
   /* replace124_0_0_0_1 -> 333 in the cache */
   /* replace124_0_0_0 -> 348 in the cache */
   /* replace124_0_0_1_0_0 -> 16 in the cache */
   /* replace124_0_0_1_0_1 -> 316 in the cache */
   /* replace124_0_0_1_0 -> 317 in the cache */
   /* replace124_0_0_1_1_0 -> 36 in the cache */
   /* replace124_0_0_1_1_1 -> 316 in the cache */
   /* replace124_0_0_1_1 -> 336 in the cache */
   /* replace124_0_0_1 -> 349 in the cache */
   /* replace124_0_0 -> 350 in the cache */
   /* replace124_0_1_0_0_0 -> 16 in the cache */
   /* replace124_0_1_0_0_1 -> 321 in the cache */
   /* replace124_0_1_0_0 -> 322 in the cache */
   /* replace124_0_1_0_1_0 -> 36 in the cache */
   /* replace124_0_1_0_1_1 -> 321 in the cache */
   /* replace124_0_1_0_1 -> 340 in the cache */
   /* replace124_0_1_0 -> 351 in the cache */
   /* replace124_0_1_1_0_0 -> 16 in the cache */
   /* replace124_0_1_1_0_1 -> 325 in the cache */
   /* replace124_0_1_1_0 -> 326 in the cache */
   /* replace124_0_1_1_1_0 -> 36 in the cache */
   /* replace124_0_1_1_1_1 -> 325 in the cache */
   /* replace124_0_1_1_1 -> 343 in the cache */
   /* replace124_0_1_1 -> 352 in the cache */
   /* replace124_0_1 -> 353 in the cache */
   /* replace124_0 -> 354 in the cache */
   /* replace124_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd_sat,
      0, 8,
      { 354, 250 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search125_0 -> 16 in the cache */
   /* search125_1 -> 36 in the cache */
   /* search125_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* replace125_0_0_0_0 -> 16 in the cache */
   /* replace125_0_0_0_1 -> 120 in the cache */
   /* replace125_0_0_0 -> 364 in the cache */
   /* replace125_0_0_1_0 -> 36 in the cache */
   /* replace125_0_0_1_1 -> 120 in the cache */
   /* replace125_0_0_1 -> 365 in the cache */
   /* replace125_0_0 -> 366 in the cache */
   /* replace125_0_1_0_0 -> 16 in the cache */
   /* replace125_0_1_0_1 -> 316 in the cache */
   /* replace125_0_1_0 -> 367 in the cache */
   /* replace125_0_1_1_0 -> 36 in the cache */
   /* replace125_0_1_1_1 -> 316 in the cache */
   /* replace125_0_1_1 -> 368 in the cache */
   /* replace125_0_1 -> 369 in the cache */
   /* replace125_0 -> 370 in the cache */
   /* replace125_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_uadd_sat,
      0, 4,
      { 370, 250 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search126_0 -> 16 in the cache */
   /* search126_1 -> 36 in the cache */
   /* search126_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* replace126_0_0_0_0 -> 16 in the cache */
   /* replace126_0_0_0_1 -> 120 in the cache */
   /* replace126_0_0_0 -> 356 in the cache */
   /* replace126_0_0_1_0 -> 36 in the cache */
   /* replace126_0_0_1_1 -> 120 in the cache */
   /* replace126_0_0_1 -> 357 in the cache */
   /* replace126_0_0 -> 358 in the cache */
   /* replace126_0_1_0_0 -> 16 in the cache */
   /* replace126_0_1_0_1 -> 316 in the cache */
   /* replace126_0_1_0 -> 359 in the cache */
   /* replace126_0_1_1_0 -> 36 in the cache */
   /* replace126_0_1_1_1 -> 316 in the cache */
   /* replace126_0_1_1 -> 360 in the cache */
   /* replace126_0_1 -> 361 in the cache */
   /* replace126_0 -> 362 in the cache */
   /* replace126_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd_sat,
      0, 4,
      { 362, 250 },
      -1,
   } },

   /* ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search127_0 -> 11 in the cache */
   /* search127_1 -> 207 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 384 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_flrp,
      -1, 0,
      { 11, 207, 385 },
      -1,
   } },

   /* replace127_0 -> 384 in the cache */
   /* replace127_1 -> 207 in the cache */
   /* replace127_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 384, 207, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search128_0 -> 11 in the cache */
   /* search128_1_0 -> 11 in the cache */
   /* search128_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 11, 207 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_flrp,
      -1, 1,
      { 11, 388, 389 },
      -1,
   } },

   /* replace128_0_0 -> 207 in the cache */
   /* replace128_0_1 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 207, 389 },
      -1,
   } },
   /* replace128_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 391, 11 },
      -1,
   } },

   /* ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search129_0_0 -> 11 in the cache */
   /* search129_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 11, 207 },
      0,
   } },
   /* search129_1_0 -> 11 in the cache */
   /* search129_1_1 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 11, 389 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_flrp,
      -1, 2,
      { 393, 394, 395 },
      -1,
   } },

   /* replace129_0_0 -> 207 in the cache */
   /* replace129_0_1 -> 389 in the cache */
   /* replace129_0_2 -> 395 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 207, 389, 395 },
      -1,
   } },
   /* replace129_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 397, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search130_0 -> 11 in the cache */
   /* search130_1_0 -> 11 in the cache */
   /* search130_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 11, 207 },
      0,
   } },
   /* search130_2 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_flrp,
      -1, 1,
      { 11, 399, 389 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace130_0_1 -> 207 in the cache */
   /* replace130_0_2 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 401, 207, 389 },
      -1,
   } },
   /* replace130_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 402, 11 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search131_0_0 -> 11 in the cache */
   /* search131_0_1_0 -> 401 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 401, 405 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 11, 406 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search131_1_1 -> 404 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 408, 404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 407, 409 },
      -1,
   } },

   /* replace131_0 -> 11 in the cache */
   /* replace131_1 -> 408 in the cache */
   /* replace131_2 -> 404 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 11, 408, 404 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search132_0_0 -> 11 in the cache */
   /* search132_0_1_0_0 -> 401 in the cache */
   /* search132_0_1_0_1_0 -> 404 in the cache */
   /* search132_0_1_0_1 -> 405 in the cache */
   /* search132_0_1_0 -> 406 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 406 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 11, 412 },
      -1,
   } },
   /* search132_1_0 -> 408 in the cache */
   /* search132_1_1_0 -> 404 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 408, 414 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 413, 415 },
      -1,
   } },

   /* replace132_0 -> 11 in the cache */
   /* replace132_1 -> 408 in the cache */
   /* replace132_2_0 -> 404 in the cache */
   /* replace132_2 -> 414 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 11, 408, 414 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search133_0 -> 11 in the cache */
   /* search133_1_0 -> 404 in the cache */
   /* search133_1_1_0 -> 408 in the cache */
   /* search133_1_1_1_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 408, 418 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 404, 419 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 11, 420 },
      -1,
   } },

   /* replace133_0 -> 11 in the cache */
   /* replace133_1 -> 408 in the cache */
   /* replace133_2 -> 404 in the cache */
   /* replace133 -> 411 in the cache */

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search134_0_0 -> 11 in the cache */
   /* search134_0_1_0 -> 401 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 422 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 423 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 401, 424 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 11, 425 },
      -1,
   } },
   /* search134_1_0 -> 408 in the cache */
   /* search134_1_1_0 -> 422 in the cache */
   /* search134_1_1 -> 423 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 408, 423 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 426, 427 },
      -1,
   } },

   /* replace134_0 -> 422 in the cache */
   /* replace134_1 -> 408 in the cache */
   /* replace134_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 422, 408, 11 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search135_0 -> 11 in the cache */
   /* search135_1_0_0 -> 422 in the cache */
   /* search135_1_0 -> 423 in the cache */
   /* search135_1_1_0 -> 408 in the cache */
   /* search135_1_1_1_0 -> 11 in the cache */
   /* search135_1_1_1 -> 418 in the cache */
   /* search135_1_1 -> 419 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 423, 419 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 11, 430 },
      -1,
   } },

   /* replace135_0 -> 422 in the cache */
   /* replace135_1 -> 408 in the cache */
   /* replace135_2 -> 11 in the cache */
   /* replace135 -> 429 in the cache */

   /* ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search136_0 -> 11 in the cache */
   /* search136_1_0 -> 401 in the cache */
   /* search136_1_1_0_0 -> 422 in the cache */
   /* search136_1_1_0 -> 423 in the cache */
   /* search136_1_1 -> 424 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 401, 424 },
      -1,
   } },
   /* search136_2_0 -> 408 in the cache */
   /* search136_2_1_0 -> 422 in the cache */
   /* search136_2_1 -> 423 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 408, 423 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_ffma,
      0, 3,
      { 11, 432, 433 },
      -1,
   } },

   /* replace136_0 -> 422 in the cache */
   /* replace136_1 -> 408 in the cache */
   /* replace136_2 -> 11 in the cache */
   /* replace136 -> 429 in the cache */

   /* ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search137_1_0 -> 422 in the cache */
   /* search137_1 -> 423 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 436 },
      -1,
   } },
   /* search137_2_1_0 -> 422 in the cache */
   /* search137_2_1 -> 423 in the cache */
   /* search137_2_2 -> 436 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 437, 423, 436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 435, 423, 438 },
      -1,
   } },

   /* replace137_0 -> 422 in the cache */
   /* replace137_1 -> 435 in the cache */
   /* replace137_2 -> 436 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 422, 435, 436 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 441 },
      -1,
   } },
   /* search138_1_0 -> 207 in the cache */
   /* search138_1_1_0 -> 436 in the cache */
   /* search138_1_1 -> 437 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 207, 437 },
      -1,
   } },
   /* search138_2 -> 436 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 442, 443, 436 },
      -1,
   } },

   /* replace138_0 -> 441 in the cache */
   /* replace138_1 -> 207 in the cache */
   /* replace138_2 -> 436 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 207, 436 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search139_0_0 -> 441 in the cache */
   /* search139_0 -> 442 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 446 },
      -1,
   } },
   /* search139_1_1 -> 408 in the cache */
   /* search139_1_2 -> 395 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 447, 408, 395 },
      -1,
   } },
   /* search139_2_0 -> 446 in the cache */
   /* search139_2_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 446, 408 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_ffma,
      0, 3,
      { 442, 448, 449 },
      -1,
   } },

   /* replace139_0 -> 441 in the cache */
   /* replace139_1 -> 395 in the cache */
   /* replace139_2_0 -> 446 in the cache */
   /* replace139_2_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 446, 408 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 441, 395, 451 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search140_0 -> 401 in the cache */
   /* search140_1_0_0_0 -> 401 in the cache */
   /* search140_1_0_0_1_0 -> 11 in the cache */
   /* search140_1_0_0_1 -> 418 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 401, 418 },
      -1,
   } },
   /* search140_1_0_1_0 -> 401 in the cache */
   /* search140_1_0_1_1_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      3, 1,
      { 401, 454 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      1, 3,
      { 453, 455 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 3,
      { 456 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 401, 457 },
      -1,
   } },

   /* replace140_0 -> 207 in the cache */
   /* replace140_1 -> 401 in the cache */
   /* replace140_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 207, 401, 11 },
      -1,
   } },

   /* ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search141_0 -> 16 in the cache */
   /* search141_1 -> 36 in the cache */
   /* search141_2_0 -> 384 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 384 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_flrp,
      -1, 0,
      { 16, 36, 460 },
      -1,
   } },

   /* replace141_0 -> 384 in the cache */
   /* replace141_1 -> 36 in the cache */
   /* replace141_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 384, 36, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search142_0 -> 16 in the cache */
   /* search142_1_0 -> 16 in the cache */
   /* search142_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* search142_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_flrp,
      -1, 1,
      { 16, 463, 250 },
      -1,
   } },

   /* replace142_0_0 -> 36 in the cache */
   /* replace142_0_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 36, 250 },
      -1,
   } },
   /* replace142_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 465, 16 },
      -1,
   } },

   /* ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search143_0_0 -> 16 in the cache */
   /* search143_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search143_1_0 -> 16 in the cache */
   /* search143_1_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 16, 250 },
      0,
   } },
   /* search143_2 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_flrp,
      -1, 2,
      { 467, 468, 251 },
      -1,
   } },

   /* replace143_0_0 -> 36 in the cache */
   /* replace143_0_1 -> 250 in the cache */
   /* replace143_0_2 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 36, 250, 251 },
      -1,
   } },
   /* replace143_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 470, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search144_0 -> 16 in the cache */
   /* search144_1_0 -> 16 in the cache */
   /* search144_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search144_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_flrp,
      -1, 1,
      { 16, 472, 250 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace144_0_1 -> 36 in the cache */
   /* replace144_0_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 474, 36, 250 },
      -1,
   } },
   /* replace144_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 475, 16 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search145_0_0 -> 16 in the cache */
   /* search145_0_1_0 -> 474 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 477 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 474, 478 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 16, 479 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search145_1_1 -> 477 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 481, 477 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 480, 482 },
      -1,
   } },

   /* replace145_0 -> 16 in the cache */
   /* replace145_1 -> 481 in the cache */
   /* replace145_2 -> 477 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 16, 481, 477 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search146_0_0 -> 16 in the cache */
   /* search146_0_1_0_0 -> 474 in the cache */
   /* search146_0_1_0_1_0 -> 477 in the cache */
   /* search146_0_1_0_1 -> 478 in the cache */
   /* search146_0_1_0 -> 479 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 479 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 16, 485 },
      -1,
   } },
   /* search146_1_0 -> 481 in the cache */
   /* search146_1_1_0 -> 477 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 477 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 481, 487 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 486, 488 },
      -1,
   } },

   /* replace146_0 -> 16 in the cache */
   /* replace146_1 -> 481 in the cache */
   /* replace146_2_0 -> 477 in the cache */
   /* replace146_2 -> 487 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 16, 481, 487 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search147_0 -> 16 in the cache */
   /* search147_1_0 -> 477 in the cache */
   /* search147_1_1_0 -> 481 in the cache */
   /* search147_1_1_1_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 481, 491 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 477, 492 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 16, 493 },
      -1,
   } },

   /* replace147_0 -> 16 in the cache */
   /* replace147_1 -> 481 in the cache */
   /* replace147_2 -> 477 in the cache */
   /* replace147 -> 484 in the cache */

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search148_0_0 -> 16 in the cache */
   /* search148_0_1_0 -> 474 in the cache */
   /* search148_0_1_1_0_0 -> 422 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 422 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 474, 496 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 16, 497 },
      -1,
   } },
   /* search148_1_0 -> 481 in the cache */
   /* search148_1_1_0 -> 422 in the cache */
   /* search148_1_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 481, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 498, 499 },
      -1,
   } },

   /* replace148_0 -> 422 in the cache */
   /* replace148_1 -> 481 in the cache */
   /* replace148_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 422, 481, 16 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search149_0 -> 16 in the cache */
   /* search149_1_0_0 -> 422 in the cache */
   /* search149_1_0 -> 495 in the cache */
   /* search149_1_1_0 -> 481 in the cache */
   /* search149_1_1_1_0 -> 16 in the cache */
   /* search149_1_1_1 -> 491 in the cache */
   /* search149_1_1 -> 492 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 495, 492 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 16, 502 },
      -1,
   } },

   /* replace149_0 -> 422 in the cache */
   /* replace149_1 -> 481 in the cache */
   /* replace149_2 -> 16 in the cache */
   /* replace149 -> 501 in the cache */

   /* ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search150_0 -> 16 in the cache */
   /* search150_1_0 -> 474 in the cache */
   /* search150_1_1_0_0 -> 422 in the cache */
   /* search150_1_1_0 -> 495 in the cache */
   /* search150_1_1 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 474, 496 },
      -1,
   } },
   /* search150_2_0 -> 481 in the cache */
   /* search150_2_1_0 -> 422 in the cache */
   /* search150_2_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 481, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 3,
      { 16, 504, 505 },
      -1,
   } },

   /* replace150_0 -> 422 in the cache */
   /* replace150_1 -> 481 in the cache */
   /* replace150_2 -> 16 in the cache */
   /* replace150 -> 501 in the cache */

   /* ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search151_1_0 -> 422 in the cache */
   /* search151_1 -> 495 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 508 },
      -1,
   } },
   /* search151_2_1_0 -> 422 in the cache */
   /* search151_2_1 -> 495 in the cache */
   /* search151_2_2 -> 508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 509, 495, 508 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 507, 495, 510 },
      -1,
   } },

   /* replace151_0 -> 422 in the cache */
   /* replace151_1 -> 507 in the cache */
   /* replace151_2 -> 508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 422, 507, 508 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search152_0_0 -> 441 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 441 },
      -1,
   } },
   /* search152_1_0 -> 36 in the cache */
   /* search152_1_1_0 -> 508 in the cache */
   /* search152_1_1 -> 509 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 36, 509 },
      -1,
   } },
   /* search152_2 -> 508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 513, 514, 508 },
      -1,
   } },

   /* replace152_0 -> 441 in the cache */
   /* replace152_1 -> 36 in the cache */
   /* replace152_2 -> 508 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 36, 508 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search153_0_0 -> 441 in the cache */
   /* search153_0 -> 513 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search153_1_1 -> 481 in the cache */
   /* search153_1_2 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 518, 481, 251 },
      -1,
   } },
   /* search153_2_0 -> 517 in the cache */
   /* search153_2_1 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 517, 481 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 3,
      { 513, 519, 520 },
      -1,
   } },

   /* replace153_0 -> 441 in the cache */
   /* replace153_1 -> 251 in the cache */
   /* replace153_2_0 -> 517 in the cache */
   /* replace153_2_1 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 517, 481 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 441, 251, 522 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search154_0 -> 474 in the cache */
   /* search154_1_0_0_0 -> 474 in the cache */
   /* search154_1_0_0_1_0 -> 16 in the cache */
   /* search154_1_0_0_1 -> 491 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 474, 491 },
      -1,
   } },
   /* search154_1_0_1_0 -> 474 in the cache */
   /* search154_1_0_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      3, 1,
      { 474, 525 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 3,
      { 524, 526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 3,
      { 527 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 474, 528 },
      -1,
   } },

   /* replace154_0 -> 36 in the cache */
   /* replace154_1 -> 474 in the cache */
   /* replace154_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 36, 474, 16 },
      -1,
   } },

   /* ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search155_0 -> 21 in the cache */
   /* search155_1 -> 41 in the cache */
   /* search155_2_0 -> 384 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 384 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_flrp,
      -1, 0,
      { 21, 41, 531 },
      -1,
   } },

   /* replace155_0 -> 384 in the cache */
   /* replace155_1 -> 41 in the cache */
   /* replace155_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 384, 41, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search156_0 -> 21 in the cache */
   /* search156_1_0 -> 21 in the cache */
   /* search156_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_flrp,
      -1, 1,
      { 21, 534, 535 },
      -1,
   } },

   /* replace156_0_0 -> 41 in the cache */
   /* replace156_0_1 -> 535 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 41, 535 },
      -1,
   } },
   /* replace156_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 537, 21 },
      -1,
   } },

   /* ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search157_0_0 -> 21 in the cache */
   /* search157_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search157_1_0 -> 21 in the cache */
   /* search157_1_1 -> 535 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 21, 535 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_flrp,
      -1, 2,
      { 539, 540, 541 },
      -1,
   } },

   /* replace157_0_0 -> 41 in the cache */
   /* replace157_0_1 -> 535 in the cache */
   /* replace157_0_2 -> 541 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 41, 535, 541 },
      -1,
   } },
   /* replace157_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 543, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search158_0 -> 21 in the cache */
   /* search158_1_0 -> 21 in the cache */
   /* search158_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search158_2 -> 535 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_flrp,
      -1, 1,
      { 21, 545, 535 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace158_0_1 -> 41 in the cache */
   /* replace158_0_2 -> 535 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 547, 41, 535 },
      -1,
   } },
   /* replace158_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 548, 21 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search159_0_0 -> 21 in the cache */
   /* search159_0_1_0 -> 547 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 550 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 547, 551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 21, 552 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search159_1_1 -> 550 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 554, 550 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 553, 555 },
      -1,
   } },

   /* replace159_0 -> 21 in the cache */
   /* replace159_1 -> 554 in the cache */
   /* replace159_2 -> 550 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 21, 554, 550 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search160_0_0 -> 21 in the cache */
   /* search160_0_1_0_0 -> 547 in the cache */
   /* search160_0_1_0_1_0 -> 550 in the cache */
   /* search160_0_1_0_1 -> 551 in the cache */
   /* search160_0_1_0 -> 552 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 552 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 21, 558 },
      -1,
   } },
   /* search160_1_0 -> 554 in the cache */
   /* search160_1_1_0 -> 550 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 550 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 554, 560 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 559, 561 },
      -1,
   } },

   /* replace160_0 -> 21 in the cache */
   /* replace160_1 -> 554 in the cache */
   /* replace160_2_0 -> 550 in the cache */
   /* replace160_2 -> 560 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 21, 554, 560 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search161_0 -> 21 in the cache */
   /* search161_1_0 -> 550 in the cache */
   /* search161_1_1_0 -> 554 in the cache */
   /* search161_1_1_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 554, 564 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 550, 565 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 21, 566 },
      -1,
   } },

   /* replace161_0 -> 21 in the cache */
   /* replace161_1 -> 554 in the cache */
   /* replace161_2 -> 550 in the cache */
   /* replace161 -> 557 in the cache */

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search162_0_0 -> 21 in the cache */
   /* search162_0_1_0 -> 547 in the cache */
   /* search162_0_1_1_0_0 -> 422 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 422 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 568 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 547, 569 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 21, 570 },
      -1,
   } },
   /* search162_1_0 -> 554 in the cache */
   /* search162_1_1_0 -> 422 in the cache */
   /* search162_1_1 -> 568 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 554, 568 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 571, 572 },
      -1,
   } },

   /* replace162_0 -> 422 in the cache */
   /* replace162_1 -> 554 in the cache */
   /* replace162_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 422, 554, 21 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search163_0 -> 21 in the cache */
   /* search163_1_0_0 -> 422 in the cache */
   /* search163_1_0 -> 568 in the cache */
   /* search163_1_1_0 -> 554 in the cache */
   /* search163_1_1_1_0 -> 21 in the cache */
   /* search163_1_1_1 -> 564 in the cache */
   /* search163_1_1 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 568, 565 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 21, 575 },
      -1,
   } },

   /* replace163_0 -> 422 in the cache */
   /* replace163_1 -> 554 in the cache */
   /* replace163_2 -> 21 in the cache */
   /* replace163 -> 574 in the cache */

   /* ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search164_0 -> 21 in the cache */
   /* search164_1_0 -> 547 in the cache */
   /* search164_1_1_0_0 -> 422 in the cache */
   /* search164_1_1_0 -> 568 in the cache */
   /* search164_1_1 -> 569 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 547, 569 },
      -1,
   } },
   /* search164_2_0 -> 554 in the cache */
   /* search164_2_1_0 -> 422 in the cache */
   /* search164_2_1 -> 568 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 554, 568 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_ffma,
      0, 3,
      { 21, 577, 578 },
      -1,
   } },

   /* replace164_0 -> 422 in the cache */
   /* replace164_1 -> 554 in the cache */
   /* replace164_2 -> 21 in the cache */
   /* replace164 -> 574 in the cache */

   /* ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search165_1_0 -> 422 in the cache */
   /* search165_1 -> 568 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 581 },
      -1,
   } },
   /* search165_2_1_0 -> 422 in the cache */
   /* search165_2_1 -> 568 in the cache */
   /* search165_2_2 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 582, 568, 581 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 580, 568, 583 },
      -1,
   } },

   /* replace165_0 -> 422 in the cache */
   /* replace165_1 -> 580 in the cache */
   /* replace165_2 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 422, 580, 581 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search166_0_0 -> 441 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 441 },
      -1,
   } },
   /* search166_1_0 -> 41 in the cache */
   /* search166_1_1_0 -> 581 in the cache */
   /* search166_1_1 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 41, 582 },
      -1,
   } },
   /* search166_2 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 586, 587, 581 },
      -1,
   } },

   /* replace166_0 -> 441 in the cache */
   /* replace166_1 -> 41 in the cache */
   /* replace166_2 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 41, 581 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search167_0_0 -> 441 in the cache */
   /* search167_0 -> 586 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 590 },
      -1,
   } },
   /* search167_1_1 -> 554 in the cache */
   /* search167_1_2 -> 541 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 591, 554, 541 },
      -1,
   } },
   /* search167_2_0 -> 590 in the cache */
   /* search167_2_1 -> 554 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 590, 554 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_ffma,
      0, 3,
      { 586, 592, 593 },
      -1,
   } },

   /* replace167_0 -> 441 in the cache */
   /* replace167_1 -> 541 in the cache */
   /* replace167_2_0 -> 590 in the cache */
   /* replace167_2_1 -> 554 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 590, 554 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 441, 541, 595 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search168_0 -> 547 in the cache */
   /* search168_1_0_0_0 -> 547 in the cache */
   /* search168_1_0_0_1_0 -> 21 in the cache */
   /* search168_1_0_0_1 -> 564 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 547, 564 },
      -1,
   } },
   /* search168_1_0_1_0 -> 547 in the cache */
   /* search168_1_0_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      3, 1,
      { 547, 598 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      1, 3,
      { 597, 599 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fneg,
      -1, 3,
      { 600 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 547, 601 },
      -1,
   } },

   /* replace168_0 -> 41 in the cache */
   /* replace168_1 -> 547 in the cache */
   /* replace168_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 41, 547, 21 },
      -1,
   } },

   /* ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search169_0_0 -> 141 in the cache */
   /* search169_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 141, 142 },
      0,
   } },
   /* search169_1_0 -> 141 in the cache */
   /* search169_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 141, 144 },
      0,
   } },
   /* search169_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_flrp,
      -1, 2,
      { 604, 605, 145 },
      -1,
   } },

   /* replace169_0_0 -> 142 in the cache */
   /* replace169_0_1 -> 144 in the cache */
   /* replace169_0_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 142, 144, 145 },
      -1,
   } },
   /* replace169_1 -> 141 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 607, 141 },
      -1,
   } },

   /* ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a') */
   /* search170_0 -> 0 in the cache */
   /* search170_1 -> 205 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_flrp,
      -1, 0,
      { 0, 205, 609 },
      -1,
   } },

   /* replace170_0_0_0 -> 0 in the cache */
   /* replace170_0_0 -> 177 in the cache */
   /* replace170_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 177, 609 },
      -1,
   } },
   /* replace170_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 611, 0 },
      -1,
   } },

   /* ('ftrunc', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search171_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ftrunc,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace171_0_0 -> 32 in the cache */
   /* replace171_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },
   /* replace171_1_0_0_0 -> 32 in the cache */
   /* replace171_1_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffloor,
      -1, 0,
      { 103 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 615 },
      -1,
   } },
   /* replace171_2_0_0 -> 32 in the cache */
   /* replace171_2_0 -> 103 in the cache */
   /* replace171_2 -> 615 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 614, 616, 615 },
      -1,
   } },

   /* ('ffloor', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search172_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffloor,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace172_0 -> 32 in the cache */
   /* replace172_1_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 0,
      { 32, 619 },
      -1,
   } },

   /* ('fadd', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search173_0 -> 32 in the cache */
   /* search173_1_0_0 -> 32 in the cache */
   /* search173_1_0 -> 619 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 619 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 32, 621 },
      -1,
   } },

   /* replace173_0 -> 32 in the cache */
   /* replace173 -> 618 in the cache */

   /* ('ffract', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search174_0 -> 32 in the cache */
   /* search174 -> 619 in the cache */

   /* replace174_0 -> 32 in the cache */
   /* replace174_1_0 -> 32 in the cache */
   /* replace174_1 -> 618 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 0,
      { 32, 618 },
      -1,
   } },

   /* ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a'))) */
   /* search175_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fceil,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace175_0_0_0 -> 32 in the cache */
   /* replace175_0_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffloor,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 625 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search176_0 -> 11 in the cache */
   /* search176_1 -> 207 in the cache */
   /* search176_2 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 11, 207, 389 },
      -1,
   } },

   /* replace176_0_0 -> 11 in the cache */
   /* replace176_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 11, 207 },
      -1,
   } },
   /* replace176_1 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 628, 389 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search177_0 -> 16 in the cache */
   /* search177_1 -> 36 in the cache */
   /* search177_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* replace177_0_0 -> 16 in the cache */
   /* replace177_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace177_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 631, 250 },
      -1,
   } },

   /* ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search178_0 -> 21 in the cache */
   /* search178_1 -> 41 in the cache */
   /* search178_2 -> 535 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 535 },
      -1,
   } },

   /* replace178_0_0 -> 21 in the cache */
   /* replace178_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace178_1 -> 535 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 634, 535 },
      -1,
   } },

   /* ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search179_0 -> 11 in the cache */
   /* search179_1 -> 207 in the cache */
   /* search179_2 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_ffma,
      0, 1,
      { 11, 207, 389 },
      -1,
   } },

   /* replace179_0_0 -> 11 in the cache */
   /* replace179_0_1 -> 207 in the cache */
   /* replace179_0 -> 628 in the cache */
   /* replace179_1 -> 389 in the cache */
   /* replace179 -> 629 in the cache */

   /* ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search180_0 -> 16 in the cache */
   /* search180_1 -> 36 in the cache */
   /* search180_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* replace180_0_0 -> 16 in the cache */
   /* replace180_0_1 -> 36 in the cache */
   /* replace180_0 -> 631 in the cache */
   /* replace180_1 -> 250 in the cache */
   /* replace180 -> 632 in the cache */

   /* ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search181_0 -> 21 in the cache */
   /* search181_1 -> 41 in the cache */
   /* search181_2 -> 535 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 535 },
      -1,
   } },

   /* replace181_0_0 -> 21 in the cache */
   /* replace181_0_1 -> 41 in the cache */
   /* replace181_0 -> 634 in the cache */
   /* replace181_1 -> 535 in the cache */
   /* replace181 -> 635 in the cache */

   /* ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_search_op_b2i,
      -1, 0,
      { 639 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 640 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 642, 643 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_iand,
      2, 2,
      { 641, 644 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_fadd,
      1, 3,
      { 645, 646 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true, false,
      nir_op_fmul,
      0, 4,
      { 647, 648 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace182_1_0_0_0 -> 642 in the cache */
   /* replace182_1_0_0_1 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 642, 643 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_fadd,
      1, 2,
      { 651, 652 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_fmul,
      0, 3,
      { 653, 654 },
      -1,
   } },
   /* replace182_2_0 -> 652 in the cache */
   /* replace182_2_1 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 652, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 650, 655, 656 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b') */
   /* search183_0 -> 0 in the cache */
   /* search183_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdph,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   /* replace183_0_3 -> 216 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 659, 660, 661, 216 },
      -1,
   } },
   /* replace183_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot4,
      0, 1,
      { 662, 3 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search184_0_0 -> 141 in the cache */
   /* search184_0_1 -> 142 in the cache */
   /* search184_0_2 -> 144 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 141, 142, 144, 664 },
      -1,
   } },
   /* search184_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fdot4,
      0, 1,
      { 665, 145 },
      -1,
   } },

   /* replace184_0_0 -> 141 in the cache */
   /* replace184_0_1 -> 142 in the cache */
   /* replace184_0_2 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_vec3,
      -1, 0,
      { 141, 142, 144 },
      -1,
   } },
   /* replace184_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fdph,
      -1, 0,
      { 667, 145 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search185_0_0 -> 0 in the cache */
   /* search185_0_1 -> 205 in the cache */
   /* search185_0_2 -> 205 in the cache */
   /* search185_0_3 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 0, 205, 205, 205 },
      -1,
   } },
   /* search185_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot4,
      0, 1,
      { 669, 3 },
      -1,
   } },

   /* replace185_0 -> 0 in the cache */
   /* replace185_1 -> 3 in the cache */
   /* replace185 -> 211 in the cache */

   /* ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search186_0_0 -> 124 in the cache */
   /* search186_0_1 -> 125 in the cache */
   { .constant = {
      { nir_search_value_constant, -3 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search186_0_3 -> 671 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 124, 125, 671, 671 },
      -1,
   } },
   /* search186_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fdot4,
      0, 1,
      { 672, 127 },
      -1,
   } },

   /* replace186_0_0 -> 124 in the cache */
   /* replace186_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace186_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fdot2,
      0, 1,
      { 674, 127 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search187_0_0 -> 141 in the cache */
   /* search187_0_1 -> 142 in the cache */
   /* search187_0_2 -> 144 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 141, 142, 144, 676 },
      -1,
   } },
   /* search187_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fdot4,
      0, 1,
      { 677, 145 },
      -1,
   } },

   /* replace187_0_0 -> 141 in the cache */
   /* replace187_0_1 -> 142 in the cache */
   /* replace187_0_2 -> 144 in the cache */
   /* replace187_0 -> 667 in the cache */
   /* replace187_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fdot3,
      0, 1,
      { 667, 145 },
      -1,
   } },

   /* ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search188_0_0 -> 0 in the cache */
   /* search188_0_1 -> 205 in the cache */
   /* search188_0_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_vec3,
      -1, 0,
      { 0, 205, 205 },
      -1,
   } },
   /* search188_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot3,
      0, 1,
      { 680, 3 },
      -1,
   } },

   /* replace188_0 -> 0 in the cache */
   /* replace188_1 -> 3 in the cache */
   /* replace188 -> 211 in the cache */

   /* ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search189_0_0 -> 124 in the cache */
   /* search189_0_1 -> 125 in the cache */
   /* search189_0_2 -> 671 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_vec3,
      -1, 0,
      { 124, 125, 671 },
      -1,
   } },
   /* search189_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fdot3,
      0, 1,
      { 682, 127 },
      -1,
   } },

   /* replace189_0_0 -> 124 in the cache */
   /* replace189_0_1 -> 125 in the cache */
   /* replace189_0 -> 674 in the cache */
   /* replace189_1 -> 127 in the cache */
   /* replace189 -> 675 in the cache */

   /* ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search190_0_0 -> 0 in the cache */
   /* search190_0_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 0, 205 },
      -1,
   } },
   /* search190_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot2,
      0, 1,
      { 684, 3 },
      -1,
   } },

   /* replace190_0 -> 0 in the cache */
   /* replace190_1 -> 3 in the cache */
   /* replace190 -> 211 in the cache */

   /* ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y') */
   /* search191_0 -> 32 in the cache */
   /* search191_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fdot2,
      0, 1,
      { 32, 192 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      -1, 0,
      { 687, 688 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b')) */
   /* search192_0 -> 0 in the cache */
   /* search192_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace192_0_0 -> 0 in the cache */
   /* replace192_0_1 -> 3 in the cache */
   /* replace192_0 -> 211 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsum2,
      -1, 1,
      { 211 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b')) */
   /* search193_0 -> 0 in the cache */
   /* search193_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace193_0_0 -> 0 in the cache */
   /* replace193_0_1 -> 3 in the cache */
   /* replace193_0 -> 211 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsum3,
      -1, 1,
      { 211 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b')) */
   /* search194_0 -> 0 in the cache */
   /* search194_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace194_0_0 -> 0 in the cache */
   /* replace194_0_1 -> 3 in the cache */
   /* replace194_0 -> 211 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsum4,
      -1, 1,
      { 211 },
      -1,
   } },

   /* ('fsum2', 'a') => ('fadd', 'a.x', 'a.y') */
   /* search195_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsum2,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace195_0 -> 687 in the cache */
   /* replace195_1 -> 688 in the cache */
   /* replace195 -> 689 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 697 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 698 },
      0,
   } },
   /* search196_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fadd,
      0, 1,
      { 699, 192 },
      -1,
   } },

   /* replace196_0_0 -> 192 in the cache */
   /* replace196_0_1_0 -> 32 in the cache */
   /* replace196_0_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 192, 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 701 },
      -1,
   } },

   /* ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd')) */
   /* search197_0_0_0 -> 124 in the cache */
   /* search197_0_0_1 -> 223 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      1, 1,
      { 124, 223 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 703, 704 },
      -1,
   } },
   /* search197_1 -> 248 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishl,
      -1, 2,
      { 705, 248 },
      -1,
   } },

   /* replace197_0_0 -> 124 in the cache */
   /* replace197_0_1_0 -> 125 in the cache */
   /* replace197_0_1_1 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 125, 251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      1, 1,
      { 124, 707 },
      -1,
   } },
   /* replace197_1_0 -> 127 in the cache */
   /* replace197_1_1 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 127, 251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 708, 709 },
      -1,
   } },

   /* ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c')) */
   /* search198_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imul,
      0, 1,
      { 0, 711 },
      -1,
   } },
   /* search198_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 712, 246 },
      -1,
   } },

   /* replace198_0 -> 0 in the cache */
   /* replace198_1_0 -> 3 in the cache */
   /* replace198_1_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 3, 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imul,
      0, 1,
      { 0, 714 },
      -1,
   } },

   /* ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search199_0_0 -> 6 in the cache */
   /* search199_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search199_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 716, 246 },
      -1,
   } },

   /* replace199_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 36, 718 },
      -1,
   } },
   /* replace199_0_0_1_0 -> 250 in the cache */
   /* replace199_0_0_1_1 -> 718 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      2, 1,
      { 250, 718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 3,
      { 719, 720 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 3,
      { 721, 722 },
      -1,
   } },
   /* replace199_1_0 -> 6 in the cache */
   /* replace199_1_1_0 -> 36 in the cache */
   /* replace199_1_1_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      3, 1,
      { 36, 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 6, 724 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 723, 725, 726 },
      -1,
   } },

   /* ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search200_0_0 -> 6 in the cache */
   /* search200_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search200_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 728, 246 },
      -1,
   } },

   /* replace200_0_0_0_0 -> 36 in the cache */
   /* replace200_0_0_0_1 -> 718 in the cache */
   /* replace200_0_0_0 -> 719 in the cache */
   /* replace200_0_0_1_0 -> 250 in the cache */
   /* replace200_0_0_1_1 -> 718 in the cache */
   /* replace200_0_0_1 -> 720 in the cache */
   /* replace200_0_0 -> 721 in the cache */
   /* replace200_0_1 -> 722 in the cache */
   /* replace200_0 -> 723 in the cache */
   /* replace200_1_0 -> 6 in the cache */
   /* replace200_1_1_0 -> 36 in the cache */
   /* replace200_1_1_1 -> 250 in the cache */
   /* replace200_1_1 -> 724 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 6, 724 },
      -1,
   } },
   /* replace200_2 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 723, 730, 726 },
      -1,
   } },

   /* ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 7)) */
   /* search201_0_0 -> 6 in the cache */
   /* search201_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search201_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 732, 246 },
      -1,
   } },

   /* replace201_0 -> 6 in the cache */
   /* replace201_1_0_0_0 -> 36 in the cache */
   /* replace201_1_0_0_1 -> 718 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      2, 1,
      { 36, 718 },
      -1,
   } },
   /* replace201_1_0_1_0 -> 250 in the cache */
   /* replace201_1_0_1_1 -> 718 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      3, 1,
      { 250, 718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 3,
      { 734, 735 },
      -1,
   } },
   /* replace201_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      0, 4,
      { 736, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishr,
      -1, 4,
      { 6, 737 },
      -1,
   } },

   /* ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search202_0_0 -> 11 in the cache */
   /* search202_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search202_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 739, 246 },
      -1,
   } },

   /* replace202_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 36, 741 },
      -1,
   } },
   /* replace202_0_0_1_0 -> 250 in the cache */
   /* replace202_0_0_1_1 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      2, 1,
      { 250, 741 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 3,
      { 742, 743 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 3,
      { 744, 745 },
      -1,
   } },
   /* replace202_1_0 -> 11 in the cache */
   /* replace202_1_1_0 -> 36 in the cache */
   /* replace202_1_1_1 -> 250 in the cache */
   /* replace202_1_1 -> 724 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 11, 724 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 746, 747, 748 },
      -1,
   } },

   /* ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search203_0_0 -> 11 in the cache */
   /* search203_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search203_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 750, 246 },
      -1,
   } },

   /* replace203_0_0_0_0 -> 36 in the cache */
   /* replace203_0_0_0_1 -> 741 in the cache */
   /* replace203_0_0_0 -> 742 in the cache */
   /* replace203_0_0_1_0 -> 250 in the cache */
   /* replace203_0_0_1_1 -> 741 in the cache */
   /* replace203_0_0_1 -> 743 in the cache */
   /* replace203_0_0 -> 744 in the cache */
   /* replace203_0_1 -> 745 in the cache */
   /* replace203_0 -> 746 in the cache */
   /* replace203_1_0 -> 11 in the cache */
   /* replace203_1_1_0 -> 36 in the cache */
   /* replace203_1_1_1 -> 250 in the cache */
   /* replace203_1_1 -> 724 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 11, 724 },
      -1,
   } },
   /* replace203_2 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 746, 752, 748 },
      -1,
   } },

   /* ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 15)) */
   /* search204_0_0 -> 11 in the cache */
   /* search204_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search204_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 754, 246 },
      -1,
   } },

   /* replace204_0 -> 11 in the cache */
   /* replace204_1_0_0_0 -> 36 in the cache */
   /* replace204_1_0_0_1 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      2, 1,
      { 36, 741 },
      -1,
   } },
   /* replace204_1_0_1_0 -> 250 in the cache */
   /* replace204_1_0_1_1 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      3, 1,
      { 250, 741 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 3,
      { 756, 757 },
      -1,
   } },
   /* replace204_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      0, 4,
      { 758, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishr,
      -1, 4,
      { 11, 759 },
      -1,
   } },

   /* ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search205_0_0 -> 16 in the cache */
   /* search205_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search205_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 761, 246 },
      -1,
   } },

   /* replace205_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 36, 763 },
      -1,
   } },
   /* replace205_0_0_1_0 -> 250 in the cache */
   /* replace205_0_0_1_1 -> 763 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      2, 1,
      { 250, 763 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 3,
      { 764, 765 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x20 /* 32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 3,
      { 766, 767 },
      -1,
   } },
   /* replace205_1_0 -> 16 in the cache */
   /* replace205_1_1_0 -> 36 in the cache */
   /* replace205_1_1_1 -> 250 in the cache */
   /* replace205_1_1 -> 724 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 16, 724 },
      -1,
   } },
   /* replace205_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 768, 769, 120 },
      -1,
   } },

   /* ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search206_0_0 -> 16 in the cache */
   /* search206_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search206_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 771, 246 },
      -1,
   } },

   /* replace206_0_0_0_0 -> 36 in the cache */
   /* replace206_0_0_0_1 -> 763 in the cache */
   /* replace206_0_0_0 -> 764 in the cache */
   /* replace206_0_0_1_0 -> 250 in the cache */
   /* replace206_0_0_1_1 -> 763 in the cache */
   /* replace206_0_0_1 -> 765 in the cache */
   /* replace206_0_0 -> 766 in the cache */
   /* replace206_0_1 -> 767 in the cache */
   /* replace206_0 -> 768 in the cache */
   /* replace206_1_0 -> 16 in the cache */
   /* replace206_1_1_0 -> 36 in the cache */
   /* replace206_1_1_1 -> 250 in the cache */
   /* replace206_1_1 -> 724 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 16, 724 },
      -1,
   } },
   /* replace206_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 768, 773, 120 },
      -1,
   } },

   /* ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 31)) */
   /* search207_0_0 -> 16 in the cache */
   /* search207_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search207_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 775, 246 },
      -1,
   } },

   /* replace207_0 -> 16 in the cache */
   /* replace207_1_0_0_0 -> 36 in the cache */
   /* replace207_1_0_0_1 -> 763 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      2, 1,
      { 36, 763 },
      -1,
   } },
   /* replace207_1_0_1_0 -> 250 in the cache */
   /* replace207_1_0_1_1 -> 763 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      3, 1,
      { 250, 763 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 3,
      { 777, 778 },
      -1,
   } },
   /* replace207_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      0, 4,
      { 779, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 4,
      { 16, 780 },
      -1,
   } },

   /* ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search208_0_0 -> 21 in the cache */
   /* search208_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search208_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 782, 246 },
      -1,
   } },

   /* replace208_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffffffffff /* 18446744073709551615 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 36, 784 },
      -1,
   } },
   /* replace208_0_0_1_0 -> 250 in the cache */
   /* replace208_0_0_1_1 -> 784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      2, 1,
      { 250, 784 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 3,
      { 785, 786 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x40 /* 64 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 3,
      { 787, 788 },
      -1,
   } },
   /* replace208_1_0 -> 21 in the cache */
   /* replace208_1_1_0 -> 36 in the cache */
   /* replace208_1_1_1 -> 250 in the cache */
   /* replace208_1_1 -> 724 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 21, 724 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 789, 790, 791 },
      -1,
   } },

   /* ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search209_0_0 -> 21 in the cache */
   /* search209_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search209_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 793, 246 },
      -1,
   } },

   /* replace209_0_0_0_0 -> 36 in the cache */
   /* replace209_0_0_0_1 -> 784 in the cache */
   /* replace209_0_0_0 -> 785 in the cache */
   /* replace209_0_0_1_0 -> 250 in the cache */
   /* replace209_0_0_1_1 -> 784 in the cache */
   /* replace209_0_0_1 -> 786 in the cache */
   /* replace209_0_0 -> 787 in the cache */
   /* replace209_0_1 -> 788 in the cache */
   /* replace209_0 -> 789 in the cache */
   /* replace209_1_0 -> 21 in the cache */
   /* replace209_1_1_0 -> 36 in the cache */
   /* replace209_1_1_1 -> 250 in the cache */
   /* replace209_1_1 -> 724 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 21, 724 },
      -1,
   } },
   /* replace209_2 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 789, 795, 791 },
      -1,
   } },

   /* ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 63)) */
   /* search210_0_0 -> 21 in the cache */
   /* search210_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search210_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 797, 246 },
      -1,
   } },

   /* replace210_0 -> 21 in the cache */
   /* replace210_1_0_0_0 -> 36 in the cache */
   /* replace210_1_0_0_1 -> 784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      2, 1,
      { 36, 784 },
      -1,
   } },
   /* replace210_1_0_1_0 -> 250 in the cache */
   /* replace210_1_0_1_1 -> 784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      3, 1,
      { 250, 784 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 3,
      { 799, 800 },
      -1,
   } },
   /* replace210_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      0, 4,
      { 801, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 4,
      { 21, 802 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search211_0_0 -> 6 in the cache */
   /* search211_0_1 -> 33 in the cache */
   /* search211_0 -> 728 in the cache */
   /* search211_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 728, 36 },
      -1,
   } },

   /* replace211_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace211_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 805, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_iand,
      0, 1,
      { 6, 806 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search212_0_0 -> 6 in the cache */
   /* search212_0_1 -> 33 in the cache */
   /* search212_0 -> 732 in the cache */
   /* search212_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 732, 36 },
      -1,
   } },

   /* replace212_0 -> 6 in the cache */
   /* replace212_1_0 -> 805 in the cache */
   /* replace212_1_1 -> 36 in the cache */
   /* replace212_1 -> 806 in the cache */
   /* replace212 -> 807 in the cache */

   /* ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b')) */
   /* search213_0_0 -> 6 in the cache */
   /* search213_0_1 -> 33 in the cache */
   /* search213_0 -> 716 in the cache */
   /* search213_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 716, 36 },
      -1,
   } },

   /* replace213_0 -> 6 in the cache */
   /* replace213_1_0 -> 805 in the cache */
   /* replace213_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 805, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_iand,
      0, 1,
      { 6, 810 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search214_0_0 -> 11 in the cache */
   /* search214_0_1 -> 33 in the cache */
   /* search214_0 -> 750 in the cache */
   /* search214_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 750, 36 },
      -1,
   } },

   /* replace214_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace214_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 813, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 11, 814 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search215_0_0 -> 11 in the cache */
   /* search215_0_1 -> 33 in the cache */
   /* search215_0 -> 754 in the cache */
   /* search215_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 754, 36 },
      -1,
   } },

   /* replace215_0 -> 11 in the cache */
   /* replace215_1_0 -> 813 in the cache */
   /* replace215_1_1 -> 36 in the cache */
   /* replace215_1 -> 814 in the cache */
   /* replace215 -> 815 in the cache */

   /* ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b')) */
   /* search216_0_0 -> 11 in the cache */
   /* search216_0_1 -> 33 in the cache */
   /* search216_0 -> 739 in the cache */
   /* search216_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 739, 36 },
      -1,
   } },

   /* replace216_0 -> 11 in the cache */
   /* replace216_1_0 -> 813 in the cache */
   /* replace216_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 813, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 11, 818 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search217_0_0 -> 16 in the cache */
   /* search217_0_1 -> 33 in the cache */
   /* search217_0 -> 771 in the cache */
   /* search217_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 771, 36 },
      -1,
   } },

   /* replace217_0 -> 16 in the cache */
   /* replace217_1_0 -> 763 in the cache */
   /* replace217_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 763, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 16, 821 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search218_0_0 -> 16 in the cache */
   /* search218_0_1 -> 33 in the cache */
   /* search218_0 -> 775 in the cache */
   /* search218_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 775, 36 },
      -1,
   } },

   /* replace218_0 -> 16 in the cache */
   /* replace218_1_0 -> 763 in the cache */
   /* replace218_1_1 -> 36 in the cache */
   /* replace218_1 -> 821 in the cache */
   /* replace218 -> 822 in the cache */

   /* ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b')) */
   /* search219_0_0 -> 16 in the cache */
   /* search219_0_1 -> 33 in the cache */
   /* search219_0 -> 761 in the cache */
   /* search219_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 761, 36 },
      -1,
   } },

   /* replace219_0 -> 16 in the cache */
   /* replace219_1_0 -> 763 in the cache */
   /* replace219_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 763, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 16, 825 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search220_0_0 -> 21 in the cache */
   /* search220_0_1 -> 33 in the cache */
   /* search220_0 -> 793 in the cache */
   /* search220_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 793, 36 },
      -1,
   } },

   /* replace220_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffffffffff /* 18446744073709551615 */ },
   } },
   /* replace220_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 828, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iand,
      0, 1,
      { 21, 829 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search221_0_0 -> 21 in the cache */
   /* search221_0_1 -> 33 in the cache */
   /* search221_0 -> 797 in the cache */
   /* search221_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 797, 36 },
      -1,
   } },

   /* replace221_0 -> 21 in the cache */
   /* replace221_1_0 -> 828 in the cache */
   /* replace221_1_1 -> 36 in the cache */
   /* replace221_1 -> 829 in the cache */
   /* replace221 -> 830 in the cache */

   /* ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b')) */
   /* search222_0_0 -> 21 in the cache */
   /* search222_0_1 -> 33 in the cache */
   /* search222_0 -> 782 in the cache */
   /* search222_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 782, 36 },
      -1,
   } },

   /* replace222_0 -> 21 in the cache */
   /* replace222_1_0 -> 828 in the cache */
   /* replace222_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 828, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iand,
      0, 1,
      { 21, 833 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b') */
   /* search223_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      6,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 835 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 836, 837 },
      -1,
   } },

   /* replace223_0 -> 16 in the cache */
   /* replace223_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b') */
   /* search224_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      7,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imul,
      1, 1,
      { 0, 840 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 2,
      { 841, 842 },
      -1,
   } },

   /* replace224_0 -> 0 in the cache */
   /* replace224_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b') */
   /* search225_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 16, 845 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffe /* 4294967294 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 2,
      { 846, 847 },
      -1,
   } },

   /* replace225_0_0 -> 16 in the cache */
   /* replace225_0_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 16, 847 },
      -1,
   } },
   /* replace225_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 849, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b') */
   /* search226_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      7,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 16, 851 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffc /* 4294967292 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 2,
      { 852, 853 },
      -1,
   } },

   /* replace226_0_0 -> 16 in the cache */
   /* replace226_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 16, 853 },
      -1,
   } },
   /* replace226_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 855, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b') */
   /* search227_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 16, 857 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff8 /* 4294967288 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 2,
      { 858, 859 },
      -1,
   } },

   /* replace227_0_0 -> 16 in the cache */
   /* replace227_0_1 -> 859 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 16, 859 },
      -1,
   } },
   /* replace227_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 861, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b') */
   /* search228_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 16, 863 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff0 /* 4294967280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 2,
      { 864, 865 },
      -1,
   } },

   /* replace228_0_0 -> 16 in the cache */
   /* replace228_0_1 -> 865 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 16, 865 },
      -1,
   } },
   /* replace228_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 867, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b') */
   /* search229_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      11,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 16, 869 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffe0 /* 4294967264 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 2,
      { 870, 871 },
      -1,
   } },

   /* replace229_0_0 -> 16 in the cache */
   /* replace229_0_1 -> 871 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 16, 871 },
      -1,
   } },
   /* replace229_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 873, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b') */
   /* search230_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      12,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 16, 875 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffc0 /* 4294967232 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 2,
      { 876, 877 },
      -1,
   } },

   /* replace230_0_0 -> 16 in the cache */
   /* replace230_0_1 -> 877 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 16, 877 },
      -1,
   } },
   /* replace230_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 879, 36 },
      -1,
   } },

   /* ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1) */
   /* search231_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 16, 881 },
      -1,
   } },
   /* search231_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 882, 316 },
      -1,
   } },

   /* replace231_0 -> 16 in the cache */
   /* replace231_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 316 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1) */
   /* search232_0_0 -> 16 in the cache */
   /* search232_0_1 -> 316 in the cache */
   /* search232_0 -> 884 in the cache */
   /* search232_1 -> 847 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 884, 847 },
      -1,
   } },

   /* replace232_0 -> 16 in the cache */
   /* replace232_1 -> 316 in the cache */
   /* replace232 -> 884 in the cache */

   /* ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1) */
   /* search233_0_0 -> 16 in the cache */
   /* search233_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 16, 316 },
      -1,
   } },
   /* search233_1 -> 881 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 886, 881 },
      -1,
   } },

   /* replace233_0 -> 16 in the cache */
   /* replace233_1 -> 316 in the cache */
   /* replace233 -> 886 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2) */
   /* search234_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffff /* 1073741823 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 16, 888 },
      -1,
   } },
   /* search234_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 889, 321 },
      -1,
   } },

   /* replace234_0 -> 16 in the cache */
   /* replace234_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 321 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2) */
   /* search235_0_0 -> 16 in the cache */
   /* search235_0_1 -> 321 in the cache */
   /* search235_0 -> 891 in the cache */
   /* search235_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 891, 853 },
      -1,
   } },

   /* replace235_0 -> 16 in the cache */
   /* replace235_1 -> 321 in the cache */
   /* replace235 -> 891 in the cache */

   /* ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2) */
   /* search236_0_0 -> 16 in the cache */
   /* search236_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 16, 321 },
      -1,
   } },
   /* search236_1 -> 888 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 893, 888 },
      -1,
   } },

   /* replace236_0 -> 16 in the cache */
   /* replace236_1 -> 321 in the cache */
   /* replace236 -> 893 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16) */
   /* search237_0_0 -> 16 in the cache */
   /* search237_0_1 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 16, 741 },
      -1,
   } },
   /* search237_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 895, 745 },
      -1,
   } },

   /* replace237_0 -> 16 in the cache */
   /* replace237_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 745 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16) */
   /* search238_0_0 -> 16 in the cache */
   /* search238_0_1 -> 745 in the cache */
   /* search238_0 -> 897 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff0000 /* 4294901760 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 897, 898 },
      -1,
   } },

   /* replace238_0 -> 16 in the cache */
   /* replace238_1 -> 745 in the cache */
   /* replace238 -> 897 in the cache */

   /* ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16) */
   /* search239_0_0 -> 16 in the cache */
   /* search239_0_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 16, 745 },
      -1,
   } },
   /* search239_1 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 900, 741 },
      -1,
   } },

   /* replace239_0 -> 16 in the cache */
   /* replace239_1 -> 745 in the cache */
   /* replace239 -> 900 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24) */
   /* search240_0_0 -> 16 in the cache */
   /* search240_0_1 -> 718 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 16, 718 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 902, 903 },
      -1,
   } },

   /* replace240_0 -> 16 in the cache */
   /* replace240_1 -> 903 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 903 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24) */
   /* search241_0_0 -> 16 in the cache */
   /* search241_0_1 -> 903 in the cache */
   /* search241_0 -> 905 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 905, 906 },
      -1,
   } },

   /* replace241_0 -> 16 in the cache */
   /* replace241_1 -> 903 in the cache */
   /* replace241 -> 905 in the cache */

   /* ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24) */
   /* search242_0_0 -> 16 in the cache */
   /* search242_0_1 -> 903 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 16, 903 },
      -1,
   } },
   /* search242_1 -> 718 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 908, 718 },
      -1,
   } },

   /* replace242_0 -> 16 in the cache */
   /* replace242_1 -> 903 in the cache */
   /* replace242 -> 908 in the cache */

   /* ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c')) */
   /* search243_0_0 -> 0 in the cache */
   /* search243_0_1 -> 711 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 0, 711 },
      -1,
   } },
   /* search243_1 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 910, 246 },
      -1,
   } },

   /* replace243_0_0 -> 0 in the cache */
   /* replace243_0_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 0, 250 },
      -1,
   } },
   /* replace243_1_0 -> 3 in the cache */
   /* replace243_1_1 -> 250 in the cache */
   /* replace243_1 -> 714 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 912, 714 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c')) */
   /* search244_0_0 -> 124 in the cache */
   /* search244_0_1 -> 223 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 124, 223 },
      0,
   } },
   /* search244_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      0, 2,
      { 914, 704 },
      -1,
   } },

   /* replace244_0_0 -> 124 in the cache */
   /* replace244_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace244_1_0 -> 125 in the cache */
   /* replace244_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      2, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 3,
      { 916, 917 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd')) */
   /* search245_0_0_0 -> 141 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      2, 1,
      { 141, 919 },
      0,
   } },
   /* search245_0_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      1, 2,
      { 920, 144 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      0, 3,
      { 921, 922 },
      -1,
   } },

   /* replace245_0_0_0 -> 141 in the cache */
   /* replace245_0_0_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      2, 1,
      { 141, 144 },
      -1,
   } },
   /* replace245_0_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      1, 2,
      { 924, 145 },
      -1,
   } },
   /* replace245_1_0 -> 142 in the cache */
   /* replace245_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      3, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      0, 4,
      { 925, 926 },
      -1,
   } },

   /* ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd')) */
   /* search246_0_0_0 -> 124 in the cache */
   /* search246_0_0_1 -> 223 in the cache */
   /* search246_0_0 -> 914 in the cache */
   /* search246_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 914, 127 },
      0,
   } },
   /* search246_1 -> 248 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishl,
      -1, 2,
      { 928, 248 },
      -1,
   } },

   /* replace246_0_0_0 -> 124 in the cache */
   /* replace246_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace246_0_1 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 930, 251 },
      -1,
   } },
   /* replace246_1_0 -> 125 in the cache */
   /* replace246_1_1 -> 251 in the cache */
   /* replace246_1 -> 707 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 931, 707 },
      -1,
   } },

   /* ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 933, 934 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 935 },
      -1,
   } },

   /* replace247_0 -> 0 in the cache */
   /* replace247_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b') */
   /* search248_0_0 -> 933 in the cache */
   /* search248_0_1 -> 934 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 933, 934 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 938 },
      -1,
   } },

   /* replace248_0 -> 0 in the cache */
   /* replace248_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b') */
   /* search249_0_0 -> 0 in the cache */
   /* search249_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 1,
      { 941 },
      -1,
   } },

   /* replace249_0 -> 0 in the cache */
   /* replace249_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b') */
   /* search250_0_0 -> 0 in the cache */
   /* search250_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 1,
      { 944 },
      -1,
   } },

   /* replace250_0 -> 0 in the cache */
   /* replace250_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b') */
   /* search251_0_0 -> 0 in the cache */
   /* search251_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 947 },
      -1,
   } },

   /* replace251_0 -> 0 in the cache */
   /* replace251_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b') */
   /* search252_0_0 -> 0 in the cache */
   /* search252_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 950 },
      -1,
   } },

   /* replace252_0 -> 0 in the cache */
   /* replace252_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b') */
   /* search253_0_0 -> 0 in the cache */
   /* search253_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 953 },
      -1,
   } },

   /* replace253_0 -> 0 in the cache */
   /* replace253_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b') */
   /* search254_0_0 -> 0 in the cache */
   /* search254_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 956 },
      -1,
   } },

   /* replace254_0 -> 0 in the cache */
   /* replace254_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b') */
   /* search255_0_0 -> 0 in the cache */
   /* search255_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 1,
      { 959 },
      -1,
   } },

   /* replace255_0 -> 0 in the cache */
   /* replace255_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b') */
   /* search256_0_0 -> 0 in the cache */
   /* search256_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 1,
      { 962 },
      -1,
   } },

   /* replace256_0 -> 0 in the cache */
   /* replace256_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False */
   /* search257_0_0 -> 0 in the cache */
   /* search257_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search257_1_0 -> 0 in the cache */
   /* search257_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 965, 966 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_FALSE /* False */ },
   } },

   /* ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False */
   /* search258_0_0 -> 0 in the cache */
   /* search258_0_1 -> 3 in the cache */
   /* search258_0 -> 940 in the cache */
   /* search258_1_0 -> 3 in the cache */
   /* search258_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 940, 969 },
      -1,
   } },

   /* replace258 -> 968 in the cache */

   /* ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False */
   /* search259_0_0 -> 0 in the cache */
   /* search259_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search259_1_0 -> 0 in the cache */
   /* search259_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 971, 972 },
      -1,
   } },

   /* replace259 -> 968 in the cache */

   /* ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False */
   /* search260_0_0 -> 0 in the cache */
   /* search260_0_1 -> 3 in the cache */
   /* search260_0 -> 955 in the cache */
   /* search260_1_0 -> 3 in the cache */
   /* search260_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 955, 974 },
      -1,
   } },

   /* replace260 -> 968 in the cache */

   /* ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False */
   /* search261_0_0 -> 0 in the cache */
   /* search261_0_1 -> 3 in the cache */
   /* search261_0 -> 958 in the cache */
   /* search261_1_0 -> 3 in the cache */
   /* search261_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 958, 976 },
      -1,
   } },

   /* replace261 -> 968 in the cache */

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search262_0_0 -> 0 in the cache */
   /* search262_0 -> 177 in the cache */
   /* search262_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 177, 978 },
      -1,
   } },

   /* replace262_0 -> 3 in the cache */
   /* replace262_1 -> 0 in the cache */
   /* replace262 -> 969 in the cache */

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search263_0_0 -> 0 in the cache */
   /* search263_0 -> 177 in the cache */
   /* search263_1_0 -> 3 in the cache */
   /* search263_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 177, 978 },
      -1,
   } },

   /* replace263_0 -> 3 in the cache */
   /* replace263_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search264_0_0 -> 0 in the cache */
   /* search264_0 -> 177 in the cache */
   /* search264_1_0 -> 3 in the cache */
   /* search264_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 177, 978 },
      -1,
   } },

   /* replace264_0 -> 3 in the cache */
   /* replace264_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search265_0_0 -> 0 in the cache */
   /* search265_0 -> 177 in the cache */
   /* search265_1_0 -> 3 in the cache */
   /* search265_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 177, 978 },
      -1,
   } },

   /* replace265_0 -> 3 in the cache */
   /* replace265_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search266_0_0 -> 32 in the cache */
   /* search266_0 -> 98 in the cache */
   /* search266_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 98, 196 },
      -1,
   } },

   /* replace266_0 -> 192 in the cache */
   /* replace266_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 192, 32 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search267_0 -> 196 in the cache */
   /* search267_1_0 -> 32 in the cache */
   /* search267_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 196, 98 },
      -1,
   } },

   /* replace267_0 -> 32 in the cache */
   /* replace267_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 32, 192 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search268_0_0 -> 32 in the cache */
   /* search268_0 -> 98 in the cache */
   /* search268_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 98, 196 },
      -1,
   } },

   /* replace268_0 -> 192 in the cache */
   /* replace268_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 192, 32 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search269_0 -> 196 in the cache */
   /* search269_1_0 -> 32 in the cache */
   /* search269_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 196, 98 },
      -1,
   } },

   /* replace269_0 -> 32 in the cache */
   /* replace269_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 32, 192 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search270_0_0 -> 32 in the cache */
   /* search270_0 -> 98 in the cache */
   /* search270_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 98, 196 },
      -1,
   } },

   /* replace270_0 -> 192 in the cache */
   /* replace270_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 192, 32 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search271_0 -> 196 in the cache */
   /* search271_1_0 -> 32 in the cache */
   /* search271_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 196, 98 },
      -1,
   } },

   /* replace271_0 -> 32 in the cache */
   /* replace271_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 32, 192 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      14,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 999 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 998, 1000 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace272_1 -> 999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1002, 999 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search273_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      14,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1004, 1005 },
      -1,
   } },

   /* replace273_0 -> 0 in the cache */
   /* replace273_1 -> 3 in the cache */
   /* replace273 -> 937 in the cache */

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search274_0_0 -> 0 in the cache */
   /* search274_0 -> 1004 in the cache */
   /* search274_1 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1004, 1005 },
      -1,
   } },

   /* replace274_0 -> 0 in the cache */
   /* replace274_1 -> 3 in the cache */
   /* replace274 -> 946 in the cache */

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search275_0_0 -> 0 in the cache */
   /* search275_0 -> 1004 in the cache */
   /* search275_1 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1004, 1005 },
      -1,
   } },

   /* replace275_0 -> 0 in the cache */
   /* replace275_1 -> 3 in the cache */
   /* replace275 -> 943 in the cache */

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search276_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      0,
   } },
   /* search276_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1009, 192 },
      -1,
   } },

   /* replace276_0 -> 32 in the cache */
   /* replace276_1 -> 192 in the cache */
   /* replace276 -> 993 in the cache */

   /* ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a') */
   /* search277_0 -> 113 in the cache */
   /* search277_1_0 -> 32 in the cache */
   /* search277_1 -> 1009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 113, 1009 },
      -1,
   } },

   /* replace277_0 -> 113 in the cache */
   /* replace277_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },

   /* ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a') */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search278_1_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 650 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1013, 1014 },
      -1,
   } },

   /* replace278_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a') */
   /* search279_0_0_0 -> 650 in the cache */
   /* search279_0_0 -> 1014 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 1014 },
      -1,
   } },
   /* search279_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1017, 1013 },
      -1,
   } },

   /* replace279_0 -> 650 in the cache */
   /* replace279 -> 1016 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search280_0_0_0 -> 650 in the cache */
   /* search280_0_0 -> 1014 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 1019 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 1014, 1020 },
      -1,
   } },
   /* search280_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 2,
      { 1021, 1013 },
      -1,
   } },

   /* replace280_0 -> 650 in the cache */
   /* replace280_1 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 650, 1019 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search281_0_0 -> 650 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search281_0_2_0 -> 1019 in the cache */
   /* search281_0_2 -> 1020 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1024, 1020 },
      -1,
   } },
   /* search281_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1025, 1013 },
      -1,
   } },

   /* replace281_0 -> 650 in the cache */
   /* replace281_1 -> 1019 in the cache */
   /* replace281 -> 1023 in the cache */

   /* ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search282_0_0 -> 650 in the cache */
   /* search282_0 -> 1014 in the cache */
   /* search282_1_0_0 -> 1019 in the cache */
   /* search282_1_0 -> 1020 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 1020 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1014, 1027 },
      -1,
   } },

   /* replace282_0 -> 650 in the cache */
   /* replace282_1 -> 1019 in the cache */
   /* replace282 -> 1023 in the cache */

   /* ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b') */
   /* search283_0_0_0 -> 650 in the cache */
   /* search283_0_0 -> 1014 in the cache */
   /* search283_0_1_0 -> 1019 in the cache */
   /* search283_0_1 -> 1020 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 1014, 1020 },
      -1,
   } },
   /* search283_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 2,
      { 1029, 1013 },
      -1,
   } },

   /* replace283_0 -> 650 in the cache */
   /* replace283_1 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 650, 1019 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b') */
   /* search284_0_0 -> 650 in the cache */
   /* search284_0_1_0 -> 1019 in the cache */
   /* search284_0_1 -> 1020 in the cache */
   /* search284_0_2 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1020, 1013 },
      -1,
   } },
   /* search284_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1032, 1013 },
      -1,
   } },

   /* replace284_0 -> 650 in the cache */
   /* replace284_1 -> 1019 in the cache */
   /* replace284 -> 1031 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b') */
   /* search285_0_0_0 -> 650 in the cache */
   /* search285_0_0 -> 1014 in the cache */
   /* search285_0_1_0_0 -> 1019 in the cache */
   /* search285_0_1_0 -> 1020 in the cache */
   /* search285_0_1 -> 1027 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 1014, 1027 },
      -1,
   } },
   /* search285_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 2,
      { 1034, 1013 },
      -1,
   } },

   /* replace285_0 -> 650 in the cache */
   /* replace285_1 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 650, 1019 },
      -1,
   } },

   /* ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b') */
   /* search286_0_0 -> 650 in the cache */
   /* search286_0 -> 1014 in the cache */
   /* search286_1_0 -> 1019 in the cache */
   /* search286_1 -> 1020 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1014, 1020 },
      -1,
   } },

   /* replace286_0 -> 650 in the cache */
   /* replace286_1 -> 1019 in the cache */
   /* replace286 -> 1036 in the cache */

   /* ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b') */
   /* search287_0_0_0 -> 650 in the cache */
   /* search287_0_0 -> 1014 in the cache */
   /* search287_0 -> 1017 in the cache */
   /* search287_1_0_0 -> 1019 in the cache */
   /* search287_1_0 -> 1020 in the cache */
   /* search287_1 -> 1027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1017, 1027 },
      -1,
   } },

   /* replace287_0 -> 650 in the cache */
   /* replace287_1 -> 1019 in the cache */
   /* replace287 -> 1036 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search288_0_0_0 -> 650 in the cache */
   /* search288_0_0 -> 1014 in the cache */
   /* search288_0_1_0 -> 1019 in the cache */
   /* search288_0_1 -> 1020 in the cache */
   /* search288_0 -> 1021 in the cache */
   /* search288_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 2,
      { 1021, 1013 },
      -1,
   } },

   /* replace288_0_0 -> 650 in the cache */
   /* replace288_0_1 -> 1019 in the cache */
   /* replace288_0 -> 1023 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 1,
      { 1023 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search289_0_0 -> 650 in the cache */
   /* search289_0_1 -> 1024 in the cache */
   /* search289_0_2_0 -> 1019 in the cache */
   /* search289_0_2 -> 1020 in the cache */
   /* search289_0 -> 1025 in the cache */
   /* search289_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1025, 1013 },
      -1,
   } },

   /* replace289_0_0 -> 650 in the cache */
   /* replace289_0_1 -> 1019 in the cache */
   /* replace289_0 -> 1023 in the cache */
   /* replace289 -> 1040 in the cache */

   /* ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search290_0_0 -> 650 in the cache */
   /* search290_0 -> 1014 in the cache */
   /* search290_1_0_0 -> 1019 in the cache */
   /* search290_1_0 -> 1020 in the cache */
   /* search290_1 -> 1027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1014, 1027 },
      -1,
   } },

   /* replace290_0_0 -> 650 in the cache */
   /* replace290_0_1 -> 1019 in the cache */
   /* replace290_0 -> 1023 in the cache */
   /* replace290 -> 1040 in the cache */

   /* ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search291_0_0_0 -> 650 in the cache */
   /* search291_0_0 -> 1014 in the cache */
   /* search291_0_1_0 -> 1019 in the cache */
   /* search291_0_1 -> 1020 in the cache */
   /* search291_0 -> 1029 in the cache */
   /* search291_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 2,
      { 1029, 1013 },
      -1,
   } },

   /* replace291_0_0 -> 650 in the cache */
   /* replace291_0_1 -> 1019 in the cache */
   /* replace291_0 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 1,
      { 1031 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search292_0_0 -> 650 in the cache */
   /* search292_0_1_0 -> 1019 in the cache */
   /* search292_0_1 -> 1020 in the cache */
   /* search292_0_2 -> 1013 in the cache */
   /* search292_0 -> 1032 in the cache */
   /* search292_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1032, 1013 },
      -1,
   } },

   /* replace292_0_0 -> 650 in the cache */
   /* replace292_0_1 -> 1019 in the cache */
   /* replace292_0 -> 1031 in the cache */
   /* replace292 -> 1044 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b') */
   /* search293_0_0_0 -> 650 in the cache */
   /* search293_0_0 -> 1014 in the cache */
   /* search293_0_1_0_0 -> 1019 in the cache */
   /* search293_0_1_0 -> 1020 in the cache */
   /* search293_0_1 -> 1027 in the cache */
   /* search293_0 -> 1034 in the cache */
   /* search293_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 2,
      { 1034, 1013 },
      -1,
   } },

   /* replace293_0 -> 650 in the cache */
   /* replace293_1 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 650, 1019 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b') */
   /* search294_0_0 -> 650 in the cache */
   /* search294_0 -> 1014 in the cache */
   /* search294_1_0 -> 1019 in the cache */
   /* search294_1 -> 1020 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1014, 1020 },
      -1,
   } },

   /* replace294_0 -> 650 in the cache */
   /* replace294_1 -> 1019 in the cache */
   /* replace294 -> 1047 in the cache */

   /* ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b') */
   /* search295_0_0_0 -> 650 in the cache */
   /* search295_0_0 -> 1014 in the cache */
   /* search295_0 -> 1017 in the cache */
   /* search295_1_0_0 -> 1019 in the cache */
   /* search295_1_0 -> 1020 in the cache */
   /* search295_1 -> 1027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1017, 1027 },
      -1,
   } },

   /* replace295_0 -> 650 in the cache */
   /* replace295_1 -> 1019 in the cache */
   /* replace295 -> 1047 in the cache */

   /* ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b') */
   /* search296_0_0_0_0 -> 650 in the cache */
   /* search296_0_0_0 -> 1014 in the cache */
   /* search296_0_0_1_0 -> 1019 in the cache */
   /* search296_0_0_1 -> 1020 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 1014, 1020 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1050 },
      -1,
   } },
   /* search296_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 1051, 1013 },
      -1,
   } },

   /* replace296_0 -> 650 in the cache */
   /* replace296_1 -> 1019 in the cache */
   /* replace296 -> 1023 in the cache */

   /* ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search297_0 -> 1013 in the cache */
   /* search297_1_0_0 -> 650 in the cache */
   /* search297_1_0 -> 1014 in the cache */
   /* search297_1_1_0 -> 1019 in the cache */
   /* search297_1_1 -> 1020 in the cache */
   /* search297_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 1013, 1050 },
      -1,
   } },

   /* replace297_0 -> 650 in the cache */
   /* replace297_1 -> 1019 in the cache */
   /* replace297 -> 1023 in the cache */

   /* ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search298_0_0_0_0 -> 650 in the cache */
   /* search298_0_0_0 -> 1014 in the cache */
   /* search298_0_0_1_0 -> 1019 in the cache */
   /* search298_0_0_1 -> 1020 in the cache */
   /* search298_0_0 -> 1050 in the cache */
   /* search298_0 -> 1051 in the cache */
   /* search298_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 1051, 1013 },
      -1,
   } },

   /* replace298_0_0 -> 650 in the cache */
   /* replace298_0_1 -> 1019 in the cache */
   /* replace298_0 -> 1023 in the cache */
   /* replace298 -> 1040 in the cache */

   /* ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search299_0 -> 1013 in the cache */
   /* search299_1_0_0 -> 650 in the cache */
   /* search299_1_0 -> 1014 in the cache */
   /* search299_1_1_0 -> 1019 in the cache */
   /* search299_1_1 -> 1020 in the cache */
   /* search299_1 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 1013, 1050 },
      -1,
   } },

   /* replace299_0_0 -> 650 in the cache */
   /* replace299_0_1 -> 1019 in the cache */
   /* replace299_0 -> 1023 in the cache */
   /* replace299 -> 1040 in the cache */

   /* ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0) */
   /* search300_0 -> 32 in the cache */
   /* search300_1_0 -> 32 in the cache */
   /* search300_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace300_0 -> 32 in the cache */
   /* replace300_1 -> 113 in the cache */
   /* replace300 -> 614 in the cache */

   /* ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0) */
   /* search301_0 -> 32 in the cache */
   /* search301_1_0 -> 32 in the cache */
   /* search301_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace301_0 -> 32 in the cache */
   /* replace301_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 32, 113 },
      -1,
   } },

   /* ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 1060 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 1062 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 1061, 1063 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1064 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmin,
      0, 2,
      { 1059, 1065 },
      -1,
   } },
   /* search302_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 2,
      { 1066, 113 },
      -1,
   } },

   /* replace302_0_0 -> 1059 in the cache */
   /* replace302_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1059, 113 },
      -1,
   } },
   /* replace302_1_0 -> 1060 in the cache */
   /* replace302_1_1 -> 1062 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 1060, 1062 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 2,
      { 1068, 1069 },
      -1,
   } },

   /* ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0) */
   /* search303_0_0 -> 0 in the cache */
   /* search303_0_1 -> 3 in the cache */
   /* search303_0 -> 218 in the cache */
   /* search303_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_flt,
      -1, 1,
      { 218, 0 },
      -1,
   } },

   /* replace303_0 -> 3 in the cache */
   /* replace303_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 3, 205 },
      -1,
   } },

   /* ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0) */
   /* search304_0_0 -> 0 in the cache */
   /* search304_0_1 -> 3 in the cache */
   /* search304_0 -> 218 in the cache */
   /* search304_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 1,
      { 218, 0 },
      -1,
   } },

   /* replace304_0 -> 3 in the cache */
   /* replace304_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 3, 205 },
      -1,
   } },

   /* ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0) */
   /* search305_0_0 -> 0 in the cache */
   /* search305_0_1 -> 3 in the cache */
   /* search305_0 -> 178 in the cache */
   /* search305_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_feq,
      0, 2,
      { 178, 0 },
      -1,
   } },

   /* replace305_0 -> 3 in the cache */
   /* replace305_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 3, 205 },
      -1,
   } },

   /* ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0) */
   /* search306_0_0 -> 0 in the cache */
   /* search306_0_1 -> 3 in the cache */
   /* search306_0 -> 178 in the cache */
   /* search306_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fneu,
      0, 2,
      { 178, 0 },
      -1,
   } },

   /* replace306_0 -> 3 in the cache */
   /* replace306_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 3, 205 },
      -1,
   } },

   /* ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search307_0_0 -> 124 in the cache */
   /* search307_0_1 -> 223 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 124, 223 },
      0,
   } },
   /* search307_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_flt,
      -1, 1,
      { 1079, 704 },
      -1,
   } },

   /* replace307_0 -> 124 in the cache */
   /* replace307_1_0 -> 127 in the cache */
   /* replace307_1_1_0 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 127, 1081 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 124, 1082 },
      -1,
   } },

   /* ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search308_0_0_0 -> 124 in the cache */
   /* search308_0_0_1 -> 223 in the cache */
   /* search308_0_0 -> 1079 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1079 },
      0,
   } },
   /* search308_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_flt,
      -1, 1,
      { 1084, 704 },
      -1,
   } },

   /* replace308_0_0_0 -> 127 in the cache */
   /* replace308_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 127, 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1086 },
      -1,
   } },
   /* replace308_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 1087, 124 },
      -1,
   } },

   /* ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search309_0_0 -> 124 in the cache */
   /* search309_0_1 -> 223 in the cache */
   /* search309_0 -> 1079 in the cache */
   /* search309_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 1,
      { 1079, 704 },
      -1,
   } },

   /* replace309_0 -> 124 in the cache */
   /* replace309_1_0 -> 127 in the cache */
   /* replace309_1_1_0 -> 125 in the cache */
   /* replace309_1_1 -> 1081 in the cache */
   /* replace309_1 -> 1082 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 124, 1082 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search310_0_0_0 -> 124 in the cache */
   /* search310_0_0_1 -> 223 in the cache */
   /* search310_0_0 -> 1079 in the cache */
   /* search310_0 -> 1084 in the cache */
   /* search310_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 1,
      { 1084, 704 },
      -1,
   } },

   /* replace310_0_0_0 -> 127 in the cache */
   /* replace310_0_0_1 -> 125 in the cache */
   /* replace310_0_0 -> 1086 in the cache */
   /* replace310_0 -> 1087 in the cache */
   /* replace310_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 1087, 124 },
      -1,
   } },

   /* ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search311_0_0 -> 124 in the cache */
   /* search311_0_1 -> 223 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 124, 223 },
      0,
   } },
   /* search311_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_feq,
      0, 2,
      { 1093, 704 },
      -1,
   } },

   /* replace311_0 -> 124 in the cache */
   /* replace311_1_0 -> 127 in the cache */
   /* replace311_1_1_0 -> 125 in the cache */
   /* replace311_1_1 -> 1081 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 127, 1081 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 2,
      { 124, 1095 },
      -1,
   } },

   /* ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search312_0_0_0 -> 124 in the cache */
   /* search312_0_0_1 -> 223 in the cache */
   /* search312_0_0 -> 1093 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1093 },
      0,
   } },
   /* search312_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_feq,
      0, 2,
      { 1097, 704 },
      -1,
   } },

   /* replace312_0_0_0 -> 127 in the cache */
   /* replace312_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 127, 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1099 },
      -1,
   } },
   /* replace312_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 2,
      { 1100, 124 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search313_0_0 -> 124 in the cache */
   /* search313_0_1 -> 223 in the cache */
   /* search313_0 -> 1093 in the cache */
   /* search313_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fneu,
      0, 2,
      { 1093, 704 },
      -1,
   } },

   /* replace313_0 -> 124 in the cache */
   /* replace313_1_0 -> 127 in the cache */
   /* replace313_1_1_0 -> 125 in the cache */
   /* replace313_1_1 -> 1081 in the cache */
   /* replace313_1 -> 1095 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 2,
      { 124, 1095 },
      -1,
   } },

   /* ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search314_0_0_0 -> 124 in the cache */
   /* search314_0_0_1 -> 223 in the cache */
   /* search314_0_0 -> 1093 in the cache */
   /* search314_0 -> 1097 in the cache */
   /* search314_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fneu,
      0, 2,
      { 1097, 704 },
      -1,
   } },

   /* replace314_0_0_0 -> 127 in the cache */
   /* replace314_0_0_1 -> 125 in the cache */
   /* replace314_0_0 -> 1099 in the cache */
   /* replace314_0 -> 1100 in the cache */
   /* replace314_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 2,
      { 1100, 124 },
      -1,
   } },

   /* ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0) */
   /* search315_0_0 -> 0 in the cache */
   /* search315_0_1 -> 3 in the cache */
   /* search315_0 -> 173 in the cache */
   /* search315_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 173, 0 },
      -1,
   } },

   /* replace315_0 -> 3 in the cache */
   /* replace315_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0) */
   /* search316_0_0 -> 0 in the cache */
   /* search316_0_1 -> 3 in the cache */
   /* search316_0 -> 173 in the cache */
   /* search316_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 173, 0 },
      -1,
   } },

   /* replace316_0 -> 3 in the cache */
   /* replace316_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a') */
   /* search317_0_0 -> 650 in the cache */
   /* search317_0 -> 1014 in the cache */
   /* search317_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1014, 1013 },
      -1,
   } },

   /* replace317_0 -> 650 in the cache */
   /* replace317 -> 1016 in the cache */

   /* ('fneu', ('b2f', 'a@1'), 0.0) => a */
   /* search318_0_0 -> 650 in the cache */
   /* search318_0 -> 1014 in the cache */
   /* search318_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1014, 1013 },
      -1,
   } },

   /* replace318 -> 650 in the cache */

   /* ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a') */
   /* search319_0_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2i,
      -1, 0,
      { 650 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1112, 1113 },
      -1,
   } },

   /* replace319_0 -> 650 in the cache */
   /* replace319 -> 1016 in the cache */

   /* ('ine', ('b2i', 'a@1'), 0) => a */
   /* search320_0_0 -> 650 in the cache */
   /* search320_0 -> 1112 in the cache */
   /* search320_1 -> 1113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1112, 1113 },
      -1,
   } },

   /* replace320 -> 650 in the cache */

   /* ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search321_0_0 -> 32 in the cache */
   /* search321_0 -> 104 in the cache */
   /* search321_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 104, 1013 },
      -1,
   } },

   /* replace321_0 -> 32 in the cache */
   /* replace321_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search322_0_0 -> 32 in the cache */
   /* search322_0 -> 104 in the cache */
   /* search322_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 104, 1013 },
      -1,
   } },

   /* replace322_0 -> 32 in the cache */
   /* replace322_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('fge', ('u2f', 'a'), 0.0) => True */
   /* search323_0_0 -> 32 in the cache */
   /* search323_0 -> 104 in the cache */
   /* search323_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 104, 1013 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_TRUE /* True */ },
   } },

   /* ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a') */
   /* search324_0 -> 1013 in the cache */
   /* search324_1_0 -> 32 in the cache */
   /* search324_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1013, 104 },
      -1,
   } },

   /* replace324_0 -> 61 in the cache */
   /* replace324_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('u2f', 'a'), 0.0) => False */
   /* search325_0_0 -> 32 in the cache */
   /* search325_0 -> 104 in the cache */
   /* search325_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 104, 1013 },
      -1,
   } },

   /* replace325 -> 968 in the cache */

   /* ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a') */
   /* search326_0 -> 1013 in the cache */
   /* search326_1_0 -> 32 in the cache */
   /* search326_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1013, 104 },
      -1,
   } },

   /* replace326_0 -> 61 in the cache */
   /* replace326_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search327_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_i2f,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search327_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1127, 1013 },
      -1,
   } },

   /* replace327_0 -> 32 in the cache */
   /* replace327_1 -> 61 in the cache */
   /* replace327 -> 1117 in the cache */

   /* ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search328_0_0 -> 32 in the cache */
   /* search328_0 -> 1127 in the cache */
   /* search328_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1127, 1013 },
      -1,
   } },

   /* replace328_0 -> 32 in the cache */
   /* replace328_1 -> 61 in the cache */
   /* replace328 -> 1119 in the cache */

   /* ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0) */
   /* search329_0_0 -> 32 in the cache */
   /* search329_0 -> 1127 in the cache */
   /* search329_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1127, 1013 },
      -1,
   } },

   /* replace329_0 -> 32 in the cache */
   /* replace329_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a') */
   /* search330_0 -> 1013 in the cache */
   /* search330_1_0 -> 32 in the cache */
   /* search330_1 -> 1127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1013, 1127 },
      -1,
   } },

   /* replace330_0 -> 61 in the cache */
   /* replace330_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0) */
   /* search331_0_0 -> 32 in the cache */
   /* search331_0 -> 1127 in the cache */
   /* search331_1 -> 1013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1127, 1013 },
      -1,
   } },

   /* replace331_0 -> 32 in the cache */
   /* replace331_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a') */
   /* search332_0 -> 1013 in the cache */
   /* search332_1_0 -> 32 in the cache */
   /* search332_1 -> 1127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1013, 1127 },
      -1,
   } },

   /* replace332_0 -> 61 in the cache */
   /* replace332_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0) */
   /* search333_0 -> 113 in the cache */
   /* search333_1_0 -> 32 in the cache */
   /* search333_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_flt,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace333_0 -> 32 in the cache */
   /* replace333_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0) */
   /* search334_0_0_0 -> 32 in the cache */
   /* search334_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 103 },
      -1,
   } },
   /* search334_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_flt,
      -1, 0,
      { 1140, 113 },
      -1,
   } },

   /* replace334_0 -> 32 in the cache */
   /* replace334_1 -> 113 in the cache */
   /* replace334 -> 1139 in the cache */

   /* ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0) */
   /* search335_0 -> 113 in the cache */
   /* search335_1_0 -> 32 in the cache */
   /* search335_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace335_0 -> 32 in the cache */
   /* replace335_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search336_0_0_0 -> 32 in the cache */
   /* search336_0_0 -> 103 in the cache */
   /* search336_0 -> 1140 in the cache */
   /* search336_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1140, 113 },
      -1,
   } },

   /* replace336_0 -> 32 in the cache */
   /* replace336_1 -> 113 in the cache */
   /* replace336 -> 1143 in the cache */

   /* ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a')) */
   /* search337_0_0 -> 32 in the cache */
   /* search337_0_1 -> 113 in the cache */
   /* search337_0 -> 1058 in the cache */
   /* search337_1_0 -> 192 in the cache */
   /* search337_1_1 -> 32 in the cache */
   /* search337_1 -> 991 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1058, 991 },
      -1,
   } },

   /* replace337_0 -> 32 in the cache */
   /* replace337_1_0 -> 32 in the cache */
   /* replace337_1 -> 182 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 32, 182 },
      -1,
   } },

   /* ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b')) */
   /* search338_0_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 650 },
      0,
   } },
   /* search338_1_0 -> 1019 in the cache */
   /* search338_1 -> 1020 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 1147, 1020 },
      -1,
   } },

   /* replace338_0_0 -> 650 in the cache */
   /* replace338_0_1 -> 1019 in the cache */
   /* replace338_0 -> 1023 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 1,
      { 1023 },
      -1,
   } },

   /* ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b'))) */
   /* search339_0_0_0 -> 650 in the cache */
   /* search339_0_0 -> 1147 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 1147 },
      0,
   } },
   /* search339_1_0_0 -> 1019 in the cache */
   /* search339_1_0 -> 1020 in the cache */
   /* search339_1 -> 1027 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 1150, 1027 },
      -1,
   } },

   /* replace339_0_0_0 -> 650 in the cache */
   /* replace339_0_0_1 -> 1019 in the cache */
   /* replace339_0_0 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 1,
      { 1031 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1152 },
      -1,
   } },

   /* ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search340_0_0 -> 650 in the cache */
   /* search340_0 -> 1147 in the cache */
   /* search340_1_0 -> 1019 in the cache */
   /* search340_1 -> 1020 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 1147, 1020 },
      -1,
   } },

   /* replace340_0_0 -> 650 in the cache */
   /* replace340_0_1 -> 1019 in the cache */
   /* replace340_0 -> 1031 in the cache */
   /* replace340 -> 1152 in the cache */

   /* ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b'))) */
   /* search341_0_0_0 -> 650 in the cache */
   /* search341_0_0 -> 1147 in the cache */
   /* search341_0 -> 1150 in the cache */
   /* search341_1_0_0 -> 1019 in the cache */
   /* search341_1_0 -> 1020 in the cache */
   /* search341_1 -> 1027 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 1150, 1027 },
      -1,
   } },

   /* replace341_0_0_0 -> 650 in the cache */
   /* replace341_0_0_1 -> 1019 in the cache */
   /* replace341_0_0 -> 1023 in the cache */
   /* replace341_0 -> 1149 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1149 },
      -1,
   } },

   /* ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0)) */
   /* search342_0_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 650 },
      -1,
   } },
   /* search342_1 -> 711 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 1157, 711 },
      -1,
   } },

   /* replace342_0 -> 650 in the cache */
   /* replace342_1_0 -> 3 in the cache */
   /* replace342_1_1 -> 216 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 3, 216 },
      -1,
   } },
   /* replace342_2_0 -> 3 in the cache */
   /* replace342_2_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      1, 1,
      { 3, 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 1159, 1160 },
      -1,
   } },

   /* ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b') */
   /* search343_0_0 -> 0 in the cache */
   /* search343_0_1_0 -> 3 in the cache */
   /* search343_0_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 0, 978 },
      0,
   } },
   /* search343_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 1162, 205 },
      -1,
   } },

   /* replace343_0 -> 0 in the cache */
   /* replace343_1 -> 3 in the cache */
   /* replace343 -> 940 in the cache */

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search344_0_0_0 -> 32 in the cache */
   /* search344_0_0 -> 103 in the cache */
   /* search344_0 -> 1140 in the cache */
   /* search344_1 -> 113 in the cache */
   /* search344 -> 1144 in the cache */

   /* replace344_0 -> 32 in the cache */
   /* replace344_1 -> 113 in the cache */
   /* replace344 -> 1143 in the cache */

   /* ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search345_0_0 -> 1002 in the cache */
   /* search345_0_1 -> 999 in the cache */
   /* search345_0 -> 1003 in the cache */
   /* search345_1 -> 1002 in the cache */
   /* search345_2 -> 999 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_bcsel,
      -1, 0,
      { 1003, 1002, 999 },
      -1,
   } },

   /* replace345_0 -> 999 in the cache */
   /* replace345_1 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 999, 1002 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search346_0_0 -> 0 in the cache */
   /* search346_0_1 -> 3 in the cache */
   /* search346_0 -> 940 in the cache */
   /* search346_1 -> 3 in the cache */
   /* search346_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_bcsel,
      -1, 0,
      { 940, 3, 0 },
      -1,
   } },

   /* replace346_0 -> 0 in the cache */
   /* replace346_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search347_0_0 -> 0 in the cache */
   /* search347_0_1 -> 3 in the cache */
   /* search347_0 -> 937 in the cache */
   /* search347_1 -> 3 in the cache */
   /* search347_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_bcsel,
      -1, 0,
      { 937, 3, 0 },
      -1,
   } },

   /* replace347_0 -> 0 in the cache */
   /* replace347_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search348_0_0 -> 1002 in the cache */
   /* search348_0_1 -> 999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1002, 999 },
      -1,
   } },
   /* search348_1 -> 1002 in the cache */
   /* search348_2 -> 999 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_bcsel,
      -1, 0,
      { 1170, 1002, 999 },
      -1,
   } },

   /* replace348_0 -> 999 in the cache */
   /* replace348_1 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 999, 1002 },
      -1,
   } },

   /* ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c') */
   /* search349_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search349_1 -> 125 in the cache */
   /* search349_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1173, 125, 127 },
      -1,
   } },

   /* replace349_0_0 -> 32 in the cache */
   /* replace349_0_1 -> 61 in the cache */
   /* replace349_0 -> 1117 in the cache */
   /* replace349_1 -> 125 in the cache */
   /* replace349_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 1117, 125, 127 },
      -1,
   } },

   /* ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b') */
   /* search350_0_0 -> 650 in the cache */
   /* search350_0 -> 1016 in the cache */
   /* search350_1 -> 125 in the cache */
   /* search350_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1016, 125, 127 },
      -1,
   } },

   /* replace350_0 -> 650 in the cache */
   /* replace350_1 -> 127 in the cache */
   /* replace350_2 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 127, 125 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd') */
   /* search351_0 -> 650 in the cache */
   /* search351_1_0 -> 650 in the cache */
   /* search351_1_1 -> 142 in the cache */
   /* search351_1_2 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 142, 144 },
      -1,
   } },
   /* search351_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1178, 145 },
      -1,
   } },

   /* replace351_0 -> 650 in the cache */
   /* replace351_1 -> 142 in the cache */
   /* replace351_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 142, 145 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd') */
   /* search352_0 -> 650 in the cache */
   /* search352_1 -> 142 in the cache */
   /* search352_2_0 -> 650 in the cache */
   /* search352_2_1 -> 144 in the cache */
   /* search352_2_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 142, 1181 },
      -1,
   } },

   /* replace352_0 -> 650 in the cache */
   /* replace352_1 -> 142 in the cache */
   /* replace352_2 -> 145 in the cache */
   /* replace352 -> 1180 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search353_0 -> 650 in the cache */
   /* search353_1_0 -> 1019 in the cache */
   /* search353_1_1 -> 643 in the cache */
   /* search353_1_2 -> 652 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1019, 643, 652 },
      -1,
   } },
   /* search353_2_0 -> 1019 in the cache */
   /* search353_2_1 -> 643 in the cache */
   /* search353_2_2 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1019, 643, 654 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1183, 1184 },
      -1,
   } },

   /* replace353_0 -> 1019 in the cache */
   /* replace353_1 -> 643 in the cache */
   /* replace353_2_0 -> 650 in the cache */
   /* replace353_2_1 -> 652 in the cache */
   /* replace353_2_2 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 652, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1019, 643, 1186 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search354_0 -> 650 in the cache */
   /* search354_1_0 -> 1019 in the cache */
   /* search354_1_1 -> 643 in the cache */
   /* search354_1_2 -> 652 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1019, 643, 652 },
      0,
   } },
   /* search354_2_0 -> 1019 in the cache */
   /* search354_2_1 -> 643 in the cache */
   /* search354_2_2 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1019, 643, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1188, 1189 },
      -1,
   } },

   /* replace354_0 -> 1019 in the cache */
   /* replace354_1 -> 643 in the cache */
   /* replace354_2_0 -> 650 in the cache */
   /* replace354_2_1 -> 652 in the cache */
   /* replace354_2_2 -> 654 in the cache */
   /* replace354_2 -> 1186 in the cache */
   /* replace354 -> 1187 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search355_0 -> 650 in the cache */
   /* search355_1_0 -> 1019 in the cache */
   /* search355_1_1 -> 144 in the cache */
   /* search355_1_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1019, 144, 145 },
      -1,
   } },
   /* search355_2_0 -> 1019 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search355_2_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1019, 1192, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1191, 1193 },
      -1,
   } },

   /* replace355_0 -> 1019 in the cache */
   /* replace355_1_0 -> 650 in the cache */
   /* replace355_1_1 -> 144 in the cache */
   /* replace355_1_2 -> 1192 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 144, 1192 },
      -1,
   } },
   /* replace355_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1019, 1195, 145 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search356_0 -> 650 in the cache */
   /* search356_1_0 -> 1019 in the cache */
   /* search356_1_1 -> 144 in the cache */
   /* search356_1_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1019, 144, 145 },
      0,
   } },
   /* search356_2_0 -> 1019 in the cache */
   /* search356_2_1 -> 1192 in the cache */
   /* search356_2_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1019, 1192, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1197, 1198 },
      -1,
   } },

   /* replace356_0 -> 1019 in the cache */
   /* replace356_1_0 -> 650 in the cache */
   /* replace356_1_1 -> 144 in the cache */
   /* replace356_1_2 -> 1192 in the cache */
   /* replace356_1 -> 1195 in the cache */
   /* replace356_2 -> 145 in the cache */
   /* replace356 -> 1196 in the cache */

   /* ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b') */
   /* search357_0 -> 650 in the cache */
   /* search357_1 -> 1121 in the cache */
   /* search357_2 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1121, 1019 },
      -1,
   } },

   /* replace357_0 -> 650 in the cache */
   /* replace357_1 -> 1019 in the cache */
   /* replace357 -> 1023 in the cache */

   /* ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b') */
   /* search358_0 -> 650 in the cache */
   /* search358_1 -> 650 in the cache */
   /* search358_2 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 650, 1019 },
      -1,
   } },

   /* replace358_0 -> 650 in the cache */
   /* replace358_1 -> 1019 in the cache */
   /* replace358 -> 1023 in the cache */

   /* ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b') */
   /* search359_0 -> 650 in the cache */
   /* search359_1 -> 1019 in the cache */
   /* search359_2 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1019, 968 },
      -1,
   } },

   /* replace359_0 -> 650 in the cache */
   /* replace359_1 -> 1019 in the cache */
   /* replace359 -> 1031 in the cache */

   /* ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b') */
   /* search360_0 -> 650 in the cache */
   /* search360_1 -> 1019 in the cache */
   /* search360_2 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1019, 650 },
      -1,
   } },

   /* replace360_0 -> 650 in the cache */
   /* replace360_1 -> 1019 in the cache */
   /* replace360 -> 1031 in the cache */

   /* ('~fmin', 'a', 'a') => a */
   /* search361_0 -> 32 in the cache */
   /* search361_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace361 -> 32 in the cache */

   /* ('~fmax', 'a', 'a') => a */
   /* search362_0 -> 32 in the cache */
   /* search362_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace362 -> 32 in the cache */

   /* ('imin', 'a', 'a') => a */
   /* search363_0 -> 32 in the cache */
   /* search363_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace363 -> 32 in the cache */

   /* ('imax', 'a', 'a') => a */
   /* search364_0 -> 32 in the cache */
   /* search364_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace364 -> 32 in the cache */

   /* ('umin', 'a', 'a') => a */
   /* search365_0 -> 32 in the cache */
   /* search365_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_umin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace365 -> 32 in the cache */

   /* ('umin', 'a', 0) => 0 */
   /* search366_0 -> 32 in the cache */
   /* search366_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_umin,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace366 -> 61 in the cache */

   /* ('umin', 'a', -1) => a */
   /* search367_0 -> 32 in the cache */
   /* search367_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_umin,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace367 -> 32 in the cache */

   /* ('umax', 'a', 'a') => a */
   /* search368_0 -> 32 in the cache */
   /* search368_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_umax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace368 -> 32 in the cache */

   /* ('umax', 'a', 0) => a */
   /* search369_0 -> 32 in the cache */
   /* search369_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_umax,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace369 -> 32 in the cache */

   /* ('umax', 'a', -1) => -1 */
   /* search370_0 -> 32 in the cache */
   /* search370_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_umax,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace370 -> 63 in the cache */

   /* ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b') */
   /* search371_0_0 -> 0 in the cache */
   /* search371_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search371_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      0, 2,
      { 1214, 3 },
      -1,
   } },

   /* replace371_0 -> 0 in the cache */
   /* replace371_1 -> 3 in the cache */
   /* replace371 -> 1167 in the cache */

   /* ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b') */
   /* search372_0_0 -> 0 in the cache */
   /* search372_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_umax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search372_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_umax,
      0, 2,
      { 1216, 3 },
      -1,
   } },

   /* replace372_0 -> 0 in the cache */
   /* replace372_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_umax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b') */
   /* search373_0_0 -> 0 in the cache */
   /* search373_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search373_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imax,
      0, 2,
      { 1219, 3 },
      -1,
   } },

   /* replace373_0 -> 0 in the cache */
   /* replace373_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b') */
   /* search374_0_0 -> 0 in the cache */
   /* search374_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search374_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      0, 2,
      { 1222, 3 },
      -1,
   } },

   /* replace374_0 -> 0 in the cache */
   /* replace374_1 -> 3 in the cache */
   /* replace374 -> 1169 in the cache */

   /* ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b') */
   /* search375_0_0 -> 0 in the cache */
   /* search375_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_umin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search375_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_umin,
      0, 2,
      { 1224, 3 },
      -1,
   } },

   /* replace375_0 -> 0 in the cache */
   /* replace375_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_umin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b') */
   /* search376_0_0 -> 0 in the cache */
   /* search376_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search376_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imin,
      0, 2,
      { 1227, 3 },
      -1,
   } },

   /* replace376_0 -> 0 in the cache */
   /* replace376_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c') */
   /* search377_0_0_0 -> 124 in the cache */
   /* search377_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search377_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmax,
      1, 2,
      { 1230, 127 },
      -1,
   } },
   /* search377_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmax,
      0, 3,
      { 1231, 124 },
      -1,
   } },

   /* replace377_0_0 -> 124 in the cache */
   /* replace377_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace377_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmax,
      0, 2,
      { 1233, 127 },
      -1,
   } },

   /* ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c') */
   /* search378_0_0_0 -> 124 in the cache */
   /* search378_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search378_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umax,
      1, 2,
      { 1235, 127 },
      -1,
   } },
   /* search378_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umax,
      0, 3,
      { 1236, 124 },
      -1,
   } },

   /* replace378_0_0 -> 124 in the cache */
   /* replace378_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace378_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umax,
      0, 2,
      { 1238, 127 },
      -1,
   } },

   /* ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c') */
   /* search379_0_0_0 -> 124 in the cache */
   /* search379_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search379_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imax,
      1, 2,
      { 1240, 127 },
      -1,
   } },
   /* search379_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imax,
      0, 3,
      { 1241, 124 },
      -1,
   } },

   /* replace379_0_0 -> 124 in the cache */
   /* replace379_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace379_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imax,
      0, 2,
      { 1243, 127 },
      -1,
   } },

   /* ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c') */
   /* search380_0_0_0 -> 124 in the cache */
   /* search380_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search380_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmin,
      1, 2,
      { 1245, 127 },
      -1,
   } },
   /* search380_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmin,
      0, 3,
      { 1246, 124 },
      -1,
   } },

   /* replace380_0_0 -> 124 in the cache */
   /* replace380_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace380_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmin,
      0, 2,
      { 1248, 127 },
      -1,
   } },

   /* ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c') */
   /* search381_0_0_0 -> 124 in the cache */
   /* search381_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search381_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umin,
      1, 2,
      { 1250, 127 },
      -1,
   } },
   /* search381_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umin,
      0, 3,
      { 1251, 124 },
      -1,
   } },

   /* replace381_0_0 -> 124 in the cache */
   /* replace381_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace381_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umin,
      0, 2,
      { 1253, 127 },
      -1,
   } },

   /* ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c') */
   /* search382_0_0_0 -> 124 in the cache */
   /* search382_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search382_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imin,
      1, 2,
      { 1255, 127 },
      -1,
   } },
   /* search382_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imin,
      0, 3,
      { 1256, 124 },
      -1,
   } },

   /* replace382_0_0 -> 124 in the cache */
   /* replace382_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace382_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imin,
      0, 2,
      { 1258, 127 },
      -1,
   } },

   /* ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b') */
   /* search383_0_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_b2i8,
      -1, 0,
      { 650 },
      -1,
   } },
   /* search383_1_0 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_b2i8,
      -1, 0,
      { 1019 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1260, 1261 },
      -1,
   } },

   /* replace383_0 -> 650 in the cache */
   /* replace383_1 -> 1019 in the cache */
   /* replace383 -> 1047 in the cache */

   /* ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b') */
   /* search384_0_0 -> 650 in the cache */
   /* search384_0 -> 1260 in the cache */
   /* search384_1_0 -> 1019 in the cache */
   /* search384_1 -> 1261 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1260, 1261 },
      -1,
   } },

   /* replace384_0 -> 650 in the cache */
   /* replace384_1 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 650, 1019 },
      -1,
   } },

   /* ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search385_0_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2i16,
      -1, 0,
      { 650 },
      -1,
   } },
   /* search385_1_0 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2i16,
      -1, 0,
      { 1019 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1265, 1266 },
      -1,
   } },

   /* replace385_0 -> 650 in the cache */
   /* replace385_1 -> 1019 in the cache */
   /* replace385 -> 1047 in the cache */

   /* ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b') */
   /* search386_0_0 -> 650 in the cache */
   /* search386_0 -> 1265 in the cache */
   /* search386_1_0 -> 1019 in the cache */
   /* search386_1 -> 1266 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1265, 1266 },
      -1,
   } },

   /* replace386_0 -> 650 in the cache */
   /* replace386_1 -> 1019 in the cache */
   /* replace386 -> 1264 in the cache */

   /* ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search387_0_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 650 },
      -1,
   } },
   /* search387_1_0 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 1019 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1269, 1270 },
      -1,
   } },

   /* replace387_0 -> 650 in the cache */
   /* replace387_1 -> 1019 in the cache */
   /* replace387 -> 1047 in the cache */

   /* ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b') */
   /* search388_0_0 -> 650 in the cache */
   /* search388_0 -> 1269 in the cache */
   /* search388_1_0 -> 1019 in the cache */
   /* search388_1 -> 1270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1269, 1270 },
      -1,
   } },

   /* replace388_0 -> 650 in the cache */
   /* replace388_1 -> 1019 in the cache */
   /* replace388 -> 1264 in the cache */

   /* ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search389_0_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2i64,
      -1, 0,
      { 650 },
      -1,
   } },
   /* search389_1_0 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2i64,
      -1, 0,
      { 1019 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1273, 1274 },
      -1,
   } },

   /* replace389_0 -> 650 in the cache */
   /* replace389_1 -> 1019 in the cache */
   /* replace389 -> 1047 in the cache */

   /* ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b') */
   /* search390_0_0 -> 650 in the cache */
   /* search390_0 -> 1273 in the cache */
   /* search390_1_0 -> 1019 in the cache */
   /* search390_1 -> 1274 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1273, 1274 },
      -1,
   } },

   /* replace390_0 -> 650 in the cache */
   /* replace390_1 -> 1019 in the cache */
   /* replace390 -> 1264 in the cache */

   /* ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search391_0_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2f16,
      -1, 0,
      { 650 },
      -1,
   } },
   /* search391_1_0 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2f16,
      -1, 0,
      { 1019 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1277, 1278 },
      -1,
   } },

   /* replace391_0 -> 650 in the cache */
   /* replace391_1 -> 1019 in the cache */
   /* replace391 -> 1047 in the cache */

   /* ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b') */
   /* search392_0_0 -> 650 in the cache */
   /* search392_0 -> 1277 in the cache */
   /* search392_1_0 -> 1019 in the cache */
   /* search392_1 -> 1278 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1277, 1278 },
      -1,
   } },

   /* replace392_0 -> 650 in the cache */
   /* replace392_1 -> 1019 in the cache */
   /* replace392 -> 1264 in the cache */

   /* ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search393_0_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2f32,
      -1, 0,
      { 650 },
      -1,
   } },
   /* search393_1_0 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2f32,
      -1, 0,
      { 1019 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1281, 1282 },
      -1,
   } },

   /* replace393_0 -> 650 in the cache */
   /* replace393_1 -> 1019 in the cache */
   /* replace393 -> 1047 in the cache */

   /* ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b') */
   /* search394_0_0 -> 650 in the cache */
   /* search394_0 -> 1281 in the cache */
   /* search394_1_0 -> 1019 in the cache */
   /* search394_1 -> 1282 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1281, 1282 },
      -1,
   } },

   /* replace394_0 -> 650 in the cache */
   /* replace394_1 -> 1019 in the cache */
   /* replace394 -> 1264 in the cache */

   /* ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search395_0_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2f64,
      -1, 0,
      { 650 },
      -1,
   } },
   /* search395_1_0 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2f64,
      -1, 0,
      { 1019 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1285, 1286 },
      -1,
   } },

   /* replace395_0 -> 650 in the cache */
   /* replace395_1 -> 1019 in the cache */
   /* replace395 -> 1047 in the cache */

   /* ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b') */
   /* search396_0_0 -> 650 in the cache */
   /* search396_0 -> 1285 in the cache */
   /* search396_1_0 -> 1019 in the cache */
   /* search396_1 -> 1286 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1285, 1286 },
      -1,
   } },

   /* replace396_0 -> 650 in the cache */
   /* replace396_1 -> 1019 in the cache */
   /* replace396 -> 1264 in the cache */

   /* ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0) */
   /* search397_0 -> 6 in the cache */
   /* search397_1_0_0 -> 6 in the cache */
   /* search397_1_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 1289 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_iand,
      0, 1,
      { 6, 1290 },
      -1,
   } },

   /* replace397_0 -> 6 in the cache */
   /* replace397_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_imax,
      0, 1,
      { 6, 726 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0) */
   /* search398_0_0 -> 6 in the cache */
   /* search398_0_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_iand,
      1, 1,
      { 6, 7 },
      -1,
   } },
   /* search398_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 1293, 726 },
      -1,
   } },

   /* replace398_0 -> 6 in the cache */
   /* replace398_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 6, 726 },
      -1,
   } },

   /* ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0) */
   /* search399_0_0 -> 6 in the cache */
   /* search399_0_1 -> 7 in the cache */
   /* search399_0 -> 1293 in the cache */
   /* search399_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 1293, 7 },
      -1,
   } },

   /* replace399_0 -> 6 in the cache */
   /* replace399_1 -> 726 in the cache */
   /* replace399 -> 1295 in the cache */

   /* ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0) */
   /* search400_0_0 -> 6 in the cache */
   /* search400_0_1 -> 7 in the cache */
   /* search400_0 -> 1293 in the cache */
   /* search400_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 1293, 726 },
      -1,
   } },

   /* replace400_0 -> 6 in the cache */
   /* replace400_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 6, 726 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0) */
   /* search401_0_0 -> 6 in the cache */
   /* search401_0_1 -> 7 in the cache */
   /* search401_0 -> 1293 in the cache */
   /* search401_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 1293, 7 },
      -1,
   } },

   /* replace401_0 -> 6 in the cache */
   /* replace401_1 -> 726 in the cache */
   /* replace401 -> 1298 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search402_0_0 -> 6 in the cache */
   /* search402_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   /* search402_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1300, 726 },
      -1,
   } },

   /* replace402_0 -> 6 in the cache */
   /* replace402_1 -> 726 in the cache */
   /* replace402 -> 1298 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search403_0_0 -> 6 in the cache */
   /* search403_0_1 -> 9 in the cache */
   /* search403_0 -> 1300 in the cache */
   /* search403_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1300, 726 },
      -1,
   } },

   /* replace403_0 -> 6 in the cache */
   /* replace403_1 -> 726 in the cache */
   /* replace403 -> 1295 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0) */
   /* search404_0_0 -> 6 in the cache */
   /* search404_0_1 -> 9 in the cache */
   /* search404_0 -> 1300 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1300, 1303 },
      -1,
   } },

   /* replace404_0 -> 6 in the cache */
   /* replace404_1 -> 726 in the cache */
   /* replace404 -> 1298 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0) */
   /* search405_0_0 -> 6 in the cache */
   /* search405_0_1 -> 9 in the cache */
   /* search405_0 -> 1300 in the cache */
   /* search405_1 -> 1303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1300, 1303 },
      -1,
   } },

   /* replace405_0 -> 6 in the cache */
   /* replace405_1 -> 726 in the cache */
   /* replace405 -> 1295 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search406_0_0 -> 6 in the cache */
   /* search406_0_1 -> 9 in the cache */
   /* search406_0 -> 1289 in the cache */
   /* search406_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1289, 726 },
      -1,
   } },

   /* replace406_0 -> 6 in the cache */
   /* replace406_1 -> 726 in the cache */
   /* replace406 -> 1298 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search407_0_0 -> 6 in the cache */
   /* search407_0_1 -> 9 in the cache */
   /* search407_0 -> 1289 in the cache */
   /* search407_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1289, 726 },
      -1,
   } },

   /* replace407_0 -> 6 in the cache */
   /* replace407_1 -> 726 in the cache */
   /* replace407 -> 1295 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0) */
   /* search408_0_0 -> 6 in the cache */
   /* search408_0_1 -> 9 in the cache */
   /* search408_0 -> 1289 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1289, 1308 },
      -1,
   } },

   /* replace408_0 -> 6 in the cache */
   /* replace408_1 -> 726 in the cache */
   /* replace408 -> 1298 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0) */
   /* search409_0_0 -> 6 in the cache */
   /* search409_0_1 -> 9 in the cache */
   /* search409_0 -> 1289 in the cache */
   /* search409_1 -> 1308 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1289, 1308 },
      -1,
   } },

   /* replace409_0 -> 6 in the cache */
   /* replace409_1 -> 726 in the cache */
   /* replace409 -> 1295 in the cache */

   /* ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0) */
   /* search410_0 -> 11 in the cache */
   /* search410_1_0_0 -> 11 in the cache */
   /* search410_1_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 1311 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 11, 1312 },
      -1,
   } },

   /* replace410_0 -> 11 in the cache */
   /* replace410_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_imax,
      0, 1,
      { 11, 748 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0) */
   /* search411_0_0 -> 11 in the cache */
   /* search411_0_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      1, 1,
      { 11, 12 },
      -1,
   } },
   /* search411_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 1315, 748 },
      -1,
   } },

   /* replace411_0 -> 11 in the cache */
   /* replace411_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 11, 748 },
      -1,
   } },

   /* ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0) */
   /* search412_0_0 -> 11 in the cache */
   /* search412_0_1 -> 12 in the cache */
   /* search412_0 -> 1315 in the cache */
   /* search412_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 1315, 12 },
      -1,
   } },

   /* replace412_0 -> 11 in the cache */
   /* replace412_1 -> 748 in the cache */
   /* replace412 -> 1317 in the cache */

   /* ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0) */
   /* search413_0_0 -> 11 in the cache */
   /* search413_0_1 -> 12 in the cache */
   /* search413_0 -> 1315 in the cache */
   /* search413_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 1315, 748 },
      -1,
   } },

   /* replace413_0 -> 11 in the cache */
   /* replace413_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 11, 748 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0) */
   /* search414_0_0 -> 11 in the cache */
   /* search414_0_1 -> 12 in the cache */
   /* search414_0 -> 1315 in the cache */
   /* search414_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 1315, 12 },
      -1,
   } },

   /* replace414_0 -> 11 in the cache */
   /* replace414_1 -> 748 in the cache */
   /* replace414 -> 1320 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search415_0_0 -> 11 in the cache */
   /* search415_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   /* search415_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1322, 748 },
      -1,
   } },

   /* replace415_0 -> 11 in the cache */
   /* replace415_1 -> 748 in the cache */
   /* replace415 -> 1320 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search416_0_0 -> 11 in the cache */
   /* search416_0_1 -> 14 in the cache */
   /* search416_0 -> 1322 in the cache */
   /* search416_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1322, 748 },
      -1,
   } },

   /* replace416_0 -> 11 in the cache */
   /* replace416_1 -> 748 in the cache */
   /* replace416 -> 1317 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0) */
   /* search417_0_0 -> 11 in the cache */
   /* search417_0_1 -> 14 in the cache */
   /* search417_0 -> 1322 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1322, 1325 },
      -1,
   } },

   /* replace417_0 -> 11 in the cache */
   /* replace417_1 -> 748 in the cache */
   /* replace417 -> 1320 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0) */
   /* search418_0_0 -> 11 in the cache */
   /* search418_0_1 -> 14 in the cache */
   /* search418_0 -> 1322 in the cache */
   /* search418_1 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1322, 1325 },
      -1,
   } },

   /* replace418_0 -> 11 in the cache */
   /* replace418_1 -> 748 in the cache */
   /* replace418 -> 1317 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search419_0_0 -> 11 in the cache */
   /* search419_0_1 -> 14 in the cache */
   /* search419_0 -> 1311 in the cache */
   /* search419_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1311, 748 },
      -1,
   } },

   /* replace419_0 -> 11 in the cache */
   /* replace419_1 -> 748 in the cache */
   /* replace419 -> 1320 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search420_0_0 -> 11 in the cache */
   /* search420_0_1 -> 14 in the cache */
   /* search420_0 -> 1311 in the cache */
   /* search420_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1311, 748 },
      -1,
   } },

   /* replace420_0 -> 11 in the cache */
   /* replace420_1 -> 748 in the cache */
   /* replace420 -> 1317 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0) */
   /* search421_0_0 -> 11 in the cache */
   /* search421_0_1 -> 14 in the cache */
   /* search421_0 -> 1311 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1311, 1330 },
      -1,
   } },

   /* replace421_0 -> 11 in the cache */
   /* replace421_1 -> 748 in the cache */
   /* replace421 -> 1320 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0) */
   /* search422_0_0 -> 11 in the cache */
   /* search422_0_1 -> 14 in the cache */
   /* search422_0 -> 1311 in the cache */
   /* search422_1 -> 1330 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1311, 1330 },
      -1,
   } },

   /* replace422_0 -> 11 in the cache */
   /* replace422_1 -> 748 in the cache */
   /* replace422 -> 1317 in the cache */

   /* ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0) */
   /* search423_0 -> 16 in the cache */
   /* search423_1_0_0 -> 16 in the cache */
   /* search423_1_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 1333 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 16, 1334 },
      -1,
   } },

   /* replace423_0 -> 16 in the cache */
   /* replace423_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imax,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0) */
   /* search424_0_0 -> 16 in the cache */
   /* search424_0_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 16, 17 },
      -1,
   } },
   /* search424_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 1337, 120 },
      -1,
   } },

   /* replace424_0 -> 16 in the cache */
   /* replace424_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0) */
   /* search425_0_0 -> 16 in the cache */
   /* search425_0_1 -> 17 in the cache */
   /* search425_0 -> 1337 in the cache */
   /* search425_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 1337, 17 },
      -1,
   } },

   /* replace425_0 -> 16 in the cache */
   /* replace425_1 -> 120 in the cache */
   /* replace425 -> 1339 in the cache */

   /* ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0) */
   /* search426_0_0 -> 16 in the cache */
   /* search426_0_1 -> 17 in the cache */
   /* search426_0 -> 1337 in the cache */
   /* search426_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 1337, 120 },
      -1,
   } },

   /* replace426_0 -> 16 in the cache */
   /* replace426_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0) */
   /* search427_0_0 -> 16 in the cache */
   /* search427_0_1 -> 17 in the cache */
   /* search427_0 -> 1337 in the cache */
   /* search427_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 1337, 17 },
      -1,
   } },

   /* replace427_0 -> 16 in the cache */
   /* replace427_1 -> 120 in the cache */
   /* replace427 -> 1342 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search428_0_0 -> 16 in the cache */
   /* search428_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   /* search428_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1344, 120 },
      -1,
   } },

   /* replace428_0 -> 16 in the cache */
   /* replace428_1 -> 120 in the cache */
   /* replace428 -> 1342 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search429_0_0 -> 16 in the cache */
   /* search429_0_1 -> 19 in the cache */
   /* search429_0 -> 1344 in the cache */
   /* search429_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1344, 120 },
      -1,
   } },

   /* replace429_0 -> 16 in the cache */
   /* replace429_1 -> 120 in the cache */
   /* replace429 -> 1339 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0) */
   /* search430_0_0 -> 16 in the cache */
   /* search430_0_1 -> 19 in the cache */
   /* search430_0 -> 1344 in the cache */
   /* search430_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1344, 316 },
      -1,
   } },

   /* replace430_0 -> 16 in the cache */
   /* replace430_1 -> 120 in the cache */
   /* replace430 -> 1342 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0) */
   /* search431_0_0 -> 16 in the cache */
   /* search431_0_1 -> 19 in the cache */
   /* search431_0 -> 1344 in the cache */
   /* search431_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1344, 316 },
      -1,
   } },

   /* replace431_0 -> 16 in the cache */
   /* replace431_1 -> 120 in the cache */
   /* replace431 -> 1339 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search432_0_0 -> 16 in the cache */
   /* search432_0_1 -> 19 in the cache */
   /* search432_0 -> 1333 in the cache */
   /* search432_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1333, 120 },
      -1,
   } },

   /* replace432_0 -> 16 in the cache */
   /* replace432_1 -> 120 in the cache */
   /* replace432 -> 1342 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search433_0_0 -> 16 in the cache */
   /* search433_0_1 -> 19 in the cache */
   /* search433_0 -> 1333 in the cache */
   /* search433_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1333, 120 },
      -1,
   } },

   /* replace433_0 -> 16 in the cache */
   /* replace433_1 -> 120 in the cache */
   /* replace433 -> 1339 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0) */
   /* search434_0_0 -> 16 in the cache */
   /* search434_0_1 -> 19 in the cache */
   /* search434_0 -> 1333 in the cache */
   /* search434_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1333, 122 },
      -1,
   } },

   /* replace434_0 -> 16 in the cache */
   /* replace434_1 -> 120 in the cache */
   /* replace434 -> 1342 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0) */
   /* search435_0_0 -> 16 in the cache */
   /* search435_0_1 -> 19 in the cache */
   /* search435_0 -> 1333 in the cache */
   /* search435_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1333, 122 },
      -1,
   } },

   /* replace435_0 -> 16 in the cache */
   /* replace435_1 -> 120 in the cache */
   /* replace435 -> 1339 in the cache */

   /* ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0) */
   /* search436_0 -> 21 in the cache */
   /* search436_1_0_0 -> 21 in the cache */
   /* search436_1_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 1353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iand,
      0, 1,
      { 21, 1354 },
      -1,
   } },

   /* replace436_0 -> 21 in the cache */
   /* replace436_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_imax,
      0, 1,
      { 21, 791 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0) */
   /* search437_0_0 -> 21 in the cache */
   /* search437_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iand,
      1, 1,
      { 21, 22 },
      -1,
   } },
   /* search437_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 1357, 791 },
      -1,
   } },

   /* replace437_0 -> 21 in the cache */
   /* replace437_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 21, 791 },
      -1,
   } },

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0) */
   /* search438_0_0 -> 21 in the cache */
   /* search438_0_1 -> 22 in the cache */
   /* search438_0 -> 1357 in the cache */
   /* search438_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 1357, 22 },
      -1,
   } },

   /* replace438_0 -> 21 in the cache */
   /* replace438_1 -> 791 in the cache */
   /* replace438 -> 1359 in the cache */

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0) */
   /* search439_0_0 -> 21 in the cache */
   /* search439_0_1 -> 22 in the cache */
   /* search439_0 -> 1357 in the cache */
   /* search439_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 1357, 791 },
      -1,
   } },

   /* replace439_0 -> 21 in the cache */
   /* replace439_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 21, 791 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0) */
   /* search440_0_0 -> 21 in the cache */
   /* search440_0_1 -> 22 in the cache */
   /* search440_0 -> 1357 in the cache */
   /* search440_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 1357, 22 },
      -1,
   } },

   /* replace440_0 -> 21 in the cache */
   /* replace440_1 -> 791 in the cache */
   /* replace440 -> 1362 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search441_0_0 -> 21 in the cache */
   /* search441_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   /* search441_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1364, 791 },
      -1,
   } },

   /* replace441_0 -> 21 in the cache */
   /* replace441_1 -> 791 in the cache */
   /* replace441 -> 1362 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search442_0_0 -> 21 in the cache */
   /* search442_0_1 -> 24 in the cache */
   /* search442_0 -> 1364 in the cache */
   /* search442_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1364, 791 },
      -1,
   } },

   /* replace442_0 -> 21 in the cache */
   /* replace442_1 -> 791 in the cache */
   /* replace442 -> 1359 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0) */
   /* search443_0_0 -> 21 in the cache */
   /* search443_0_1 -> 24 in the cache */
   /* search443_0 -> 1364 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1364, 1367 },
      -1,
   } },

   /* replace443_0 -> 21 in the cache */
   /* replace443_1 -> 791 in the cache */
   /* replace443 -> 1362 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0) */
   /* search444_0_0 -> 21 in the cache */
   /* search444_0_1 -> 24 in the cache */
   /* search444_0 -> 1364 in the cache */
   /* search444_1 -> 1367 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1364, 1367 },
      -1,
   } },

   /* replace444_0 -> 21 in the cache */
   /* replace444_1 -> 791 in the cache */
   /* replace444 -> 1359 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search445_0_0 -> 21 in the cache */
   /* search445_0_1 -> 24 in the cache */
   /* search445_0 -> 1353 in the cache */
   /* search445_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1353, 791 },
      -1,
   } },

   /* replace445_0 -> 21 in the cache */
   /* replace445_1 -> 791 in the cache */
   /* replace445 -> 1362 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search446_0_0 -> 21 in the cache */
   /* search446_0_1 -> 24 in the cache */
   /* search446_0 -> 1353 in the cache */
   /* search446_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1353, 791 },
      -1,
   } },

   /* replace446_0 -> 21 in the cache */
   /* replace446_1 -> 791 in the cache */
   /* replace446 -> 1359 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0) */
   /* search447_0_0 -> 21 in the cache */
   /* search447_0_1 -> 24 in the cache */
   /* search447_0 -> 1353 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1353, 1372 },
      -1,
   } },

   /* replace447_0 -> 21 in the cache */
   /* replace447_1 -> 791 in the cache */
   /* replace447 -> 1362 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0) */
   /* search448_0_0 -> 21 in the cache */
   /* search448_0_1 -> 24 in the cache */
   /* search448_0 -> 1353 in the cache */
   /* search448_1 -> 1372 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1353, 1372 },
      -1,
   } },

   /* replace448_0 -> 21 in the cache */
   /* replace448_1 -> 791 in the cache */
   /* replace448 -> 1359 in the cache */

   /* ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a')) */
   /* search449_0 -> 32 in the cache */
   /* search449_1_0 -> 32 in the cache */
   /* search449_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace449_0_0 -> 32 in the cache */
   /* replace449_0 -> 103 in the cache */
   /* replace449 -> 1140 in the cache */

   /* ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a')) */
   /* search450_0 -> 32 in the cache */
   /* search450_1_0 -> 32 in the cache */
   /* search450_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imin,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace450_0_0 -> 32 in the cache */
   /* replace450_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 106 },
      -1,
   } },

   /* ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a')) */
   /* search451_0 -> 32 in the cache */
   /* search451_1_0_0 -> 32 in the cache */
   /* search451_1_0 -> 103 in the cache */
   /* search451_1 -> 1140 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 32, 1140 },
      -1,
   } },

   /* replace451_0_0 -> 32 in the cache */
   /* replace451_0 -> 103 in the cache */
   /* replace451 -> 1140 in the cache */

   /* ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a')) */
   /* search452_0 -> 32 in the cache */
   /* search452_1_0_0 -> 32 in the cache */
   /* search452_1_0 -> 106 in the cache */
   /* search452_1 -> 1377 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imin,
      0, 1,
      { 32, 1377 },
      -1,
   } },

   /* replace452_0_0 -> 32 in the cache */
   /* replace452_0 -> 106 in the cache */
   /* replace452 -> 1377 in the cache */

   /* ('~fmin', 'a', ('fabs', 'a')) => a */
   /* search453_0 -> 32 in the cache */
   /* search453_1_0 -> 32 in the cache */
   /* search453_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmin,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace453 -> 32 in the cache */

   /* ('imin', 'a', ('iabs', 'a')) => a */
   /* search454_0 -> 32 in the cache */
   /* search454_1_0 -> 32 in the cache */
   /* search454_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imin,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace454 -> 32 in the cache */

   /* ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a */
   /* search455_0 -> 32 in the cache */
   /* search455_1_0_0 -> 32 in the cache */
   /* search455_1_0 -> 103 in the cache */
   /* search455_1 -> 1140 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmax,
      0, 1,
      { 32, 1140 },
      -1,
   } },

   /* replace455 -> 32 in the cache */

   /* ('imax', 'a', ('ineg', ('iabs', 'a'))) => a */
   /* search456_0 -> 32 in the cache */
   /* search456_1_0_0 -> 32 in the cache */
   /* search456_1_0 -> 106 in the cache */
   /* search456_1 -> 1377 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imax,
      0, 1,
      { 32, 1377 },
      -1,
   } },

   /* replace456 -> 32 in the cache */

   /* ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a') */
   /* search457_0 -> 32 in the cache */
   /* search457_1_0 -> 32 in the cache */
   /* search457_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace457_0 -> 32 in the cache */
   /* replace457 -> 103 in the cache */

   /* ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a') */
   /* search458_0 -> 32 in the cache */
   /* search458_1_0 -> 32 in the cache */
   /* search458_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imax,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace458_0 -> 32 in the cache */
   /* replace458 -> 106 in the cache */

   /* ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a') */
   /* search459_0 -> 32 in the cache */
   /* search459_1_0 -> 32 in the cache */
   /* search459_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace459_0 -> 32 in the cache */
   /* replace459 -> 103 in the cache */

   /* ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a') */
   /* search460_0 -> 32 in the cache */
   /* search460_1_0 -> 32 in the cache */
   /* search460_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imax,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace460_0 -> 32 in the cache */
   /* replace460 -> 106 in the cache */

   /* ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a') */
   /* search461_0_0 -> 32 in the cache */
   /* search461_0 -> 103 in the cache */
   /* search461_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmax,
      0, 1,
      { 103, 113 },
      -1,
   } },

   /* replace461_0 -> 32 in the cache */
   /* replace461 -> 103 in the cache */

   /* ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a') */
   /* search462_0_0 -> 32 in the cache */
   /* search462_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search462_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmin,
      0, 2,
      { 1389, 192 },
      -1,
   } },

   /* replace462_0 -> 32 in the cache */
   /* replace462 -> 182 in the cache */

   /* ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a') */
   /* search463_0_0 -> 32 in the cache */
   /* search463_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmin,
      1, 1,
      { 32, 192 },
      -1,
   } },
   /* search463_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmax,
      0, 2,
      { 1391, 113 },
      -1,
   } },

   /* replace463_0 -> 32 in the cache */
   /* replace463 -> 182 in the cache */

   /* ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search464_0_0 -> 32 in the cache */
   /* search464_0_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 32, 196 },
      -1,
   } },
   /* search464_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmin,
      0, 2,
      { 1393, 113 },
      -1,
   } },

   /* replace464_0_0_0 -> 32 in the cache */
   /* replace464_0_0 -> 98 in the cache */
   /* replace464_0 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 183 },
      -1,
   } },

   /* ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search465_0_0 -> 32 in the cache */
   /* search465_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmin,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search465_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmax,
      0, 2,
      { 1396, 196 },
      -1,
   } },

   /* replace465_0_0_0 -> 32 in the cache */
   /* replace465_0_0 -> 98 in the cache */
   /* replace465_0 -> 183 in the cache */
   /* replace465 -> 1395 in the cache */

   /* ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a')) */
   /* search466_0_0 -> 32 in the cache */
   /* search466_0 -> 199 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 199 },
      -1,
   } },

   /* replace466_0_0 -> 113 in the cache */
   /* replace466_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 1399 },
      -1,
   } },

   /* ('fsat', ('b2f', 'a')) => ('b2f', 'a') */
   /* search467_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 1401 },
      -1,
   } },

   /* replace467_0 -> 32 in the cache */
   /* replace467 -> 1401 in the cache */

   /* ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0) */
   /* search468_0 -> 32 in the cache */
   /* search468 -> 182 in the cache */

   /* replace468_0_0 -> 32 in the cache */
   /* replace468_0_1 -> 113 in the cache */
   /* replace468_0 -> 1389 in the cache */
   /* replace468_1 -> 192 in the cache */
   /* replace468 -> 1390 in the cache */

   /* ('fsat', ('fsat', 'a')) => ('fsat', 'a') */
   /* search469_0_0 -> 32 in the cache */
   /* search469_0 -> 182 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 182 },
      -1,
   } },

   /* replace469_0 -> 32 in the cache */
   /* replace469 -> 182 in the cache */

   /* ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b'))) */
   /* search470_0_0_0 -> 0 in the cache */
   /* search470_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1404 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 1405 },
      -1,
   } },

   /* replace470_0_0_0 -> 0 in the cache */
   /* replace470_0_0 -> 177 in the cache */
   /* replace470_0_1_0 -> 3 in the cache */
   /* replace470_0_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 177, 978 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 1407 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b')) */
   /* search471_0_0_0 -> 0 in the cache */
   /* search471_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1409 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 1410 },
      -1,
   } },

   /* replace471_0_0_0 -> 0 in the cache */
   /* replace471_0_0 -> 177 in the cache */
   /* replace471_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 177, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 1412 },
      -1,
   } },

   /* ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b'))) */
   /* search472_0_0_0 -> 0 in the cache */
   /* search472_0_0_1 -> 3 in the cache */
   /* search472_0_0 -> 1409 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fabs,
      -1, 1,
      { 1409 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 1414 },
      -1,
   } },

   /* replace472_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace472_0_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 1416, 1417 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 1418 },
      -1,
   } },

   /* ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c') */
   /* search473_0_0_0_0 -> 124 in the cache */
   /* search473_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search473_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmin,
      2, 2,
      { 1420, 127 },
      -1,
   } },
   /* search473_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmax,
      1, 3,
      { 1421, 125 },
      -1,
   } },
   /* search473_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmin,
      0, 4,
      { 1422, 127 },
      -1,
   } },

   /* replace473_0_0 -> 124 in the cache */
   /* replace473_0_1 -> 125 in the cache */
   /* replace473_0 -> 1233 in the cache */
   /* replace473_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmin,
      0, 2,
      { 1233, 127 },
      -1,
   } },

   /* ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c') */
   /* search474_0_0_0_0 -> 124 in the cache */
   /* search474_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search474_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imin,
      2, 2,
      { 1425, 127 },
      -1,
   } },
   /* search474_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imax,
      1, 3,
      { 1426, 125 },
      -1,
   } },
   /* search474_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imin,
      0, 4,
      { 1427, 127 },
      -1,
   } },

   /* replace474_0_0 -> 124 in the cache */
   /* replace474_0_1 -> 125 in the cache */
   /* replace474_0 -> 1243 in the cache */
   /* replace474_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imin,
      0, 2,
      { 1243, 127 },
      -1,
   } },

   /* ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c') */
   /* search475_0_0_0_0 -> 124 in the cache */
   /* search475_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search475_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umin,
      2, 2,
      { 1430, 127 },
      -1,
   } },
   /* search475_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umax,
      1, 3,
      { 1431, 125 },
      -1,
   } },
   /* search475_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umin,
      0, 4,
      { 1432, 127 },
      -1,
   } },

   /* replace475_0_0 -> 124 in the cache */
   /* replace475_0_1 -> 125 in the cache */
   /* replace475_0 -> 1238 in the cache */
   /* replace475_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umin,
      0, 2,
      { 1238, 127 },
      -1,
   } },

   /* ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b')) */
   /* search476_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      15,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 1435, 1436 },
      -1,
   } },

   /* replace476_0_0 -> 0 in the cache */
   /* replace476_0_1 -> 3 in the cache */
   /* replace476_0 -> 1167 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 1167 },
      -1,
   } },

   /* ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b')) */
   /* search477_0_0 -> 0 in the cache */
   /* search477_0 -> 1435 in the cache */
   /* search477_1 -> 1436 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_fmin,
      0, 1,
      { 1435, 1436 },
      -1,
   } },

   /* replace477_0_0 -> 0 in the cache */
   /* replace477_0_1 -> 3 in the cache */
   /* replace477_0 -> 1169 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 1169 },
      -1,
   } },

   /* ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a')) */
   /* search478_0_0_0 -> 1002 in the cache */
   /* search478_0_0_1 -> 999 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      1, 1,
      { 1002, 999 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1441 },
      -1,
   } },
   /* search478_1 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      0, 2,
      { 1442, 1002 },
      -1,
   } },

   /* replace478_0_0 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 1002 },
      -1,
   } },
   /* replace478_1_0 -> 999 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 999 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 1444, 1445 },
      -1,
   } },

   /* ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a')) */
   /* search479_0_0_0 -> 1002 in the cache */
   /* search479_0_0_1 -> 999 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 1002, 999 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 1447 },
      -1,
   } },
   /* search479_1 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      0, 2,
      { 1448, 1002 },
      -1,
   } },

   /* replace479_0_0_0 -> 1002 in the cache */
   /* replace479_0_0 -> 1444 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 1444 },
      -1,
   } },
   /* replace479_1_0 -> 999 in the cache */
   /* replace479_1 -> 1445 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 1450, 1445 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 1452 },
      -1,
   } },
   /* search480_0_1 -> 1436 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 1453, 1436 },
      0,
   } },
   /* search480_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      0, 2,
      { 1454, 205 },
      -1,
   } },

   /* replace480_0_0_0 -> 0 in the cache */
   /* replace480_0_0 -> 177 in the cache */
   /* replace480_0_1 -> 3 in the cache */
   /* replace480_0 -> 221 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 221 },
      -1,
   } },

   /* ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255) */
   /* search481_0_0_0 -> 32 in the cache */
   /* search481_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imax,
      1, 1,
      { 32, 61 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imin,
      0, 2,
      { 1457, 1458 },
      -1,
   } },
   /* search481_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_extract_u8,
      -1, 2,
      { 1459, 61 },
      -1,
   } },

   /* replace481_0_0 -> 32 in the cache */
   /* replace481_0_1 -> 61 in the cache */
   /* replace481_0 -> 1457 in the cache */
   /* replace481_1 -> 1458 in the cache */
   /* replace481 -> 1459 in the cache */

   /* ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search482_0_0 -> 124 in the cache */
   /* search482_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search482_1_0 -> 124 in the cache */
   /* search482_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1461, 1462 },
      -1,
   } },

   /* replace482_0 -> 124 in the cache */
   /* replace482_1_0 -> 125 in the cache */
   /* replace482_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, true,
      nir_op_fmax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 124, 1464 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   /* search483_0_0 -> 0 in the cache */
   /* search483_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 0, 609 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search483_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1467, 609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1466, 1468 },
      -1,
   } },

   /* replace483_0_0 -> 0 in the cache */
   /* replace483_0_1 -> 1467 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, true,
      nir_op_fmin,
      0, 1,
      { 0, 1467 },
      -1,
   } },
   /* replace483_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 1470, 609 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search484_0_0 -> 124 in the cache */
   /* search484_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search484_1_0 -> 124 in the cache */
   /* search484_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1472, 1473 },
      -1,
   } },

   /* replace484_0 -> 124 in the cache */
   /* replace484_1_0 -> 125 in the cache */
   /* replace484_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, true,
      nir_op_fmin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 124, 1475 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search485_0_0 -> 0 in the cache */
   /* search485_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 0, 609 },
      0,
   } },
   /* search485_1_0 -> 1467 in the cache */
   /* search485_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1467, 609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1477, 1478 },
      -1,
   } },

   /* replace485_0_0 -> 0 in the cache */
   /* replace485_0_1 -> 1467 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, true,
      nir_op_fmax,
      0, 1,
      { 0, 1467 },
      -1,
   } },
   /* replace485_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 1480, 609 },
      -1,
   } },

   /* ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search486_0_0 -> 124 in the cache */
   /* search486_0_1 -> 223 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 124, 223 },
      -1,
   } },
   /* search486_1_0 -> 124 in the cache */
   /* search486_1_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 124, 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1482, 1483 },
      -1,
   } },

   /* replace486_0 -> 124 in the cache */
   /* replace486_1_0 -> 125 in the cache */
   /* replace486_1_1 -> 127 in the cache */
   /* replace486_1 -> 1464 in the cache */
   /* replace486 -> 1465 in the cache */

   /* ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search487_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1485, 609 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search487_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1487, 609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1486, 1488 },
      -1,
   } },

   /* replace487_0_0 -> 0 in the cache */
   /* replace487_0_1 -> 1467 in the cache */
   /* replace487_0 -> 1470 in the cache */
   /* replace487_1 -> 609 in the cache */
   /* replace487 -> 1471 in the cache */

   /* ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search488_0_0 -> 124 in the cache */
   /* search488_0_1 -> 223 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 124, 223 },
      -1,
   } },
   /* search488_1_0 -> 124 in the cache */
   /* search488_1_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 124, 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1490, 1491 },
      -1,
   } },

   /* replace488_0 -> 124 in the cache */
   /* replace488_1_0 -> 125 in the cache */
   /* replace488_1_1 -> 127 in the cache */
   /* replace488_1 -> 1475 in the cache */
   /* replace488 -> 1476 in the cache */

   /* ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search489_0_0 -> 1485 in the cache */
   /* search489_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1485, 609 },
      -1,
   } },
   /* search489_1_0 -> 1487 in the cache */
   /* search489_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1487, 609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1493, 1494 },
      -1,
   } },

   /* replace489_0_0 -> 0 in the cache */
   /* replace489_0_1 -> 1467 in the cache */
   /* replace489_0 -> 1480 in the cache */
   /* replace489_1 -> 609 in the cache */
   /* replace489 -> 1481 in the cache */

   /* ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search490_0_0 -> 124 in the cache */
   /* search490_0_1 -> 125 in the cache */
   /* search490_0 -> 1461 in the cache */
   /* search490_1_0 -> 124 in the cache */
   /* search490_1_1 -> 127 in the cache */
   /* search490_1 -> 1462 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1461, 1462 },
      -1,
   } },

   /* replace490_0 -> 124 in the cache */
   /* replace490_1_0 -> 125 in the cache */
   /* replace490_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 124, 1497 },
      -1,
   } },

   /* ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   /* search491_0_0 -> 0 in the cache */
   /* search491_0_1 -> 609 in the cache */
   /* search491_0 -> 1466 in the cache */
   /* search491_1_0 -> 1467 in the cache */
   /* search491_1_1 -> 609 in the cache */
   /* search491_1 -> 1468 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1466, 1468 },
      -1,
   } },

   /* replace491_0_0 -> 0 in the cache */
   /* replace491_0_1 -> 1467 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 0, 1467 },
      -1,
   } },
   /* replace491_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 1500, 609 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search492_0_0 -> 124 in the cache */
   /* search492_0_1 -> 125 in the cache */
   /* search492_0 -> 1472 in the cache */
   /* search492_1_0 -> 124 in the cache */
   /* search492_1_1 -> 127 in the cache */
   /* search492_1 -> 1473 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1472, 1473 },
      -1,
   } },

   /* replace492_0 -> 124 in the cache */
   /* replace492_1_0 -> 125 in the cache */
   /* replace492_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 124, 1503 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search493_0_0 -> 0 in the cache */
   /* search493_0_1 -> 609 in the cache */
   /* search493_0 -> 1477 in the cache */
   /* search493_1_0 -> 1467 in the cache */
   /* search493_1_1 -> 609 in the cache */
   /* search493_1 -> 1478 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1477, 1478 },
      -1,
   } },

   /* replace493_0_0 -> 0 in the cache */
   /* replace493_0_1 -> 1467 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 0, 1467 },
      -1,
   } },
   /* replace493_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 1506, 609 },
      -1,
   } },

   /* ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search494_0_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 124, 1508 },
      -1,
   } },
   /* search494_1_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 124, 1510 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1509, 1511 },
      -1,
   } },

   /* replace494_0 -> 124 in the cache */
   /* replace494_1_0 -> 125 in the cache */
   /* replace494_1_1 -> 127 in the cache */
   /* replace494_1 -> 1497 in the cache */
   /* replace494 -> 1498 in the cache */

   /* ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search495_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1513, 609 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search495_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1515, 609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1514, 1516 },
      -1,
   } },

   /* replace495_0_0 -> 0 in the cache */
   /* replace495_0_1 -> 1467 in the cache */
   /* replace495_0 -> 1500 in the cache */
   /* replace495_1 -> 609 in the cache */
   /* replace495 -> 1501 in the cache */

   /* ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search496_0_0 -> 124 in the cache */
   /* search496_0_1 -> 1508 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 124, 1508 },
      -1,
   } },
   /* search496_1_0 -> 124 in the cache */
   /* search496_1_1 -> 1510 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 124, 1510 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1518, 1519 },
      -1,
   } },

   /* replace496_0 -> 124 in the cache */
   /* replace496_1_0 -> 125 in the cache */
   /* replace496_1_1 -> 127 in the cache */
   /* replace496_1 -> 1503 in the cache */
   /* replace496 -> 1504 in the cache */

   /* ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search497_0_0 -> 1513 in the cache */
   /* search497_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1513, 609 },
      -1,
   } },
   /* search497_1_0 -> 1515 in the cache */
   /* search497_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1515, 609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1521, 1522 },
      -1,
   } },

   /* replace497_0_0 -> 0 in the cache */
   /* replace497_0_1 -> 1467 in the cache */
   /* replace497_0 -> 1506 in the cache */
   /* replace497_1 -> 609 in the cache */
   /* replace497 -> 1507 in the cache */

   /* ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c')) */
   /* search498_0_0 -> 124 in the cache */
   /* search498_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search498_1_0 -> 124 in the cache */
   /* search498_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1524, 1525 },
      -1,
   } },

   /* replace498_0 -> 124 in the cache */
   /* replace498_1_0 -> 125 in the cache */
   /* replace498_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 124, 1527 },
      -1,
   } },

   /* ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c') */
   /* search499_0_0 -> 0 in the cache */
   /* search499_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 0, 609 },
      0,
   } },
   /* search499_1_0 -> 1467 in the cache */
   /* search499_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1467, 609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1529, 1530 },
      -1,
   } },

   /* replace499_0_0 -> 0 in the cache */
   /* replace499_0_1 -> 1467 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imin,
      0, 1,
      { 0, 1467 },
      -1,
   } },
   /* replace499_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 1532, 609 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c')) */
   /* search500_0_0 -> 124 in the cache */
   /* search500_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search500_1_0 -> 124 in the cache */
   /* search500_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1534, 1535 },
      -1,
   } },

   /* replace500_0 -> 124 in the cache */
   /* replace500_1_0 -> 125 in the cache */
   /* replace500_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 124, 1537 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c') */
   /* search501_0_0 -> 0 in the cache */
   /* search501_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 0, 609 },
      0,
   } },
   /* search501_1_0 -> 1467 in the cache */
   /* search501_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1467, 609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1539, 1540 },
      -1,
   } },

   /* replace501_0_0 -> 0 in the cache */
   /* replace501_0_1 -> 1467 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imax,
      0, 1,
      { 0, 1467 },
      -1,
   } },
   /* replace501_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 1542, 609 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c')) */
   /* search502_0_0 -> 124 in the cache */
   /* search502_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search502_1_0 -> 124 in the cache */
   /* search502_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1544, 1545 },
      -1,
   } },

   /* replace502_0 -> 124 in the cache */
   /* replace502_1_0 -> 125 in the cache */
   /* replace502_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 124, 1547 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c') */
   /* search503_0_0 -> 0 in the cache */
   /* search503_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 0, 609 },
      0,
   } },
   /* search503_1_0 -> 1467 in the cache */
   /* search503_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1467, 609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1549, 1550 },
      -1,
   } },

   /* replace503_0_0 -> 0 in the cache */
   /* replace503_0_1 -> 1467 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_umin,
      0, 1,
      { 0, 1467 },
      -1,
   } },
   /* replace503_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 1552, 609 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c')) */
   /* search504_0_0 -> 124 in the cache */
   /* search504_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search504_1_0 -> 124 in the cache */
   /* search504_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1554, 1555 },
      -1,
   } },

   /* replace504_0 -> 124 in the cache */
   /* replace504_1_0 -> 125 in the cache */
   /* replace504_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 124, 1557 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c') */
   /* search505_0_0 -> 0 in the cache */
   /* search505_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 0, 609 },
      0,
   } },
   /* search505_1_0 -> 1467 in the cache */
   /* search505_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1467, 609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1559, 1560 },
      -1,
   } },

   /* replace505_0_0 -> 0 in the cache */
   /* replace505_0_1 -> 1467 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_umax,
      0, 1,
      { 0, 1467 },
      -1,
   } },
   /* replace505_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 1562, 609 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c')) */
   /* search506_0_0 -> 124 in the cache */
   /* search506_0_1 -> 125 in the cache */
   /* search506_0 -> 1524 in the cache */
   /* search506_1_0 -> 124 in the cache */
   /* search506_1_1 -> 127 in the cache */
   /* search506_1 -> 1525 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1524, 1525 },
      -1,
   } },

   /* replace506_0 -> 124 in the cache */
   /* replace506_1_0 -> 125 in the cache */
   /* replace506_1_1 -> 127 in the cache */
   /* replace506_1 -> 1537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 124, 1537 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c') */
   /* search507_0_0 -> 0 in the cache */
   /* search507_0_1 -> 609 in the cache */
   /* search507_0 -> 1529 in the cache */
   /* search507_1_0 -> 1467 in the cache */
   /* search507_1_1 -> 609 in the cache */
   /* search507_1 -> 1530 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1529, 1530 },
      -1,
   } },

   /* replace507_0_0 -> 0 in the cache */
   /* replace507_0_1 -> 1467 in the cache */
   /* replace507_0 -> 1542 in the cache */
   /* replace507_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 1542, 609 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c')) */
   /* search508_0_0 -> 124 in the cache */
   /* search508_0_1 -> 125 in the cache */
   /* search508_0 -> 1534 in the cache */
   /* search508_1_0 -> 124 in the cache */
   /* search508_1_1 -> 127 in the cache */
   /* search508_1 -> 1535 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1534, 1535 },
      -1,
   } },

   /* replace508_0 -> 124 in the cache */
   /* replace508_1_0 -> 125 in the cache */
   /* replace508_1_1 -> 127 in the cache */
   /* replace508_1 -> 1527 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 124, 1527 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c') */
   /* search509_0_0 -> 0 in the cache */
   /* search509_0_1 -> 609 in the cache */
   /* search509_0 -> 1539 in the cache */
   /* search509_1_0 -> 1467 in the cache */
   /* search509_1_1 -> 609 in the cache */
   /* search509_1 -> 1540 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1539, 1540 },
      -1,
   } },

   /* replace509_0_0 -> 0 in the cache */
   /* replace509_0_1 -> 1467 in the cache */
   /* replace509_0 -> 1532 in the cache */
   /* replace509_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 1532, 609 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c')) */
   /* search510_0_0 -> 124 in the cache */
   /* search510_0_1 -> 125 in the cache */
   /* search510_0 -> 1544 in the cache */
   /* search510_1_0 -> 124 in the cache */
   /* search510_1_1 -> 127 in the cache */
   /* search510_1 -> 1545 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1544, 1545 },
      -1,
   } },

   /* replace510_0 -> 124 in the cache */
   /* replace510_1_0 -> 125 in the cache */
   /* replace510_1_1 -> 127 in the cache */
   /* replace510_1 -> 1557 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 124, 1557 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c') */
   /* search511_0_0 -> 0 in the cache */
   /* search511_0_1 -> 609 in the cache */
   /* search511_0 -> 1549 in the cache */
   /* search511_1_0 -> 1467 in the cache */
   /* search511_1_1 -> 609 in the cache */
   /* search511_1 -> 1550 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1549, 1550 },
      -1,
   } },

   /* replace511_0_0 -> 0 in the cache */
   /* replace511_0_1 -> 1467 in the cache */
   /* replace511_0 -> 1562 in the cache */
   /* replace511_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 1562, 609 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c')) */
   /* search512_0_0 -> 124 in the cache */
   /* search512_0_1 -> 125 in the cache */
   /* search512_0 -> 1554 in the cache */
   /* search512_1_0 -> 124 in the cache */
   /* search512_1_1 -> 127 in the cache */
   /* search512_1 -> 1555 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1554, 1555 },
      -1,
   } },

   /* replace512_0 -> 124 in the cache */
   /* replace512_1_0 -> 125 in the cache */
   /* replace512_1_1 -> 127 in the cache */
   /* replace512_1 -> 1547 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 124, 1547 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c') */
   /* search513_0_0 -> 0 in the cache */
   /* search513_0_1 -> 609 in the cache */
   /* search513_0 -> 1559 in the cache */
   /* search513_1_0 -> 1467 in the cache */
   /* search513_1_1 -> 609 in the cache */
   /* search513_1 -> 1560 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1559, 1560 },
      -1,
   } },

   /* replace513_0_0 -> 0 in the cache */
   /* replace513_0_1 -> 1467 in the cache */
   /* replace513_0 -> 1552 in the cache */
   /* replace513_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 1552, 609 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search514_0_0_0 -> 0 in the cache */
   /* search514_0_0_1 -> 609 in the cache */
   /* search514_0_0 -> 1466 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 1466, 1580 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search514_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1582, 609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 2,
      { 1581, 1583 },
      -1,
   } },

   /* replace514_0_0_0 -> 0 in the cache */
   /* replace514_0_0_1 -> 1582 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, true,
      nir_op_fmin,
      1, 1,
      { 0, 1582 },
      -1,
   } },
   /* replace514_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 1585, 609 },
      -1,
   } },
   /* replace514_1 -> 1580 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 2,
      { 1586, 1580 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search515_0_0_0 -> 0 in the cache */
   /* search515_0_0_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 0, 609 },
      -1,
   } },
   /* search515_0_1 -> 1580 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 1588, 1580 },
      0,
   } },
   /* search515_1_0 -> 1582 in the cache */
   /* search515_1_1 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1582, 609 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 2,
      { 1589, 1590 },
      -1,
   } },

   /* replace515_0_0_0 -> 0 in the cache */
   /* replace515_0_0_1 -> 1582 in the cache */
   /* replace515_0_0 -> 1585 in the cache */
   /* replace515_0_1 -> 609 in the cache */
   /* replace515_0 -> 1586 in the cache */
   /* replace515_1 -> 1580 in the cache */
   /* replace515 -> 1587 in the cache */

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search516_0_0_0 -> 141 in the cache */
   /* search516_0_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 141, 142 },
      0,
   } },
   /* search516_0_1 -> 1580 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 1592, 1580 },
      0,
   } },
   /* search516_1_0 -> 141 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 141, 1594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 2,
      { 1593, 1595 },
      -1,
   } },

   /* replace516_0_0 -> 141 in the cache */
   /* replace516_0_1_0 -> 142 in the cache */
   /* replace516_0_1_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, true,
      nir_op_fmax,
      1, 1,
      { 142, 1594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 141, 1597 },
      -1,
   } },
   /* replace516_1 -> 1580 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 2,
      { 1598, 1580 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search517_0_0_0 -> 141 in the cache */
   /* search517_0_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 141, 142 },
      -1,
   } },
   /* search517_0_1 -> 1580 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 1600, 1580 },
      0,
   } },
   /* search517_1_0 -> 141 in the cache */
   /* search517_1_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 141, 1594 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 2,
      { 1601, 1602 },
      -1,
   } },

   /* replace517_0_0 -> 141 in the cache */
   /* replace517_0_1_0 -> 142 in the cache */
   /* replace517_0_1_1 -> 1594 in the cache */
   /* replace517_0_1 -> 1597 in the cache */
   /* replace517_0 -> 1598 in the cache */
   /* replace517_1 -> 1580 in the cache */
   /* replace517 -> 1599 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b') */
   /* search518_0_0 -> 933 in the cache */
   /* search518_0_1 -> 934 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 933, 934 },
      -1,
   } },
   /* search518_1_0 -> 3 in the cache */
   /* search518_1_1 -> 0 in the cache */
   /* search518_1 -> 969 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1604, 969 },
      -1,
   } },

   /* replace518_0 -> 0 in the cache */
   /* replace518_1 -> 3 in the cache */
   /* replace518 -> 943 in the cache */

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search519_0_0 -> 115 in the cache */
   /* search519_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search519_1_0 -> 207 in the cache */
   /* search519_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 207, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1606, 1607 },
      -1,
   } },

   /* replace519_0 -> 115 in the cache */
   /* replace519_1_0 -> 11 in the cache */
   /* replace519_1_1_0 -> 207 in the cache */
   /* replace519_1_1 -> 454 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 11, 454 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 115, 1609 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search520_0_0 -> 115 in the cache */
   /* search520_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search520_1_0 -> 207 in the cache */
   /* search520_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 207, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1611, 1612 },
      -1,
   } },

   /* replace520_0 -> 115 in the cache */
   /* replace520_1_0 -> 11 in the cache */
   /* replace520_1_1_0 -> 207 in the cache */
   /* replace520_1_1 -> 454 in the cache */
   /* replace520_1 -> 1609 in the cache */
   /* replace520 -> 1610 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search521_0_0 -> 115 in the cache */
   /* search521_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search521_1_0 -> 207 in the cache */
   /* search521_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 207, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1614, 1615 },
      -1,
   } },

   /* replace521_0 -> 115 in the cache */
   /* replace521_1_0 -> 11 in the cache */
   /* replace521_1_1_0 -> 207 in the cache */
   /* replace521_1_1 -> 454 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 11, 454 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 115, 1617 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search522_0_0 -> 115 in the cache */
   /* search522_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search522_1_0 -> 207 in the cache */
   /* search522_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 207, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1619, 1620 },
      -1,
   } },

   /* replace522_0 -> 115 in the cache */
   /* replace522_1_0 -> 11 in the cache */
   /* replace522_1_1_0 -> 207 in the cache */
   /* replace522_1_1 -> 454 in the cache */
   /* replace522_1 -> 1617 in the cache */
   /* replace522 -> 1618 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search523_0_0 -> 115 in the cache */
   /* search523_0_1 -> 11 in the cache */
   /* search523_0 -> 1606 in the cache */
   /* search523_1_0 -> 207 in the cache */
   /* search523_1_1 -> 115 in the cache */
   /* search523_1 -> 1607 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1606, 1607 },
      -1,
   } },

   /* replace523_0 -> 115 in the cache */
   /* replace523_1_0 -> 11 in the cache */
   /* replace523_1_1_0 -> 207 in the cache */
   /* replace523_1_1 -> 454 in the cache */
   /* replace523_1 -> 1617 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 115, 1617 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search524_0_0 -> 115 in the cache */
   /* search524_0_1 -> 11 in the cache */
   /* search524_0 -> 1611 in the cache */
   /* search524_1_0 -> 207 in the cache */
   /* search524_1_1 -> 115 in the cache */
   /* search524_1 -> 1612 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1611, 1612 },
      -1,
   } },

   /* replace524_0 -> 115 in the cache */
   /* replace524_1_0 -> 11 in the cache */
   /* replace524_1_1_0 -> 207 in the cache */
   /* replace524_1_1 -> 454 in the cache */
   /* replace524_1 -> 1617 in the cache */
   /* replace524 -> 1623 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search525_0_0 -> 115 in the cache */
   /* search525_0_1 -> 11 in the cache */
   /* search525_0 -> 1614 in the cache */
   /* search525_1_0 -> 207 in the cache */
   /* search525_1_1 -> 115 in the cache */
   /* search525_1 -> 1615 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1614, 1615 },
      -1,
   } },

   /* replace525_0 -> 115 in the cache */
   /* replace525_1_0 -> 11 in the cache */
   /* replace525_1_1_0 -> 207 in the cache */
   /* replace525_1_1 -> 454 in the cache */
   /* replace525_1 -> 1609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 115, 1609 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search526_0_0 -> 115 in the cache */
   /* search526_0_1 -> 11 in the cache */
   /* search526_0 -> 1619 in the cache */
   /* search526_1_0 -> 207 in the cache */
   /* search526_1_1 -> 115 in the cache */
   /* search526_1 -> 1620 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1619, 1620 },
      -1,
   } },

   /* replace526_0 -> 115 in the cache */
   /* replace526_1_0 -> 11 in the cache */
   /* replace526_1_1_0 -> 207 in the cache */
   /* replace526_1_1 -> 454 in the cache */
   /* replace526_1 -> 1609 in the cache */
   /* replace526 -> 1626 in the cache */

   /* ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search527_0_0 -> 11 in the cache */
   /* search527_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 11, 115 },
      -1,
   } },
   /* search527_1 -> 401 in the cache */
   /* search527_2_0_0_0_0 -> 115 in the cache */
   /* search527_2_0_0_0_1 -> 11 in the cache */
   /* search527_2_0_0_0 -> 1611 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2i16,
      -1, 0,
      { 1611 },
      -1,
   } },
   /* search527_2_0_1_0_0_0 -> 11 in the cache */
   /* search527_2_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2i16,
      -1, 0,
      { 1630 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 1631 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 1629, 1632 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2f16,
      -1, 1,
      { 1633 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 1628, 401, 1634 },
      -1,
   } },

   /* replace527_0_0_0_0 -> 11 in the cache */
   /* replace527_0_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_fge,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 1636 },
      -1,
   } },
   /* replace527_0_1_0_0_0 -> 11 in the cache */
   /* replace527_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 1638 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 1639 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 1637, 1640 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2f16,
      -1, 1,
      { 1641 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search528_0 -> 650 in the cache */
   /* search528_1_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 207 },
      0,
   } },
   /* search528_2_0 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 389 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1643, 1644 },
      -1,
   } },

   /* replace528_0_0 -> 650 in the cache */
   /* replace528_0_1 -> 207 in the cache */
   /* replace528_0_2 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 207, 389 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 1646 },
      -1,
   } },

   /* ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a') */
   /* search529_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_i2f16,
      -1, 0,
      { 1648 },
      -1,
   } },

   /* replace529_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ftrunc,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('~f2i16', ('i2f', 'a@16')) => a */
   /* search530_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_i2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_f2i16,
      -1, 0,
      { 1651 },
      -1,
   } },

   /* replace530 -> 11 in the cache */

   /* ('~f2i16', ('u2f', 'a@16')) => a */
   /* search531_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_u2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_f2i16,
      -1, 0,
      { 1653 },
      -1,
   } },

   /* replace531 -> 11 in the cache */

   /* ('~f2u16', ('i2f', 'a@16')) => a */
   /* search532_0_0 -> 11 in the cache */
   /* search532_0 -> 1651 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_f2u16,
      -1, 0,
      { 1651 },
      -1,
   } },

   /* replace532 -> 11 in the cache */

   /* ('~f2u16', ('u2f', 'a@16')) => a */
   /* search533_0_0 -> 11 in the cache */
   /* search533_0 -> 1653 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_f2u16,
      -1, 0,
      { 1653 },
      -1,
   } },

   /* replace533 -> 11 in the cache */

   /* ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a') */
   /* search534_0_0_0 -> 115 in the cache */
   /* search534_0_0_1 -> 11 in the cache */
   /* search534_0_0 -> 1611 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2f16,
      -1, 0,
      { 1611 },
      -1,
   } },
   /* search534_1_0_0_0 -> 11 in the cache */
   /* search534_1_0_0_1 -> 115 in the cache */
   /* search534_1_0_0 -> 1630 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2f16,
      -1, 0,
      { 1630 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 1658 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 1657, 1659 },
      -1,
   } },

   /* replace534_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a')) */
   /* search535_0_0_0 -> 748 in the cache */
   /* search535_0_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 748, 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2i16,
      -1, 0,
      { 1662 },
      -1,
   } },
   /* search535_1_0_0_0 -> 11 in the cache */
   /* search535_1_0_0_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 11, 748 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2i16,
      -1, 0,
      { 1664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 1665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 1663, 1666 },
      -1,
   } },

   /* replace535_0_0 -> 11 in the cache */
   /* replace535_0 -> 1661 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2i16,
      -1, 0,
      { 1661 },
      -1,
   } },

   /* ('f2f16', ('f2f32', 'a@16')) => a */
   /* search536_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 1669 },
      -1,
   } },

   /* replace536 -> 11 in the cache */

   /* ('i2i16', ('i2i32', 'a@16')) => a */
   /* search537_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 1671 },
      -1,
   } },

   /* replace537 -> 11 in the cache */

   /* ('u2u16', ('u2u32', 'a@16')) => a */
   /* search538_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 1673 },
      -1,
   } },

   /* replace538 -> 11 in the cache */

   /* ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search539_0_0 -> 650 in the cache */
   /* search539_0 -> 1281 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 1281 },
      -1,
   } },

   /* replace539_0 -> 650 in the cache */
   /* replace539 -> 1277 in the cache */

   /* ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search540_0_0 -> 650 in the cache */
   /* search540_0 -> 1269 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 1269 },
      -1,
   } },

   /* replace540_0 -> 650 in the cache */
   /* replace540 -> 1265 in the cache */

   /* ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search541_0_0 -> 650 in the cache */
   /* search541_0 -> 1269 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 1269 },
      -1,
   } },

   /* replace541_0 -> 650 in the cache */
   /* replace541 -> 1265 in the cache */

   /* ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a') */
   /* search542_0_0 -> 11 in the cache */
   /* search542_0 -> 1669 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2u32,
      -1, 0,
      { 1669 },
      -1,
   } },

   /* replace542_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2u32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a') */
   /* search543_0_0 -> 11 in the cache */
   /* search543_0 -> 1669 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2i32,
      -1, 0,
      { 1669 },
      -1,
   } },

   /* replace543_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2i32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a') */
   /* search544_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 1682 },
      -1,
   } },

   /* replace544_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a') */
   /* search545_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 1685 },
      -1,
   } },

   /* replace545_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a') */
   /* search546_0_0 -> 11 in the cache */
   /* search546_0 -> 1673 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2f32,
      -1, 0,
      { 1673 },
      -1,
   } },

   /* replace546_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a') */
   /* search547_0_0 -> 11 in the cache */
   /* search547_0 -> 1671 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2f32,
      -1, 0,
      { 1671 },
      -1,
   } },

   /* replace547_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('f2f64', 'a@16')) => a */
   /* search548_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2f64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 1692 },
      -1,
   } },

   /* replace548 -> 11 in the cache */

   /* ('i2i16', ('i2i64', 'a@16')) => a */
   /* search549_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 1694 },
      -1,
   } },

   /* replace549 -> 11 in the cache */

   /* ('u2u16', ('u2u64', 'a@16')) => a */
   /* search550_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 1696 },
      -1,
   } },

   /* replace550 -> 11 in the cache */

   /* ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a') */
   /* search551_0_0 -> 650 in the cache */
   /* search551_0 -> 1285 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 1285 },
      -1,
   } },

   /* replace551_0 -> 650 in the cache */
   /* replace551 -> 1277 in the cache */

   /* ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search552_0_0 -> 650 in the cache */
   /* search552_0 -> 1273 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 1273 },
      -1,
   } },

   /* replace552_0 -> 650 in the cache */
   /* replace552 -> 1265 in the cache */

   /* ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search553_0_0 -> 650 in the cache */
   /* search553_0 -> 1273 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 1273 },
      -1,
   } },

   /* replace553_0 -> 650 in the cache */
   /* replace553 -> 1265 in the cache */

   /* ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a') */
   /* search554_0_0 -> 11 in the cache */
   /* search554_0 -> 1692 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2u64,
      -1, 0,
      { 1692 },
      -1,
   } },

   /* replace554_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2u64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a') */
   /* search555_0_0 -> 11 in the cache */
   /* search555_0 -> 1692 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2i64,
      -1, 0,
      { 1692 },
      -1,
   } },

   /* replace555_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2i64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a') */
   /* search556_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 1705 },
      -1,
   } },

   /* replace556_0 -> 32 in the cache */
   /* replace556 -> 1684 in the cache */

   /* ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a') */
   /* search557_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 1707 },
      -1,
   } },

   /* replace557_0 -> 32 in the cache */
   /* replace557 -> 1687 in the cache */

   /* ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a') */
   /* search558_0_0 -> 11 in the cache */
   /* search558_0 -> 1696 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2f64,
      -1, 0,
      { 1696 },
      -1,
   } },

   /* replace558_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a') */
   /* search559_0_0 -> 11 in the cache */
   /* search559_0 -> 1694 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2f64,
      -1, 0,
      { 1694 },
      -1,
   } },

   /* replace559_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search560_0_0 -> 117 in the cache */
   /* search560_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search560_1_0 -> 36 in the cache */
   /* search560_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1713, 1714 },
      -1,
   } },

   /* replace560_0 -> 117 in the cache */
   /* replace560_1_0 -> 16 in the cache */
   /* replace560_1_1_0 -> 36 in the cache */
   /* replace560_1_1 -> 525 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 16, 525 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 117, 1716 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search561_0_0 -> 117 in the cache */
   /* search561_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search561_1_0 -> 36 in the cache */
   /* search561_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1718, 1719 },
      -1,
   } },

   /* replace561_0 -> 117 in the cache */
   /* replace561_1_0 -> 16 in the cache */
   /* replace561_1_1_0 -> 36 in the cache */
   /* replace561_1_1 -> 525 in the cache */
   /* replace561_1 -> 1716 in the cache */
   /* replace561 -> 1717 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search562_0_0 -> 117 in the cache */
   /* search562_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search562_1_0 -> 36 in the cache */
   /* search562_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1721, 1722 },
      -1,
   } },

   /* replace562_0 -> 117 in the cache */
   /* replace562_1_0 -> 16 in the cache */
   /* replace562_1_1_0 -> 36 in the cache */
   /* replace562_1_1 -> 525 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 16, 525 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 117, 1724 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search563_0_0 -> 117 in the cache */
   /* search563_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search563_1_0 -> 36 in the cache */
   /* search563_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1726, 1727 },
      -1,
   } },

   /* replace563_0 -> 117 in the cache */
   /* replace563_1_0 -> 16 in the cache */
   /* replace563_1_1_0 -> 36 in the cache */
   /* replace563_1_1 -> 525 in the cache */
   /* replace563_1 -> 1724 in the cache */
   /* replace563 -> 1725 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search564_0_0 -> 117 in the cache */
   /* search564_0_1 -> 16 in the cache */
   /* search564_0 -> 1713 in the cache */
   /* search564_1_0 -> 36 in the cache */
   /* search564_1_1 -> 117 in the cache */
   /* search564_1 -> 1714 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1713, 1714 },
      -1,
   } },

   /* replace564_0 -> 117 in the cache */
   /* replace564_1_0 -> 16 in the cache */
   /* replace564_1_1_0 -> 36 in the cache */
   /* replace564_1_1 -> 525 in the cache */
   /* replace564_1 -> 1724 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 117, 1724 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search565_0_0 -> 117 in the cache */
   /* search565_0_1 -> 16 in the cache */
   /* search565_0 -> 1718 in the cache */
   /* search565_1_0 -> 36 in the cache */
   /* search565_1_1 -> 117 in the cache */
   /* search565_1 -> 1719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1718, 1719 },
      -1,
   } },

   /* replace565_0 -> 117 in the cache */
   /* replace565_1_0 -> 16 in the cache */
   /* replace565_1_1_0 -> 36 in the cache */
   /* replace565_1_1 -> 525 in the cache */
   /* replace565_1 -> 1724 in the cache */
   /* replace565 -> 1730 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search566_0_0 -> 117 in the cache */
   /* search566_0_1 -> 16 in the cache */
   /* search566_0 -> 1721 in the cache */
   /* search566_1_0 -> 36 in the cache */
   /* search566_1_1 -> 117 in the cache */
   /* search566_1 -> 1722 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1721, 1722 },
      -1,
   } },

   /* replace566_0 -> 117 in the cache */
   /* replace566_1_0 -> 16 in the cache */
   /* replace566_1_1_0 -> 36 in the cache */
   /* replace566_1_1 -> 525 in the cache */
   /* replace566_1 -> 1716 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 117, 1716 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search567_0_0 -> 117 in the cache */
   /* search567_0_1 -> 16 in the cache */
   /* search567_0 -> 1726 in the cache */
   /* search567_1_0 -> 36 in the cache */
   /* search567_1_1 -> 117 in the cache */
   /* search567_1 -> 1727 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1726, 1727 },
      -1,
   } },

   /* replace567_0 -> 117 in the cache */
   /* replace567_1_0 -> 16 in the cache */
   /* replace567_1_1_0 -> 36 in the cache */
   /* replace567_1_1 -> 525 in the cache */
   /* replace567_1 -> 1716 in the cache */
   /* replace567 -> 1733 in the cache */

   /* ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search568_0_0 -> 16 in the cache */
   /* search568_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 16, 117 },
      -1,
   } },
   /* search568_1 -> 474 in the cache */
   /* search568_2_0_0_0_0 -> 117 in the cache */
   /* search568_2_0_0_0_1 -> 16 in the cache */
   /* search568_2_0_0_0 -> 1718 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 1718 },
      -1,
   } },
   /* search568_2_0_1_0_0_0 -> 16 in the cache */
   /* search568_2_0_1_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 1737 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 1738 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 1736, 1739 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2f32,
      -1, 1,
      { 1740 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 1735, 474, 1741 },
      -1,
   } },

   /* replace568_0_0_0_0 -> 16 in the cache */
   /* replace568_0_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_fge,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 1743 },
      -1,
   } },
   /* replace568_0_1_0_0_0 -> 16 in the cache */
   /* replace568_0_1_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 1745 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 1746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 1744, 1747 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2f32,
      -1, 1,
      { 1748 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search569_0 -> 650 in the cache */
   /* search569_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 36 },
      0,
   } },
   /* search569_2_0 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1750, 1751 },
      -1,
   } },

   /* replace569_0_0 -> 650 in the cache */
   /* replace569_0_1 -> 36 in the cache */
   /* replace569_0_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 36, 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 1753 },
      -1,
   } },

   /* ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a') */
   /* search570_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_i2f32,
      -1, 0,
      { 1755 },
      -1,
   } },

   /* replace570_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ftrunc,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~f2i32', ('i2f', 'a@32')) => a */
   /* search571_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_i2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2i32,
      -1, 0,
      { 1758 },
      -1,
   } },

   /* replace571 -> 16 in the cache */

   /* ('~f2i32', ('u2f', 'a@32')) => a */
   /* search572_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_u2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2i32,
      -1, 0,
      { 1760 },
      -1,
   } },

   /* replace572 -> 16 in the cache */

   /* ('~f2u32', ('i2f', 'a@32')) => a */
   /* search573_0_0 -> 16 in the cache */
   /* search573_0 -> 1758 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2u32,
      -1, 0,
      { 1758 },
      -1,
   } },

   /* replace573 -> 16 in the cache */

   /* ('~f2u32', ('u2f', 'a@32')) => a */
   /* search574_0_0 -> 16 in the cache */
   /* search574_0 -> 1760 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2u32,
      -1, 0,
      { 1760 },
      -1,
   } },

   /* replace574 -> 16 in the cache */

   /* ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a') */
   /* search575_0_0_0 -> 117 in the cache */
   /* search575_0_0_1 -> 16 in the cache */
   /* search575_0_0 -> 1718 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2f32,
      -1, 0,
      { 1718 },
      -1,
   } },
   /* search575_1_0_0_0 -> 16 in the cache */
   /* search575_1_0_0_1 -> 117 in the cache */
   /* search575_1_0_0 -> 1737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2f32,
      -1, 0,
      { 1737 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 1765 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 1764, 1766 },
      -1,
   } },

   /* replace575_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a')) */
   /* search576_0_0_0 -> 120 in the cache */
   /* search576_0_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 1769 },
      -1,
   } },
   /* search576_1_0_0_0 -> 16 in the cache */
   /* search576_1_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 1771 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 1772 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 1770, 1773 },
      -1,
   } },

   /* replace576_0_0 -> 16 in the cache */
   /* replace576_0 -> 1768 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2i32,
      -1, 0,
      { 1768 },
      -1,
   } },

   /* ('f2f32', ('f2f64', 'a@32')) => a */
   /* search577_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2f64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 1776 },
      -1,
   } },

   /* replace577 -> 16 in the cache */

   /* ('i2i32', ('i2i64', 'a@32')) => a */
   /* search578_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 1778 },
      -1,
   } },

   /* replace578 -> 16 in the cache */

   /* ('u2u32', ('u2u64', 'a@32')) => a */
   /* search579_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 1780 },
      -1,
   } },

   /* replace579 -> 16 in the cache */

   /* ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a') */
   /* search580_0_0 -> 650 in the cache */
   /* search580_0 -> 1285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 1285 },
      -1,
   } },

   /* replace580_0 -> 650 in the cache */
   /* replace580 -> 1281 in the cache */

   /* ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search581_0_0 -> 650 in the cache */
   /* search581_0 -> 1273 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 1273 },
      -1,
   } },

   /* replace581_0 -> 650 in the cache */
   /* replace581 -> 1269 in the cache */

   /* ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search582_0_0 -> 650 in the cache */
   /* search582_0 -> 1273 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 1273 },
      -1,
   } },

   /* replace582_0 -> 650 in the cache */
   /* replace582 -> 1269 in the cache */

   /* ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a') */
   /* search583_0_0 -> 16 in the cache */
   /* search583_0 -> 1776 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2u64,
      -1, 0,
      { 1776 },
      -1,
   } },

   /* replace583_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2u64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a') */
   /* search584_0_0 -> 16 in the cache */
   /* search584_0 -> 1776 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2i64,
      -1, 0,
      { 1776 },
      -1,
   } },

   /* replace584_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2i64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a') */
   /* search585_0_0 -> 32 in the cache */
   /* search585_0 -> 1705 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 1705 },
      -1,
   } },

   /* replace585_0 -> 32 in the cache */
   /* replace585 -> 1682 in the cache */

   /* ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a') */
   /* search586_0_0 -> 32 in the cache */
   /* search586_0 -> 1707 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 1707 },
      -1,
   } },

   /* replace586_0 -> 32 in the cache */
   /* replace586 -> 1685 in the cache */

   /* ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a') */
   /* search587_0_0 -> 16 in the cache */
   /* search587_0 -> 1780 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2f64,
      -1, 0,
      { 1780 },
      -1,
   } },

   /* replace587_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a') */
   /* search588_0_0 -> 16 in the cache */
   /* search588_0 -> 1778 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2f64,
      -1, 0,
      { 1778 },
      -1,
   } },

   /* replace588_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search589_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1795, 21 },
      0,
   } },
   /* search589_1_0 -> 41 in the cache */
   /* search589_1_1 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 41, 1795 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1796, 1797 },
      -1,
   } },

   /* replace589_0 -> 1795 in the cache */
   /* replace589_1_0 -> 21 in the cache */
   /* replace589_1_1_0 -> 41 in the cache */
   /* replace589_1_1 -> 598 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 21, 598 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 1795, 1799 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search590_0_0 -> 1795 in the cache */
   /* search590_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1795, 21 },
      -1,
   } },
   /* search590_1_0 -> 41 in the cache */
   /* search590_1_1 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 41, 1795 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1801, 1802 },
      -1,
   } },

   /* replace590_0 -> 1795 in the cache */
   /* replace590_1_0 -> 21 in the cache */
   /* replace590_1_1_0 -> 41 in the cache */
   /* replace590_1_1 -> 598 in the cache */
   /* replace590_1 -> 1799 in the cache */
   /* replace590 -> 1800 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search591_0_0 -> 1795 in the cache */
   /* search591_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1795, 21 },
      0,
   } },
   /* search591_1_0 -> 41 in the cache */
   /* search591_1_1 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 41, 1795 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1804, 1805 },
      -1,
   } },

   /* replace591_0 -> 1795 in the cache */
   /* replace591_1_0 -> 21 in the cache */
   /* replace591_1_1_0 -> 41 in the cache */
   /* replace591_1_1 -> 598 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 21, 598 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 1795, 1807 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search592_0_0 -> 1795 in the cache */
   /* search592_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1795, 21 },
      -1,
   } },
   /* search592_1_0 -> 41 in the cache */
   /* search592_1_1 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 41, 1795 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1809, 1810 },
      -1,
   } },

   /* replace592_0 -> 1795 in the cache */
   /* replace592_1_0 -> 21 in the cache */
   /* replace592_1_1_0 -> 41 in the cache */
   /* replace592_1_1 -> 598 in the cache */
   /* replace592_1 -> 1807 in the cache */
   /* replace592 -> 1808 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search593_0_0 -> 1795 in the cache */
   /* search593_0_1 -> 21 in the cache */
   /* search593_0 -> 1796 in the cache */
   /* search593_1_0 -> 41 in the cache */
   /* search593_1_1 -> 1795 in the cache */
   /* search593_1 -> 1797 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1796, 1797 },
      -1,
   } },

   /* replace593_0 -> 1795 in the cache */
   /* replace593_1_0 -> 21 in the cache */
   /* replace593_1_1_0 -> 41 in the cache */
   /* replace593_1_1 -> 598 in the cache */
   /* replace593_1 -> 1807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 1795, 1807 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search594_0_0 -> 1795 in the cache */
   /* search594_0_1 -> 21 in the cache */
   /* search594_0 -> 1801 in the cache */
   /* search594_1_0 -> 41 in the cache */
   /* search594_1_1 -> 1795 in the cache */
   /* search594_1 -> 1802 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1801, 1802 },
      -1,
   } },

   /* replace594_0 -> 1795 in the cache */
   /* replace594_1_0 -> 21 in the cache */
   /* replace594_1_1_0 -> 41 in the cache */
   /* replace594_1_1 -> 598 in the cache */
   /* replace594_1 -> 1807 in the cache */
   /* replace594 -> 1813 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search595_0_0 -> 1795 in the cache */
   /* search595_0_1 -> 21 in the cache */
   /* search595_0 -> 1804 in the cache */
   /* search595_1_0 -> 41 in the cache */
   /* search595_1_1 -> 1795 in the cache */
   /* search595_1 -> 1805 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1804, 1805 },
      -1,
   } },

   /* replace595_0 -> 1795 in the cache */
   /* replace595_1_0 -> 21 in the cache */
   /* replace595_1_1_0 -> 41 in the cache */
   /* replace595_1_1 -> 598 in the cache */
   /* replace595_1 -> 1799 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 1795, 1799 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search596_0_0 -> 1795 in the cache */
   /* search596_0_1 -> 21 in the cache */
   /* search596_0 -> 1809 in the cache */
   /* search596_1_0 -> 41 in the cache */
   /* search596_1_1 -> 1795 in the cache */
   /* search596_1 -> 1810 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_iand,
      0, 1,
      { 1809, 1810 },
      -1,
   } },

   /* replace596_0 -> 1795 in the cache */
   /* replace596_1_0 -> 21 in the cache */
   /* replace596_1_1_0 -> 41 in the cache */
   /* replace596_1_1 -> 598 in the cache */
   /* replace596_1 -> 1799 in the cache */
   /* replace596 -> 1816 in the cache */

   /* ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search597_0_0 -> 21 in the cache */
   /* search597_0_1 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 21, 1795 },
      -1,
   } },
   /* search597_1 -> 547 in the cache */
   /* search597_2_0_0_0_0 -> 1795 in the cache */
   /* search597_2_0_0_0_1 -> 21 in the cache */
   /* search597_2_0_0_0 -> 1801 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2i64,
      -1, 0,
      { 1801 },
      -1,
   } },
   /* search597_2_0_1_0_0_0 -> 21 in the cache */
   /* search597_2_0_1_0_0_1 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 21, 1795 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2i64,
      -1, 0,
      { 1820 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 1821 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 1819, 1822 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2f64,
      -1, 1,
      { 1823 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 1818, 547, 1824 },
      -1,
   } },

   /* replace597_0_0_0_0 -> 21 in the cache */
   /* replace597_0_0_0_1 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_fge,
      -1, 0,
      { 21, 1795 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 1826 },
      -1,
   } },
   /* replace597_0_1_0_0_0 -> 21 in the cache */
   /* replace597_0_1_0_0_1 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_flt,
      -1, 0,
      { 21, 1795 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 1828 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 1829 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 1827, 1830 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2f64,
      -1, 1,
      { 1831 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search598_0 -> 650 in the cache */
   /* search598_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 41 },
      0,
   } },
   /* search598_2_0 -> 535 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 535 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1833, 1834 },
      -1,
   } },

   /* replace598_0_0 -> 650 in the cache */
   /* replace598_0_1 -> 41 in the cache */
   /* replace598_0_2 -> 535 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 41, 535 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 1836 },
      -1,
   } },

   /* ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a') */
   /* search599_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2i,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_i2f64,
      -1, 0,
      { 1838 },
      -1,
   } },

   /* replace599_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ftrunc,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('~f2i64', ('i2f', 'a@64')) => a */
   /* search600_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_i2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_f2i64,
      -1, 0,
      { 1841 },
      -1,
   } },

   /* replace600 -> 21 in the cache */

   /* ('~f2i64', ('u2f', 'a@64')) => a */
   /* search601_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_u2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_f2i64,
      -1, 0,
      { 1843 },
      -1,
   } },

   /* replace601 -> 21 in the cache */

   /* ('~f2u64', ('i2f', 'a@64')) => a */
   /* search602_0_0 -> 21 in the cache */
   /* search602_0 -> 1841 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_f2u64,
      -1, 0,
      { 1841 },
      -1,
   } },

   /* replace602 -> 21 in the cache */

   /* ('~f2u64', ('u2f', 'a@64')) => a */
   /* search603_0_0 -> 21 in the cache */
   /* search603_0 -> 1843 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_f2u64,
      -1, 0,
      { 1843 },
      -1,
   } },

   /* replace603 -> 21 in the cache */

   /* ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a') */
   /* search604_0_0_0 -> 1795 in the cache */
   /* search604_0_0_1 -> 21 in the cache */
   /* search604_0_0 -> 1801 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2f64,
      -1, 0,
      { 1801 },
      -1,
   } },
   /* search604_1_0_0_0 -> 21 in the cache */
   /* search604_1_0_0_1 -> 1795 in the cache */
   /* search604_1_0_0 -> 1820 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2f64,
      -1, 0,
      { 1820 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 1848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 1847, 1849 },
      -1,
   } },

   /* replace604_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a')) */
   /* search605_0_0_0 -> 791 in the cache */
   /* search605_0_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 791, 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2i64,
      -1, 0,
      { 1852 },
      -1,
   } },
   /* search605_1_0_0_0 -> 21 in the cache */
   /* search605_1_0_0_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 21, 791 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2i64,
      -1, 0,
      { 1854 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 1855 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 1853, 1856 },
      -1,
   } },

   /* replace605_0_0 -> 21 in the cache */
   /* replace605_0 -> 1851 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2i64,
      -1, 0,
      { 1851 },
      -1,
   } },

   /* ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a') */
   /* search606_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 1859 },
      -1,
   } },

   /* replace606_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a') */
   /* search607_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 1862 },
      -1,
   } },

   /* replace607_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a') */
   /* search608_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2u16,
      -1, 0,
      { 1865 },
      -1,
   } },

   /* replace608_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a') */
   /* search609_0_0 -> 16 in the cache */
   /* search609_0 -> 1865 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2i16,
      -1, 0,
      { 1865 },
      -1,
   } },

   /* replace609_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a') */
   /* search610_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2u32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 1870 },
      -1,
   } },

   /* replace610_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2ump,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a') */
   /* search611_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 1873 },
      -1,
   } },

   /* replace611_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2imp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a') */
   /* search612_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2f16,
      -1, 0,
      { 1876 },
      -1,
   } },

   /* replace612_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a') */
   /* search613_0_0 -> 16 in the cache */
   /* search613_0 -> 1876 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2f16,
      -1, 0,
      { 1876 },
      -1,
   } },

   /* replace613_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255)) */
   /* search614_0_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 1881 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1882, 1883 },
      -1,
   } },

   /* replace614_0 -> 11 in the cache */
   /* replace614_1_0 -> 207 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      1, 1,
      { 207, 1885 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 2,
      { 11, 1886 },
      -1,
   } },

   /* ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255)) */
   /* search615_0_0_0 -> 11 in the cache */
   /* search615_0_0_1 -> 1883 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 11, 1883 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1888 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 1,
      { 1889 },
      -1,
   } },

   /* replace615_0 -> 11 in the cache */
   /* replace615_1_0 -> 207 in the cache */
   /* replace615_1_1 -> 1885 in the cache */
   /* replace615_1 -> 1886 in the cache */
   /* replace615 -> 1887 in the cache */

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search616_0_0_0_0 -> 11 in the cache */
   /* search616_0_0_0 -> 1881 in the cache */
   /* search616_0_0 -> 1882 in the cache */
   /* search616_0_1_0_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 1891 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1882, 1892 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1893 },
      -1,
   } },

   /* replace616_0_0 -> 11 in the cache */
   /* replace616_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 11, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1895 },
      -1,
   } },

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search617_0_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 1897 },
      -1,
   } },
   /* search617_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 1899 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1898, 1900 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1901 },
      -1,
   } },

   /* replace617_0_0 -> 16 in the cache */
   /* replace617_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1903 },
      -1,
   } },

   /* ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b') */
   /* search618_0_0 -> 0 in the cache */
   /* search618_0_1 -> 711 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 711 },
      -1,
   } },
   /* search618_1_0 -> 132 in the cache */
   /* search618_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 132, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1905, 1906 },
      -1,
   } },

   /* replace618_0_0 -> 0 in the cache */
   /* replace618_0_1 -> 132 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 1,
      { 0, 132 },
      -1,
   } },
   /* replace618_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i8,
      -1, 1,
      { 1908, 3 },
      -1,
   } },

   /* ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b') */
   /* search619_0_0 -> 0 in the cache */
   /* search619_0_1 -> 711 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 711 },
      -1,
   } },
   /* search619_1_0 -> 132 in the cache */
   /* search619_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 132, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1910, 1911 },
      -1,
   } },

   /* replace619_0_0 -> 0 in the cache */
   /* replace619_0_1 -> 132 in the cache */
   /* replace619_0 -> 1908 in the cache */
   /* replace619_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 1,
      { 1908, 3 },
      -1,
   } },

   /* ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b') */
   /* search620_0_0 -> 0 in the cache */
   /* search620_0_1 -> 711 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 711 },
      -1,
   } },
   /* search620_1_0 -> 132 in the cache */
   /* search620_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 132, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1914, 1915 },
      -1,
   } },

   /* replace620_0_0 -> 0 in the cache */
   /* replace620_0_1 -> 132 in the cache */
   /* replace620_0 -> 1908 in the cache */
   /* replace620_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i16,
      -1, 1,
      { 1908, 3 },
      -1,
   } },

   /* ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b') */
   /* search621_0_0 -> 0 in the cache */
   /* search621_0_1 -> 711 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 711 },
      -1,
   } },
   /* search621_1_0 -> 132 in the cache */
   /* search621_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 132, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1918, 1919 },
      -1,
   } },

   /* replace621_0_0 -> 0 in the cache */
   /* replace621_0_1 -> 132 in the cache */
   /* replace621_0 -> 1908 in the cache */
   /* replace621_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u16,
      -1, 1,
      { 1908, 3 },
      -1,
   } },

   /* ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b') */
   /* search622_0_0 -> 124 in the cache */
   /* search622_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search622_1_0 -> 127 in the cache */
   /* search622_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1922, 1923 },
      -1,
   } },

   /* replace622_0_0 -> 124 in the cache */
   /* replace622_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace622_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 1925, 36 },
      -1,
   } },

   /* ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b') */
   /* search623_0_0 -> 124 in the cache */
   /* search623_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search623_1_0 -> 127 in the cache */
   /* search623_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1927, 1928 },
      -1,
   } },

   /* replace623_0_0 -> 124 in the cache */
   /* replace623_0_1 -> 127 in the cache */
   /* replace623_0 -> 1925 in the cache */
   /* replace623_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 1925, 36 },
      -1,
   } },

   /* ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b') */
   /* search624_0_0 -> 124 in the cache */
   /* search624_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search624_1_0 -> 127 in the cache */
   /* search624_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1931, 1932 },
      -1,
   } },

   /* replace624_0_0 -> 124 in the cache */
   /* replace624_0_1 -> 127 in the cache */
   /* replace624_0 -> 1925 in the cache */
   /* replace624_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 1925, 36 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search625_0_0_0_0 -> 11 in the cache */
   /* search625_0_0_0 -> 1881 in the cache */
   /* search625_0_0 -> 1882 in the cache */
   /* search625_0_1_0_0 -> 207 in the cache */
   /* search625_0_1_0 -> 1891 in the cache */
   /* search625_0_1 -> 1892 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1882, 1892 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1935 },
      -1,
   } },

   /* replace625_0_0 -> 11 in the cache */
   /* replace625_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 1,
      { 11, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1937 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search626_0_0_0_0 -> 16 in the cache */
   /* search626_0_0_0 -> 1897 in the cache */
   /* search626_0_0 -> 1898 in the cache */
   /* search626_0_1_0_0 -> 36 in the cache */
   /* search626_0_1_0 -> 1899 in the cache */
   /* search626_0_1 -> 1900 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1898, 1900 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1939 },
      -1,
   } },

   /* replace626_0_0 -> 16 in the cache */
   /* replace626_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1941 },
      -1,
   } },

   /* ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b') */
   /* search627_0_0 -> 0 in the cache */
   /* search627_0_1 -> 711 in the cache */
   /* search627_0 -> 1905 in the cache */
   /* search627_1_0 -> 132 in the cache */
   /* search627_1_1 -> 3 in the cache */
   /* search627_1 -> 1906 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1905, 1906 },
      -1,
   } },

   /* replace627_0_0 -> 0 in the cache */
   /* replace627_0_1 -> 132 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ior,
      0, 1,
      { 0, 132 },
      -1,
   } },
   /* replace627_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i8,
      -1, 1,
      { 1944, 3 },
      -1,
   } },

   /* ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b') */
   /* search628_0_0 -> 0 in the cache */
   /* search628_0_1 -> 711 in the cache */
   /* search628_0 -> 1910 in the cache */
   /* search628_1_0 -> 132 in the cache */
   /* search628_1_1 -> 3 in the cache */
   /* search628_1 -> 1911 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1910, 1911 },
      -1,
   } },

   /* replace628_0_0 -> 0 in the cache */
   /* replace628_0_1 -> 132 in the cache */
   /* replace628_0 -> 1944 in the cache */
   /* replace628_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 1,
      { 1944, 3 },
      -1,
   } },

   /* ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b') */
   /* search629_0_0 -> 0 in the cache */
   /* search629_0_1 -> 711 in the cache */
   /* search629_0 -> 1914 in the cache */
   /* search629_1_0 -> 132 in the cache */
   /* search629_1_1 -> 3 in the cache */
   /* search629_1 -> 1915 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1914, 1915 },
      -1,
   } },

   /* replace629_0_0 -> 0 in the cache */
   /* replace629_0_1 -> 132 in the cache */
   /* replace629_0 -> 1944 in the cache */
   /* replace629_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i16,
      -1, 1,
      { 1944, 3 },
      -1,
   } },

   /* ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b') */
   /* search630_0_0 -> 0 in the cache */
   /* search630_0_1 -> 711 in the cache */
   /* search630_0 -> 1918 in the cache */
   /* search630_1_0 -> 132 in the cache */
   /* search630_1_1 -> 3 in the cache */
   /* search630_1 -> 1919 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1918, 1919 },
      -1,
   } },

   /* replace630_0_0 -> 0 in the cache */
   /* replace630_0_1 -> 132 in the cache */
   /* replace630_0 -> 1944 in the cache */
   /* replace630_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u16,
      -1, 1,
      { 1944, 3 },
      -1,
   } },

   /* ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b') */
   /* search631_0_0 -> 124 in the cache */
   /* search631_0_1 -> 33 in the cache */
   /* search631_0 -> 1922 in the cache */
   /* search631_1_0 -> 127 in the cache */
   /* search631_1_1 -> 36 in the cache */
   /* search631_1 -> 1923 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1922, 1923 },
      -1,
   } },

   /* replace631_0_0 -> 124 in the cache */
   /* replace631_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace631_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 1953, 36 },
      -1,
   } },

   /* ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b') */
   /* search632_0_0 -> 124 in the cache */
   /* search632_0_1 -> 33 in the cache */
   /* search632_0 -> 1927 in the cache */
   /* search632_1_0 -> 127 in the cache */
   /* search632_1_1 -> 36 in the cache */
   /* search632_1 -> 1928 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1927, 1928 },
      -1,
   } },

   /* replace632_0_0 -> 124 in the cache */
   /* replace632_0_1 -> 127 in the cache */
   /* replace632_0 -> 1953 in the cache */
   /* replace632_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 1953, 36 },
      -1,
   } },

   /* ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b') */
   /* search633_0_0 -> 124 in the cache */
   /* search633_0_1 -> 33 in the cache */
   /* search633_0 -> 1931 in the cache */
   /* search633_1_0 -> 127 in the cache */
   /* search633_1_1 -> 36 in the cache */
   /* search633_1 -> 1932 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1931, 1932 },
      -1,
   } },

   /* replace633_0_0 -> 124 in the cache */
   /* replace633_0_1 -> 127 in the cache */
   /* replace633_0 -> 1953 in the cache */
   /* replace633_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 1953, 36 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search634_0_0_0_0 -> 11 in the cache */
   /* search634_0_0_0 -> 1881 in the cache */
   /* search634_0_0 -> 1882 in the cache */
   /* search634_0_1_0_0 -> 207 in the cache */
   /* search634_0_1_0 -> 1891 in the cache */
   /* search634_0_1 -> 1892 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 1882, 1892 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1959 },
      -1,
   } },

   /* replace634_0_0 -> 11 in the cache */
   /* replace634_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 11, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1961 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search635_0_0_0_0 -> 16 in the cache */
   /* search635_0_0_0 -> 1897 in the cache */
   /* search635_0_0 -> 1898 in the cache */
   /* search635_0_1_0_0 -> 36 in the cache */
   /* search635_0_1_0 -> 1899 in the cache */
   /* search635_0_1 -> 1900 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 1898, 1900 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1963 },
      -1,
   } },

   /* replace635_0_0 -> 16 in the cache */
   /* replace635_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 1,
      { 1965 },
      -1,
   } },

   /* ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b') */
   /* search636_0_0 -> 0 in the cache */
   /* search636_0_1 -> 711 in the cache */
   /* search636_0 -> 1905 in the cache */
   /* search636_1_0 -> 132 in the cache */
   /* search636_1_1 -> 3 in the cache */
   /* search636_1 -> 1906 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 1905, 1906 },
      -1,
   } },

   /* replace636_0_0 -> 0 in the cache */
   /* replace636_0_1 -> 132 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 0, 132 },
      -1,
   } },
   /* replace636_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i8,
      -1, 1,
      { 1968, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b') */
   /* search637_0_0 -> 0 in the cache */
   /* search637_0_1 -> 711 in the cache */
   /* search637_0 -> 1910 in the cache */
   /* search637_1_0 -> 132 in the cache */
   /* search637_1_1 -> 3 in the cache */
   /* search637_1 -> 1911 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 1910, 1911 },
      -1,
   } },

   /* replace637_0_0 -> 0 in the cache */
   /* replace637_0_1 -> 132 in the cache */
   /* replace637_0 -> 1968 in the cache */
   /* replace637_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 1,
      { 1968, 3 },
      -1,
   } },

   /* ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b') */
   /* search638_0_0 -> 0 in the cache */
   /* search638_0_1 -> 711 in the cache */
   /* search638_0 -> 1914 in the cache */
   /* search638_1_0 -> 132 in the cache */
   /* search638_1_1 -> 3 in the cache */
   /* search638_1 -> 1915 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 1914, 1915 },
      -1,
   } },

   /* replace638_0_0 -> 0 in the cache */
   /* replace638_0_1 -> 132 in the cache */
   /* replace638_0 -> 1968 in the cache */
   /* replace638_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i16,
      -1, 1,
      { 1968, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b') */
   /* search639_0_0 -> 0 in the cache */
   /* search639_0_1 -> 711 in the cache */
   /* search639_0 -> 1918 in the cache */
   /* search639_1_0 -> 132 in the cache */
   /* search639_1_1 -> 3 in the cache */
   /* search639_1 -> 1919 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 1918, 1919 },
      -1,
   } },

   /* replace639_0_0 -> 0 in the cache */
   /* replace639_0_1 -> 132 in the cache */
   /* replace639_0 -> 1968 in the cache */
   /* replace639_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u16,
      -1, 1,
      { 1968, 3 },
      -1,
   } },

   /* ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b') */
   /* search640_0_0 -> 124 in the cache */
   /* search640_0_1 -> 33 in the cache */
   /* search640_0 -> 1922 in the cache */
   /* search640_1_0 -> 127 in the cache */
   /* search640_1_1 -> 36 in the cache */
   /* search640_1 -> 1923 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 1922, 1923 },
      -1,
   } },

   /* replace640_0_0 -> 124 in the cache */
   /* replace640_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace640_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 1977, 36 },
      -1,
   } },

   /* ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b') */
   /* search641_0_0 -> 124 in the cache */
   /* search641_0_1 -> 33 in the cache */
   /* search641_0 -> 1927 in the cache */
   /* search641_1_0 -> 127 in the cache */
   /* search641_1_1 -> 36 in the cache */
   /* search641_1 -> 1928 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 1927, 1928 },
      -1,
   } },

   /* replace641_0_0 -> 124 in the cache */
   /* replace641_0_1 -> 127 in the cache */
   /* replace641_0 -> 1977 in the cache */
   /* replace641_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 1977, 36 },
      -1,
   } },

   /* ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b') */
   /* search642_0_0 -> 124 in the cache */
   /* search642_0_1 -> 33 in the cache */
   /* search642_0 -> 1931 in the cache */
   /* search642_1_0 -> 127 in the cache */
   /* search642_1_1 -> 36 in the cache */
   /* search642_1 -> 1932 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 1931, 1932 },
      -1,
   } },

   /* replace642_0_0 -> 124 in the cache */
   /* replace642_0_1 -> 127 in the cache */
   /* replace642_0 -> 1977 in the cache */
   /* replace642_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 1977, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search643_0_0 -> 6 in the cache */
   /* search643_0_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 6, 726 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search643_1_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 1984, 726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 1983, 1985 },
      -1,
   } },

   /* replace643_0_0 -> 6 in the cache */
   /* replace643_0_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ior,
      1, 1,
      { 6, 1984 },
      -1,
   } },
   /* replace643_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 1987, 726 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search644_0_0 -> 6 in the cache */
   /* search644_0_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 6, 726 },
      -1,
   } },
   /* search644_1_0 -> 1984 in the cache */
   /* search644_1_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 1984, 726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 1989, 1990 },
      -1,
   } },

   /* replace644_0_0 -> 6 in the cache */
   /* replace644_0_1 -> 1984 in the cache */
   /* replace644_0 -> 1987 in the cache */
   /* replace644_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 1987, 726 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search645_0_0 -> 6 in the cache */
   /* search645_0_1 -> 726 in the cache */
   /* search645_0 -> 1983 in the cache */
   /* search645_1_0 -> 1984 in the cache */
   /* search645_1_1 -> 726 in the cache */
   /* search645_1 -> 1985 in the cache */
   /* search645 -> 1986 in the cache */

   /* replace645_0_0 -> 6 in the cache */
   /* replace645_0_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_umax,
      1, 1,
      { 6, 1984 },
      -1,
   } },
   /* replace645_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 1993, 726 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search646_0_0 -> 6 in the cache */
   /* search646_0_1 -> 726 in the cache */
   /* search646_0 -> 1983 in the cache */
   /* search646_1_0 -> 1984 in the cache */
   /* search646_1_1 -> 726 in the cache */
   /* search646_1 -> 1985 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 1983, 1985 },
      -1,
   } },

   /* replace646_0_0 -> 6 in the cache */
   /* replace646_0_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_umin,
      1, 1,
      { 6, 1984 },
      -1,
   } },
   /* replace646_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 1996, 726 },
      -1,
   } },

   /* ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search647_0_0 -> 6 in the cache */
   /* search647_0_1 -> 726 in the cache */
   /* search647_0 -> 1989 in the cache */
   /* search647_1_0 -> 1984 in the cache */
   /* search647_1_1 -> 726 in the cache */
   /* search647_1 -> 1990 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 1989, 1990 },
      -1,
   } },

   /* replace647_0_0 -> 6 in the cache */
   /* replace647_0_1 -> 1984 in the cache */
   /* replace647_0 -> 1996 in the cache */
   /* replace647_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 1996, 726 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search648_0_0 -> 6 in the cache */
   /* search648_0_1 -> 726 in the cache */
   /* search648_0 -> 1989 in the cache */
   /* search648_1_0 -> 1984 in the cache */
   /* search648_1_1 -> 726 in the cache */
   /* search648_1 -> 1990 in the cache */
   /* search648 -> 1991 in the cache */

   /* replace648_0_0 -> 6 in the cache */
   /* replace648_0_1 -> 1984 in the cache */
   /* replace648_0 -> 1993 in the cache */
   /* replace648_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 1993, 726 },
      -1,
   } },

   /* ('ineg', ('b2i8', 'a@8')) => a */
   /* search649_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_b2i8,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 2001 },
      -1,
   } },

   /* replace649 -> 6 in the cache */

   /* ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b') */
   /* search650_0 -> 6 in the cache */
   /* search650_1_0 -> 9 in the cache */
   /* search650_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 9, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 6, 2003 },
      -1,
   } },

   /* replace650_0 -> 6 in the cache */
   /* replace650_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b') */
   /* search651_0 -> 6 in the cache */
   /* search651_1_0 -> 9 in the cache */
   /* search651_1_1 -> 36 in the cache */
   /* search651_1 -> 2003 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 6, 2003 },
      -1,
   } },

   /* replace651_0 -> 6 in the cache */
   /* replace651_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b') */
   /* search652_0 -> 6 in the cache */
   /* search652_1_0 -> 9 in the cache */
   /* search652_1_1 -> 36 in the cache */
   /* search652_1 -> 2003 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 6, 2003 },
      -1,
   } },

   /* replace652_0 -> 6 in the cache */
   /* replace652_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search653_0_0 -> 11 in the cache */
   /* search653_0_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 11, 748 },
      -1,
   } },
   /* search653_1_0 -> 207 in the cache */
   /* search653_1_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 207, 748 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 2010, 2011 },
      -1,
   } },

   /* replace653_0_0 -> 11 in the cache */
   /* replace653_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      1, 1,
      { 11, 207 },
      -1,
   } },
   /* replace653_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 2013, 748 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search654_0_0 -> 11 in the cache */
   /* search654_0_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 11, 748 },
      -1,
   } },
   /* search654_1_0 -> 207 in the cache */
   /* search654_1_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 207, 748 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 2015, 2016 },
      -1,
   } },

   /* replace654_0_0 -> 11 in the cache */
   /* replace654_0_1 -> 207 in the cache */
   /* replace654_0 -> 2013 in the cache */
   /* replace654_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 2013, 748 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search655_0_0 -> 11 in the cache */
   /* search655_0_1 -> 748 in the cache */
   /* search655_0 -> 2010 in the cache */
   /* search655_1_0 -> 207 in the cache */
   /* search655_1_1 -> 748 in the cache */
   /* search655_1 -> 2011 in the cache */
   /* search655 -> 2012 in the cache */

   /* replace655_0_0 -> 11 in the cache */
   /* replace655_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_umax,
      1, 1,
      { 11, 207 },
      -1,
   } },
   /* replace655_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 2019, 748 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search656_0_0 -> 11 in the cache */
   /* search656_0_1 -> 748 in the cache */
   /* search656_0 -> 2010 in the cache */
   /* search656_1_0 -> 207 in the cache */
   /* search656_1_1 -> 748 in the cache */
   /* search656_1 -> 2011 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 2010, 2011 },
      -1,
   } },

   /* replace656_0_0 -> 11 in the cache */
   /* replace656_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_umin,
      1, 1,
      { 11, 207 },
      -1,
   } },
   /* replace656_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 2022, 748 },
      -1,
   } },

   /* ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search657_0_0 -> 11 in the cache */
   /* search657_0_1 -> 748 in the cache */
   /* search657_0 -> 2015 in the cache */
   /* search657_1_0 -> 207 in the cache */
   /* search657_1_1 -> 748 in the cache */
   /* search657_1 -> 2016 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 2015, 2016 },
      -1,
   } },

   /* replace657_0_0 -> 11 in the cache */
   /* replace657_0_1 -> 207 in the cache */
   /* replace657_0 -> 2022 in the cache */
   /* replace657_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 2022, 748 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search658_0_0 -> 11 in the cache */
   /* search658_0_1 -> 748 in the cache */
   /* search658_0 -> 2015 in the cache */
   /* search658_1_0 -> 207 in the cache */
   /* search658_1_1 -> 748 in the cache */
   /* search658_1 -> 2016 in the cache */
   /* search658 -> 2017 in the cache */

   /* replace658_0_0 -> 11 in the cache */
   /* replace658_0_1 -> 207 in the cache */
   /* replace658_0 -> 2019 in the cache */
   /* replace658_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 2019, 748 },
      -1,
   } },

   /* ('ineg', ('b2i16', 'a@16')) => a */
   /* search659_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2i16,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 2027 },
      -1,
   } },

   /* replace659 -> 11 in the cache */

   /* ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b') */
   /* search660_0 -> 11 in the cache */
   /* search660_1_0 -> 14 in the cache */
   /* search660_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 14, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 11, 2029 },
      -1,
   } },

   /* replace660_0 -> 11 in the cache */
   /* replace660_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b') */
   /* search661_0 -> 11 in the cache */
   /* search661_1_0 -> 14 in the cache */
   /* search661_1_1 -> 36 in the cache */
   /* search661_1 -> 2029 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 11, 2029 },
      -1,
   } },

   /* replace661_0 -> 11 in the cache */
   /* replace661_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b') */
   /* search662_0 -> 11 in the cache */
   /* search662_1_0 -> 14 in the cache */
   /* search662_1_1 -> 36 in the cache */
   /* search662_1 -> 2029 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 11, 2029 },
      -1,
   } },

   /* replace662_0 -> 11 in the cache */
   /* replace662_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search663_0_0 -> 16 in the cache */
   /* search663_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 16, 120 },
      -1,
   } },
   /* search663_1_0 -> 36 in the cache */
   /* search663_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 2036, 2037 },
      -1,
   } },

   /* replace663_0_0 -> 16 in the cache */
   /* replace663_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace663_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 2039, 120 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search664_0_0 -> 16 in the cache */
   /* search664_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 16, 120 },
      -1,
   } },
   /* search664_1_0 -> 36 in the cache */
   /* search664_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 2041, 2042 },
      -1,
   } },

   /* replace664_0_0 -> 16 in the cache */
   /* replace664_0_1 -> 36 in the cache */
   /* replace664_0 -> 2039 in the cache */
   /* replace664_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 2039, 120 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search665_0_0 -> 16 in the cache */
   /* search665_0_1 -> 120 in the cache */
   /* search665_0 -> 2036 in the cache */
   /* search665_1_0 -> 36 in the cache */
   /* search665_1_1 -> 120 in the cache */
   /* search665_1 -> 2037 in the cache */
   /* search665 -> 2038 in the cache */

   /* replace665_0_0 -> 16 in the cache */
   /* replace665_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umax,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace665_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 2045, 120 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search666_0_0 -> 16 in the cache */
   /* search666_0_1 -> 120 in the cache */
   /* search666_0 -> 2036 in the cache */
   /* search666_1_0 -> 36 in the cache */
   /* search666_1_1 -> 120 in the cache */
   /* search666_1 -> 2037 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 2036, 2037 },
      -1,
   } },

   /* replace666_0_0 -> 16 in the cache */
   /* replace666_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umin,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace666_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 2048, 120 },
      -1,
   } },

   /* ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search667_0_0 -> 16 in the cache */
   /* search667_0_1 -> 120 in the cache */
   /* search667_0 -> 2041 in the cache */
   /* search667_1_0 -> 36 in the cache */
   /* search667_1_1 -> 120 in the cache */
   /* search667_1 -> 2042 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 2041, 2042 },
      -1,
   } },

   /* replace667_0_0 -> 16 in the cache */
   /* replace667_0_1 -> 36 in the cache */
   /* replace667_0 -> 2048 in the cache */
   /* replace667_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 2048, 120 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search668_0_0 -> 16 in the cache */
   /* search668_0_1 -> 120 in the cache */
   /* search668_0 -> 2041 in the cache */
   /* search668_1_0 -> 36 in the cache */
   /* search668_1_1 -> 120 in the cache */
   /* search668_1 -> 2042 in the cache */
   /* search668 -> 2043 in the cache */

   /* replace668_0_0 -> 16 in the cache */
   /* replace668_0_1 -> 36 in the cache */
   /* replace668_0 -> 2045 in the cache */
   /* replace668_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 2045, 120 },
      -1,
   } },

   /* ('ineg', ('b2i32', 'a@32')) => a */
   /* search669_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 2053 },
      -1,
   } },

   /* replace669 -> 16 in the cache */

   /* ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b') */
   /* search670_0 -> 16 in the cache */
   /* search670_1_0 -> 19 in the cache */
   /* search670_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 19, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 16, 2055 },
      -1,
   } },

   /* replace670_0 -> 16 in the cache */
   /* replace670_1 -> 36 in the cache */
   /* replace670 -> 839 in the cache */

   /* ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b') */
   /* search671_0 -> 16 in the cache */
   /* search671_1_0 -> 19 in the cache */
   /* search671_1_1 -> 36 in the cache */
   /* search671_1 -> 2055 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 16, 2055 },
      -1,
   } },

   /* replace671_0 -> 16 in the cache */
   /* replace671_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b') */
   /* search672_0 -> 16 in the cache */
   /* search672_1_0 -> 19 in the cache */
   /* search672_1_1 -> 36 in the cache */
   /* search672_1 -> 2055 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 16, 2055 },
      -1,
   } },

   /* replace672_0 -> 16 in the cache */
   /* replace672_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search673_0_0 -> 21 in the cache */
   /* search673_0_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 21, 791 },
      -1,
   } },
   /* search673_1_0 -> 41 in the cache */
   /* search673_1_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 41, 791 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 2061, 2062 },
      -1,
   } },

   /* replace673_0_0 -> 21 in the cache */
   /* replace673_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ior,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace673_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 2064, 791 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search674_0_0 -> 21 in the cache */
   /* search674_0_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 21, 791 },
      -1,
   } },
   /* search674_1_0 -> 41 in the cache */
   /* search674_1_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 41, 791 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 2066, 2067 },
      -1,
   } },

   /* replace674_0_0 -> 21 in the cache */
   /* replace674_0_1 -> 41 in the cache */
   /* replace674_0 -> 2064 in the cache */
   /* replace674_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 2064, 791 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search675_0_0 -> 21 in the cache */
   /* search675_0_1 -> 791 in the cache */
   /* search675_0 -> 2061 in the cache */
   /* search675_1_0 -> 41 in the cache */
   /* search675_1_1 -> 791 in the cache */
   /* search675_1 -> 2062 in the cache */
   /* search675 -> 2063 in the cache */

   /* replace675_0_0 -> 21 in the cache */
   /* replace675_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_umax,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace675_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 2070, 791 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search676_0_0 -> 21 in the cache */
   /* search676_0_1 -> 791 in the cache */
   /* search676_0 -> 2061 in the cache */
   /* search676_1_0 -> 41 in the cache */
   /* search676_1_1 -> 791 in the cache */
   /* search676_1 -> 2062 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 2061, 2062 },
      -1,
   } },

   /* replace676_0_0 -> 21 in the cache */
   /* replace676_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_umin,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace676_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 2073, 791 },
      -1,
   } },

   /* ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search677_0_0 -> 21 in the cache */
   /* search677_0_1 -> 791 in the cache */
   /* search677_0 -> 2066 in the cache */
   /* search677_1_0 -> 41 in the cache */
   /* search677_1_1 -> 791 in the cache */
   /* search677_1 -> 2067 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 2066, 2067 },
      -1,
   } },

   /* replace677_0_0 -> 21 in the cache */
   /* replace677_0_1 -> 41 in the cache */
   /* replace677_0 -> 2073 in the cache */
   /* replace677_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 2073, 791 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search678_0_0 -> 21 in the cache */
   /* search678_0_1 -> 791 in the cache */
   /* search678_0 -> 2066 in the cache */
   /* search678_1_0 -> 41 in the cache */
   /* search678_1_1 -> 791 in the cache */
   /* search678_1 -> 2067 in the cache */
   /* search678 -> 2068 in the cache */

   /* replace678_0_0 -> 21 in the cache */
   /* replace678_0_1 -> 41 in the cache */
   /* replace678_0 -> 2070 in the cache */
   /* replace678_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 2070, 791 },
      -1,
   } },

   /* ('ineg', ('b2i64', 'a@64')) => a */
   /* search679_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2i64,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 2078 },
      -1,
   } },

   /* replace679 -> 21 in the cache */

   /* ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b') */
   /* search680_0 -> 21 in the cache */
   /* search680_1_0 -> 24 in the cache */
   /* search680_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 24, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 21, 2080 },
      -1,
   } },

   /* replace680_0 -> 21 in the cache */
   /* replace680_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b') */
   /* search681_0 -> 21 in the cache */
   /* search681_1_0 -> 24 in the cache */
   /* search681_1_1 -> 36 in the cache */
   /* search681_1 -> 2080 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 21, 2080 },
      -1,
   } },

   /* replace681_0 -> 21 in the cache */
   /* replace681_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b') */
   /* search682_0 -> 21 in the cache */
   /* search682_1_0 -> 24 in the cache */
   /* search682_1_1 -> 36 in the cache */
   /* search682_1 -> 2080 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 21, 2080 },
      -1,
   } },

   /* replace682_0 -> 21 in the cache */
   /* replace682_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a') */
   /* search683_0_0 -> 32 in the cache */
   /* search683_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 32, 61 },
      -1,
   } },
   /* search683_1_0 -> 32 in the cache */
   /* search683_1_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 2087, 2088 },
      -1,
   } },

   /* replace683_0 -> 35 in the cache */
   /* replace683_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 35, 32 },
      -1,
   } },

   /* ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a') */
   /* search684_0_0 -> 35 in the cache */
   /* search684_0_1 -> 32 in the cache */
   /* search684_0 -> 2090 in the cache */
   /* search684_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 32, 2091 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 2,
      { 2090, 2092 },
      -1,
   } },

   /* replace684_0 -> 2091 in the cache */
   /* replace684_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 2091, 32 },
      -1,
   } },

   /* ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a') */
   /* search685_0_0 -> 2091 in the cache */
   /* search685_0_1 -> 32 in the cache */
   /* search685_0 -> 2094 in the cache */
   /* search685_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 32, 2095 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 2,
      { 2094, 2096 },
      -1,
   } },

   /* replace685_0 -> 2095 in the cache */
   /* replace685_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 2095, 32 },
      -1,
   } },

   /* ('ior', 'a', ('ieq', 'a', False)) => True */
   /* search686_0 -> 650 in the cache */
   /* search686_1_0 -> 650 in the cache */
   /* search686_1_1 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 650, 968 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 2,
      { 650, 2099 },
      -1,
   } },

   /* replace686 -> 1121 in the cache */

   /* ('ior', 'a', ('inot', 'a')) => -1 */
   /* search687_0 -> 32 in the cache */
   /* search687_1_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 32, 2101 },
      -1,
   } },

   /* replace687 -> 63 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b') */
   /* search688_0_0_0 -> 650 in the cache */
   /* search688_0_0 -> 1112 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 1112 },
      -1,
   } },
   /* search688_1_0_0 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2i,
      -1, 0,
      { 1019 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 2104 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 2103, 2105 },
      -1,
   } },

   /* replace688_0 -> 650 in the cache */
   /* replace688_1 -> 1019 in the cache */
   /* replace688 -> 1264 in the cache */

   /* ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b')) */
   /* search689_0_0 -> 650 in the cache */
   /* search689_0_1 -> 1019 in the cache */
   /* search689_0 -> 1264 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2i,
      -1, 1,
      { 1264 },
      -1,
   } },

   /* replace689_0_0 -> 650 in the cache */
   /* replace689_0_1 -> 1019 in the cache */
   /* replace689_0 -> 1036 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2i,
      -1, 1,
      { 1036 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0)) */
   /* search690_0_0_0_0_0 -> 32 in the cache */
   /* search690_0_0_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      3, 1,
      { 32, 61 },
      -1,
   } },
   /* search690_0_0_0_1 -> 1019 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      2, 2,
      { 2109, 1019 },
      -1,
   } },
   /* search690_0_0_1 -> 384 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      1, 3,
      { 2110, 384 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 3,
      { 2111 },
      -1,
   } },
   /* search690_1_0 -> 32 in the cache */
   /* search690_1_1 -> 61 in the cache */
   /* search690_1 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 4,
      { 2112, 1135 },
      -1,
   } },

   /* replace690_0_0_0 -> 1019 in the cache */
   /* replace690_0_0_1 -> 384 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      1, 1,
      { 1019, 384 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 1,
      { 2114 },
      -1,
   } },
   /* replace690_1_0 -> 32 in the cache */
   /* replace690_1_1 -> 61 in the cache */
   /* replace690_1 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 2115, 1135 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0)) */
   /* search691_0_0_0_0_0 -> 0 in the cache */
   /* search691_0_0_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_umin,
      3, 1,
      { 0, 3 },
      -1,
   } },
   /* search691_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 2,
      { 2117, 86 },
      -1,
   } },
   /* search691_0_0_1 -> 384 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      1, 3,
      { 2118, 384 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 3,
      { 2119 },
      -1,
   } },
   /* search691_1_0 -> 0 in the cache */
   /* search691_1_1 -> 86 in the cache */
   /* search691_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 4,
      { 2120, 90 },
      -1,
   } },

   /* replace691_0_0_0_0 -> 3 in the cache */
   /* replace691_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 3, 86 },
      -1,
   } },
   /* replace691_0_0_1 -> 384 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      1, 2,
      { 2122, 384 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 2,
      { 2123 },
      -1,
   } },
   /* replace691_1_0 -> 0 in the cache */
   /* replace691_1_1 -> 86 in the cache */
   /* replace691_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 2124, 90 },
      -1,
   } },

   /* ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b') */
   /* search692_0 -> 32 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search692_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 2126, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 32, 2127 },
      -1,
   } },

   /* replace692_0 -> 32 in the cache */
   /* replace692_1 -> 2126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 32, 2126 },
      -1,
   } },

   /* ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a') */
   /* search693_0_0 -> 0 in the cache */
   /* search693_0_1 -> 3 in the cache */
   /* search693_0 -> 1169 in the cache */
   /* search693_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 1169, 0 },
      -1,
   } },

   /* replace693_0 -> 3 in the cache */
   /* replace693_1 -> 0 in the cache */
   /* replace693 -> 969 in the cache */

   /* ('~fge', 'a', ('fmin', 'b', 'a')) => True */
   /* search694_0 -> 32 in the cache */
   /* search694_1_0 -> 2126 in the cache */
   /* search694_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 2126, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 1,
      { 32, 2131 },
      -1,
   } },

   /* replace694 -> 1121 in the cache */

   /* ('~fge', ('fmax', 'a', 'b'), 'a') => True */
   /* search695_0_0 -> 0 in the cache */
   /* search695_0_1 -> 3 in the cache */
   /* search695_0 -> 1167 in the cache */
   /* search695_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 1,
      { 1167, 0 },
      -1,
   } },

   /* replace695 -> 1121 in the cache */

   /* ('flt', 'a', ('fmin', 'b', 'a')) => False */
   /* search696_0 -> 32 in the cache */
   /* search696_1_0 -> 2126 in the cache */
   /* search696_1_1 -> 32 in the cache */
   /* search696_1 -> 2131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 32, 2131 },
      -1,
   } },

   /* replace696 -> 968 in the cache */

   /* ('flt', ('fmax', 'a', 'b'), 'a') => False */
   /* search697_0_0 -> 0 in the cache */
   /* search697_0_1 -> 3 in the cache */
   /* search697_0 -> 1167 in the cache */
   /* search697_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 1167, 0 },
      -1,
   } },

   /* replace697 -> 968 in the cache */

   /* ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b') */
   /* search698_0 -> 32 in the cache */
   /* search698_1_0 -> 2126 in the cache */
   /* search698_1_1 -> 32 in the cache */
   /* search698_1 -> 2127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 1,
      { 32, 2127 },
      -1,
   } },

   /* replace698_0 -> 32 in the cache */
   /* replace698_1 -> 2126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 32, 2126 },
      -1,
   } },

   /* ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a') */
   /* search699_0_0 -> 0 in the cache */
   /* search699_0_1 -> 3 in the cache */
   /* search699_0 -> 1169 in the cache */
   /* search699_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 1,
      { 1169, 0 },
      -1,
   } },

   /* replace699_0 -> 3 in the cache */
   /* replace699_1 -> 0 in the cache */
   /* replace699 -> 981 in the cache */

   /* ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b') */
   /* search700_0 -> 32 in the cache */
   /* search700_1_0 -> 2126 in the cache */
   /* search700_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imax,
      0, 1,
      { 2126, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 32, 2139 },
      -1,
   } },

   /* replace700_0 -> 32 in the cache */
   /* replace700_1 -> 2126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 32, 2126 },
      -1,
   } },

   /* ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a') */
   /* search701_0_0 -> 0 in the cache */
   /* search701_0_1 -> 3 in the cache */
   /* search701_0 -> 1229 in the cache */
   /* search701_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 1229, 0 },
      -1,
   } },

   /* replace701_0 -> 3 in the cache */
   /* replace701_1 -> 0 in the cache */
   /* replace701 -> 974 in the cache */

   /* ('ige', 'a', ('imin', 'b', 'a')) => True */
   /* search702_0 -> 32 in the cache */
   /* search702_1_0 -> 2126 in the cache */
   /* search702_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imin,
      0, 1,
      { 2126, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 32, 2143 },
      -1,
   } },

   /* replace702 -> 1121 in the cache */

   /* ('ige', ('imax', 'a', 'b'), 'a') => True */
   /* search703_0_0 -> 0 in the cache */
   /* search703_0_1 -> 3 in the cache */
   /* search703_0 -> 1221 in the cache */
   /* search703_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 1221, 0 },
      -1,
   } },

   /* replace703 -> 1121 in the cache */

   /* ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b') */
   /* search704_0 -> 32 in the cache */
   /* search704_1_0 -> 2126 in the cache */
   /* search704_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_umax,
      0, 1,
      { 2126, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 32, 2146 },
      -1,
   } },

   /* replace704_0 -> 32 in the cache */
   /* replace704_1 -> 2126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 32, 2126 },
      -1,
   } },

   /* ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a') */
   /* search705_0_0 -> 0 in the cache */
   /* search705_0_1 -> 3 in the cache */
   /* search705_0 -> 1226 in the cache */
   /* search705_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 1226, 0 },
      -1,
   } },

   /* replace705_0 -> 3 in the cache */
   /* replace705_1 -> 0 in the cache */
   /* replace705 -> 976 in the cache */

   /* ('uge', 'a', ('umin', 'b', 'a')) => True */
   /* search706_0 -> 32 in the cache */
   /* search706_1_0 -> 2126 in the cache */
   /* search706_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_umin,
      0, 1,
      { 2126, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 32, 2150 },
      -1,
   } },

   /* replace706 -> 1121 in the cache */

   /* ('uge', ('umax', 'a', 'b'), 'a') => True */
   /* search707_0_0 -> 0 in the cache */
   /* search707_0_1 -> 3 in the cache */
   /* search707_0 -> 1218 in the cache */
   /* search707_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 1218, 0 },
      -1,
   } },

   /* replace707 -> 1121 in the cache */

   /* ('ilt', 'a', ('imin', 'b', 'a')) => False */
   /* search708_0 -> 32 in the cache */
   /* search708_1_0 -> 2126 in the cache */
   /* search708_1_1 -> 32 in the cache */
   /* search708_1 -> 2143 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 32, 2143 },
      -1,
   } },

   /* replace708 -> 968 in the cache */

   /* ('ilt', ('imax', 'a', 'b'), 'a') => False */
   /* search709_0_0 -> 0 in the cache */
   /* search709_0_1 -> 3 in the cache */
   /* search709_0 -> 1221 in the cache */
   /* search709_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 1221, 0 },
      -1,
   } },

   /* replace709 -> 968 in the cache */

   /* ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b') */
   /* search710_0 -> 32 in the cache */
   /* search710_1_0 -> 2126 in the cache */
   /* search710_1_1 -> 32 in the cache */
   /* search710_1 -> 2139 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 32, 2139 },
      -1,
   } },

   /* replace710_0 -> 32 in the cache */
   /* replace710_1 -> 2126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 32, 2126 },
      -1,
   } },

   /* ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a') */
   /* search711_0_0 -> 0 in the cache */
   /* search711_0_1 -> 3 in the cache */
   /* search711_0 -> 1229 in the cache */
   /* search711_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 1229, 0 },
      -1,
   } },

   /* replace711_0 -> 3 in the cache */
   /* replace711_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('umin', 'b', 'a')) => False */
   /* search712_0 -> 32 in the cache */
   /* search712_1_0 -> 2126 in the cache */
   /* search712_1_1 -> 32 in the cache */
   /* search712_1 -> 2150 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 32, 2150 },
      -1,
   } },

   /* replace712 -> 968 in the cache */

   /* ('ult', ('umax', 'a', 'b'), 'a') => False */
   /* search713_0_0 -> 0 in the cache */
   /* search713_0_1 -> 3 in the cache */
   /* search713_0 -> 1218 in the cache */
   /* search713_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 1218, 0 },
      -1,
   } },

   /* replace713 -> 968 in the cache */

   /* ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b') */
   /* search714_0 -> 32 in the cache */
   /* search714_1_0 -> 2126 in the cache */
   /* search714_1_1 -> 32 in the cache */
   /* search714_1 -> 2146 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 32, 2146 },
      -1,
   } },

   /* replace714_0 -> 32 in the cache */
   /* replace714_1 -> 2126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 32, 2126 },
      -1,
   } },

   /* ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a') */
   /* search715_0_0 -> 0 in the cache */
   /* search715_0_1 -> 3 in the cache */
   /* search715_0 -> 1226 in the cache */
   /* search715_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 1226, 0 },
      -1,
   } },

   /* replace715_0 -> 3 in the cache */
   /* replace715_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('iand', 'b', 'a')) => False */
   /* search716_0 -> 32 in the cache */
   /* search716_1_0 -> 2126 in the cache */
   /* search716_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2126, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 32, 2165 },
      -1,
   } },

   /* replace716 -> 968 in the cache */

   /* ('ult', ('ior', 'a', 'b'), 'a') => False */
   /* search717_0_0 -> 0 in the cache */
   /* search717_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ior,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* search717_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 2167, 0 },
      -1,
   } },

   /* replace717 -> 968 in the cache */

   /* ('uge', 'a', ('iand', 'b', 'a')) => True */
   /* search718_0 -> 32 in the cache */
   /* search718_1_0 -> 2126 in the cache */
   /* search718_1_1 -> 32 in the cache */
   /* search718_1 -> 2165 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 32, 2165 },
      -1,
   } },

   /* replace718 -> 1121 in the cache */

   /* ('uge', ('ior', 'a', 'b'), 'a') => True */
   /* search719_0_0 -> 0 in the cache */
   /* search719_0_1 -> 3 in the cache */
   /* search719_0 -> 2167 in the cache */
   /* search719_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 2167, 0 },
      -1,
   } },

   /* replace719 -> 1121 in the cache */

   /* ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search720_0 -> 222 in the cache */
   /* search720_1_0 -> 223 in the cache */
   /* search720_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imax,
      0, 1,
      { 223, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 222, 2171 },
      -1,
   } },

   /* replace720_0_0 -> 124 in the cache */
   /* replace720_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace720_1_0 -> 124 in the cache */
   /* replace720_1_1 -> 127 in the cache */
   /* replace720_1 -> 1525 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2173, 1525 },
      -1,
   } },

   /* ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search721_0_0 -> 222 in the cache */
   /* search721_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imin,
      0, 1,
      { 222, 125 },
      -1,
   } },
   /* search721_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 2175, 704 },
      -1,
   } },

   /* replace721_0_0 -> 124 in the cache */
   /* replace721_0_1 -> 127 in the cache */
   /* replace721_0 -> 1525 in the cache */
   /* replace721_1_0 -> 125 in the cache */
   /* replace721_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1525, 2177 },
      -1,
   } },

   /* ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search722_0 -> 222 in the cache */
   /* search722_1_0 -> 223 in the cache */
   /* search722_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imin,
      0, 1,
      { 223, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 222, 2179 },
      -1,
   } },

   /* replace722_0_0 -> 124 in the cache */
   /* replace722_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace722_1_0 -> 124 in the cache */
   /* replace722_1_1 -> 127 in the cache */
   /* replace722_1 -> 1535 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2181, 1535 },
      -1,
   } },

   /* ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search723_0_0 -> 222 in the cache */
   /* search723_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imax,
      0, 1,
      { 222, 125 },
      -1,
   } },
   /* search723_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 2183, 704 },
      -1,
   } },

   /* replace723_0_0 -> 124 in the cache */
   /* replace723_0_1 -> 127 in the cache */
   /* replace723_0 -> 1535 in the cache */
   /* replace723_1_0 -> 125 in the cache */
   /* replace723_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1535, 2185 },
      -1,
   } },

   /* ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search724_0 -> 222 in the cache */
   /* search724_1_0 -> 223 in the cache */
   /* search724_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umax,
      0, 1,
      { 223, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 222, 2187 },
      -1,
   } },

   /* replace724_0_0 -> 124 in the cache */
   /* replace724_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace724_1_0 -> 124 in the cache */
   /* replace724_1_1 -> 127 in the cache */
   /* replace724_1 -> 1545 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2189, 1545 },
      -1,
   } },

   /* ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search725_0_0 -> 222 in the cache */
   /* search725_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umin,
      0, 1,
      { 222, 125 },
      -1,
   } },
   /* search725_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 2191, 704 },
      -1,
   } },

   /* replace725_0_0 -> 124 in the cache */
   /* replace725_0_1 -> 127 in the cache */
   /* replace725_0 -> 1545 in the cache */
   /* replace725_1_0 -> 125 in the cache */
   /* replace725_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1545, 2193 },
      -1,
   } },

   /* ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search726_0 -> 222 in the cache */
   /* search726_1_0 -> 223 in the cache */
   /* search726_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umin,
      0, 1,
      { 223, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 222, 2195 },
      -1,
   } },

   /* replace726_0_0 -> 124 in the cache */
   /* replace726_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace726_1_0 -> 124 in the cache */
   /* replace726_1_1 -> 127 in the cache */
   /* replace726_1 -> 1555 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2197, 1555 },
      -1,
   } },

   /* ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search727_0_0 -> 222 in the cache */
   /* search727_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_umax,
      0, 1,
      { 222, 125 },
      -1,
   } },
   /* search727_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 2199, 704 },
      -1,
   } },

   /* replace727_0_0 -> 124 in the cache */
   /* replace727_0_1 -> 127 in the cache */
   /* replace727_0 -> 1555 in the cache */
   /* replace727_1_0 -> 125 in the cache */
   /* replace727_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1555, 2201 },
      -1,
   } },

   /* ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search728_0 -> 222 in the cache */
   /* search728_1_0 -> 223 in the cache */
   /* search728_1_1 -> 127 in the cache */
   /* search728_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 222, 2179 },
      -1,
   } },

   /* replace728_0_0 -> 124 in the cache */
   /* replace728_0_1 -> 125 in the cache */
   /* replace728_0 -> 2173 in the cache */
   /* replace728_1_0 -> 124 in the cache */
   /* replace728_1_1 -> 127 in the cache */
   /* replace728_1 -> 1525 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2173, 1525 },
      -1,
   } },

   /* ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search729_0_0 -> 222 in the cache */
   /* search729_0_1 -> 125 in the cache */
   /* search729_0 -> 2183 in the cache */
   /* search729_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 2183, 704 },
      -1,
   } },

   /* replace729_0_0 -> 124 in the cache */
   /* replace729_0_1 -> 127 in the cache */
   /* replace729_0 -> 1525 in the cache */
   /* replace729_1_0 -> 125 in the cache */
   /* replace729_1_1 -> 127 in the cache */
   /* replace729_1 -> 2177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1525, 2177 },
      -1,
   } },

   /* ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search730_0 -> 222 in the cache */
   /* search730_1_0 -> 223 in the cache */
   /* search730_1_1 -> 127 in the cache */
   /* search730_1 -> 2171 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 222, 2171 },
      -1,
   } },

   /* replace730_0_0 -> 124 in the cache */
   /* replace730_0_1 -> 125 in the cache */
   /* replace730_0 -> 2181 in the cache */
   /* replace730_1_0 -> 124 in the cache */
   /* replace730_1_1 -> 127 in the cache */
   /* replace730_1 -> 1535 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2181, 1535 },
      -1,
   } },

   /* ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search731_0_0 -> 222 in the cache */
   /* search731_0_1 -> 125 in the cache */
   /* search731_0 -> 2175 in the cache */
   /* search731_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 2175, 704 },
      -1,
   } },

   /* replace731_0_0 -> 124 in the cache */
   /* replace731_0_1 -> 127 in the cache */
   /* replace731_0 -> 1535 in the cache */
   /* replace731_1_0 -> 125 in the cache */
   /* replace731_1_1 -> 127 in the cache */
   /* replace731_1 -> 2185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1535, 2185 },
      -1,
   } },

   /* ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search732_0 -> 222 in the cache */
   /* search732_1_0 -> 223 in the cache */
   /* search732_1_1 -> 127 in the cache */
   /* search732_1 -> 2195 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 222, 2195 },
      -1,
   } },

   /* replace732_0_0 -> 124 in the cache */
   /* replace732_0_1 -> 125 in the cache */
   /* replace732_0 -> 2189 in the cache */
   /* replace732_1_0 -> 124 in the cache */
   /* replace732_1_1 -> 127 in the cache */
   /* replace732_1 -> 1545 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2189, 1545 },
      -1,
   } },

   /* ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search733_0_0 -> 222 in the cache */
   /* search733_0_1 -> 125 in the cache */
   /* search733_0 -> 2199 in the cache */
   /* search733_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 2199, 704 },
      -1,
   } },

   /* replace733_0_0 -> 124 in the cache */
   /* replace733_0_1 -> 127 in the cache */
   /* replace733_0 -> 1545 in the cache */
   /* replace733_1_0 -> 125 in the cache */
   /* replace733_1_1 -> 127 in the cache */
   /* replace733_1 -> 2193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1545, 2193 },
      -1,
   } },

   /* ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search734_0 -> 222 in the cache */
   /* search734_1_0 -> 223 in the cache */
   /* search734_1_1 -> 127 in the cache */
   /* search734_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 222, 2187 },
      -1,
   } },

   /* replace734_0_0 -> 124 in the cache */
   /* replace734_0_1 -> 125 in the cache */
   /* replace734_0 -> 2197 in the cache */
   /* replace734_1_0 -> 124 in the cache */
   /* replace734_1_1 -> 127 in the cache */
   /* replace734_1 -> 1555 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2197, 1555 },
      -1,
   } },

   /* ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search735_0_0 -> 222 in the cache */
   /* search735_0_1 -> 125 in the cache */
   /* search735_0 -> 2191 in the cache */
   /* search735_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 1,
      { 2191, 704 },
      -1,
   } },

   /* replace735_0_0 -> 124 in the cache */
   /* replace735_0_1 -> 127 in the cache */
   /* replace735_0 -> 1555 in the cache */
   /* replace735_1_0 -> 125 in the cache */
   /* replace735_1_1 -> 127 in the cache */
   /* replace735_1 -> 2201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1555, 2201 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b')) */
   /* search736_0_0 -> 32 in the cache */
   /* search736_0_1 -> 61 in the cache */
   /* search736_0 -> 1135 in the cache */
   /* search736_1_0_0 -> 32 in the cache */
   /* search736_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 32, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 2219 },
      -1,
   } },
   /* search736_2_0 -> 32 in the cache */
   /* search736_2_1 -> 36 in the cache */
   /* search736_2 -> 2219 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1135, 2220, 2219 },
      -1,
   } },

   /* replace736_0_0 -> 32 in the cache */
   /* replace736_0_1 -> 36 in the cache */
   /* replace736_0 -> 2219 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 2219 },
      -1,
   } },

   /* ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b') */
   /* search737_0_0_0 -> 32 in the cache */
   /* search737_0_0 -> 106 in the cache */
   /* search737_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 106, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 2223 },
      -1,
   } },

   /* replace737_0_0 -> 32 in the cache */
   /* replace737_0 -> 106 in the cache */
   /* replace737_1 -> 36 in the cache */
   /* replace737 -> 2223 in the cache */

   /* ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b') */
   /* search738_0_0 -> 16 in the cache */
   /* search738_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_slt,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 2225 },
      -1,
   } },

   /* replace738_0 -> 16 in the cache */
   /* replace738_1 -> 36 in the cache */
   /* replace738 -> 2225 in the cache */

   /* ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b') */
   /* search739_0_0 -> 0 in the cache */
   /* search739_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_sge,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 2227 },
      -1,
   } },

   /* replace739_0 -> 0 in the cache */
   /* replace739_1 -> 3 in the cache */
   /* replace739 -> 2227 in the cache */

   /* ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b') */
   /* search740_0_0 -> 16 in the cache */
   /* search740_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fabs,
      -1, 1,
      { 2229 },
      -1,
   } },

   /* replace740_0 -> 16 in the cache */
   /* replace740_1 -> 36 in the cache */
   /* replace740 -> 2229 in the cache */

   /* ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b') */
   /* search741_0_0 -> 16 in the cache */
   /* search741_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fabs,
      -1, 1,
      { 2231 },
      -1,
   } },

   /* replace741_0 -> 16 in the cache */
   /* replace741_1 -> 36 in the cache */
   /* replace741 -> 2231 in the cache */

   /* ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b')) */
   /* search742_0 -> 16 in the cache */
   /* search742_1 -> 36 in the cache */
   /* search742 -> 2225 in the cache */

   /* replace742_0_0 -> 16 in the cache */
   /* replace742_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 2233 },
      -1,
   } },

   /* ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b')) */
   /* search743_0 -> 0 in the cache */
   /* search743_1 -> 3 in the cache */
   /* search743 -> 2227 in the cache */

   /* replace743_0_0 -> 0 in the cache */
   /* replace743_0_1 -> 3 in the cache */
   /* replace743_0 -> 937 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 937 },
      -1,
   } },

   /* ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b')) */
   /* search744_0 -> 16 in the cache */
   /* search744_1 -> 36 in the cache */
   /* search744 -> 2229 in the cache */

   /* replace744_0_0 -> 16 in the cache */
   /* replace744_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_b2f,
      -1, 1,
      { 2236 },
      -1,
   } },

   /* ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b')) */
   /* search745_0 -> 16 in the cache */
   /* search745_1 -> 36 in the cache */
   /* search745 -> 2231 in the cache */

   /* replace745_0_0 -> 16 in the cache */
   /* replace745_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_b2f,
      -1, 1,
      { 2238 },
      -1,
   } },

   /* ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search746_0_0 -> 16 in the cache */
   /* search746_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* search746_1 -> 474 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 2,
      { 2240, 474 },
      -1,
   } },

   /* replace746_0 -> 16 in the cache */
   /* replace746_1 -> 36 in the cache */
   /* replace746 -> 2229 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search747_0_0 -> 16 in the cache */
   /* search747_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* search747_1 -> 474 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 2,
      { 2242, 474 },
      -1,
   } },

   /* replace747_0 -> 16 in the cache */
   /* replace747_1 -> 36 in the cache */
   /* replace747 -> 2231 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search748_0_0 -> 16 in the cache */
   /* search748_0_1 -> 36 in the cache */
   /* search748_0 -> 2225 in the cache */
   /* search748_1 -> 474 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 1,
      { 2225, 474 },
      -1,
   } },

   /* replace748_0 -> 16 in the cache */
   /* replace748_1 -> 36 in the cache */
   /* replace748 -> 2225 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search749_0_0 -> 16 in the cache */
   /* search749_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sge,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   /* search749_1 -> 474 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 1,
      { 2245, 474 },
      -1,
   } },

   /* replace749_0 -> 16 in the cache */
   /* replace749_1 -> 36 in the cache */
   /* replace749 -> 2245 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search750_0_0 -> 16 in the cache */
   /* search750_0_1 -> 36 in the cache */
   /* search750_0 -> 2240 in the cache */
   /* search750_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      0, 2,
      { 2240, 117 },
      -1,
   } },

   /* replace750_0 -> 16 in the cache */
   /* replace750_1 -> 36 in the cache */
   /* replace750 -> 2229 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search751_0_0 -> 16 in the cache */
   /* search751_0_1 -> 36 in the cache */
   /* search751_0 -> 2242 in the cache */
   /* search751_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      0, 2,
      { 2242, 117 },
      -1,
   } },

   /* replace751_0 -> 16 in the cache */
   /* replace751_1 -> 36 in the cache */
   /* replace751 -> 2231 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search752_0_0 -> 16 in the cache */
   /* search752_0_1 -> 36 in the cache */
   /* search752_0 -> 2225 in the cache */
   /* search752_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      0, 1,
      { 2225, 117 },
      -1,
   } },

   /* replace752_0 -> 16 in the cache */
   /* replace752_1 -> 36 in the cache */
   /* replace752 -> 2225 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search753_0_0 -> 16 in the cache */
   /* search753_0_1 -> 36 in the cache */
   /* search753_0 -> 2245 in the cache */
   /* search753_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      0, 1,
      { 2245, 117 },
      -1,
   } },

   /* replace753_0 -> 16 in the cache */
   /* replace753_1 -> 36 in the cache */
   /* replace753 -> 2245 in the cache */

   /* ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search754_0_0 -> 16 in the cache */
   /* search754_0_1 -> 36 in the cache */
   /* search754_0 -> 2240 in the cache */
   /* search754_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 2,
      { 2240, 117 },
      -1,
   } },

   /* replace754_0 -> 16 in the cache */
   /* replace754_1 -> 36 in the cache */
   /* replace754 -> 2231 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search755_0_0 -> 16 in the cache */
   /* search755_0_1 -> 36 in the cache */
   /* search755_0 -> 2242 in the cache */
   /* search755_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 2,
      { 2242, 117 },
      -1,
   } },

   /* replace755_0 -> 16 in the cache */
   /* replace755_1 -> 36 in the cache */
   /* replace755 -> 2229 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search756_0_0 -> 16 in the cache */
   /* search756_0_1 -> 36 in the cache */
   /* search756_0 -> 2225 in the cache */
   /* search756_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 1,
      { 2225, 117 },
      -1,
   } },

   /* replace756_0 -> 16 in the cache */
   /* replace756_1 -> 36 in the cache */
   /* replace756 -> 2245 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search757_0_0 -> 16 in the cache */
   /* search757_0_1 -> 36 in the cache */
   /* search757_0 -> 2245 in the cache */
   /* search757_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 1,
      { 2245, 117 },
      -1,
   } },

   /* replace757_0 -> 16 in the cache */
   /* replace757_1 -> 36 in the cache */
   /* replace757 -> 2225 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search758_0_0 -> 16 in the cache */
   /* search758_0_1 -> 36 in the cache */
   /* search758_0 -> 2240 in the cache */
   /* search758_1 -> 474 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      0, 2,
      { 2240, 474 },
      -1,
   } },

   /* replace758_0 -> 16 in the cache */
   /* replace758_1 -> 36 in the cache */
   /* replace758 -> 2231 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search759_0_0 -> 16 in the cache */
   /* search759_0_1 -> 36 in the cache */
   /* search759_0 -> 2242 in the cache */
   /* search759_1 -> 474 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      0, 2,
      { 2242, 474 },
      -1,
   } },

   /* replace759_0 -> 16 in the cache */
   /* replace759_1 -> 36 in the cache */
   /* replace759 -> 2229 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search760_0_0 -> 16 in the cache */
   /* search760_0_1 -> 36 in the cache */
   /* search760_0 -> 2225 in the cache */
   /* search760_1 -> 474 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      0, 1,
      { 2225, 474 },
      -1,
   } },

   /* replace760_0 -> 16 in the cache */
   /* replace760_1 -> 36 in the cache */
   /* replace760 -> 2245 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search761_0_0 -> 16 in the cache */
   /* search761_0_1 -> 36 in the cache */
   /* search761_0 -> 2245 in the cache */
   /* search761_1 -> 474 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      0, 1,
      { 2245, 474 },
      -1,
   } },

   /* replace761_0 -> 16 in the cache */
   /* replace761_1 -> 36 in the cache */
   /* replace761 -> 2225 in the cache */

   /* ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y')) */
   /* search762_0 -> 16 in the cache */
   /* search762_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fall_equal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 1,
      { 2260, 2261 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      1, 1,
      { 2263, 2264 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmin,
      -1, 2,
      { 2262, 2265 },
      -1,
   } },

   /* ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0) */
   /* search763_0 -> 16 in the cache */
   /* search763_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fall_equal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace763_0_0 -> 16 in the cache */
   /* replace763_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fany_nequal3,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace763_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 2,
      { 2268, 117 },
      -1,
   } },

   /* ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0) */
   /* search764_0 -> 16 in the cache */
   /* search764_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fall_equal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace764_0_0 -> 16 in the cache */
   /* replace764_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fany_nequal4,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace764_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_seq,
      0, 2,
      { 2271, 117 },
      -1,
   } },

   /* ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y')) */
   /* search765_0 -> 16 in the cache */
   /* search765_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fany_nequal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace765_0_0 -> 2260 in the cache */
   /* replace765_0_1 -> 2261 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      0, 1,
      { 2260, 2261 },
      -1,
   } },
   /* replace765_1_0 -> 2263 in the cache */
   /* replace765_1_1 -> 2264 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sne,
      1, 1,
      { 2263, 2264 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmax,
      -1, 2,
      { 2274, 2275 },
      -1,
   } },

   /* ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search766_0 -> 16 in the cache */
   /* search766_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fany_nequal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace766_0_0_0 -> 16 in the cache */
   /* replace766_0_0_1 -> 36 in the cache */
   /* replace766_0_0 -> 2231 in the cache */
   /* replace766_0_1_0 -> 16 in the cache */
   /* replace766_0_1_1 -> 36 in the cache */
   /* replace766_0_1 -> 2242 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fdot3,
      -1, 2,
      { 2231, 2242 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fsat,
      -1, 2,
      { 2278 },
      -1,
   } },

   /* ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search767_0 -> 16 in the cache */
   /* search767_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fany_nequal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace767_0_0_0 -> 16 in the cache */
   /* replace767_0_0_1 -> 36 in the cache */
   /* replace767_0_0 -> 2231 in the cache */
   /* replace767_0_1_0 -> 16 in the cache */
   /* replace767_0_1_1 -> 36 in the cache */
   /* replace767_0_1 -> 2242 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fdot4,
      -1, 2,
      { 2231, 2242 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fsat,
      -1, 2,
      { 2281 },
      -1,
   } },

   /* ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')) */
   /* search768_0 -> 0 in the cache */
   /* search768_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace768_0_0 -> 659 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 659, 2284 },
      -1,
   } },
   /* replace768_1_0 -> 660 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 660, 2286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      -1, 2,
      { 2285, 2287 },
      -1,
   } },

   /* ('ball_iequal3', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('ieq', 'a.z', 'b.z')) */
   /* search769_0 -> 0 in the cache */
   /* search769_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace769_0_0_0 -> 659 in the cache */
   /* replace769_0_0_1 -> 2284 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 659, 2284 },
      -1,
   } },
   /* replace769_0_1_0 -> 660 in the cache */
   /* replace769_0_1_1 -> 2286 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 660, 2286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      -1, 2,
      { 2290, 2291 },
      -1,
   } },
   /* replace769_1_0 -> 661 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      3, 1,
      { 661, 2293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 4,
      { 2292, 2294 },
      -1,
   } },

   /* ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w'))) */
   /* search770_0 -> 0 in the cache */
   /* search770_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace770_0_0_0 -> 659 in the cache */
   /* replace770_0_0_1 -> 2284 in the cache */
   /* replace770_0_0 -> 2285 in the cache */
   /* replace770_0_1_0 -> 660 in the cache */
   /* replace770_0_1_1 -> 2286 in the cache */
   /* replace770_0_1 -> 2287 in the cache */
   /* replace770_0 -> 2288 in the cache */
   /* replace770_1_0_0 -> 661 in the cache */
   /* replace770_1_0_1 -> 2293 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 661, 2293 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      3, 1,
      { 2298, 2299 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      -1, 2,
      { 2297, 2300 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      -1, 4,
      { 2288, 2301 },
      -1,
   } },

   /* ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')) */
   /* search771_0 -> 0 in the cache */
   /* search771_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace771_0_0 -> 659 in the cache */
   /* replace771_0_1 -> 2284 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 659, 2284 },
      -1,
   } },
   /* replace771_1_0 -> 660 in the cache */
   /* replace771_1_1 -> 2286 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 660, 2286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      -1, 2,
      { 2304, 2305 },
      -1,
   } },

   /* ('bany_inequal3', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ine', 'a.z', 'b.z')) */
   /* search772_0 -> 0 in the cache */
   /* search772_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace772_0_0_0 -> 659 in the cache */
   /* replace772_0_0_1 -> 2284 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 659, 2284 },
      -1,
   } },
   /* replace772_0_1_0 -> 660 in the cache */
   /* replace772_0_1_1 -> 2286 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 660, 2286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      -1, 2,
      { 2308, 2309 },
      -1,
   } },
   /* replace772_1_0 -> 661 in the cache */
   /* replace772_1_1 -> 2293 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      3, 1,
      { 661, 2293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 4,
      { 2310, 2311 },
      -1,
   } },

   /* ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w'))) */
   /* search773_0 -> 0 in the cache */
   /* search773_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace773_0_0_0 -> 659 in the cache */
   /* replace773_0_0_1 -> 2284 in the cache */
   /* replace773_0_0 -> 2304 in the cache */
   /* replace773_0_1_0 -> 660 in the cache */
   /* replace773_0_1_1 -> 2286 in the cache */
   /* replace773_0_1 -> 2305 in the cache */
   /* replace773_0 -> 2306 in the cache */
   /* replace773_1_0_0 -> 661 in the cache */
   /* replace773_1_0_1 -> 2293 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 661, 2293 },
      -1,
   } },
   /* replace773_1_1_0 -> 2298 in the cache */
   /* replace773_1_1_1 -> 2299 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      3, 1,
      { 2298, 2299 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      -1, 2,
      { 2314, 2315 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      -1, 4,
      { 2306, 2316 },
      -1,
   } },

   /* ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')) */
   /* search774_0 -> 0 in the cache */
   /* search774_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_fequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace774_0_0 -> 659 in the cache */
   /* replace774_0_1 -> 2284 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 659, 2284 },
      -1,
   } },
   /* replace774_1_0 -> 660 in the cache */
   /* replace774_1_1 -> 2286 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      1, 1,
      { 660, 2286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      -1, 2,
      { 2319, 2320 },
      -1,
   } },

   /* ('ball_fequal3', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('feq', 'a.z', 'b.z')) */
   /* search775_0 -> 0 in the cache */
   /* search775_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_fequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace775_0_0_0 -> 659 in the cache */
   /* replace775_0_0_1 -> 2284 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      1, 1,
      { 659, 2284 },
      -1,
   } },
   /* replace775_0_1_0 -> 660 in the cache */
   /* replace775_0_1_1 -> 2286 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      2, 1,
      { 660, 2286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      -1, 2,
      { 2323, 2324 },
      -1,
   } },
   /* replace775_1_0 -> 661 in the cache */
   /* replace775_1_1 -> 2293 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      3, 1,
      { 661, 2293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 4,
      { 2325, 2326 },
      -1,
   } },

   /* ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w'))) */
   /* search776_0 -> 0 in the cache */
   /* search776_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_fequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace776_0_0_0 -> 659 in the cache */
   /* replace776_0_0_1 -> 2284 in the cache */
   /* replace776_0_0 -> 2319 in the cache */
   /* replace776_0_1_0 -> 660 in the cache */
   /* replace776_0_1_1 -> 2286 in the cache */
   /* replace776_0_1 -> 2320 in the cache */
   /* replace776_0 -> 2321 in the cache */
   /* replace776_1_0_0 -> 661 in the cache */
   /* replace776_1_0_1 -> 2293 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      2, 1,
      { 661, 2293 },
      -1,
   } },
   /* replace776_1_1_0 -> 2298 in the cache */
   /* replace776_1_1_1 -> 2299 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      3, 1,
      { 2298, 2299 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      -1, 2,
      { 2329, 2330 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      -1, 4,
      { 2321, 2331 },
      -1,
   } },

   /* ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')) */
   /* search777_0 -> 0 in the cache */
   /* search777_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_fnequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace777_0_0 -> 659 in the cache */
   /* replace777_0_1 -> 2284 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 659, 2284 },
      -1,
   } },
   /* replace777_1_0 -> 660 in the cache */
   /* replace777_1_1 -> 2286 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      1, 1,
      { 660, 2286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      -1, 2,
      { 2334, 2335 },
      -1,
   } },

   /* ('bany_fnequal3', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('fneu', 'a.z', 'b.z')) */
   /* search778_0 -> 0 in the cache */
   /* search778_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_fnequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace778_0_0_0 -> 659 in the cache */
   /* replace778_0_0_1 -> 2284 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      1, 1,
      { 659, 2284 },
      -1,
   } },
   /* replace778_0_1_0 -> 660 in the cache */
   /* replace778_0_1_1 -> 2286 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      2, 1,
      { 660, 2286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      -1, 2,
      { 2338, 2339 },
      -1,
   } },
   /* replace778_1_0 -> 661 in the cache */
   /* replace778_1_1 -> 2293 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      3, 1,
      { 661, 2293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 4,
      { 2340, 2341 },
      -1,
   } },

   /* ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w'))) */
   /* search779_0 -> 0 in the cache */
   /* search779_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_fnequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace779_0_0_0 -> 659 in the cache */
   /* replace779_0_0_1 -> 2284 in the cache */
   /* replace779_0_0 -> 2334 in the cache */
   /* replace779_0_1_0 -> 660 in the cache */
   /* replace779_0_1_1 -> 2286 in the cache */
   /* replace779_0_1 -> 2335 in the cache */
   /* replace779_0 -> 2336 in the cache */
   /* replace779_1_0_0 -> 661 in the cache */
   /* replace779_1_0_1 -> 2293 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      2, 1,
      { 661, 2293 },
      -1,
   } },
   /* replace779_1_1_0 -> 2298 in the cache */
   /* replace779_1_1_1 -> 2299 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      3, 1,
      { 2298, 2299 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      -1, 2,
      { 2344, 2345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      -1, 4,
      { 2336, 2346 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0) */
   /* search780_0_0 -> 32 in the cache */
   /* search780_0 -> 98 in the cache */
   /* search780_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace780_0 -> 32 in the cache */
   /* replace780_1 -> 113 in the cache */
   /* replace780 -> 1139 in the cache */

   /* ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0) */
   /* search781_0_0 -> 32 in the cache */
   /* search781_0 -> 98 in the cache */
   /* search781_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace781_0 -> 32 in the cache */
   /* replace781_1 -> 113 in the cache */
   /* replace781 -> 1143 in the cache */

   /* ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search782_0_0 -> 650 in the cache */
   /* search782_0 -> 1112 in the cache */
   /* search782_1_0 -> 1019 in the cache */
   /* search782_1 -> 2104 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_imul,
      0, 1,
      { 1112, 2104 },
      -1,
   } },

   /* replace782_0_0 -> 650 in the cache */
   /* replace782_0_1 -> 1019 in the cache */
   /* replace782_0 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2i,
      -1, 1,
      { 1031 },
      -1,
   } },

   /* ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search783_0_0 -> 650 in the cache */
   /* search783_0 -> 1112 in the cache */
   /* search783_1_0 -> 1019 in the cache */
   /* search783_1 -> 2104 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1112, 2104 },
      -1,
   } },

   /* replace783_0_0 -> 650 in the cache */
   /* replace783_0_1 -> 1019 in the cache */
   /* replace783_0 -> 1031 in the cache */
   /* replace783 -> 2351 in the cache */

   /* ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b')) */
   /* search784_0_0 -> 650 in the cache */
   /* search784_0 -> 1112 in the cache */
   /* search784_1_0 -> 1019 in the cache */
   /* search784_1 -> 2104 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1112, 2104 },
      -1,
   } },

   /* replace784_0_0 -> 650 in the cache */
   /* replace784_0_1 -> 1019 in the cache */
   /* replace784_0 -> 1023 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2i,
      -1, 1,
      { 1023 },
      -1,
   } },

   /* ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search785_0_0 -> 650 in the cache */
   /* search785_0 -> 1014 in the cache */
   /* search785_1_0 -> 1019 in the cache */
   /* search785_1 -> 1020 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 1014, 1020 },
      -1,
   } },

   /* replace785_0_0 -> 650 in the cache */
   /* replace785_0_1 -> 1019 in the cache */
   /* replace785_0 -> 1031 in the cache */
   /* replace785 -> 1152 in the cache */

   /* ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b')) */
   /* search786_0_0_0 -> 650 in the cache */
   /* search786_0_0 -> 1014 in the cache */
   /* search786_0_1_0 -> 1019 in the cache */
   /* search786_0_1 -> 1020 in the cache */
   /* search786_0 -> 1050 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 1050 },
      -1,
   } },

   /* replace786_0_0 -> 650 in the cache */
   /* replace786_0_1 -> 1019 in the cache */
   /* replace786_0 -> 1023 in the cache */
   /* replace786 -> 1149 in the cache */

   /* ('iand', 'a@bool16', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search787_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2357, 401 },
      -1,
   } },

   /* replace787_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iand', 'a@bool32', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search788_1 -> 474 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2360, 474 },
      -1,
   } },

   /* replace788_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('flt', ('fneg', ('b2f', 'a@1')), 0) => a */
   /* search789_0_0_0 -> 650 in the cache */
   /* search789_0_0 -> 1014 in the cache */
   /* search789_0 -> 1017 in the cache */
   /* search789_1 -> 1113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1017, 1113 },
      -1,
   } },

   /* replace789 -> 650 in the cache */

   /* ('ilt', 'a', 'a') => False */
   /* search790_0 -> 32 in the cache */
   /* search790_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace790 -> 968 in the cache */

   /* ('ige', 'a', 'a') => True */
   /* search791_0 -> 32 in the cache */
   /* search791_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace791 -> 1121 in the cache */

   /* ('ieq', 'a', 'a') => True */
   /* search792_0 -> 32 in the cache */
   /* search792_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace792 -> 1121 in the cache */

   /* ('ine', 'a', 'a') => False */
   /* search793_0 -> 32 in the cache */
   /* search793_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace793 -> 968 in the cache */

   /* ('ult', 'a', 'a') => False */
   /* search794_0 -> 32 in the cache */
   /* search794_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace794 -> 968 in the cache */

   /* ('uge', 'a', 'a') => True */
   /* search795_0 -> 32 in the cache */
   /* search795_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace795 -> 1121 in the cache */

   /* ('flt', 'a', 'a') => False */
   /* search796_0 -> 32 in the cache */
   /* search796_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace796 -> 968 in the cache */

   /* ('fge', 'a(is_a_number)', 'a') => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search797_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 2371, 32 },
      -1,
   } },

   /* replace797 -> 1121 in the cache */

   /* ('feq', 'a(is_a_number)', 'a') => True */
   /* search798_0 -> 2371 in the cache */
   /* search798_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      -1, 0,
      { 2371, 32 },
      -1,
   } },

   /* replace798 -> 1121 in the cache */

   /* ('fneu', 'a(is_a_number)', 'a') => False */
   /* search799_0 -> 2371 in the cache */
   /* search799_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      -1, 0,
      { 2371, 32 },
      -1,
   } },

   /* replace799 -> 968 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search800_0 -> 32 in the cache */
   /* search800_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iand,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace800 -> 32 in the cache */

   /* ('iand', 'a', -1) => a */
   /* search801_0 -> 32 in the cache */
   /* search801_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace801 -> 32 in the cache */

   /* ('iand', 'a', 0) => 0 */
   /* search802_0 -> 32 in the cache */
   /* search802_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace802 -> 61 in the cache */

   /* ('ior', 'a', 'a') => a */
   /* search803_0 -> 32 in the cache */
   /* search803_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ior,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace803 -> 32 in the cache */

   /* ('ior', 'a', 0) => a */
   /* search804_0 -> 32 in the cache */
   /* search804_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace804 -> 32 in the cache */

   /* ('ior', 'a', True) => True */
   /* search805_0 -> 650 in the cache */
   /* search805_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 650, 1121 },
      -1,
   } },

   /* replace805 -> 1121 in the cache */

   /* ('ixor', 'a', 'a') => 0 */
   /* search806_0 -> 32 in the cache */
   /* search806_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ixor,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace806 -> 61 in the cache */

   /* ('ixor', 'a', 0) => a */
   /* search807_0 -> 32 in the cache */
   /* search807_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace807 -> 32 in the cache */

   /* ('inot', ('inot', 'a')) => a */
   /* search808_0_0 -> 32 in the cache */
   /* search808_0 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 2101 },
      -1,
   } },

   /* replace808 -> 32 in the cache */

   /* ('ior', ('iand', 'a', 'b'), 'b') => b */
   /* search809_0_0 -> 0 in the cache */
   /* search809_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search809_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ior,
      0, 2,
      { 2384, 3 },
      -1,
   } },

   /* replace809 -> 3 in the cache */

   /* ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b') */
   /* search810_0_0 -> 0 in the cache */
   /* search810_0_1 -> 3 in the cache */
   /* search810_0 -> 84 in the cache */
   /* search810_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ior,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace810_0 -> 0 in the cache */
   /* replace810_1 -> 3 in the cache */
   /* replace810 -> 2167 in the cache */

   /* ('iand', ('ior', 'a', 'b'), 'b') => b */
   /* search811_0_0 -> 0 in the cache */
   /* search811_0_1 -> 3 in the cache */
   /* search811_0 -> 84 in the cache */
   /* search811_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace811 -> 3 in the cache */

   /* ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b') */
   /* search812_0_0 -> 0 in the cache */
   /* search812_0_1 -> 3 in the cache */
   /* search812_0 -> 2384 in the cache */
   /* search812_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 2,
      { 2384, 3 },
      -1,
   } },

   /* replace812_0 -> 0 in the cache */
   /* replace812_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b')) */
   /* search813_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search813_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2390, 2391 },
      -1,
   } },

   /* replace813_0_0 -> 0 in the cache */
   /* replace813_0_1 -> 3 in the cache */
   /* replace813_0 -> 2167 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_inot,
      -1, 1,
      { 2167 },
      -1,
   } },

   /* ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b')) */
   /* search814_0_0 -> 0 in the cache */
   /* search814_0 -> 2390 in the cache */
   /* search814_1_0 -> 3 in the cache */
   /* search814_1 -> 2391 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2390, 2391 },
      -1,
   } },

   /* replace814_0_0 -> 0 in the cache */
   /* replace814_0_1 -> 3 in the cache */
   /* replace814_0 -> 2389 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_inot,
      -1, 1,
      { 2389 },
      -1,
   } },

   /* ('ishl', 0, 'a') => 0 */
   /* search815_0 -> 1113 in the cache */
   /* search815_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 1113, 16 },
      -1,
   } },

   /* replace815 -> 1113 in the cache */

   /* ('ishl', 'a', 0) => a */
   /* search816_0 -> 32 in the cache */
   /* search816_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace816 -> 32 in the cache */

   /* ('ishr', 0, 'a') => 0 */
   /* search817_0 -> 1113 in the cache */
   /* search817_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 1113, 16 },
      -1,
   } },

   /* replace817 -> 1113 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search818_0 -> 32 in the cache */
   /* search818_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace818 -> 32 in the cache */

   /* ('ushr', 0, 'a') => 0 */
   /* search819_0 -> 1113 in the cache */
   /* search819_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 1113, 16 },
      -1,
   } },

   /* replace819 -> 1113 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search820_0 -> 32 in the cache */
   /* search820_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace820 -> 32 in the cache */

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search821_0_0 -> 11 in the cache */
   /* search821_0_1 -> 36 in the cache */
   /* search821_0 -> 2031 in the cache */
   /* search821_1_0 -> 11 in the cache */
   /* search821_1_1_0 -> 745 in the cache */
   /* search821_1_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 745, 2402 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 11, 2403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 2,
      { 2031, 2404 },
      -1,
   } },

   /* replace821_0 -> 11 in the cache */
   /* replace821_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_urol,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b') */
   /* search822_0_0 -> 11 in the cache */
   /* search822_0_1 -> 36 in the cache */
   /* search822_0 -> 2031 in the cache */
   /* search822_1_0 -> 11 in the cache */
   /* search822_1_1_0 -> 745 in the cache */
   /* search822_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 745, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 11, 2407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2031, 2408 },
      -1,
   } },

   /* replace822_0 -> 11 in the cache */
   /* replace822_1 -> 36 in the cache */
   /* replace822 -> 2406 in the cache */

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search823_0_0 -> 16 in the cache */
   /* search823_0_1 -> 36 in the cache */
   /* search823_0 -> 839 in the cache */
   /* search823_1_0 -> 16 in the cache */
   /* search823_1_1_0 -> 767 in the cache */
   /* search823_1_1_1_0 -> 36 in the cache */
   /* search823_1_1_1 -> 2402 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 767, 2402 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 16, 2410 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 2,
      { 839, 2411 },
      -1,
   } },

   /* replace823_0 -> 16 in the cache */
   /* replace823_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_urol,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b') */
   /* search824_0_0 -> 16 in the cache */
   /* search824_0_1 -> 36 in the cache */
   /* search824_0 -> 839 in the cache */
   /* search824_1_0 -> 16 in the cache */
   /* search824_1_1_0 -> 767 in the cache */
   /* search824_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 767, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 16, 2414 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 839, 2415 },
      -1,
   } },

   /* replace824_0 -> 16 in the cache */
   /* replace824_1 -> 36 in the cache */
   /* replace824 -> 2413 in the cache */

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search825_0_0 -> 11 in the cache */
   /* search825_0_1 -> 36 in the cache */
   /* search825_0 -> 2035 in the cache */
   /* search825_1_0 -> 11 in the cache */
   /* search825_1_1_0 -> 745 in the cache */
   /* search825_1_1_1_0 -> 36 in the cache */
   /* search825_1_1_1 -> 2402 in the cache */
   /* search825_1_1 -> 2403 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 11, 2403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 2,
      { 2035, 2417 },
      -1,
   } },

   /* replace825_0 -> 11 in the cache */
   /* replace825_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_uror,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b') */
   /* search826_0_0 -> 11 in the cache */
   /* search826_0_1 -> 36 in the cache */
   /* search826_0 -> 2035 in the cache */
   /* search826_1_0 -> 11 in the cache */
   /* search826_1_1_0 -> 745 in the cache */
   /* search826_1_1_1 -> 36 in the cache */
   /* search826_1_1 -> 2407 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 11, 2407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2035, 2420 },
      -1,
   } },

   /* replace826_0 -> 11 in the cache */
   /* replace826_1 -> 36 in the cache */
   /* replace826 -> 2419 in the cache */

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search827_0_0 -> 16 in the cache */
   /* search827_0_1 -> 36 in the cache */
   /* search827_0 -> 2060 in the cache */
   /* search827_1_0 -> 16 in the cache */
   /* search827_1_1_0 -> 767 in the cache */
   /* search827_1_1_1_0 -> 36 in the cache */
   /* search827_1_1_1 -> 2402 in the cache */
   /* search827_1_1 -> 2410 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 16, 2410 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 2,
      { 2060, 2422 },
      -1,
   } },

   /* replace827_0 -> 16 in the cache */
   /* replace827_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_uror,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b') */
   /* search828_0_0 -> 16 in the cache */
   /* search828_0_1 -> 36 in the cache */
   /* search828_0 -> 2060 in the cache */
   /* search828_1_0 -> 16 in the cache */
   /* search828_1_1_0 -> 767 in the cache */
   /* search828_1_1_1 -> 36 in the cache */
   /* search828_1_1 -> 2414 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 2414 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2060, 2425 },
      -1,
   } },

   /* replace828_0 -> 16 in the cache */
   /* replace828_1 -> 36 in the cache */
   /* replace828 -> 2424 in the cache */

   /* ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b'))) */
   /* search829_0 -> 11 in the cache */
   /* search829_1 -> 36 in the cache */
   /* search829 -> 2406 in the cache */

   /* replace829_0_0 -> 11 in the cache */
   /* replace829_0_1 -> 36 in the cache */
   /* replace829_0 -> 2031 in the cache */
   /* replace829_1_0 -> 11 in the cache */
   /* replace829_1_1_0 -> 745 in the cache */
   /* replace829_1_1_1 -> 36 in the cache */
   /* replace829_1_1 -> 2407 in the cache */
   /* replace829_1 -> 2408 in the cache */
   /* replace829 -> 2409 in the cache */

   /* ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b'))) */
   /* search830_0 -> 16 in the cache */
   /* search830_1 -> 36 in the cache */
   /* search830 -> 2413 in the cache */

   /* replace830_0_0 -> 16 in the cache */
   /* replace830_0_1 -> 36 in the cache */
   /* replace830_0 -> 839 in the cache */
   /* replace830_1_0 -> 16 in the cache */
   /* replace830_1_1_0 -> 767 in the cache */
   /* replace830_1_1_1 -> 36 in the cache */
   /* replace830_1_1 -> 2414 in the cache */
   /* replace830_1 -> 2415 in the cache */
   /* replace830 -> 2416 in the cache */

   /* ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b'))) */
   /* search831_0 -> 11 in the cache */
   /* search831_1 -> 36 in the cache */
   /* search831 -> 2419 in the cache */

   /* replace831_0_0 -> 11 in the cache */
   /* replace831_0_1 -> 36 in the cache */
   /* replace831_0 -> 2035 in the cache */
   /* replace831_1_0 -> 11 in the cache */
   /* replace831_1_1_0 -> 745 in the cache */
   /* replace831_1_1_1 -> 36 in the cache */
   /* replace831_1_1 -> 2407 in the cache */
   /* replace831_1 -> 2420 in the cache */
   /* replace831 -> 2421 in the cache */

   /* ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b'))) */
   /* search832_0 -> 16 in the cache */
   /* search832_1 -> 36 in the cache */
   /* search832 -> 2424 in the cache */

   /* replace832_0_0 -> 16 in the cache */
   /* replace832_0_1 -> 36 in the cache */
   /* replace832_0 -> 2060 in the cache */
   /* replace832_1_0 -> 16 in the cache */
   /* replace832_1_1_0 -> 767 in the cache */
   /* replace832_1_1_1 -> 36 in the cache */
   /* replace832_1_1 -> 2414 in the cache */
   /* replace832_1 -> 2425 in the cache */
   /* replace832 -> 2426 in the cache */

   /* ('~fexp2', ('flog2', 'a')) => a */
   /* search833_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_flog2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fexp2,
      -1, 0,
      { 2427 },
      -1,
   } },

   /* replace833 -> 32 in the cache */

   /* ('~flog2', ('fexp2', 'a')) => a */
   /* search834_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fexp2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_flog2,
      -1, 0,
      { 2429 },
      -1,
   } },

   /* replace834 -> 32 in the cache */

   /* ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b')) */
   /* search835_0 -> 0 in the cache */
   /* search835_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace835_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_flog2,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace835_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 2432, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fexp2,
      -1, 1,
      { 2433 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b') */
   /* search836_0_0_0 -> 0 in the cache */
   /* search836_0_0 -> 2432 in the cache */
   /* search836_0_1 -> 3 in the cache */
   /* search836_0 -> 2433 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_fexp2,
      -1, 1,
      { 2433 },
      -1,
   } },

   /* replace836_0 -> 0 in the cache */
   /* replace836_1 -> 3 in the cache */
   /* replace836 -> 2431 in the cache */

   /* ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd')) */
   /* search837_0_0_0_0 -> 141 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_flog2,
      -1, 0,
      { 141 },
      -1,
   } },
   /* search837_0_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 2436, 142 },
      -1,
   } },
   /* search837_0_1_0_0 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_flog2,
      -1, 0,
      { 144 },
      -1,
   } },
   /* search837_0_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 2438, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      0, 3,
      { 2437, 2439 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_fexp2,
      -1, 3,
      { 2440 },
      -1,
   } },

   /* replace837_0_0 -> 141 in the cache */
   /* replace837_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 141, 142 },
      -1,
   } },
   /* replace837_1_0 -> 144 in the cache */
   /* replace837_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_fmul,
      0, 1,
      { 2442, 2443 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a') */
   /* search838_0_0_0 -> 32 in the cache */
   /* search838_0_0 -> 2427 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000 /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 2427, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fexp2,
      -1, 1,
      { 2446 },
      -1,
   } },

   /* replace838_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsqrt,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a') */
   /* search839_0_0_0 -> 32 in the cache */
   /* search839_0_0 -> 2427 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 2427, 2449 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fexp2,
      -1, 1,
      { 2450 },
      -1,
   } },

   /* replace839_0 -> 32 in the cache */
   /* replace839_1 -> 32 in the cache */
   /* replace839 -> 200 in the cache */

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search840_0_0_0 -> 32 in the cache */
   /* search840_0_0 -> 2427 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4010000000000000 /* 4.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 2427, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fexp2,
      -1, 1,
      { 2453 },
      -1,
   } },

   /* replace840_0_0 -> 32 in the cache */
   /* replace840_0_1 -> 32 in the cache */
   /* replace840_0 -> 200 in the cache */
   /* replace840_1_0 -> 32 in the cache */
   /* replace840_1_1 -> 32 in the cache */
   /* replace840_1 -> 200 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      -1, 0,
      { 200, 200 },
      -1,
   } },

   /* ('~fpow', 'a', 1.0) => a */
   /* search841_0 -> 32 in the cache */
   /* search841_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fpow,
      -1, 0,
      { 32, 192 },
      -1,
   } },

   /* replace841 -> 32 in the cache */

   /* ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a') */
   /* search842_0 -> 32 in the cache */
   /* search842_1 -> 2449 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fpow,
      -1, 0,
      { 32, 2449 },
      -1,
   } },

   /* replace842_0 -> 32 in the cache */
   /* replace842_1 -> 32 in the cache */
   /* replace842 -> 200 in the cache */

   /* ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search843_0 -> 32 in the cache */
   /* search843_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fpow,
      -1, 0,
      { 32, 2452 },
      -1,
   } },

   /* replace843_0_0 -> 32 in the cache */
   /* replace843_0_1 -> 32 in the cache */
   /* replace843_0 -> 200 in the cache */
   /* replace843_1_0 -> 32 in the cache */
   /* replace843_1_1 -> 32 in the cache */
   /* replace843_1 -> 200 in the cache */
   /* replace843 -> 2455 in the cache */

   /* ('~fpow', 2.0, 'a') => ('fexp2', 'a') */
   /* search844_0 -> 2449 in the cache */
   /* search844_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fpow,
      -1, 0,
      { 2449, 32 },
      -1,
   } },

   /* replace844_0 -> 32 in the cache */
   /* replace844 -> 2429 in the cache */

   /* ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a */
   /* search845_0_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x400199999999999a /* 2.2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 32, 2460 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fdd1743e963dc48 /* 0.454545 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fpow,
      -1, 0,
      { 2461, 2462 },
      -1,
   } },

   /* replace845 -> 32 in the cache */

   /* ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a') */
   /* search846_0_0_0 -> 32 in the cache */
   /* search846_0_0_1 -> 2460 in the cache */
   /* search846_0_0 -> 2461 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 2461 },
      -1,
   } },
   /* search846_1 -> 2462 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fpow,
      -1, 0,
      { 2464, 2462 },
      -1,
   } },

   /* replace846_0 -> 32 in the cache */
   /* replace846 -> 103 in the cache */

   /* ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a')) */
   /* search847_0_0 -> 32 in the cache */
   /* search847_0 -> 2429 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fsqrt,
      -1, 0,
      { 2429 },
      -1,
   } },

   /* replace847_0_0 -> 2445 in the cache */
   /* replace847_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 2445, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fexp2,
      -1, 1,
      { 2467 },
      -1,
   } },

   /* ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a')) */
   /* search848_0_0 -> 32 in the cache */
   /* search848_0 -> 2429 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_frcp,
      -1, 0,
      { 2429 },
      -1,
   } },

   /* replace848_0_0 -> 32 in the cache */
   /* replace848_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fexp2,
      -1, 0,
      { 98 },
      -1,
   } },

   /* ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a')) */
   /* search849_0_0 -> 32 in the cache */
   /* search849_0 -> 2429 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_frsq,
      -1, 0,
      { 2429 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbfe0000000000000 /* -0.5 */ },
   } },
   /* replace849_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 2472, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fexp2,
      -1, 1,
      { 2473 },
      -1,
   } },

   /* ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a')) */
   /* search850_0_0 -> 32 in the cache */
   /* search850_0 -> 2448 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_flog2,
      -1, 0,
      { 2448 },
      -1,
   } },

   /* replace850_0 -> 2445 in the cache */
   /* replace850_1_0 -> 32 in the cache */
   /* replace850_1 -> 2427 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 2445, 2427 },
      -1,
   } },

   /* ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a')) */
   /* search851_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_frcp,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_flog2,
      -1, 0,
      { 2477 },
      -1,
   } },

   /* replace851_0_0 -> 32 in the cache */
   /* replace851_0 -> 2427 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 2427 },
      -1,
   } },

   /* ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a')) */
   /* search852_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_frsq,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_flog2,
      -1, 0,
      { 2480 },
      -1,
   } },

   /* replace852_0 -> 2472 in the cache */
   /* replace852_1_0 -> 32 in the cache */
   /* replace852_1 -> 2427 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 2472, 2427 },
      -1,
   } },

   /* ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a')) */
   /* search853_0_0 -> 0 in the cache */
   /* search853_0_1 -> 3 in the cache */
   /* search853_0 -> 2431 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_flog2,
      -1, 0,
      { 2431 },
      -1,
   } },

   /* replace853_0 -> 3 in the cache */
   /* replace853_1_0 -> 0 in the cache */
   /* replace853_1 -> 2432 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 3, 2432 },
      -1,
   } },

   /* ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b')) */
   /* search854_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fexp2,
      -1, 0,
      { 0 },
      0,
   } },
   /* search854_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fexp2,
      -1, 0,
      { 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_fmul,
      0, 1,
      { 2485, 2486 },
      -1,
   } },

   /* replace854_0_0 -> 0 in the cache */
   /* replace854_0_1 -> 3 in the cache */
   /* replace854_0 -> 218 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fexp2,
      -1, 1,
      { 218 },
      -1,
   } },

   /* ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0)) */
   /* search855_0_0 -> 32 in the cache */
   /* search855_0_1 -> 113 in the cache */
   /* search855_0 -> 614 in the cache */
   /* search855_1 -> 113 in the cache */
   /* search855_2_0 -> 32 in the cache */
   /* search855_2 -> 2448 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 614, 113, 2448 },
      -1,
   } },

   /* replace855_0_0 -> 32 in the cache */
   /* replace855_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsqrt,
      -1, 1,
      { 2490 },
      -1,
   } },

   /* ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search856_0_0 -> 32 in the cache */
   /* search856_0 -> 2448 in the cache */
   /* search856_1_0 -> 32 in the cache */
   /* search856_1 -> 2448 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmul,
      -1, 0,
      { 2448, 2448 },
      -1,
   } },

   /* replace856_0 -> 32 in the cache */
   /* replace856 -> 103 in the cache */

   /* ('~fdiv', 1.0, 'a') => ('frcp', 'a') */
   /* search857_0 -> 192 in the cache */
   /* search857_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fdiv,
      -1, 0,
      { 192, 32 },
      -1,
   } },

   /* replace857_0 -> 32 in the cache */
   /* replace857 -> 2477 in the cache */

   /* ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b')) */
   /* search858_0 -> 0 in the cache */
   /* search858_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdiv,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace858_0 -> 0 in the cache */
   /* replace858_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_frcp,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 0, 2495 },
      -1,
   } },

   /* ('~frcp', ('frcp', 'a')) => a */
   /* search859_0_0 -> 32 in the cache */
   /* search859_0 -> 2477 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_frcp,
      -1, 0,
      { 2477 },
      -1,
   } },

   /* replace859 -> 32 in the cache */

   /* ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a') */
   /* search860_0_0 -> 32 in the cache */
   /* search860_0 -> 2448 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_frcp,
      -1, 0,
      { 2448 },
      -1,
   } },

   /* replace860_0 -> 32 in the cache */
   /* replace860 -> 2480 in the cache */

   /* ('fsqrt', 'a') => ('frcp', ('frsq', 'a')) */
   /* search861_0 -> 32 in the cache */
   /* search861 -> 2448 in the cache */

   /* replace861_0_0 -> 32 in the cache */
   /* replace861_0 -> 2480 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_frcp,
      -1, 0,
      { 2480 },
      -1,
   } },

   /* ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a') */
   /* search862_0_0 -> 32 in the cache */
   /* search862_0 -> 2480 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_frcp,
      -1, 0,
      { 2480 },
      -1,
   } },

   /* replace862_0 -> 32 in the cache */
   /* replace862 -> 2448 in the cache */

   /* ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)) */
   /* search863_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsin,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace863_0_0_0_0_0_0 -> 2449 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fc45f306dc9c883 /* 0.15915494309189535 */ },
   } },
   /* replace863_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      5, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_0_0_0_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      4, 2,
      { 2503, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      3, 3,
      { 2449, 2505 },
      -1,
   } },
   /* replace863_0_0_0_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2506, 192 },
      -1,
   } },
   /* replace863_0_0_0_1_0_0_0 -> 2449 in the cache */
   /* replace863_0_0_0_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace863_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      9, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_0_0_0_1_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      8, 2,
      { 2508, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2509 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      7, 3,
      { 2449, 2510 },
      -1,
   } },
   /* replace863_0_0_0_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2511, 192 },
      -1,
   } },
   /* replace863_0_0_0_1_1_0_0_0 -> 2449 in the cache */
   /* replace863_0_0_0_1_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace863_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      12, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_0_0_0_1_1_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      11, 2,
      { 2513, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2514 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      10, 3,
      { 2449, 2515 },
      -1,
   } },
   /* replace863_0_0_0_1_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2516, 192 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 3,
      { 2517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      6, 7,
      { 2512, 2518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 10,
      { 2507, 2519 },
      -1,
   } },
   /* replace863_0_0_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      2, 11,
      { 2520, 2452 },
      -1,
   } },
   /* replace863_0_1_0_0_0_0_0 -> 2449 in the cache */
   /* replace863_0_1_0_0_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace863_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      16, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_0_1_0_0_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      15, 2,
      { 2522, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2523 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      14, 3,
      { 2449, 2524 },
      -1,
   } },
   /* replace863_0_1_0_0_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2525, 192 },
      -1,
   } },
   /* replace863_0_1_0_0_1_0_0_0 -> 2449 in the cache */
   /* replace863_0_1_0_0_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace863_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      20, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_0_1_0_0_1_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      19, 2,
      { 2527, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      18, 3,
      { 2449, 2529 },
      -1,
   } },
   /* replace863_0_1_0_0_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2530, 192 },
      -1,
   } },
   /* replace863_0_1_0_0_1_1_0_0_0 -> 2449 in the cache */
   /* replace863_0_1_0_0_1_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace863_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      23, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_0_1_0_0_1_1_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      22, 2,
      { 2532, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2533 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      21, 3,
      { 2449, 2534 },
      -1,
   } },
   /* replace863_0_1_0_0_1_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2535, 192 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 3,
      { 2536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      17, 7,
      { 2531, 2537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 10,
      { 2526, 2538 },
      -1,
   } },
   /* replace863_0_1_0_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      13, 11,
      { 2539, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 11,
      { 2540 },
      -1,
   } },
   /* replace863_0_2_0_0_0_0_0 -> 2449 in the cache */
   /* replace863_0_2_0_0_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace863_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      27, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_0_2_0_0_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      26, 2,
      { 2542, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2543 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      25, 3,
      { 2449, 2544 },
      -1,
   } },
   /* replace863_0_2_0_0_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2545, 192 },
      -1,
   } },
   /* replace863_0_2_0_0_1_0_0_0 -> 2449 in the cache */
   /* replace863_0_2_0_0_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace863_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      31, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_0_2_0_0_1_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      30, 2,
      { 2547, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2548 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      29, 3,
      { 2449, 2549 },
      -1,
   } },
   /* replace863_0_2_0_0_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2550, 192 },
      -1,
   } },
   /* replace863_0_2_0_0_1_1_0_0_0 -> 2449 in the cache */
   /* replace863_0_2_0_0_1_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace863_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      34, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_0_2_0_0_1_1_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      33, 2,
      { 2552, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      32, 3,
      { 2449, 2554 },
      -1,
   } },
   /* replace863_0_2_0_0_1_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2555, 192 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 3,
      { 2556 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      28, 7,
      { 2551, 2557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 10,
      { 2546, 2558 },
      -1,
   } },
   /* replace863_0_2_0_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      24, 11,
      { 2559, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 11,
      { 2560 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffma,
      1, 34,
      { 2521, 2541, 2561 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fcccccccccccccd /* 0.225 */ },
   } },
   /* replace863_2_0_0_0_0 -> 2449 in the cache */
   /* replace863_2_0_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace863_2_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      38, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_2_0_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      37, 2,
      { 2564, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2565 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      36, 3,
      { 2449, 2566 },
      -1,
   } },
   /* replace863_2_0_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2567, 192 },
      -1,
   } },
   /* replace863_2_0_1_0_0_0 -> 2449 in the cache */
   /* replace863_2_0_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace863_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      42, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_2_0_1_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      41, 2,
      { 2569, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2570 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      40, 3,
      { 2449, 2571 },
      -1,
   } },
   /* replace863_2_0_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2572, 192 },
      -1,
   } },
   /* replace863_2_0_1_1_0_0_0 -> 2449 in the cache */
   /* replace863_2_0_1_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace863_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      45, 1,
      { 2502, 32 },
      -1,
   } },
   /* replace863_2_0_1_1_0_0_1_0_1 -> 2445 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      44, 2,
      { 2574, 2445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2575 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      43, 3,
      { 2449, 2576 },
      -1,
   } },
   /* replace863_2_0_1_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2577, 192 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 3,
      { 2578 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      39, 7,
      { 2573, 2579 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 10,
      { 2568, 2580 },
      -1,
   } },
   /* replace863_2_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      35, 11,
      { 2581, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffma,
      0, 46,
      { 2562, 2563, 2582 },
      -1,
   } },

   /* ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)) */
   /* search864_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fcos,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace864_0_0_0_0_0_0 -> 2449 in the cache */
   /* replace864_0_0_0_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_0_0_0_0_0_1_0_0 -> 2503 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe8000000000000 /* 0.75 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      4, 2,
      { 2503, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2586 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      3, 3,
      { 2449, 2587 },
      -1,
   } },
   /* replace864_0_0_0_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2588, 192 },
      -1,
   } },
   /* replace864_0_0_0_1_0_0_0 -> 2449 in the cache */
   /* replace864_0_0_0_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_0_0_0_1_0_0_1_0_0 -> 2508 in the cache */
   /* replace864_0_0_0_1_0_0_1_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      8, 2,
      { 2508, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2590 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      7, 3,
      { 2449, 2591 },
      -1,
   } },
   /* replace864_0_0_0_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2592, 192 },
      -1,
   } },
   /* replace864_0_0_0_1_1_0_0_0 -> 2449 in the cache */
   /* replace864_0_0_0_1_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_0_0_0_1_1_0_0_1_0_0 -> 2513 in the cache */
   /* replace864_0_0_0_1_1_0_0_1_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      11, 2,
      { 2513, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      10, 3,
      { 2449, 2595 },
      -1,
   } },
   /* replace864_0_0_0_1_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2596, 192 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 3,
      { 2597 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      6, 7,
      { 2593, 2598 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 10,
      { 2589, 2599 },
      -1,
   } },
   /* replace864_0_0_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      2, 11,
      { 2600, 2452 },
      -1,
   } },
   /* replace864_0_1_0_0_0_0_0 -> 2449 in the cache */
   /* replace864_0_1_0_0_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_0_1_0_0_0_0_1_0_0 -> 2522 in the cache */
   /* replace864_0_1_0_0_0_0_1_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      15, 2,
      { 2522, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      14, 3,
      { 2449, 2603 },
      -1,
   } },
   /* replace864_0_1_0_0_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2604, 192 },
      -1,
   } },
   /* replace864_0_1_0_0_1_0_0_0 -> 2449 in the cache */
   /* replace864_0_1_0_0_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_0_1_0_0_1_0_0_1_0_0 -> 2527 in the cache */
   /* replace864_0_1_0_0_1_0_0_1_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      19, 2,
      { 2527, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2606 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      18, 3,
      { 2449, 2607 },
      -1,
   } },
   /* replace864_0_1_0_0_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2608, 192 },
      -1,
   } },
   /* replace864_0_1_0_0_1_1_0_0_0 -> 2449 in the cache */
   /* replace864_0_1_0_0_1_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_0_1_0_0_1_1_0_0_1_0_0 -> 2532 in the cache */
   /* replace864_0_1_0_0_1_1_0_0_1_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      22, 2,
      { 2532, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2610 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      21, 3,
      { 2449, 2611 },
      -1,
   } },
   /* replace864_0_1_0_0_1_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2612, 192 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 3,
      { 2613 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      17, 7,
      { 2609, 2614 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 10,
      { 2605, 2615 },
      -1,
   } },
   /* replace864_0_1_0_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      13, 11,
      { 2616, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 11,
      { 2617 },
      -1,
   } },
   /* replace864_0_2_0_0_0_0_0 -> 2449 in the cache */
   /* replace864_0_2_0_0_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_0_2_0_0_0_0_1_0_0 -> 2542 in the cache */
   /* replace864_0_2_0_0_0_0_1_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      26, 2,
      { 2542, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2619 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      25, 3,
      { 2449, 2620 },
      -1,
   } },
   /* replace864_0_2_0_0_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2621, 192 },
      -1,
   } },
   /* replace864_0_2_0_0_1_0_0_0 -> 2449 in the cache */
   /* replace864_0_2_0_0_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_0_2_0_0_1_0_0_1_0_0 -> 2547 in the cache */
   /* replace864_0_2_0_0_1_0_0_1_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      30, 2,
      { 2547, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2623 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      29, 3,
      { 2449, 2624 },
      -1,
   } },
   /* replace864_0_2_0_0_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2625, 192 },
      -1,
   } },
   /* replace864_0_2_0_0_1_1_0_0_0 -> 2449 in the cache */
   /* replace864_0_2_0_0_1_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_0_2_0_0_1_1_0_0_1_0_0 -> 2552 in the cache */
   /* replace864_0_2_0_0_1_1_0_0_1_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      33, 2,
      { 2552, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      32, 3,
      { 2449, 2628 },
      -1,
   } },
   /* replace864_0_2_0_0_1_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2629, 192 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 3,
      { 2630 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      28, 7,
      { 2626, 2631 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 10,
      { 2622, 2632 },
      -1,
   } },
   /* replace864_0_2_0_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      24, 11,
      { 2633, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 11,
      { 2634 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffma,
      1, 34,
      { 2601, 2618, 2635 },
      -1,
   } },
   /* replace864_1 -> 2563 in the cache */
   /* replace864_2_0_0_0_0 -> 2449 in the cache */
   /* replace864_2_0_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_2_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_2_0_0_0_1_0_0 -> 2564 in the cache */
   /* replace864_2_0_0_0_1_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      37, 2,
      { 2564, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2637 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      36, 3,
      { 2449, 2638 },
      -1,
   } },
   /* replace864_2_0_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2639, 192 },
      -1,
   } },
   /* replace864_2_0_1_0_0_0 -> 2449 in the cache */
   /* replace864_2_0_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_2_0_1_0_0_1_0_0 -> 2569 in the cache */
   /* replace864_2_0_1_0_0_1_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      41, 2,
      { 2569, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2641 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      40, 3,
      { 2449, 2642 },
      -1,
   } },
   /* replace864_2_0_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2643, 192 },
      -1,
   } },
   /* replace864_2_0_1_1_0_0_0 -> 2449 in the cache */
   /* replace864_2_0_1_1_0_0_1_0_0_0 -> 2502 in the cache */
   /* replace864_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace864_2_0_1_1_0_0_1_0_0 -> 2574 in the cache */
   /* replace864_2_0_1_1_0_0_1_0_1 -> 2585 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      44, 2,
      { 2574, 2585 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffract,
      -1, 2,
      { 2645 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      43, 3,
      { 2449, 2646 },
      -1,
   } },
   /* replace864_2_0_1_1_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 3,
      { 2647, 192 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 3,
      { 2648 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      39, 7,
      { 2644, 2649 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 10,
      { 2640, 2650 },
      -1,
   } },
   /* replace864_2_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      35, 11,
      { 2651, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffma,
      0, 46,
      { 2636, 2563, 2652 },
      -1,
   } },

   /* ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0) */
   /* search865_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2b16,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace865_0 -> 32 in the cache */
   /* replace865_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ine16,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0) */
   /* search866_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2b32,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace866_0 -> 32 in the cache */
   /* replace866_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ine32,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0) */
   /* search867_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2b1,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace867_0 -> 32 in the cache */
   /* replace867_1 -> 61 in the cache */
   /* replace867 -> 1117 in the cache */

   /* ('ieq', 'a', True) => a */
   /* search868_0 -> 650 in the cache */
   /* search868_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 650, 1121 },
      -1,
   } },

   /* replace868 -> 650 in the cache */

   /* ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a') */
   /* search869_0 -> 650 in the cache */
   /* search869_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 650, 1121 },
      3,
   } },

   /* replace869_0 -> 650 in the cache */
   /* replace869 -> 1016 in the cache */

   /* ('ine', 'a', False) => a */
   /* search870_0 -> 650 in the cache */
   /* search870_1 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 650, 968 },
      -1,
   } },

   /* replace870 -> 650 in the cache */

   /* ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a') */
   /* search871_0 -> 650 in the cache */
   /* search871_1 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 650, 968 },
      3,
   } },

   /* replace871_0 -> 650 in the cache */
   /* replace871 -> 1016 in the cache */

   /* ('bcsel', 'a', True, False) => a */
   /* search872_0 -> 650 in the cache */
   /* search872_1 -> 1121 in the cache */
   /* search872_2 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1121, 968 },
      -1,
   } },

   /* replace872 -> 650 in the cache */

   /* ('bcsel', 'a', False, True) => ('inot', 'a') */
   /* search873_0 -> 650 in the cache */
   /* search873_1 -> 968 in the cache */
   /* search873_2 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 968, 1121 },
      -1,
   } },

   /* replace873_0 -> 650 in the cache */
   /* replace873 -> 1016 in the cache */

   /* ('bcsel', True, 'b', 'c') => b */
   /* search874_0 -> 1121 in the cache */
   /* search874_1 -> 1002 in the cache */
   /* search874_2 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1121, 1002, 609 },
      -1,
   } },

   /* replace874 -> 1002 in the cache */

   /* ('bcsel', False, 'b', 'c') => c */
   /* search875_0 -> 968 in the cache */
   /* search875_1 -> 1002 in the cache */
   /* search875_2 -> 609 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 968, 1002, 609 },
      -1,
   } },

   /* replace875 -> 609 in the cache */

   /* ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search876_0 -> 650 in the cache */
   /* search876_1 -> 401 in the cache */
   /* search876_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 401, 115 },
      -1,
   } },

   /* replace876_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search877_0 -> 650 in the cache */
   /* search877_1 -> 115 in the cache */
   /* search877_2 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 115, 401 },
      -1,
   } },

   /* replace877_0_0 -> 650 in the cache */
   /* replace877_0 -> 1016 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 1016 },
      -1,
   } },

   /* ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search878_0 -> 650 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 2671, 2672 },
      -1,
   } },

   /* replace878_0_0 -> 650 in the cache */
   /* replace878_0 -> 2668 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 2668 },
      -1,
   } },

   /* ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search879_0 -> 650 in the cache */
   /* search879_1 -> 2672 in the cache */
   /* search879_2 -> 2671 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 2672, 2671 },
      -1,
   } },

   /* replace879_0_0_0 -> 650 in the cache */
   /* replace879_0_0 -> 1016 in the cache */
   /* replace879_0 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 2670 },
      -1,
   } },

   /* ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search880_0 -> 650 in the cache */
   /* search880_1 -> 474 in the cache */
   /* search880_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 474, 117 },
      -1,
   } },

   /* replace880_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search881_0 -> 650 in the cache */
   /* search881_1 -> 117 in the cache */
   /* search881_2 -> 474 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 117, 474 },
      -1,
   } },

   /* replace881_0_0 -> 650 in the cache */
   /* replace881_0 -> 1016 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 1016 },
      -1,
   } },

   /* ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search882_0 -> 650 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 2681, 2682 },
      -1,
   } },

   /* replace882_0_0 -> 650 in the cache */
   /* replace882_0 -> 2678 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 2678 },
      -1,
   } },

   /* ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search883_0 -> 650 in the cache */
   /* search883_1 -> 2682 in the cache */
   /* search883_2 -> 2681 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 2682, 2681 },
      -1,
   } },

   /* replace883_0_0_0 -> 650 in the cache */
   /* replace883_0_0 -> 1016 in the cache */
   /* replace883_0 -> 2680 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 2680 },
      -1,
   } },

   /* ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search884_0 -> 650 in the cache */
   /* search884_1 -> 547 in the cache */
   /* search884_2 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 547, 1795 },
      -1,
   } },

   /* replace884_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search885_0 -> 650 in the cache */
   /* search885_1 -> 1795 in the cache */
   /* search885_2 -> 547 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1795, 547 },
      -1,
   } },

   /* replace885_0_0 -> 650 in the cache */
   /* replace885_0 -> 1016 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 1016 },
      -1,
   } },

   /* ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search886_0 -> 650 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 2691, 2692 },
      -1,
   } },

   /* replace886_0_0 -> 650 in the cache */
   /* replace886_0 -> 2688 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 2688 },
      -1,
   } },

   /* ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search887_0 -> 650 in the cache */
   /* search887_1 -> 2692 in the cache */
   /* search887_2 -> 2691 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 2692, 2691 },
      -1,
   } },

   /* replace887_0_0_0 -> 650 in the cache */
   /* replace887_0_0 -> 1016 in the cache */
   /* replace887_0 -> 2690 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 2690 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', 'b') => b */
   /* search888_0 -> 650 in the cache */
   /* search888_1 -> 3 in the cache */
   /* search888_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 3, 3 },
      -1,
   } },

   /* replace888 -> 3 in the cache */

   /* ('~fcsel', 'a', 'b', 'b') => b */
   /* search889_0 -> 16 in the cache */
   /* search889_1 -> 36 in the cache */
   /* search889_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fcsel,
      -1, 0,
      { 16, 36, 36 },
      -1,
   } },

   /* replace889 -> 36 in the cache */

   /* ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1')) */
   /* search890_0 -> 650 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* search890_2 -> 1113 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 2699, 1113 },
      -1,
   } },

   /* replace890_0_0 -> 650 in the cache */
   /* replace890_0 -> 1112 in the cache */
   /* replace890 -> 2103 in the cache */

   /* ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a'))) */
   /* search891_0 -> 650 in the cache */
   /* search891_1 -> 1113 in the cache */
   /* search891_2 -> 2699 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1113, 2699 },
      -1,
   } },

   /* replace891_0_0_0 -> 650 in the cache */
   /* replace891_0_0 -> 1016 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2i,
      -1, 0,
      { 1016 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 2702 },
      -1,
   } },

   /* ('bcsel', 'a', 1, 0) => ('b2i', 'a@1') */
   /* search892_0 -> 650 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   /* search892_2 -> 1113 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 2704, 1113 },
      -1,
   } },

   /* replace892_0 -> 650 in the cache */
   /* replace892 -> 1112 in the cache */

   /* ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a')) */
   /* search893_0 -> 650 in the cache */
   /* search893_1 -> 1113 in the cache */
   /* search893_2 -> 2704 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1113, 2704 },
      -1,
   } },

   /* replace893_0_0 -> 650 in the cache */
   /* replace893_0 -> 1016 in the cache */
   /* replace893 -> 2702 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search894_0_0_0 -> 650 in the cache */
   /* search894_0_0 -> 1112 in the cache */
   /* search894_0 -> 2103 in the cache */
   /* search894_1_0_0 -> 1019 in the cache */
   /* search894_1_0 -> 2104 in the cache */
   /* search894_1 -> 2105 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2103, 2105 },
      -1,
   } },

   /* replace894_0_0_0 -> 650 in the cache */
   /* replace894_0_0_1 -> 1019 in the cache */
   /* replace894_0_0 -> 1031 in the cache */
   /* replace894_0 -> 2351 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_ineg,
      -1, 1,
      { 2351 },
      -1,
   } },

   /* ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search895_0_0_0 -> 650 in the cache */
   /* search895_0_0 -> 1112 in the cache */
   /* search895_0 -> 2103 in the cache */
   /* search895_1_0_0 -> 1019 in the cache */
   /* search895_1_0 -> 2104 in the cache */
   /* search895_1 -> 2105 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2103, 2105 },
      -1,
   } },

   /* replace895_0_0_0 -> 650 in the cache */
   /* replace895_0_0_1 -> 1019 in the cache */
   /* replace895_0_0 -> 1023 in the cache */
   /* replace895_0 -> 2354 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_ineg,
      -1, 1,
      { 2354 },
      -1,
   } },

   /* ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search896_0_0_0 -> 650 in the cache */
   /* search896_0_0 -> 1112 in the cache */
   /* search896_0 -> 2103 in the cache */
   /* search896_1 -> 1113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 2103, 1113 },
      -1,
   } },

   /* replace896_0 -> 650 in the cache */
   /* replace896 -> 1016 in the cache */

   /* ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a */
   /* search897_0_0_0 -> 650 in the cache */
   /* search897_0_0 -> 1112 in the cache */
   /* search897_0 -> 2103 in the cache */
   /* search897_1 -> 2699 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 2103, 2699 },
      -1,
   } },

   /* replace897 -> 650 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search898_0_0_0 -> 650 in the cache */
   /* search898_0_0 -> 1112 in the cache */
   /* search898_0 -> 2103 in the cache */
   /* search898_1 -> 1113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 2103, 1113 },
      -1,
   } },

   /* replace898 -> 650 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a') */
   /* search899_0_0_0 -> 650 in the cache */
   /* search899_0_0 -> 1112 in the cache */
   /* search899_0 -> 2103 in the cache */
   /* search899_1 -> 2699 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 2103, 2699 },
      -1,
   } },

   /* replace899_0 -> 650 in the cache */
   /* replace899 -> 1016 in the cache */

   /* ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search900_0_0_0 -> 650 in the cache */
   /* search900_0_0 -> 1112 in the cache */
   /* search900_0 -> 2103 in the cache */
   /* search900_1 -> 1113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 2103, 1113 },
      -1,
   } },

   /* replace900_0 -> 650 in the cache */
   /* replace900 -> 1016 in the cache */

   /* ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search901_0_0_0 -> 650 in the cache */
   /* search901_0_0 -> 1112 in the cache */
   /* search901_0 -> 2103 in the cache */
   /* search901_1 -> 1113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 2103, 1113 },
      -1,
   } },

   /* replace901 -> 650 in the cache */

   /* ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a */
   /* search902_0 -> 1113 in the cache */
   /* search902_1_0_0 -> 650 in the cache */
   /* search902_1_0 -> 1112 in the cache */
   /* search902_1 -> 2103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1113, 2103 },
      -1,
   } },

   /* replace902 -> 650 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a') */
   /* search903_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2i,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 2718 },
      -1,
   } },
   /* search903_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2719, 1024 },
      -1,
   } },

   /* replace903_0 -> 32 in the cache */
   /* replace903 -> 1401 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a') */
   /* search904_0_0_0 -> 32 in the cache */
   /* search904_0_0 -> 2718 in the cache */
   /* search904_0 -> 2719 in the cache */
   /* search904_1 -> 2704 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2719, 2704 },
      -1,
   } },

   /* replace904_0 -> 32 in the cache */
   /* replace904 -> 2718 in the cache */

   /* ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search905_0_0_0 -> 650 in the cache */
   /* search905_0_0 -> 1112 in the cache */
   /* search905_0 -> 2103 in the cache */
   /* search905_1_0_0 -> 1019 in the cache */
   /* search905_1_0 -> 2104 in the cache */
   /* search905_1 -> 2105 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_imax,
      0, 1,
      { 2103, 2105 },
      -1,
   } },

   /* replace905_0_0_0 -> 650 in the cache */
   /* replace905_0_0_1 -> 1019 in the cache */
   /* replace905_0_0 -> 1031 in the cache */
   /* replace905_0 -> 2351 in the cache */
   /* replace905 -> 2708 in the cache */

   /* ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search906_0_0_0 -> 650 in the cache */
   /* search906_0_0 -> 1112 in the cache */
   /* search906_0 -> 2103 in the cache */
   /* search906_1_0_0 -> 1019 in the cache */
   /* search906_1_0 -> 2104 in the cache */
   /* search906_1 -> 2105 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_imin,
      0, 1,
      { 2103, 2105 },
      -1,
   } },

   /* replace906_0_0_0 -> 650 in the cache */
   /* replace906_0_0_1 -> 1019 in the cache */
   /* replace906_0_0 -> 1023 in the cache */
   /* replace906_0 -> 2354 in the cache */
   /* replace906 -> 2710 in the cache */

   /* ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search907_0_0_0 -> 650 in the cache */
   /* search907_0_0 -> 1112 in the cache */
   /* search907_0 -> 2103 in the cache */
   /* search907_1_0_0 -> 1019 in the cache */
   /* search907_1_0 -> 2104 in the cache */
   /* search907_1 -> 2105 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_umax,
      0, 1,
      { 2103, 2105 },
      -1,
   } },

   /* replace907_0_0_0 -> 650 in the cache */
   /* replace907_0_0_1 -> 1019 in the cache */
   /* replace907_0_0 -> 1023 in the cache */
   /* replace907_0 -> 2354 in the cache */
   /* replace907 -> 2710 in the cache */

   /* ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search908_0_0_0 -> 650 in the cache */
   /* search908_0_0 -> 1112 in the cache */
   /* search908_0 -> 2103 in the cache */
   /* search908_1_0_0 -> 1019 in the cache */
   /* search908_1_0 -> 2104 in the cache */
   /* search908_1 -> 2105 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_op_umin,
      0, 1,
      { 2103, 2105 },
      -1,
   } },

   /* replace908_0_0_0 -> 650 in the cache */
   /* replace908_0_0_1 -> 1019 in the cache */
   /* replace908_0_0 -> 1031 in the cache */
   /* replace908_0 -> 2351 in the cache */
   /* replace908 -> 2708 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search909_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2b16,
      -1, 0,
      { 2726 },
      -1,
   } },

   /* replace909 -> 11 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search910_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2b32,
      -1, 0,
      { 2728 },
      -1,
   } },

   /* replace910 -> 16 in the cache */

   /* ('f2i', ('ftrunc', 'a')) => ('f2i', 'a') */
   /* search911_0_0 -> 32 in the cache */
   /* search911_0 -> 613 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2i,
      -1, 0,
      { 613 },
      -1,
   } },

   /* replace911_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2i,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2u', ('ftrunc', 'a')) => ('f2u', 'a') */
   /* search912_0_0 -> 32 in the cache */
   /* search912_0 -> 613 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2u,
      -1, 0,
      { 613 },
      -1,
   } },

   /* replace912_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2u,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search913_0_0 -> 32 in the cache */
   /* search913_0 -> 100 in the cache */
   /* search913 -> 111 in the cache */

   /* replace913_0 -> 32 in the cache */
   /* replace913 -> 112 in the cache */

   /* ('i2b', ('iabs', 'a')) => ('i2b', 'a') */
   /* search914_0_0 -> 32 in the cache */
   /* search914_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_i2b,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace914_0 -> 32 in the cache */
   /* replace914 -> 112 in the cache */

   /* ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0) */
   /* search915_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_f2b1,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 2735 },
      -1,
   } },

   /* replace915_0 -> 32 in the cache */
   /* replace915_1 -> 113 in the cache */
   /* replace915 -> 1143 in the cache */

   /* ('f2fmp', ('f2f32', 'a@16')) => a */
   /* search916_0_0 -> 11 in the cache */
   /* search916_0 -> 1669 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 1669 },
      -1,
   } },

   /* replace916 -> 11 in the cache */

   /* ('i2imp', ('i2i32', 'a@16')) => a */
   /* search917_0_0 -> 11 in the cache */
   /* search917_0 -> 1671 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 1671 },
      -1,
   } },

   /* replace917 -> 11 in the cache */

   /* ('i2imp', ('u2u32', 'a@16')) => a */
   /* search918_0_0 -> 11 in the cache */
   /* search918_0 -> 1673 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 1673 },
      -1,
   } },

   /* replace918 -> 11 in the cache */

   /* ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a') */
   /* search919_0_0 -> 11 in the cache */
   /* search919_0 -> 1669 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2imp,
      -1, 0,
      { 1669 },
      -1,
   } },

   /* replace919_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a') */
   /* search920_0_0 -> 11 in the cache */
   /* search920_0 -> 1669 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2ump,
      -1, 0,
      { 1669 },
      -1,
   } },

   /* replace920_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a') */
   /* search921_0_0 -> 11 in the cache */
   /* search921_0 -> 1671 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2fmp,
      -1, 0,
      { 1671 },
      -1,
   } },

   /* replace921_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a') */
   /* search922_0_0 -> 11 in the cache */
   /* search922_0 -> 1673 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2fmp,
      -1, 0,
      { 1673 },
      -1,
   } },

   /* replace922_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search923_0_0 -> 650 in the cache */
   /* search923_0 -> 1281 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 1281 },
      -1,
   } },

   /* replace923_0 -> 650 in the cache */
   /* replace923 -> 1277 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search924_0_0 -> 650 in the cache */
   /* search924_0 -> 1269 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 1269 },
      -1,
   } },

   /* replace924_0 -> 650 in the cache */
   /* replace924 -> 1265 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search925_0_0 -> 650 in the cache */
   /* search925_0 -> 1269 in the cache */
   /* search925 -> 2749 in the cache */

   /* replace925_0 -> 650 in the cache */
   /* replace925 -> 1265 in the cache */

   /* ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search926_0_0 -> 650 in the cache */
   /* search926_0 -> 1281 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2imp,
      -1, 0,
      { 1281 },
      -1,
   } },

   /* replace926_0 -> 650 in the cache */
   /* replace926 -> 1265 in the cache */

   /* ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search927_0_0 -> 650 in the cache */
   /* search927_0 -> 1281 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2ump,
      -1, 0,
      { 1281 },
      -1,
   } },

   /* replace927_0 -> 650 in the cache */
   /* replace927 -> 1265 in the cache */

   /* ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search928_0_0 -> 650 in the cache */
   /* search928_0 -> 1269 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2fmp,
      -1, 0,
      { 1269 },
      -1,
   } },

   /* replace928_0 -> 650 in the cache */
   /* replace928 -> 1277 in the cache */

   /* ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search929_0_0 -> 650 in the cache */
   /* search929_0 -> 1269 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2fmp,
      -1, 0,
      { 1269 },
      -1,
   } },

   /* replace929_0 -> 650 in the cache */
   /* replace929 -> 1277 in the cache */

   /* ('f2f32', ('f2fmp', 'a@32')) => a */
   /* search930_0_0 -> 16 in the cache */
   /* search930_0 -> 1865 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 1865 },
      -1,
   } },

   /* replace930 -> 16 in the cache */

   /* ('i2i32', ('i2imp', 'a@32')) => a */
   /* search931_0_0 -> 16 in the cache */
   /* search931_0 -> 1876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 1876 },
      -1,
   } },

   /* replace931 -> 16 in the cache */

   /* ('u2u32', ('i2imp', 'a@32')) => a */
   /* search932_0_0 -> 16 in the cache */
   /* search932_0 -> 1876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 1876 },
      -1,
   } },

   /* replace932 -> 16 in the cache */

   /* ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a') */
   /* search933_0_0 -> 16 in the cache */
   /* search933_0 -> 1875 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 1875 },
      -1,
   } },

   /* replace933_0 -> 16 in the cache */
   /* replace933 -> 1873 in the cache */

   /* ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a') */
   /* search934_0_0 -> 16 in the cache */
   /* search934_0 -> 1872 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 1872 },
      -1,
   } },

   /* replace934_0 -> 16 in the cache */
   /* replace934 -> 1870 in the cache */

   /* ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a') */
   /* search935_0_0 -> 16 in the cache */
   /* search935_0 -> 1864 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 1864 },
      -1,
   } },

   /* replace935_0 -> 16 in the cache */
   /* replace935 -> 1862 in the cache */

   /* ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a') */
   /* search936_0_0 -> 16 in the cache */
   /* search936_0 -> 1861 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 1861 },
      -1,
   } },

   /* replace936_0 -> 16 in the cache */
   /* replace936 -> 1859 in the cache */

   /* ('~f2f32', ('f2f64', 'a@32')) => a */
   /* search937_0_0 -> 16 in the cache */
   /* search937_0 -> 1776 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 1776 },
      -1,
   } },

   /* replace937 -> 16 in the cache */

   /* ('ffloor', 'a(is_integral)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ffloor,
      -1, 0,
      { 2762 },
      -1,
   } },

   /* replace938 -> 32 in the cache */

   /* ('fceil', 'a(is_integral)') => a */
   /* search939_0 -> 2762 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fceil,
      -1, 0,
      { 2762 },
      -1,
   } },

   /* replace939 -> 32 in the cache */

   /* ('ftrunc', 'a(is_integral)') => a */
   /* search940_0 -> 2762 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ftrunc,
      -1, 0,
      { 2762 },
      -1,
   } },

   /* replace940 -> 32 in the cache */

   /* ('~ffract', 'a(is_integral)') => 0.0 */
   /* search941_0 -> 2762 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_ffract,
      -1, 0,
      { 2762 },
      -1,
   } },

   /* replace941 -> 113 in the cache */

   /* ('fabs', 'a(is_not_negative)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 2767 },
      -1,
   } },

   /* replace942 -> 32 in the cache */

   /* ('iabs', 'a(is_not_negative)') => a */
   /* search943_0 -> 2767 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 2767 },
      -1,
   } },

   /* replace943 -> 32 in the cache */

   /* ('fsat', 'a(is_not_positive)') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      18,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 2770 },
      -1,
   } },

   /* replace944 -> 113 in the cache */

   /* ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a') */
   /* search945_0 -> 2767 in the cache */
   /* search945_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fmin,
      0, 1,
      { 2767, 192 },
      -1,
   } },

   /* replace945_0 -> 32 in the cache */
   /* replace945 -> 182 in the cache */

   /* ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search946_0_0_0_0 -> 32 in the cache */
   /* search946_0_0_0 -> 182 in the cache */
   /* search946_0_0_1_0_0 -> 32 in the cache */
   /* search946_0_0_1_0 -> 182 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 182 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 182, 2773 },
      -1,
   } },
   /* search946_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 2774, 192 },
      -1,
   } },
   /* search946_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 2,
      { 2775, 113 },
      -1,
   } },

   /* replace946 -> 968 in the cache */

   /* ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search947_0_0_0_0_0 -> 32 in the cache */
   /* search947_0_0_0_0 -> 182 in the cache */
   /* search947_0_0_0_1_0 -> 32 in the cache */
   /* search947_0_0_0_1 -> 182 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      -1, 0,
      { 182, 182 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 2777 },
      -1,
   } },
   /* search947_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 2778, 192 },
      -1,
   } },
   /* search947_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 2779, 113 },
      -1,
   } },

   /* replace947 -> 968 in the cache */

   /* ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0) */
   /* search948_0_0_0_0 -> 32 in the cache */
   /* search948_0_0_0 -> 182 in the cache */
   /* search948_0_0_1_0_0 -> 32 in the cache */
   /* search948_0_0_1_0 -> 182 in the cache */
   /* search948_0_0_1 -> 2773 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 182, 2773 },
      -1,
   } },
   /* search948_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      1, 2,
      { 2781, 192 },
      -1,
   } },
   /* search948_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmax,
      0, 3,
      { 2782, 113 },
      -1,
   } },

   /* replace948_0_0_0 -> 32 in the cache */
   /* replace948_0_0 -> 182 in the cache */
   /* replace948_0_1_0_0 -> 32 in the cache */
   /* replace948_0_1_0 -> 182 in the cache */
   /* replace948_0_1 -> 2773 in the cache */
   /* replace948_0 -> 2774 in the cache */
   /* replace948_1 -> 192 in the cache */
   /* replace948 -> 2775 in the cache */

   /* ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0) */
   /* search949_0_0_0_0_0 -> 32 in the cache */
   /* search949_0_0_0_0 -> 182 in the cache */
   /* search949_0_0_0_1_0 -> 32 in the cache */
   /* search949_0_0_0_1 -> 182 in the cache */
   /* search949_0_0_0 -> 2777 in the cache */
   /* search949_0_0 -> 2778 in the cache */
   /* search949_0_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 2778, 192 },
      -1,
   } },
   /* search949_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmax,
      0, 2,
      { 2784, 113 },
      -1,
   } },

   /* replace949_0_0_0_0 -> 32 in the cache */
   /* replace949_0_0_0 -> 182 in the cache */
   /* replace949_0_0_1_0 -> 32 in the cache */
   /* replace949_0_0_1 -> 182 in the cache */
   /* replace949_0_0 -> 2777 in the cache */
   /* replace949_0 -> 2778 in the cache */
   /* replace949_1 -> 192 in the cache */
   /* replace949 -> 2779 in the cache */

   /* ('fneu', 'a(is_not_zero)', 0.0) => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search950_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 2786, 113 },
      -1,
   } },

   /* replace950 -> 1121 in the cache */

   /* ('feq', 'a(is_not_zero)', 0.0) => False */
   /* search951_0 -> 2786 in the cache */
   /* search951_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 2786, 113 },
      -1,
   } },

   /* replace951 -> 968 in the cache */

   /* ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 2789, 2790 },
      -1,
   } },

   /* replace952 -> 1121 in the cache */

   /* ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      18,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      22,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 2792, 2793 },
      -1,
   } },

   /* replace953 -> 968 in the cache */

   /* ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 2795, 2796 },
      -1,
   } },

   /* replace954 -> 968 in the cache */

   /* ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search955_0 -> 1452 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      18,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1452, 2798 },
      -1,
   } },

   /* replace955 -> 968 in the cache */

   /* ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 2800, 2801 },
      -1,
   } },

   /* replace956 -> 1121 in the cache */

   /* ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 2803, 2804 },
      -1,
   } },

   /* replace957 -> 1121 in the cache */

   /* ('ine', 'a(is_not_zero)', 0) => True */
   /* search958_0 -> 2786 in the cache */
   /* search958_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 2786, 61 },
      -1,
   } },

   /* replace958 -> 1121 in the cache */

   /* ('ieq', 'a(is_not_zero)', 0) => False */
   /* search959_0 -> 2786 in the cache */
   /* search959_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 2786, 61 },
      -1,
   } },

   /* replace959 -> 968 in the cache */

   /* ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True */
   /* search960_0 -> 1452 in the cache */
   /* search960_1 -> 2798 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1452, 2798 },
      -1,
   } },

   /* replace960 -> 1121 in the cache */

   /* ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   /* search961_0 -> 2792 in the cache */
   /* search961_1 -> 2793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 2792, 2793 },
      -1,
   } },

   /* replace961 -> 968 in the cache */

   /* ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   /* search962_0 -> 2795 in the cache */
   /* search962_1 -> 2796 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 2795, 2796 },
      -1,
   } },

   /* replace962 -> 968 in the cache */

   /* ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search963_0 -> 1452 in the cache */
   /* search963_1 -> 2798 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1452, 2798 },
      -1,
   } },

   /* replace963 -> 968 in the cache */

   /* ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True */
   /* search964_0 -> 2792 in the cache */
   /* search964_1 -> 2793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 2792, 2793 },
      -1,
   } },

   /* replace964 -> 1121 in the cache */

   /* ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True */
   /* search965_0 -> 2795 in the cache */
   /* search965_1 -> 2796 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 2795, 2796 },
      -1,
   } },

   /* replace965 -> 1121 in the cache */

   /* ('ult', 0, 'a(is_gt_zero)') => True */
   /* search966_0 -> 61 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      22,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 61, 2814 },
      -1,
   } },

   /* replace966 -> 1121 in the cache */

   /* ('ult', 'a', 0) => False */
   /* search967_0 -> 32 in the cache */
   /* search967_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace967 -> 968 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a */
   /* search968_0_0 -> 16 in the cache */
   /* search968_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 2817 },
      -1,
   } },

   /* replace968 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b */
   /* search969_0_0 -> 16 in the cache */
   /* search969_0_1 -> 36 in the cache */
   /* search969_0 -> 2817 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 2817 },
      -1,
   } },

   /* replace969 -> 36 in the cache */

   /* ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b') */
   /* search970_0_0 -> 16 in the cache */
   /* search970_0_1 -> 36 in the cache */
   /* search970_0 -> 2817 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 2817 },
      -1,
   } },

   /* replace970_0 -> 16 in the cache */
   /* replace970_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a */
   /* search971_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 2822 },
      -1,
   } },

   /* replace971 -> 16 in the cache */

   /* ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a */
   /* search972_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 2824 },
      -1,
   } },

   /* replace972 -> 16 in the cache */

   /* ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a */
   /* search973_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 21 },
      -1,
   } },
   /* search973_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 2826, 2827 },
      -1,
   } },

   /* replace973 -> 21 in the cache */

   /* ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a */
   /* search974_0_0_0 -> 21 in the cache */
   /* search974_0_0 -> 2826 in the cache */
   /* search974_0_1_0 -> 21 in the cache */
   /* search974_0_1 -> 2827 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 2826, 2827 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 2829 },
      -1,
   } },

   /* replace974 -> 21 in the cache */

   /* ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a */
   /* search975_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 2831 },
      -1,
   } },

   /* replace975 -> 21 in the cache */

   /* ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a */
   /* search976_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 2833 },
      -1,
   } },

   /* replace976 -> 21 in the cache */

   /* ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c')) */
   /* search977_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search977_0_1 -> 1883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 2835, 1883 },
      -1,
   } },
   /* search977_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_unpack_32_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 2837, 2838 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 2836, 2839 },
      -1,
   } },

   /* replace977_0 -> 16 in the cache */
   /* replace977_1_0 -> 207 in the cache */
   /* replace977_1_1 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 207, 389 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 16, 2841 },
      -1,
   } },

   /* ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1) */
   /* search978_0 -> 11 in the cache */
   /* search978_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 11, 722 },
      -1,
   } },

   /* replace978_0 -> 11 in the cache */
   /* replace978_1 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 1325 },
      -1,
   } },

   /* ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3) */
   /* search979_0 -> 16 in the cache */
   /* search979_1 -> 903 in the cache */
   /* search979 -> 908 in the cache */

   /* replace979_0 -> 16 in the cache */
   /* replace979_1 -> 325 in the cache */
   /* replace979 -> 342 in the cache */

   /* ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7) */
   /* search980_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x38 /* 56 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 21, 2845 },
      -1,
   } },

   /* replace980_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 2847 },
      -1,
   } },

   /* ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1) */
   /* search981_0 -> 11 in the cache */
   /* search981_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 11, 722 },
      -1,
   } },

   /* replace981_0 -> 11 in the cache */
   /* replace981_1 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 1325 },
      -1,
   } },

   /* ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3) */
   /* search982_0 -> 16 in the cache */
   /* search982_1 -> 903 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 16, 903 },
      -1,
   } },

   /* replace982_0 -> 16 in the cache */
   /* replace982_1 -> 325 in the cache */
   /* replace982 -> 326 in the cache */

   /* ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7) */
   /* search983_0 -> 21 in the cache */
   /* search983_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 21, 2845 },
      -1,
   } },

   /* replace983_0 -> 21 in the cache */
   /* replace983_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 2847 },
      -1,
   } },

   /* ('iand', 255, 'a') => ('extract_u8', 'a', 0) */
   /* search984_0 -> 1458 in the cache */
   /* search984_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1458, 32 },
      -1,
   } },

   /* replace984_0 -> 32 in the cache */
   /* replace984_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2)) */
   /* search985_0_0 -> 32 in the cache */
   /* search985_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 2856 },
      -1,
   } },

   /* replace985_0_0 -> 32 in the cache */
   /* replace985_0_1 -> 2091 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 2091 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 2858 },
      -1,
   } },

   /* ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1)) */
   /* search986_0_0 -> 32 in the cache */
   /* search986_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 32, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 2860 },
      -1,
   } },

   /* replace986_0_0 -> 32 in the cache */
   /* replace986_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 2862 },
      -1,
   } },

   /* ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b')) */
   /* search987_0_0_0 -> 0 in the cache */
   /* search987_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 2864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 2865 },
      -1,
   } },

   /* replace987_0_0 -> 0 in the cache */
   /* replace987_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 2867 },
      -1,
   } },

   /* ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b')) */
   /* search988_0_0_0 -> 0 in the cache */
   /* search988_0_0_1 -> 3 in the cache */
   /* search988_0_0 -> 2864 in the cache */
   /* search988_0 -> 2865 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 2865 },
      -1,
   } },

   /* replace988_0_0 -> 0 in the cache */
   /* replace988_0_1 -> 3 in the cache */
   /* replace988_0 -> 2864 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 2864 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0) */
   /* search989_0 -> 16 in the cache */
   /* search989_1 -> 120 in the cache */
   /* search989_2 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 722 },
      -1,
   } },

   /* replace989_0 -> 16 in the cache */
   /* replace989_1 -> 120 in the cache */
   /* replace989 -> 332 in the cache */

   /* ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1) */
   /* search990_0 -> 16 in the cache */
   /* search990_1 -> 722 in the cache */
   /* search990_2 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 16, 722, 722 },
      -1,
   } },

   /* replace990_0 -> 16 in the cache */
   /* replace990_1 -> 316 in the cache */
   /* replace990 -> 335 in the cache */

   /* ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2) */
   /* search991_0 -> 16 in the cache */
   /* search991_1 -> 745 in the cache */
   /* search991_2 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 16, 745, 722 },
      -1,
   } },

   /* replace991_0 -> 16 in the cache */
   /* replace991_1 -> 321 in the cache */
   /* replace991 -> 339 in the cache */

   /* ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3) */
   /* search992_0 -> 16 in the cache */
   /* search992_1 -> 903 in the cache */
   /* search992_2 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 16, 903, 722 },
      -1,
   } },

   /* replace992_0 -> 16 in the cache */
   /* replace992_1 -> 325 in the cache */
   /* replace992 -> 342 in the cache */

   /* ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0) */
   /* search993_0 -> 16 in the cache */
   /* search993_1 -> 120 in the cache */
   /* search993_2 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 16, 120, 722 },
      -1,
   } },

   /* replace993_0 -> 16 in the cache */
   /* replace993_1 -> 120 in the cache */
   /* replace993 -> 313 in the cache */

   /* ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1) */
   /* search994_0 -> 16 in the cache */
   /* search994_1 -> 722 in the cache */
   /* search994_2 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 16, 722, 722 },
      -1,
   } },

   /* replace994_0 -> 16 in the cache */
   /* replace994_1 -> 316 in the cache */
   /* replace994 -> 317 in the cache */

   /* ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2) */
   /* search995_0 -> 16 in the cache */
   /* search995_1 -> 745 in the cache */
   /* search995_2 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 16, 745, 722 },
      -1,
   } },

   /* replace995_0 -> 16 in the cache */
   /* replace995_1 -> 321 in the cache */
   /* replace995 -> 322 in the cache */

   /* ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3) */
   /* search996_0 -> 16 in the cache */
   /* search996_1 -> 903 in the cache */
   /* search996_2 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 16, 903, 722 },
      -1,
   } },

   /* replace996_0 -> 16 in the cache */
   /* replace996_1 -> 325 in the cache */
   /* replace996 -> 326 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search997_0_0 -> 0 in the cache */
   /* search997_0_1 -> 3 in the cache */
   /* search997_0 -> 2867 in the cache */
   /* search997_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2867, 86 },
      -1,
   } },

   /* replace997_0 -> 0 in the cache */
   /* replace997_1 -> 3 in the cache */
   /* replace997 -> 2864 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search998_0_0 -> 0 in the cache */
   /* search998_0_1 -> 3 in the cache */
   /* search998_0 -> 2864 in the cache */
   /* search998_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2864, 86 },
      -1,
   } },

   /* replace998_0 -> 0 in the cache */
   /* replace998_1 -> 3 in the cache */
   /* replace998 -> 2864 in the cache */

   /* ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0) */
   /* search999_0_0 -> 16 in the cache */
   /* search999_0_1 -> 745 in the cache */
   /* search999_0 -> 897 in the cache */
   /* search999_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 897, 745 },
      -1,
   } },

   /* replace999_0 -> 16 in the cache */
   /* replace999_1 -> 120 in the cache */
   /* replace999 -> 364 in the cache */

   /* ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1) */
   /* search1000_0 -> 16 in the cache */
   /* search1000_1 -> 745 in the cache */
   /* search1000 -> 900 in the cache */

   /* replace1000_0 -> 16 in the cache */
   /* replace1000_1 -> 316 in the cache */
   /* replace1000 -> 367 in the cache */

   /* ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0) */
   /* search1001_0_0 -> 16 in the cache */
   /* search1001_0_1 -> 745 in the cache */
   /* search1001_0 -> 897 in the cache */
   /* search1001_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 897, 745 },
      -1,
   } },

   /* replace1001_0 -> 16 in the cache */
   /* replace1001_1 -> 120 in the cache */
   /* replace1001 -> 356 in the cache */

   /* ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1) */
   /* search1002_0 -> 16 in the cache */
   /* search1002_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 16, 745 },
      -1,
   } },

   /* replace1002_0 -> 16 in the cache */
   /* replace1002_1 -> 316 in the cache */
   /* replace1002 -> 359 in the cache */

   /* ('iand', 65535, 'a') => ('extract_u16', 'a', 0) */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* search1003_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 2884, 32 },
      -1,
   } },

   /* replace1003_0 -> 32 in the cache */
   /* replace1003_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0) */
   /* search1004_0 -> 16 in the cache */
   /* search1004_1 -> 120 in the cache */
   /* search1004_2 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 745 },
      -1,
   } },

   /* replace1004_0 -> 16 in the cache */
   /* replace1004_1 -> 120 in the cache */
   /* replace1004 -> 364 in the cache */

   /* ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1) */
   /* search1005_0 -> 16 in the cache */
   /* search1005_1 -> 745 in the cache */
   /* search1005_2 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 16, 745, 745 },
      -1,
   } },

   /* replace1005_0 -> 16 in the cache */
   /* replace1005_1 -> 316 in the cache */
   /* replace1005 -> 367 in the cache */

   /* ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0) */
   /* search1006_0 -> 16 in the cache */
   /* search1006_1 -> 120 in the cache */
   /* search1006_2 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 16, 120, 745 },
      -1,
   } },

   /* replace1006_0 -> 16 in the cache */
   /* replace1006_1 -> 120 in the cache */
   /* replace1006 -> 356 in the cache */

   /* ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1) */
   /* search1007_0 -> 16 in the cache */
   /* search1007_1 -> 745 in the cache */
   /* search1007_2 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 16, 745, 745 },
      -1,
   } },

   /* replace1007_0 -> 16 in the cache */
   /* replace1007_1 -> 316 in the cache */
   /* replace1007 -> 359 in the cache */

   /* ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a')) */
   /* search1008_0_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 6 },
      -1,
   } },
   /* search1008_0_1 -> 903 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 2891, 903 },
      -1,
   } },
   /* search1008_1_0_0_0 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 1984 },
      -1,
   } },
   /* search1008_1_0_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 2893, 745 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 2895 },
      -1,
   } },
   /* search1008_1_1_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 2896, 722 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 2898 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      2, 1,
      { 2897, 2899 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      1, 2,
      { 2894, 2900 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 3,
      { 2892, 2901 },
      -1,
   } },

   /* replace1008_0_0 -> 2898 in the cache */
   /* replace1008_0_1 -> 2895 in the cache */
   /* replace1008_0_2 -> 1984 in the cache */
   /* replace1008_0_3 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 2898, 2895, 1984, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_32_4x8,
      -1, 0,
      { 2903 },
      -1,
   } },

   /* ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1009_0_0 -> 0 in the cache */
   /* search1009_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   /* search1009_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 2905, 86 },
      -1,
   } },

   /* replace1009_0 -> 0 in the cache */
   /* replace1009_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1010_0_0 -> 0 in the cache */
   /* search1010_0_1 -> 3 in the cache */
   /* search1010_0 -> 2907 in the cache */
   /* search1010_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 2907, 86 },
      -1,
   } },

   /* replace1010_0 -> 0 in the cache */
   /* replace1010_1 -> 3 in the cache */
   /* replace1010 -> 2907 in the cache */

   /* ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32)) */
   /* search1011_0 -> 16 in the cache */
   /* search1011_1 -> 36 in the cache */
   /* search1011 -> 2817 in the cache */

   /* replace1011_0_0 -> 16 in the cache */
   /* replace1011_0 -> 1780 in the cache */
   /* replace1011_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 36 },
      -1,
   } },
   /* replace1011_1_1 -> 767 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 2909, 767 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1780, 2910 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16)) */
   /* search1012_0 -> 11 in the cache */
   /* search1012_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 11, 207 },
      -1,
   } },

   /* replace1012_0_0 -> 11 in the cache */
   /* replace1012_0 -> 1673 in the cache */
   /* replace1012_1_0_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 207 },
      -1,
   } },
   /* replace1012_1_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 2913, 745 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1673, 2914 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a') */
   /* search1013_0 -> 21 in the cache */
   /* search1013 -> 2826 in the cache */

   /* replace1013_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32)) */
   /* search1014_0 -> 21 in the cache */
   /* search1014 -> 2827 in the cache */

   /* replace1014_0_0 -> 21 in the cache */
   /* replace1014_0_1 -> 767 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 21, 767 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 2917 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a') */
   /* search1015_0 -> 16 in the cache */
   /* search1015 -> 2835 in the cache */

   /* replace1015_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1016_0 -> 16 in the cache */
   /* search1016 -> 2837 in the cache */

   /* replace1016_0_0 -> 16 in the cache */
   /* replace1016_0_1 -> 745 in the cache */
   /* replace1016_0 -> 900 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 900 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1017_0_0 -> 16 in the cache */
   /* search1017_0_1 -> 741 in the cache */
   /* search1017_0 -> 895 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_half_2x16_split_x,
      -1, 1,
      { 895 },
      -1,
   } },

   /* replace1017_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1018_0_0 -> 16 in the cache */
   /* search1018_0_1 -> 741 in the cache */
   /* search1018_0 -> 895 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_unpack_32_2x16_split_x,
      -1, 1,
      { 895 },
      -1,
   } },

   /* replace1018_0 -> 16 in the cache */
   /* replace1018 -> 2835 in the cache */

   /* ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a') */
   /* search1019_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iand,
      0, 1,
      { 21, 2924 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 2925 },
      -1,
   } },

   /* replace1019_0 -> 21 in the cache */
   /* replace1019 -> 2826 in the cache */

   /* ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1020_0_0 -> 16 in the cache */
   /* search1020_0_1 -> 898 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 16, 898 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_half_2x16_split_y,
      -1, 1,
      { 2927 },
      -1,
   } },

   /* replace1020_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_half_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1021_0_0 -> 16 in the cache */
   /* search1021_0_1 -> 898 in the cache */
   /* search1021_0 -> 2927 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_unpack_32_2x16_split_y,
      -1, 1,
      { 2927 },
      -1,
   } },

   /* replace1021_0 -> 16 in the cache */
   /* replace1021 -> 2837 in the cache */

   /* ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a') */
   /* search1022_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff00000000 /* 18446744069414584320 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iand,
      0, 1,
      { 21, 2931 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32_split_y,
      -1, 1,
      { 2932 },
      -1,
   } },

   /* replace1022_0 -> 21 in the cache */
   /* replace1022 -> 2827 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1023_0_0 -> 16 in the cache */
   /* search1023_0_1 -> 120 in the cache */
   /* search1023_0 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 364 },
      -1,
   } },

   /* replace1023_0 -> 16 in the cache */
   /* replace1023 -> 2922 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1024_0_0 -> 16 in the cache */
   /* search1024_0_1 -> 316 in the cache */
   /* search1024_0 -> 367 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 367 },
      -1,
   } },

   /* replace1024_0 -> 16 in the cache */
   /* replace1024 -> 2929 in the cache */

   /* ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1025_0_0 -> 16 in the cache */
   /* search1025_0_1 -> 745 in the cache */
   /* search1025_0 -> 900 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 900 },
      -1,
   } },

   /* replace1025_0 -> 16 in the cache */
   /* replace1025 -> 2929 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1026_0_0 -> 16 in the cache */
   /* search1026_0_1 -> 120 in the cache */
   /* search1026_0 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 364 },
      -1,
   } },

   /* replace1026_0 -> 16 in the cache */
   /* replace1026 -> 2835 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1027_0_0 -> 16 in the cache */
   /* search1027_0_1 -> 316 in the cache */
   /* search1027_0 -> 367 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 367 },
      -1,
   } },

   /* replace1027_0 -> 16 in the cache */
   /* replace1027 -> 2837 in the cache */

   /* ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a')) */
   /* search1028_0_0_0 -> 16 in the cache */
   /* search1028_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 2939 },
      -1,
   } },
   /* search1028_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 2940, 745 },
      -1,
   } },

   /* replace1028_0_0 -> 120 in the cache */
   /* replace1028_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 2942 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0)) */
   /* search1029_0_0_0 -> 120 in the cache */
   /* search1029_0_0_1 -> 16 in the cache */
   /* search1029_0_0 -> 2942 in the cache */
   /* search1029_0 -> 2943 in the cache */
   /* search1029_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 2943, 745 },
      -1,
   } },

   /* replace1029_0_0 -> 16 in the cache */
   /* replace1029_0_1 -> 120 in the cache */
   /* replace1029_0 -> 2939 in the cache */
   /* replace1029 -> 2940 in the cache */

   /* ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1030_0_0_0 -> 16 in the cache */
   /* search1030_0_0_1 -> 120 in the cache */
   /* search1030_0_0 -> 2939 in the cache */
   /* search1030_0 -> 2940 in the cache */
   /* search1030_1_0_0 -> 120 in the cache */
   /* search1030_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 2945 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 2940, 2946 },
      -1,
   } },

   /* replace1030_0_0 -> 16 in the cache */
   /* replace1030_0_1 -> 36 in the cache */
   /* replace1030_0 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 2821 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1031_0_0_0 -> 16 in the cache */
   /* search1031_0_0_1 -> 120 in the cache */
   /* search1031_0_0 -> 2939 in the cache */
   /* search1031_0 -> 2940 in the cache */
   /* search1031_1_0_0 -> 120 in the cache */
   /* search1031_1_0_1 -> 36 in the cache */
   /* search1031_1_0 -> 2945 in the cache */
   /* search1031_1 -> 2946 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2940, 2946 },
      -1,
   } },

   /* replace1031_0_0 -> 16 in the cache */
   /* replace1031_0_1 -> 36 in the cache */
   /* replace1031_0 -> 2821 in the cache */
   /* replace1031 -> 2948 in the cache */

   /* ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a') */
   /* search1032_0_0 -> 16 in the cache */
   /* search1032_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1032_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 2950, 745 },
      -1,
   } },

   /* replace1032_0 -> 120 in the cache */
   /* replace1032_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 120, 16 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0) */
   /* search1033_0_0 -> 120 in the cache */
   /* search1033_0_1 -> 16 in the cache */
   /* search1033_0 -> 2952 in the cache */
   /* search1033_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 2952, 745 },
      -1,
   } },

   /* replace1033_0 -> 16 in the cache */
   /* replace1033_1 -> 120 in the cache */
   /* replace1033 -> 2950 in the cache */

   /* ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0) */
   /* search1034_0_0 -> 120 in the cache */
   /* search1034_0_1 -> 16 in the cache */
   /* search1034_0 -> 2952 in the cache */
   /* search1034_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 2952, 316 },
      -1,
   } },

   /* replace1034_0 -> 16 in the cache */
   /* replace1034_1 -> 120 in the cache */
   /* replace1034 -> 2950 in the cache */

   /* ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1035_0_0 -> 16 in the cache */
   /* search1035_0_1 -> 120 in the cache */
   /* search1035_0 -> 2950 in the cache */
   /* search1035_1_0 -> 120 in the cache */
   /* search1035_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 2950, 2955 },
      -1,
   } },

   /* replace1035_0 -> 16 in the cache */
   /* replace1035_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1036_0_0 -> 16 in the cache */
   /* search1036_0_1 -> 120 in the cache */
   /* search1036_0 -> 2950 in the cache */
   /* search1036_1_0 -> 120 in the cache */
   /* search1036_1_1 -> 36 in the cache */
   /* search1036_1 -> 2955 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2950, 2955 },
      -1,
   } },

   /* replace1036_0 -> 16 in the cache */
   /* replace1036_1 -> 36 in the cache */
   /* replace1036 -> 2957 in the cache */

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a') */
   /* search1037_0_0 -> 6 in the cache */
   /* search1037_0_1 -> 1984 in the cache */
   /* search1037_0_2 -> 2895 in the cache */
   /* search1037_0_3 -> 2898 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_32_4x8_split,
      -1, 0,
      { 6, 1984, 2895, 2898 },
      -1,
   } },
   /* search1037_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 2959, 120 },
      -1,
   } },

   /* replace1037_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_i2i,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b') */
   /* search1038_0_0 -> 6 in the cache */
   /* search1038_0_1 -> 1984 in the cache */
   /* search1038_0_2 -> 2895 in the cache */
   /* search1038_0_3 -> 2898 in the cache */
   /* search1038_0 -> 2959 in the cache */
   /* search1038_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 2959, 316 },
      -1,
   } },

   /* replace1038_0 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_i2i,
      -1, 0,
      { 1984 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c') */
   /* search1039_0_0 -> 6 in the cache */
   /* search1039_0_1 -> 1984 in the cache */
   /* search1039_0_2 -> 2895 in the cache */
   /* search1039_0_3 -> 2898 in the cache */
   /* search1039_0 -> 2959 in the cache */
   /* search1039_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 2959, 321 },
      -1,
   } },

   /* replace1039_0 -> 2895 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_i2i,
      -1, 0,
      { 2895 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd') */
   /* search1040_0_0 -> 6 in the cache */
   /* search1040_0_1 -> 1984 in the cache */
   /* search1040_0_2 -> 2895 in the cache */
   /* search1040_0_3 -> 2898 in the cache */
   /* search1040_0 -> 2959 in the cache */
   /* search1040_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 2959, 325 },
      -1,
   } },

   /* replace1040_0 -> 2898 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_i2i,
      -1, 0,
      { 2898 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a') */
   /* search1041_0_0 -> 6 in the cache */
   /* search1041_0_1 -> 1984 in the cache */
   /* search1041_0_2 -> 2895 in the cache */
   /* search1041_0_3 -> 2898 in the cache */
   /* search1041_0 -> 2959 in the cache */
   /* search1041_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2959, 120 },
      -1,
   } },

   /* replace1041_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_u2u,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b') */
   /* search1042_0_0 -> 6 in the cache */
   /* search1042_0_1 -> 1984 in the cache */
   /* search1042_0_2 -> 2895 in the cache */
   /* search1042_0_3 -> 2898 in the cache */
   /* search1042_0 -> 2959 in the cache */
   /* search1042_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2959, 316 },
      -1,
   } },

   /* replace1042_0 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_u2u,
      -1, 0,
      { 1984 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c') */
   /* search1043_0_0 -> 6 in the cache */
   /* search1043_0_1 -> 1984 in the cache */
   /* search1043_0_2 -> 2895 in the cache */
   /* search1043_0_3 -> 2898 in the cache */
   /* search1043_0 -> 2959 in the cache */
   /* search1043_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2959, 321 },
      -1,
   } },

   /* replace1043_0 -> 2895 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_u2u,
      -1, 0,
      { 2895 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd') */
   /* search1044_0_0 -> 6 in the cache */
   /* search1044_0_1 -> 1984 in the cache */
   /* search1044_0_2 -> 2895 in the cache */
   /* search1044_0_3 -> 2898 in the cache */
   /* search1044_0 -> 2959 in the cache */
   /* search1044_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2959, 325 },
      -1,
   } },

   /* replace1044_0 -> 2898 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_u2u,
      -1, 0,
      { 2898 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1045_0_0 -> 11 in the cache */
   /* search1045_0_1 -> 722 in the cache */
   /* search1045_0 -> 2843 in the cache */
   /* search1045_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2843, 748 },
      -1,
   } },

   /* replace1045_0 -> 11 in the cache */
   /* replace1045_1 -> 1325 in the cache */
   /* replace1045 -> 2844 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1046_0_0 -> 16 in the cache */
   /* search1046_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 16, 722 },
      -1,
   } },
   /* search1046_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2977, 120 },
      -1,
   } },

   /* replace1046_0 -> 16 in the cache */
   /* replace1046_1 -> 316 in the cache */
   /* replace1046 -> 335 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1047_0_0 -> 16 in the cache */
   /* search1047_0_1 -> 745 in the cache */
   /* search1047_0 -> 900 in the cache */
   /* search1047_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 900, 120 },
      -1,
   } },

   /* replace1047_0 -> 16 in the cache */
   /* replace1047_1 -> 321 in the cache */
   /* replace1047 -> 339 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1048_0_0 -> 16 in the cache */
   /* search1048_0_1 -> 903 in the cache */
   /* search1048_0 -> 908 in the cache */
   /* search1048_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 908, 120 },
      -1,
   } },

   /* replace1048_0 -> 16 in the cache */
   /* replace1048_1 -> 325 in the cache */
   /* replace1048 -> 342 in the cache */

   /* ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1049_0_0 -> 21 in the cache */
   /* search1049_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 21, 722 },
      -1,
   } },
   /* search1049_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2981, 791 },
      -1,
   } },

   /* replace1049_0 -> 21 in the cache */
   /* replace1049_1 -> 1367 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 1367 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1050_0_0 -> 21 in the cache */
   /* search1050_0_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 21, 745 },
      -1,
   } },
   /* search1050_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2984, 791 },
      -1,
   } },

   /* replace1050_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 2986 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1051_0_0 -> 21 in the cache */
   /* search1051_0_1 -> 903 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 21, 903 },
      -1,
   } },
   /* search1051_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2988, 791 },
      -1,
   } },

   /* replace1051_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 2990 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1052_0_0 -> 21 in the cache */
   /* search1052_0_1 -> 767 in the cache */
   /* search1052_0 -> 2917 in the cache */
   /* search1052_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2917, 791 },
      -1,
   } },

   /* replace1052_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 2993 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1053_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x28 /* 40 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 21, 2995 },
      -1,
   } },
   /* search1053_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2996, 791 },
      -1,
   } },

   /* replace1053_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x5 /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 2998 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1054_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x30 /* 48 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 21, 3000 },
      -1,
   } },
   /* search1054_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3001, 791 },
      -1,
   } },

   /* replace1054_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x6 /* 6 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3003 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1055_0_0 -> 21 in the cache */
   /* search1055_0_1 -> 2845 in the cache */
   /* search1055_0 -> 2846 in the cache */
   /* search1055_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2846, 791 },
      -1,
   } },

   /* replace1055_0 -> 21 in the cache */
   /* replace1055_1 -> 2847 in the cache */
   /* replace1055 -> 2848 in the cache */

   /* ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1056_0_0 -> 11 in the cache */
   /* search1056_0_1 -> 722 in the cache */
   /* search1056_0 -> 2849 in the cache */
   /* search1056_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2849, 748 },
      -1,
   } },

   /* replace1056_0 -> 11 in the cache */
   /* replace1056_1 -> 1325 in the cache */
   /* replace1056 -> 2844 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1057_0_0 -> 16 in the cache */
   /* search1057_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 16, 722 },
      -1,
   } },
   /* search1057_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3007, 120 },
      -1,
   } },

   /* replace1057_0 -> 16 in the cache */
   /* replace1057_1 -> 316 in the cache */
   /* replace1057 -> 335 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1058_0_0 -> 16 in the cache */
   /* search1058_0_1 -> 745 in the cache */
   /* search1058_0 -> 2883 in the cache */
   /* search1058_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2883, 120 },
      -1,
   } },

   /* replace1058_0 -> 16 in the cache */
   /* replace1058_1 -> 321 in the cache */
   /* replace1058 -> 339 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1059_0_0 -> 16 in the cache */
   /* search1059_0_1 -> 903 in the cache */
   /* search1059_0 -> 2851 in the cache */
   /* search1059_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2851, 120 },
      -1,
   } },

   /* replace1059_0 -> 16 in the cache */
   /* replace1059_1 -> 325 in the cache */
   /* replace1059 -> 342 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1060_0_0 -> 21 in the cache */
   /* search1060_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 21, 722 },
      -1,
   } },
   /* search1060_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3011, 791 },
      -1,
   } },

   /* replace1060_0 -> 21 in the cache */
   /* replace1060_1 -> 1367 in the cache */
   /* replace1060 -> 2983 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1061_0_0 -> 21 in the cache */
   /* search1061_0_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 21, 745 },
      -1,
   } },
   /* search1061_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3013, 791 },
      -1,
   } },

   /* replace1061_0 -> 21 in the cache */
   /* replace1061_1 -> 2986 in the cache */
   /* replace1061 -> 2987 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1062_0_0 -> 21 in the cache */
   /* search1062_0_1 -> 903 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 21, 903 },
      -1,
   } },
   /* search1062_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3015, 791 },
      -1,
   } },

   /* replace1062_0 -> 21 in the cache */
   /* replace1062_1 -> 2990 in the cache */
   /* replace1062 -> 2991 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1063_0_0 -> 21 in the cache */
   /* search1063_0_1 -> 767 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 21, 767 },
      -1,
   } },
   /* search1063_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3017, 791 },
      -1,
   } },

   /* replace1063_0 -> 21 in the cache */
   /* replace1063_1 -> 2993 in the cache */
   /* replace1063 -> 2994 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1064_0_0 -> 21 in the cache */
   /* search1064_0_1 -> 2995 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 21, 2995 },
      -1,
   } },
   /* search1064_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3019, 791 },
      -1,
   } },

   /* replace1064_0 -> 21 in the cache */
   /* replace1064_1 -> 2998 in the cache */
   /* replace1064 -> 2999 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1065_0_0 -> 21 in the cache */
   /* search1065_0_1 -> 3000 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 21, 3000 },
      -1,
   } },
   /* search1065_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3021, 791 },
      -1,
   } },

   /* replace1065_0 -> 21 in the cache */
   /* replace1065_1 -> 3003 in the cache */
   /* replace1065 -> 3004 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1066_0_0 -> 21 in the cache */
   /* search1066_0_1 -> 2845 in the cache */
   /* search1066_0 -> 2852 in the cache */
   /* search1066_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2852, 791 },
      -1,
   } },

   /* replace1066_0 -> 21 in the cache */
   /* replace1066_1 -> 2847 in the cache */
   /* replace1066 -> 2848 in the cache */

   /* ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2) */
   /* search1067_0_0 -> 32 in the cache */
   /* search1067_0_1 -> 35 in the cache */
   /* search1067_0 -> 2856 in the cache */
   /* search1067_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 2856, 61 },
      -1,
   } },

   /* replace1067_0 -> 32 in the cache */
   /* replace1067_1 -> 2091 in the cache */
   /* replace1067 -> 2858 in the cache */

   /* ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0) */
   /* search1068_0_0 -> 11 in the cache */
   /* search1068_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 11, 722 },
      -1,
   } },
   /* search1068_1 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3025, 1325 },
      -1,
   } },

   /* replace1068_0 -> 11 in the cache */
   /* replace1068_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 748 },
      -1,
   } },

   /* ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2) */
   /* search1069_0_0 -> 16 in the cache */
   /* search1069_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 722 },
      -1,
   } },
   /* search1069_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3028, 325 },
      -1,
   } },

   /* replace1069_0 -> 16 in the cache */
   /* replace1069_1 -> 321 in the cache */
   /* replace1069 -> 339 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1) */
   /* search1070_0_0 -> 16 in the cache */
   /* search1070_0_1 -> 745 in the cache */
   /* search1070_0 -> 897 in the cache */
   /* search1070_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 897, 325 },
      -1,
   } },

   /* replace1070_0 -> 16 in the cache */
   /* replace1070_1 -> 316 in the cache */
   /* replace1070 -> 335 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0) */
   /* search1071_0_0 -> 16 in the cache */
   /* search1071_0_1 -> 903 in the cache */
   /* search1071_0 -> 905 in the cache */
   /* search1071_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 905, 325 },
      -1,
   } },

   /* replace1071_0 -> 16 in the cache */
   /* replace1071_1 -> 120 in the cache */
   /* replace1071 -> 332 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6) */
   /* search1072_0_0 -> 21 in the cache */
   /* search1072_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 722 },
      -1,
   } },
   /* search1072_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3032, 2847 },
      -1,
   } },

   /* replace1072_0 -> 21 in the cache */
   /* replace1072_1 -> 3003 in the cache */
   /* replace1072 -> 3004 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5) */
   /* search1073_0_0 -> 21 in the cache */
   /* search1073_0_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 745 },
      -1,
   } },
   /* search1073_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3034, 2847 },
      -1,
   } },

   /* replace1073_0 -> 21 in the cache */
   /* replace1073_1 -> 2998 in the cache */
   /* replace1073 -> 2999 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4) */
   /* search1074_0_0 -> 21 in the cache */
   /* search1074_0_1 -> 903 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 903 },
      -1,
   } },
   /* search1074_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3036, 2847 },
      -1,
   } },

   /* replace1074_0 -> 21 in the cache */
   /* replace1074_1 -> 2993 in the cache */
   /* replace1074 -> 2994 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3) */
   /* search1075_0_0 -> 21 in the cache */
   /* search1075_0_1 -> 767 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 767 },
      -1,
   } },
   /* search1075_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3038, 2847 },
      -1,
   } },

   /* replace1075_0 -> 21 in the cache */
   /* replace1075_1 -> 2990 in the cache */
   /* replace1075 -> 2991 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2) */
   /* search1076_0_0 -> 21 in the cache */
   /* search1076_0_1 -> 2995 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 2995 },
      -1,
   } },
   /* search1076_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3040, 2847 },
      -1,
   } },

   /* replace1076_0 -> 21 in the cache */
   /* replace1076_1 -> 2986 in the cache */
   /* replace1076 -> 2987 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1) */
   /* search1077_0_0 -> 21 in the cache */
   /* search1077_0_1 -> 3000 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 3000 },
      -1,
   } },
   /* search1077_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3042, 2847 },
      -1,
   } },

   /* replace1077_0 -> 21 in the cache */
   /* replace1077_1 -> 1367 in the cache */
   /* replace1077 -> 2983 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0) */
   /* search1078_0_0 -> 21 in the cache */
   /* search1078_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 21, 2845 },
      -1,
   } },
   /* search1078_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3044, 2847 },
      -1,
   } },

   /* replace1078_0 -> 21 in the cache */
   /* replace1078_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 791 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0) */
   /* search1079_0_0 -> 11 in the cache */
   /* search1079_0_1 -> 722 in the cache */
   /* search1079_0 -> 3025 in the cache */
   /* search1079_1 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3025, 1325 },
      -1,
   } },

   /* replace1079_0 -> 11 in the cache */
   /* replace1079_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 748 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2) */
   /* search1080_0_0 -> 16 in the cache */
   /* search1080_0_1 -> 722 in the cache */
   /* search1080_0 -> 3028 in the cache */
   /* search1080_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3028, 325 },
      -1,
   } },

   /* replace1080_0 -> 16 in the cache */
   /* replace1080_1 -> 321 in the cache */
   /* replace1080 -> 322 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1) */
   /* search1081_0_0 -> 16 in the cache */
   /* search1081_0_1 -> 745 in the cache */
   /* search1081_0 -> 897 in the cache */
   /* search1081_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 897, 325 },
      -1,
   } },

   /* replace1081_0 -> 16 in the cache */
   /* replace1081_1 -> 316 in the cache */
   /* replace1081 -> 317 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0) */
   /* search1082_0_0 -> 16 in the cache */
   /* search1082_0_1 -> 903 in the cache */
   /* search1082_0 -> 905 in the cache */
   /* search1082_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 905, 325 },
      -1,
   } },

   /* replace1082_0 -> 16 in the cache */
   /* replace1082_1 -> 120 in the cache */
   /* replace1082 -> 313 in the cache */

   /* ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6) */
   /* search1083_0_0 -> 21 in the cache */
   /* search1083_0_1 -> 722 in the cache */
   /* search1083_0 -> 3032 in the cache */
   /* search1083_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3032, 2847 },
      -1,
   } },

   /* replace1083_0 -> 21 in the cache */
   /* replace1083_1 -> 3003 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3003 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5) */
   /* search1084_0_0 -> 21 in the cache */
   /* search1084_0_1 -> 745 in the cache */
   /* search1084_0 -> 3034 in the cache */
   /* search1084_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3034, 2847 },
      -1,
   } },

   /* replace1084_0 -> 21 in the cache */
   /* replace1084_1 -> 2998 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 2998 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4) */
   /* search1085_0_0 -> 21 in the cache */
   /* search1085_0_1 -> 903 in the cache */
   /* search1085_0 -> 3036 in the cache */
   /* search1085_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3036, 2847 },
      -1,
   } },

   /* replace1085_0 -> 21 in the cache */
   /* replace1085_1 -> 2993 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 2993 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3) */
   /* search1086_0_0 -> 21 in the cache */
   /* search1086_0_1 -> 767 in the cache */
   /* search1086_0 -> 3038 in the cache */
   /* search1086_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3038, 2847 },
      -1,
   } },

   /* replace1086_0 -> 21 in the cache */
   /* replace1086_1 -> 2990 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 2990 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2) */
   /* search1087_0_0 -> 21 in the cache */
   /* search1087_0_1 -> 2995 in the cache */
   /* search1087_0 -> 3040 in the cache */
   /* search1087_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3040, 2847 },
      -1,
   } },

   /* replace1087_0 -> 21 in the cache */
   /* replace1087_1 -> 2986 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 2986 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1) */
   /* search1088_0_0 -> 21 in the cache */
   /* search1088_0_1 -> 3000 in the cache */
   /* search1088_0 -> 3042 in the cache */
   /* search1088_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3042, 2847 },
      -1,
   } },

   /* replace1088_0 -> 21 in the cache */
   /* replace1088_1 -> 1367 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 1367 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0) */
   /* search1089_0_0 -> 21 in the cache */
   /* search1089_0_1 -> 2845 in the cache */
   /* search1089_0 -> 3044 in the cache */
   /* search1089_1 -> 2847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3044, 2847 },
      -1,
   } },

   /* replace1089_0 -> 21 in the cache */
   /* replace1089_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 791 },
      -1,
   } },

   /* ('ussub_4x8_vc4', 'a', 0) => a */
   /* search1090_0 -> 16 in the cache */
   /* search1090_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* replace1090 -> 16 in the cache */

   /* ('ussub_4x8_vc4', 'a', -1) => 0 */
   /* search1091_0 -> 16 in the cache */
   /* search1091_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 122 },
      -1,
   } },

   /* replace1091 -> 120 in the cache */

   /* ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b')) */
   /* search1092_0 -> 0 in the cache */
   /* search1092_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1092_0 -> 0 in the cache */
   /* replace1092_1_0 -> 3 in the cache */
   /* replace1092_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 0, 978 },
      -1,
   } },

   /* ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b')) */
   /* search1093_0 -> 0 in the cache */
   /* search1093_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1093_0 -> 0 in the cache */
   /* replace1093_1_0 -> 3 in the cache */
   /* replace1093_1 -> 93 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 0, 93 },
      -1,
   } },

   /* ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1094_0 -> 0 in the cache */
   /* search1094_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_uabs_usub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1094_0_0 -> 0 in the cache */
   /* replace1094_0_1 -> 3 in the cache */
   /* replace1094_0 -> 958 in the cache */
   /* replace1094_1_0_0 -> 0 in the cache */
   /* replace1094_1_0_1 -> 3 in the cache */
   /* replace1094_1_0 -> 3070 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 3070 },
      -1,
   } },
   /* replace1094_2_0 -> 0 in the cache */
   /* replace1094_2_1 -> 3 in the cache */
   /* replace1094_2 -> 3070 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 958, 3073, 3070 },
      -1,
   } },

   /* ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1095_0 -> 0 in the cache */
   /* search1095_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_uabs_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1095_0_0 -> 0 in the cache */
   /* replace1095_0_1 -> 3 in the cache */
   /* replace1095_0 -> 955 in the cache */
   /* replace1095_1_0_0 -> 0 in the cache */
   /* replace1095_1_0_1 -> 3 in the cache */
   /* replace1095_1_0 -> 3070 in the cache */
   /* replace1095_1 -> 3073 in the cache */
   /* replace1095_2_0 -> 0 in the cache */
   /* replace1095_2_1 -> 3 in the cache */
   /* replace1095_2 -> 3070 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 955, 3073, 3070 },
      -1,
   } },

   /* ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b')) */
   /* search1096_0_0 -> 0 in the cache */
   /* search1096_0 -> 177 in the cache */
   /* search1096_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 177, 3 },
      4,
   } },

   /* replace1096_0_0 -> 0 in the cache */
   /* replace1096_0_1 -> 3 in the cache */
   /* replace1096_0 -> 211 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 211 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   /* search1097_0_0 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 124 },
      -1,
   } },
   /* search1097_1_0 -> 125 in the cache */
   /* search1097_1 -> 1081 in the cache */
   /* search1097_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 3079, 1081, 127 },
      -1,
   } },

   /* replace1097_0 -> 124 in the cache */
   /* replace1097_1 -> 125 in the cache */
   /* replace1097_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 124, 125, 127 },
      -1,
   } },

   /* ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b')) */
   /* search1098_0_0 -> 0 in the cache */
   /* search1098_0 -> 172 in the cache */
   /* search1098_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imul,
      0, 1,
      { 172, 3 },
      -1,
   } },

   /* replace1098_0_0 -> 0 in the cache */
   /* replace1098_0_1 -> 3 in the cache */
   /* replace1098_0 -> 844 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ineg,
      -1, 1,
      { 844 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 3084, 3085 },
      0,
   } },
   /* search1099_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_fmul,
      0, 2,
      { 3086, 704 },
      0,
   } },

   /* replace1099_0_0 -> 124 in the cache */
   /* replace1099_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1099_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      0, 2,
      { 3088, 125 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1100_0_0 -> 3084 in the cache */
   /* search1100_0_1 -> 3085 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      1, 1,
      { 3084, 3085 },
      0,
   } },
   /* search1100_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      0, 2,
      { 3090, 704 },
      0,
   } },

   /* replace1100_0_0 -> 124 in the cache */
   /* replace1100_0_1 -> 127 in the cache */
   /* replace1100_0 -> 916 in the cache */
   /* replace1100_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      0, 2,
      { 916, 125 },
      -1,
   } },

   /* ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 3093, 3094 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1101_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 3095, 3096, 145 },
      -1,
   } },

   /* replace1101_0_0 -> 141 in the cache */
   /* replace1101_0_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 141, 144 },
      -1,
   } },
   /* replace1101_1 -> 142 in the cache */
   /* replace1101_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ffma,
      0, 2,
      { 3098, 142, 145 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1102_0_0 -> 3084 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      26,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 3084, 3100 },
      0,
   } },
   /* search1102_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 3101, 704 },
      0,
   } },

   /* replace1102_0_0 -> 124 in the cache */
   /* replace1102_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1102_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 3103, 125 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1103_0_0 -> 3084 in the cache */
   /* search1103_0_1 -> 3085 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 3084, 3085 },
      0,
   } },
   /* search1103_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 3105, 704 },
      0,
   } },

   /* replace1103_0_0 -> 124 in the cache */
   /* replace1103_0_1 -> 127 in the cache */
   /* replace1103_0 -> 3103 in the cache */
   /* replace1103_1 -> 125 in the cache */
   /* replace1103 -> 3104 in the cache */

   /* ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c') */
   /* search1104_0_0 -> 3093 in the cache */
   /* search1104_0_1 -> 142 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 3093, 142, 3107 },
      0,
   } },
   /* search1104_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 3108, 922 },
      0,
   } },

   /* replace1104_0_0 -> 141 in the cache */
   /* replace1104_0_1 -> 142 in the cache */
   /* replace1104_0_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 141, 142, 145 },
      -1,
   } },
   /* replace1104_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 3110, 144 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1105_0_0 -> 3084 in the cache */
   /* search1105_0_1 -> 3085 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 3084, 3085 },
      0,
   } },
   /* search1105_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 3112, 704 },
      0,
   } },

   /* replace1105_0_0 -> 124 in the cache */
   /* replace1105_0_1 -> 127 in the cache */
   /* replace1105_0 -> 930 in the cache */
   /* replace1105_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 930, 125 },
      -1,
   } },

   /* ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b') */
   /* search1106_0 -> 222 in the cache */
   /* search1106_1_0 -> 3085 in the cache */
   /* search1106_1_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 3085, 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_fmul,
      0, 2,
      { 222, 3115 },
      -1,
   } },

   /* replace1106_0_0 -> 124 in the cache */
   /* replace1106_0_1 -> 127 in the cache */
   /* replace1106_0 -> 3088 in the cache */
   /* replace1106_1 -> 125 in the cache */
   /* replace1106 -> 3089 in the cache */

   /* ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1107_1_0 -> 3094 in the cache */
   /* search1107_1_1 -> 3096 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 3094, 3096 },
      -1,
   } },
   /* search1107_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 3117, 3118, 145 },
      -1,
   } },

   /* replace1107_0_0 -> 141 in the cache */
   /* replace1107_0_1 -> 144 in the cache */
   /* replace1107_0 -> 3098 in the cache */
   /* replace1107_1 -> 142 in the cache */
   /* replace1107_2 -> 145 in the cache */
   /* replace1107 -> 3099 in the cache */

   /* ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1108_0 -> 222 in the cache */
   /* search1108_1_0 -> 3085 in the cache */
   /* search1108_1_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      1, 1,
      { 3085, 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      0, 2,
      { 222, 3120 },
      -1,
   } },

   /* replace1108_0_0 -> 124 in the cache */
   /* replace1108_0_1 -> 127 in the cache */
   /* replace1108_0 -> 916 in the cache */
   /* replace1108_1 -> 125 in the cache */
   /* replace1108 -> 3092 in the cache */

   /* ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1109_0 -> 222 in the cache */
   /* search1109_1_0 -> 3085 in the cache */
   /* search1109_1_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 3085, 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 222, 3122 },
      -1,
   } },

   /* replace1109_0_0 -> 124 in the cache */
   /* replace1109_0_1 -> 127 in the cache */
   /* replace1109_0 -> 3103 in the cache */
   /* replace1109_1 -> 125 in the cache */
   /* replace1109 -> 3104 in the cache */

   /* ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b')) */
   /* search1110_0 -> 222 in the cache */
   /* search1110_1_0_0 -> 3085 in the cache */
   /* search1110_1_0_1 -> 704 in the cache */
   /* search1110_1_0 -> 3122 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 3122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 222, 3124 },
      -1,
   } },

   /* replace1110_0_0 -> 124 in the cache */
   /* replace1110_0_1_0 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 124, 3126 },
      -1,
   } },
   /* replace1110_1_0 -> 125 in the cache */
   /* replace1110_1 -> 1081 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 3127, 1081 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1111_0 -> 3117 in the cache */
   /* search1111_1_0 -> 3094 in the cache */
   /* search1111_1_1 -> 3107 in the cache */
   /* search1111_1_2 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 3094, 3107, 922 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 3117, 3129 },
      -1,
   } },

   /* replace1111_0 -> 142 in the cache */
   /* replace1111_1 -> 144 in the cache */
   /* replace1111_2_0 -> 141 in the cache */
   /* replace1111_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 141, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ffma,
      0, 2,
      { 142, 144, 3131 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1112_0 -> 3117 in the cache */
   /* search1112_1_0_0 -> 3094 in the cache */
   /* search1112_1_0_1 -> 3107 in the cache */
   /* search1112_1_0_2 -> 922 in the cache */
   /* search1112_1_0 -> 3129 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 3129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 3117, 3133 },
      -1,
   } },

   /* replace1112_0_0 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 142 },
      -1,
   } },
   /* replace1112_1 -> 144 in the cache */
   /* replace1112_2_0 -> 141 in the cache */
   /* replace1112_2_1_0 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 141, 3136 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ffma,
      0, 2,
      { 3135, 144, 3137 },
      -1,
   } },

   /* ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1113_0 -> 222 in the cache */
   /* search1113_1_0 -> 3085 in the cache */
   /* search1113_1_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 3085, 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 222, 3139 },
      -1,
   } },

   /* replace1113_0_0 -> 124 in the cache */
   /* replace1113_0_1 -> 127 in the cache */
   /* replace1113_0 -> 930 in the cache */
   /* replace1113_1 -> 125 in the cache */
   /* replace1113 -> 3114 in the cache */

   /* ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b') */
   /* search1114_0 -> 222 in the cache */
   /* search1114_1_0 -> 3085 in the cache */
   /* search1114_1_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      1, 1,
      { 3085, 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      0, 2,
      { 222, 3141 },
      -1,
   } },

   /* replace1114_0_0 -> 124 in the cache */
   /* replace1114_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1114_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3143, 125 },
      -1,
   } },

   /* ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b') */
   /* search1115_0 -> 222 in the cache */
   /* search1115_1_0 -> 3085 in the cache */
   /* search1115_1_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3085, 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      0, 2,
      { 222, 3145 },
      -1,
   } },

   /* replace1115_0_0 -> 124 in the cache */
   /* replace1115_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1115_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ior,
      0, 2,
      { 3147, 125 },
      -1,
   } },

   /* ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b') */
   /* search1116_0 -> 222 in the cache */
   /* search1116_1_0 -> 3085 in the cache */
   /* search1116_1_1 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ixor,
      1, 1,
      { 3085, 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ixor,
      0, 2,
      { 222, 3149 },
      -1,
   } },

   /* replace1116_0_0 -> 124 in the cache */
   /* replace1116_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ixor,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1116_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ixor,
      0, 2,
      { 3151, 125 },
      -1,
   } },

   /* ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      26,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1117_0_1 -> 3100 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 3153, 3100 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 3154, 3155 },
      -1,
   } },

   /* replace1117_0_0 -> 124 in the cache */
   /* replace1117_0_1 -> 127 in the cache */
   /* replace1117_0 -> 3103 in the cache */
   /* replace1117_1 -> 125 in the cache */
   /* replace1117 -> 3104 in the cache */

   /* ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a */
   /* search1118_0_0 -> 0 in the cache */
   /* search1118_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      5,
   } },
   /* search1118_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_idiv,
      -1, 1,
      { 3157, 3 },
      -1,
   } },

   /* replace1118 -> 0 in the cache */

   /* ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1119_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_find_lsb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1119_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3159, 120 },
      -1,
   } },
   /* search1119_1_0 -> 32 in the cache */
   /* search1119_1 -> 3159 in the cache */
   /* search1119_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3160, 3159, 122 },
      -1,
   } },

   /* replace1119_0 -> 32 in the cache */
   /* replace1119 -> 3159 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1120_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ifind_msb,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1120_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3162, 120 },
      -1,
   } },
   /* search1120_1_0 -> 16 in the cache */
   /* search1120_1 -> 3162 in the cache */
   /* search1120_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3163, 3162, 122 },
      -1,
   } },

   /* replace1120_0 -> 16 in the cache */
   /* replace1120 -> 3162 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1121_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ufind_msb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1121_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3165, 120 },
      -1,
   } },
   /* search1121_1_0 -> 32 in the cache */
   /* search1121_1 -> 3165 in the cache */
   /* search1121_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3166, 3165, 122 },
      -1,
   } },

   /* replace1121_0 -> 32 in the cache */
   /* replace1121 -> 3165 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1122_0_0 -> 32 in the cache */
   /* search1122_0_1 -> 61 in the cache */
   /* search1122_0 -> 1117 in the cache */
   /* search1122_1_0 -> 32 in the cache */
   /* search1122_1 -> 3159 in the cache */
   /* search1122_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 1117, 3159, 122 },
      -1,
   } },

   /* replace1122_0 -> 32 in the cache */
   /* replace1122 -> 3159 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1123_0_0 -> 16 in the cache */
   /* search1123_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 16, 120 },
      -1,
   } },
   /* search1123_1_0 -> 16 in the cache */
   /* search1123_1 -> 3162 in the cache */
   /* search1123_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 3169, 3162, 122 },
      -1,
   } },

   /* replace1123_0 -> 16 in the cache */
   /* replace1123 -> 3162 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1124_0_0 -> 32 in the cache */
   /* search1124_0_1 -> 61 in the cache */
   /* search1124_0 -> 1117 in the cache */
   /* search1124_1_0 -> 32 in the cache */
   /* search1124_1 -> 3165 in the cache */
   /* search1124_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 1117, 3165, 122 },
      -1,
   } },

   /* replace1124_0 -> 32 in the cache */
   /* replace1124 -> 3165 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1125_0_0 -> 16 in the cache */
   /* search1125_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 16, 122 },
      -1,
   } },
   /* search1125_1_0 -> 16 in the cache */
   /* search1125_1 -> 3162 in the cache */
   /* search1125_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 3172, 3162, 122 },
      -1,
   } },

   /* replace1125_0 -> 16 in the cache */
   /* replace1125 -> 3162 in the cache */

   /* ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1126_0_0 -> 441 in the cache */
   /* search1126_0_1 -> 219 in the cache */
   /* search1126_0_2 -> 216 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 219, 216 },
      0,
   } },
   /* search1126_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_fmul,
      0, 1,
      { 3174, 3 },
      -1,
   } },

   /* replace1126_0 -> 441 in the cache */
   /* replace1126_1_0 -> 3 in the cache */
   /* replace1126_1 -> 978 in the cache */
   /* replace1126_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 978, 3 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1127_0_0 -> 441 in the cache */
   /* search1127_0_1 -> 216 in the cache */
   /* search1127_0_2 -> 219 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 216, 219 },
      0,
   } },
   /* search1127_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_fmul,
      0, 1,
      { 3177, 3 },
      -1,
   } },

   /* replace1127_0 -> 441 in the cache */
   /* replace1127_1 -> 3 in the cache */
   /* replace1127_2_0 -> 3 in the cache */
   /* replace1127_2 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 3, 978 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a') */
   /* search1128_0_0 -> 32 in the cache */
   /* search1128_0_1 -> 113 in the cache */
   /* search1128_0 -> 614 in the cache */
   /* search1128_1_0 -> 32 in the cache */
   /* search1128_1 -> 98 in the cache */
   /* search1128_2 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_bcsel,
      -1, 0,
      { 614, 98, 32 },
      -1,
   } },

   /* replace1128_0 -> 32 in the cache */
   /* replace1128 -> 103 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd') */
   /* search1129_0 -> 650 in the cache */
   /* search1129_1_0 -> 1019 in the cache */
   /* search1129_1_1 -> 144 in the cache */
   /* search1129_1_2 -> 145 in the cache */
   /* search1129_1 -> 1191 in the cache */
   /* search1129_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 1191, 145 },
      -1,
   } },

   /* replace1129_0_0 -> 650 in the cache */
   /* replace1129_0_1 -> 1019 in the cache */
   /* replace1129_0 -> 1031 in the cache */
   /* replace1129_1 -> 144 in the cache */
   /* replace1129_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 1031, 144, 145 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd') */
   /* search1130_0 -> 650 in the cache */
   /* search1130_1 -> 142 in the cache */
   /* search1130_2_0 -> 384 in the cache */
   /* search1130_2_1 -> 142 in the cache */
   /* search1130_2_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 384, 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 142, 3183 },
      -1,
   } },

   /* replace1130_0_0 -> 650 in the cache */
   /* replace1130_0_1 -> 384 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 650, 384 },
      -1,
   } },
   /* replace1130_1 -> 142 in the cache */
   /* replace1130_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 3185, 142, 145 },
      -1,
   } },

   /* ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b')))) */
   /* search1131_0 -> 0 in the cache */
   /* search1131_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmod,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1131_0 -> 0 in the cache */
   /* replace1131_1_0 -> 3 in the cache */
   /* replace1131_1_1_0_0 -> 0 in the cache */
   /* replace1131_1_1_0_1 -> 3 in the cache */
   /* replace1131_1_1_0 -> 2494 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ffloor,
      -1, 0,
      { 2494 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 3, 3188 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsub,
      -1, 1,
      { 0, 3189 },
      -1,
   } },

   /* ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b')))) */
   /* search1132_0 -> 0 in the cache */
   /* search1132_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_frem,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1132_0 -> 0 in the cache */
   /* replace1132_1_0 -> 3 in the cache */
   /* replace1132_1_1_0_0 -> 0 in the cache */
   /* replace1132_1_1_0_1 -> 3 in the cache */
   /* replace1132_1_1_0 -> 2494 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ftrunc,
      -1, 0,
      { 2494 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 3, 3192 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsub,
      -1, 1,
      { 0, 3193 },
      -1,
   } },

   /* ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a')) */
   /* search1133_0 -> 0 in the cache */
   /* search1133_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_uadd_carry,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1133_0_0_0 -> 0 in the cache */
   /* replace1133_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1133_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 3196, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_search_op_b2i,
      -1, 1,
      { 3197 },
      -1,
   } },

   /* ('usub_borrow@32', 'a', 'b') => ('b2i', ('ult', 'a', 'b')) */
   /* search1134_0 -> 16 in the cache */
   /* search1134_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_usub_borrow,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1134_0_0 -> 16 in the cache */
   /* replace1134_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_b2i,
      -1, 0,
      { 3200 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* base */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* insert */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bitfield_insert,
      -1, 0,
      { 3202, 3203, 3204, 3205 },
      -1,
   } },

   /* replace1135_0_0 -> 19 in the cache */
   /* replace1135_0_1 -> 3205 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 19, 3205 },
      -1,
   } },
   /* replace1135_1 -> 3203 in the cache */
   /* replace1135_2_0_0 -> 3205 in the cache */
   /* replace1135_2_0_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bfm,
      -1, 0,
      { 3205, 3204 },
      -1,
   } },
   /* replace1135_2_1 -> 3203 in the cache */
   /* replace1135_2_2 -> 3202 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bfi,
      -1, 0,
      { 3208, 3203, 3202 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3207, 3203, 3209 },
      -1,
   } },

   /* ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1136_0 -> 0 in the cache */
   /* search1136_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ihadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1136_0_0 -> 0 in the cache */
   /* replace1136_0_1 -> 3 in the cache */
   /* replace1136_0 -> 2384 in the cache */
   /* replace1136_1_0_0 -> 0 in the cache */
   /* replace1136_1_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ixor,
      2, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1136_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 3212, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      0, 3,
      { 2384, 3213 },
      -1,
   } },

   /* ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1137_0 -> 0 in the cache */
   /* search1137_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_uhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1137_0_0 -> 0 in the cache */
   /* replace1137_0_1 -> 3 in the cache */
   /* replace1137_0 -> 2384 in the cache */
   /* replace1137_1_0_0 -> 0 in the cache */
   /* replace1137_1_0_1 -> 3 in the cache */
   /* replace1137_1_0 -> 3212 in the cache */
   /* replace1137_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 3212, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      0, 3,
      { 2384, 3216 },
      -1,
   } },

   /* ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1138_0 -> 0 in the cache */
   /* search1138_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_irhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1138_0_0 -> 0 in the cache */
   /* replace1138_0_1 -> 3 in the cache */
   /* replace1138_0 -> 2167 in the cache */
   /* replace1138_1_0_0 -> 0 in the cache */
   /* replace1138_1_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ixor,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1138_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 3219, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_isub,
      -1, 2,
      { 2167, 3220 },
      -1,
   } },

   /* ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1139_0 -> 0 in the cache */
   /* search1139_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_urhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1139_0_0 -> 0 in the cache */
   /* replace1139_0_1 -> 3 in the cache */
   /* replace1139_0 -> 2167 in the cache */
   /* replace1139_1_0_0 -> 0 in the cache */
   /* replace1139_1_0_1 -> 3 in the cache */
   /* replace1139_1_0 -> 3219 in the cache */
   /* replace1139_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 3219, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_isub,
      -1, 2,
      { 2167, 3223 },
      -1,
   } },

   /* ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1140_0 -> 21 in the cache */
   /* search1140_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ihadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1140_0_0 -> 21 in the cache */
   /* replace1140_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iand,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1140_1_0_0 -> 21 in the cache */
   /* replace1140_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ixor,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1140_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 3227, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd,
      0, 3,
      { 3226, 3228 },
      -1,
   } },

   /* ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1141_0 -> 21 in the cache */
   /* search1141_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_uhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1141_0_0 -> 21 in the cache */
   /* replace1141_0_1 -> 41 in the cache */
   /* replace1141_0 -> 3226 in the cache */
   /* replace1141_1_0_0 -> 21 in the cache */
   /* replace1141_1_0_1 -> 41 in the cache */
   /* replace1141_1_0 -> 3227 in the cache */
   /* replace1141_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 3227, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd,
      0, 3,
      { 3226, 3231 },
      -1,
   } },

   /* ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1142_0 -> 21 in the cache */
   /* search1142_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_irhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1142_0_0 -> 21 in the cache */
   /* replace1142_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ior,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1142_1_0_0 -> 21 in the cache */
   /* replace1142_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ixor,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1142_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 3235, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_isub,
      -1, 2,
      { 3234, 3236 },
      -1,
   } },

   /* ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1143_0 -> 21 in the cache */
   /* search1143_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_urhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1143_0_0 -> 21 in the cache */
   /* replace1143_0_1 -> 41 in the cache */
   /* replace1143_0 -> 3234 in the cache */
   /* replace1143_1_0_0 -> 21 in the cache */
   /* replace1143_1_0_1 -> 41 in the cache */
   /* replace1143_1_0 -> 3235 in the cache */
   /* replace1143_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 3235, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_isub,
      -1, 2,
      { 3234, 3239 },
      -1,
   } },

   /* ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1144_0 -> 21 in the cache */
   /* search1144_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_uadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1144_0_0_0 -> 21 in the cache */
   /* replace1144_0_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1144_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 3242, 21 },
      -1,
   } },
   /* replace1144_1 -> 1372 in the cache */
   /* replace1144_2_0 -> 21 in the cache */
   /* replace1144_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 3243, 1372, 3244 },
      -1,
   } },

   /* ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1145_0 -> 0 in the cache */
   /* search1145_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_uadd_sat,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1145_0_0_0 -> 0 in the cache */
   /* replace1145_0_0_1 -> 3 in the cache */
   /* replace1145_0_0 -> 3196 in the cache */
   /* replace1145_0_1 -> 0 in the cache */
   /* replace1145_0 -> 3197 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* replace1145_2_0 -> 0 in the cache */
   /* replace1145_2_1 -> 3 in the cache */
   /* replace1145_2 -> 173 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 3197, 3247, 173 },
      -1,
   } },

   /* ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1146_0 -> 0 in the cache */
   /* search1146_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_usub_sat,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1146_0_0 -> 0 in the cache */
   /* replace1146_0_1 -> 3 in the cache */
   /* replace1146_0 -> 958 in the cache */
   /* replace1146_1 -> 86 in the cache */
   /* replace1146_2_0 -> 0 in the cache */
   /* replace1146_2_1 -> 3 in the cache */
   /* replace1146_2 -> 3070 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 958, 86, 3070 },
      -1,
   } },

   /* ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1147_0 -> 21 in the cache */
   /* search1147_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_usub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1147_0_0 -> 21 in the cache */
   /* replace1147_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   /* replace1147_1 -> 791 in the cache */
   /* replace1147_2_0 -> 21 in the cache */
   /* replace1147_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3252, 791, 3253 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807)) */
   /* search1148_0 -> 21 in the cache */
   /* search1148_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1148_0_0_0_0 -> 21 in the cache */
   /* replace1148_0_0_0_1 -> 791 in the cache */
   /* replace1148_0_0_0 -> 1362 in the cache */
   /* replace1148_0_0_1_0 -> 41 in the cache */
   /* replace1148_0_0_1_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 41, 791 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      1, 1,
      { 1362, 3256 },
      -1,
   } },
   /* replace1148_0_1_0_0 -> 21 in the cache */
   /* replace1148_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1148_0_1_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 3258, 791 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 3257, 3259 },
      -1,
   } },
   /* replace1148_1 -> 22 in the cache */
   /* replace1148_2_0_0_0_0 -> 21 in the cache */
   /* replace1148_2_0_0_0_1 -> 791 in the cache */
   /* replace1148_2_0_0_0 -> 1362 in the cache */
   /* replace1148_2_0_0_1_0 -> 41 in the cache */
   /* replace1148_2_0_0_1_1 -> 791 in the cache */
   /* replace1148_2_0_0_1 -> 3256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      4, 1,
      { 1362, 3256 },
      -1,
   } },
   /* replace1148_2_0_1_0_0 -> 21 in the cache */
   /* replace1148_2_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd,
      5, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1148_2_0_1_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 3262, 791 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      3, 3,
      { 3261, 3263 },
      -1,
   } },
   /* replace1148_2_1_0 -> 21 in the cache */
   /* replace1148_2_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd,
      6, 1,
      { 21, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffffffffffff /* 9223372036854775807 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 3264, 3265, 3266 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 7,
      { 3260, 22, 3267 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807)) */
   /* search1149_0 -> 21 in the cache */
   /* search1149_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_isub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1149_0_0_0_0 -> 21 in the cache */
   /* replace1149_0_0_0_1 -> 791 in the cache */
   /* replace1149_0_0_0 -> 1362 in the cache */
   /* replace1149_0_0_1_0 -> 41 in the cache */
   /* replace1149_0_0_1_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 41, 791 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      1, 1,
      { 1362, 3270 },
      -1,
   } },
   /* replace1149_0_1_0_0 -> 21 in the cache */
   /* replace1149_0_1_0_1 -> 41 in the cache */
   /* replace1149_0_1_0 -> 3253 in the cache */
   /* replace1149_0_1_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3253, 791 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3271, 3272 },
      -1,
   } },
   /* replace1149_1 -> 22 in the cache */
   /* replace1149_2_0_0_0_0 -> 21 in the cache */
   /* replace1149_2_0_0_0_1 -> 791 in the cache */
   /* replace1149_2_0_0_0 -> 1362 in the cache */
   /* replace1149_2_0_0_1_0 -> 41 in the cache */
   /* replace1149_2_0_0_1_1 -> 791 in the cache */
   /* replace1149_2_0_0_1 -> 3270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      3, 1,
      { 1362, 3270 },
      -1,
   } },
   /* replace1149_2_0_1_0_0 -> 21 in the cache */
   /* replace1149_2_0_1_0_1 -> 41 in the cache */
   /* replace1149_2_0_1_0 -> 3253 in the cache */
   /* replace1149_2_0_1_1 -> 791 in the cache */
   /* replace1149_2_0_1 -> 3272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      2, 2,
      { 3274, 3272 },
      -1,
   } },
   /* replace1149_2_1_0 -> 21 in the cache */
   /* replace1149_2_1_1 -> 41 in the cache */
   /* replace1149_2_1 -> 3253 in the cache */
   /* replace1149_2_2 -> 3266 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 3275, 3253, 3266 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 3273, 22, 3276 },
      -1,
   } },

   /* ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1150_0_0 -> 21 in the cache */
   /* search1150_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_imax,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1150_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 3278, 791 },
      -1,
   } },

   /* replace1150_0_0_0 -> 21 in the cache */
   /* replace1150_0_0 -> 2827 in the cache */
   /* replace1150_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imax,
      0, 1,
      { 2827, 3280 },
      -1,
   } },
   /* replace1150_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 3281, 120 },
      -1,
   } },

   /* ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1151_0_0 -> 21 in the cache */
   /* search1151_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_imin,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1151_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 3283, 791 },
      -1,
   } },

   /* replace1151_0_0_0 -> 21 in the cache */
   /* replace1151_0_0 -> 2827 in the cache */
   /* replace1151_0_1_0 -> 41 in the cache */
   /* replace1151_0_1 -> 3280 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      0, 1,
      { 2827, 3280 },
      -1,
   } },
   /* replace1151_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 3285, 120 },
      -1,
   } },

   /* ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1152_0_0 -> 21 in the cache */
   /* search1152_0_1 -> 41 in the cache */
   /* search1152_0 -> 3278 in the cache */
   /* search1152_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 3278, 791 },
      -1,
   } },

   /* replace1152_0_0_0 -> 21 in the cache */
   /* replace1152_0_0 -> 2827 in the cache */
   /* replace1152_0_1_0 -> 41 in the cache */
   /* replace1152_0_1 -> 3280 in the cache */
   /* replace1152_0 -> 3281 in the cache */
   /* replace1152_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 3281, 120 },
      -1,
   } },

   /* ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1153_0_0 -> 21 in the cache */
   /* search1153_0_1 -> 41 in the cache */
   /* search1153_0 -> 3283 in the cache */
   /* search1153_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 3283, 791 },
      -1,
   } },

   /* replace1153_0_0_0 -> 21 in the cache */
   /* replace1153_0_0 -> 2827 in the cache */
   /* replace1153_0_1_0 -> 41 in the cache */
   /* replace1153_0_1 -> 3280 in the cache */
   /* replace1153_0 -> 3285 in the cache */
   /* replace1153_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 1,
      { 3285, 120 },
      -1,
   } },

   /* ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1154_0 -> 21 in the cache */
   /* search1154_1 -> 791 in the cache */
   /* search1154 -> 1362 in the cache */

   /* replace1154_0_0 -> 21 in the cache */
   /* replace1154_0 -> 2827 in the cache */
   /* replace1154_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 2827, 120 },
      -1,
   } },

   /* ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1155_0 -> 21 in the cache */
   /* search1155_1 -> 791 in the cache */
   /* search1155 -> 1359 in the cache */

   /* replace1155_0_0 -> 21 in the cache */
   /* replace1155_0 -> 2827 in the cache */
   /* replace1155_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 2827, 120 },
      -1,
   } },

   /* ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1156_0 -> 21 in the cache */
   /* search1156_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 21, 791 },
      -1,
   } },

   /* replace1156_0_0_0 -> 21 in the cache */
   /* replace1156_0_0 -> 2826 in the cache */
   /* replace1156_0_1_0 -> 21 in the cache */
   /* replace1156_0_1 -> 2827 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      1, 1,
      { 2826, 2827 },
      -1,
   } },
   /* replace1156_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 3294, 120 },
      -1,
   } },

   /* ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1157_0 -> 21 in the cache */
   /* search1157_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 21, 791 },
      -1,
   } },

   /* replace1157_0_0_0 -> 21 in the cache */
   /* replace1157_0_0 -> 2826 in the cache */
   /* replace1157_0_1_0 -> 21 in the cache */
   /* replace1157_0_1 -> 2827 in the cache */
   /* replace1157_0 -> 3294 in the cache */
   /* replace1157_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 3294, 120 },
      -1,
   } },

   /* ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1158_0 -> 791 in the cache */
   /* search1158_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 791, 21 },
      -1,
   } },

   /* replace1158_0_0_0 -> 21 in the cache */
   /* replace1158_0_0 -> 2826 in the cache */
   /* replace1158_0_1_0 -> 21 in the cache */
   /* replace1158_0_1 -> 2827 in the cache */
   /* replace1158_0 -> 3294 in the cache */
   /* replace1158_1 -> 120 in the cache */
   /* replace1158 -> 3295 in the cache */

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset')))) */
   /* search1159_0 -> 3202 in the cache */
   /* search1159_1 -> 3203 in the cache */
   /* search1159_2 -> 3204 in the cache */
   /* search1159_3 -> 3205 in the cache */
   /* search1159 -> 3206 in the cache */

   /* replace1159_0_0 -> 19 in the cache */
   /* replace1159_0_1 -> 3205 in the cache */
   /* replace1159_0 -> 3207 in the cache */
   /* replace1159_1 -> 3203 in the cache */
   /* replace1159_2_0_0 -> 3202 in the cache */
   /* replace1159_2_0_1_0_0_0_0 -> 316 in the cache */
   /* replace1159_2_0_1_0_0_0_1 -> 3205 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 316, 3205 },
      -1,
   } },
   /* replace1159_2_0_1_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 3299, 316 },
      -1,
   } },
   /* replace1159_2_0_1_0_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 3300, 3204 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 3301 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 3202, 3302 },
      -1,
   } },
   /* replace1159_2_1_0_0 -> 3203 in the cache */
   /* replace1159_2_1_0_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 3203, 3204 },
      -1,
   } },
   /* replace1159_2_1_1_0_0_0 -> 316 in the cache */
   /* replace1159_2_1_1_0_0_1 -> 3205 in the cache */
   /* replace1159_2_1_1_0_0 -> 3299 in the cache */
   /* replace1159_2_1_1_0_1 -> 316 in the cache */
   /* replace1159_2_1_1_0 -> 3300 in the cache */
   /* replace1159_2_1_1_1 -> 3204 in the cache */
   /* replace1159_2_1_1 -> 3301 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      2, 1,
      { 3304, 3301 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 3,
      { 3303, 3305 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 3,
      { 3207, 3203, 3306 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base')) */
   /* search1160_0 -> 3202 in the cache */
   /* search1160_1 -> 3203 in the cache */
   /* search1160_2 -> 3204 in the cache */
   /* search1160_3 -> 3205 in the cache */
   /* search1160 -> 3206 in the cache */

   /* replace1160_0_0 -> 19 in the cache */
   /* replace1160_0_1 -> 3205 in the cache */
   /* replace1160_0 -> 3207 in the cache */
   /* replace1160_1 -> 3203 in the cache */
   /* replace1160_2_0_0 -> 3205 in the cache */
   /* replace1160_2_0_1 -> 3204 in the cache */
   /* replace1160_2_0 -> 3208 in the cache */
   /* replace1160_2_1_0 -> 3203 in the cache */
   /* replace1160_2_1_1 -> 3204 in the cache */
   /* replace1160_2_1 -> 3304 in the cache */
   /* replace1160_2_2 -> 3202 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bitfield_select,
      -1, 0,
      { 3208, 3304, 3202 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3207, 3203, 3308 },
      -1,
   } },

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibitfield_extract,
      -1, 0,
      { 3310, 3311, 3312 },
      -1,
   } },

   /* replace1161_0_0 -> 19 in the cache */
   /* replace1161_0_1 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 19, 3312 },
      -1,
   } },
   /* replace1161_1 -> 3310 in the cache */
   /* replace1161_2_0 -> 3310 in the cache */
   /* replace1161_2_1 -> 3311 in the cache */
   /* replace1161_2_2 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 3310, 3311, 3312 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3314, 3310, 3315 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits')) */
   /* search1162_0 -> 3310 in the cache */
   /* search1162_1 -> 3311 in the cache */
   /* search1162_2 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubitfield_extract,
      -1, 0,
      { 3310, 3311, 3312 },
      -1,
   } },

   /* replace1162_0_0 -> 19 in the cache */
   /* replace1162_0_1 -> 3312 in the cache */
   /* replace1162_0 -> 3314 in the cache */
   /* replace1162_1 -> 3310 in the cache */
   /* replace1162_2_0 -> 3310 in the cache */
   /* replace1162_2_1 -> 3311 in the cache */
   /* replace1162_2_2 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 3310, 3311, 3312 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3314, 3310, 3318 },
      -1,
   } },

   /* ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b') */
   /* search1163_0 -> 0 in the cache */
   /* search1163_1 -> 3 in the cache */
   /* search1163_2 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_bitfield_select,
      -1, 0,
      { 0, 3, 86 },
      -1,
   } },

   /* replace1163_0 -> 0 in the cache */
   /* replace1163_1 -> 3 in the cache */
   /* replace1163 -> 2389 in the cache */

   /* ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c') */
   /* search1164_0 -> 124 in the cache */
   /* search1164_1_0 -> 124 in the cache */
   /* search1164_1_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iand,
      0, 1,
      { 124, 125 },
      -1,
   } },
   /* search1164_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bitfield_select,
      -1, 1,
      { 124, 3321, 127 },
      -1,
   } },

   /* replace1164_0 -> 124 in the cache */
   /* replace1164_1 -> 125 in the cache */
   /* replace1164_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bitfield_select,
      -1, 0,
      { 124, 125, 127 },
      -1,
   } },

   /* ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits') */
   /* search1165_0 -> 3310 in the cache */
   /* search1165_1 -> 3311 in the cache */
   /* search1165_2_0 -> 19 in the cache */
   /* search1165_2_1 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 19, 3312 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 1,
      { 3310, 3311, 3324 },
      -1,
   } },

   /* replace1165_0 -> 3310 in the cache */
   /* replace1165_1 -> 3311 in the cache */
   /* replace1165_2 -> 3312 in the cache */
   /* replace1165 -> 3318 in the cache */

   /* ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits') */
   /* search1166_0 -> 3310 in the cache */
   /* search1166_1_0 -> 19 in the cache */
   /* search1166_1_1 -> 3311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 19, 3311 },
      -1,
   } },
   /* search1166_2 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 1,
      { 3310, 3326, 3312 },
      -1,
   } },

   /* replace1166_0 -> 3310 in the cache */
   /* replace1166_1 -> 3311 in the cache */
   /* replace1166_2 -> 3312 in the cache */
   /* replace1166 -> 3318 in the cache */

   /* ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits') */
   /* search1167_0 -> 3310 in the cache */
   /* search1167_1 -> 3311 in the cache */
   /* search1167_2_0 -> 19 in the cache */
   /* search1167_2_1 -> 3312 in the cache */
   /* search1167_2 -> 3324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 1,
      { 3310, 3311, 3324 },
      -1,
   } },

   /* replace1167_0 -> 3310 in the cache */
   /* replace1167_1 -> 3311 in the cache */
   /* replace1167_2 -> 3312 in the cache */
   /* replace1167 -> 3315 in the cache */

   /* ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits') */
   /* search1168_0 -> 3310 in the cache */
   /* search1168_1_0 -> 19 in the cache */
   /* search1168_1_1 -> 3311 in the cache */
   /* search1168_1 -> 3326 in the cache */
   /* search1168_2 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 1,
      { 3310, 3326, 3312 },
      -1,
   } },

   /* replace1168_0 -> 3310 in the cache */
   /* replace1168_1 -> 3311 in the cache */
   /* replace1168_2 -> 3312 in the cache */
   /* replace1168 -> 3315 in the cache */

   /* ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1169_1_0 -> 19 in the cache */
   /* search1169_1_1 -> 3311 in the cache */
   /* search1169_1 -> 3326 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bfm,
      -1, 1,
      { 3330, 3326 },
      -1,
   } },

   /* replace1169_0 -> 3330 in the cache */
   /* replace1169_1 -> 3311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bfm,
      -1, 0,
      { 3330, 3311 },
      -1,
   } },

   /* ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset') */
   /* search1170_0_0 -> 19 in the cache */
   /* search1170_0_1 -> 3330 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 19, 3330 },
      -1,
   } },
   /* search1170_1 -> 3311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bfm,
      -1, 1,
      { 3333, 3311 },
      -1,
   } },

   /* replace1170_0 -> 3330 in the cache */
   /* replace1170_1 -> 3311 in the cache */
   /* replace1170 -> 3332 in the cache */

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search1171_0 -> 16 in the cache */
   /* search1171_1 -> 36 in the cache */
   /* search1171_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1171 -> 120 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search1172_0 -> 16 in the cache */
   /* search1172_1 -> 36 in the cache */
   /* search1172_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1172 -> 120 in the cache */

   /* ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b'))) */
   /* search1173_0 -> 16 in the cache */
   /* search1173_1 -> 120 in the cache */
   /* search1173_2 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 33 },
      -1,
   } },

   /* replace1173_0 -> 16 in the cache */
   /* replace1173_1_0 -> 763 in the cache */
   /* replace1173_1_1_0 -> 36 in the cache */
   /* replace1173_1_1 -> 2402 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 763, 2402 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 16, 3338 },
      -1,
   } },

   /* ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1174_0_0_0 -> 16 in the cache */
   /* search1174_0_0_1 -> 36 in the cache */
   /* search1174_0_0_2 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_i2b,
      -1, 0,
      { 3340 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 3341 },
      -1,
   } },

   /* replace1174_0 -> 16 in the cache */
   /* replace1174_1 -> 36 in the cache */
   /* replace1174_2 -> 316 in the cache */
   /* replace1174 -> 3340 in the cache */

   /* ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1175_0_0_0 -> 16 in the cache */
   /* search1175_0_0_1 -> 36 in the cache */
   /* search1175_0_0_2 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_i2b,
      -1, 0,
      { 3343 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2i32,
      -1, 0,
      { 3344 },
      -1,
   } },

   /* replace1175_0 -> 16 in the cache */
   /* replace1175_1 -> 36 in the cache */
   /* replace1175_2 -> 316 in the cache */
   /* replace1175 -> 3340 in the cache */

   /* ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1176_0_0 -> 16 in the cache */
   /* search1176_0_1 -> 33 in the cache */
   /* search1176_0_2 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 16, 33, 246 },
      0,
   } },
   /* search1176_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3346, 120 },
      -1,
   } },

   /* replace1176_0_0 -> 16 in the cache */
   /* replace1176_0_1_0_0 -> 763 in the cache */
   /* replace1176_0_1_0_1_0 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 763, 3348 },
      -1,
   } },
   /* replace1176_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 3349, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 16, 3350 },
      -1,
   } },
   /* replace1176_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 3351, 120 },
      -1,
   } },

   /* ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1177_0_0 -> 16 in the cache */
   /* search1177_0_1 -> 33 in the cache */
   /* search1177_0_2 -> 246 in the cache */
   /* search1177_0 -> 3346 in the cache */
   /* search1177_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3346, 120 },
      -1,
   } },

   /* replace1177_0_0 -> 16 in the cache */
   /* replace1177_0_1_0_0 -> 763 in the cache */
   /* replace1177_0_1_0_1_0 -> 250 in the cache */
   /* replace1177_0_1_0_1 -> 3348 in the cache */
   /* replace1177_0_1_0 -> 3349 in the cache */
   /* replace1177_0_1_1 -> 36 in the cache */
   /* replace1177_0_1 -> 3350 in the cache */
   /* replace1177_0 -> 3351 in the cache */
   /* replace1177_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 3351, 120 },
      -1,
   } },

   /* ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1178_0_0 -> 16 in the cache */
   /* search1178_0_1 -> 33 in the cache */
   /* search1178_0_2 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 16, 33, 246 },
      0,
   } },
   /* search1178_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3355, 120 },
      -1,
   } },

   /* replace1178_0_0 -> 16 in the cache */
   /* replace1178_0_1_0_0 -> 763 in the cache */
   /* replace1178_0_1_0_1_0 -> 250 in the cache */
   /* replace1178_0_1_0_1 -> 3348 in the cache */
   /* replace1178_0_1_0 -> 3349 in the cache */
   /* replace1178_0_1_1 -> 36 in the cache */
   /* replace1178_0_1 -> 3350 in the cache */
   /* replace1178_0 -> 3351 in the cache */
   /* replace1178_1 -> 120 in the cache */
   /* replace1178 -> 3352 in the cache */

   /* ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1179_0_0 -> 16 in the cache */
   /* search1179_0_1 -> 33 in the cache */
   /* search1179_0_2 -> 246 in the cache */
   /* search1179_0 -> 3355 in the cache */
   /* search1179_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3355, 120 },
      -1,
   } },

   /* replace1179_0_0 -> 16 in the cache */
   /* replace1179_0_1_0_0 -> 763 in the cache */
   /* replace1179_0_1_0_1_0 -> 250 in the cache */
   /* replace1179_0_1_0_1 -> 3348 in the cache */
   /* replace1179_0_1_0 -> 3349 in the cache */
   /* replace1179_0_1_1 -> 36 in the cache */
   /* replace1179_0_1 -> 3350 in the cache */
   /* replace1179_0 -> 3351 in the cache */
   /* replace1179_1 -> 120 in the cache */
   /* replace1179 -> 3354 in the cache */

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits'))) */
   /* search1180_0 -> 3310 in the cache */
   /* search1180_1 -> 3311 in the cache */
   /* search1180_2 -> 3312 in the cache */
   /* search1180 -> 3313 in the cache */

   /* replace1180_0_0 -> 120 in the cache */
   /* replace1180_0_1 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 120, 3312 },
      -1,
   } },
   /* replace1180_1 -> 120 in the cache */
   /* replace1180_2_0_0 -> 3310 in the cache */
   /* replace1180_2_0_1_0_0 -> 767 in the cache */
   /* replace1180_2_0_1_0_1 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 767, 3312 },
      -1,
   } },
   /* replace1180_2_0_1_1 -> 3311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 3359, 3311 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 3310, 3360 },
      -1,
   } },
   /* replace1180_2_1_0 -> 767 in the cache */
   /* replace1180_2_1_1 -> 3312 in the cache */
   /* replace1180_2_1 -> 3359 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 3361, 3359 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 3358, 120, 3362 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1))) */
   /* search1181_0 -> 3310 in the cache */
   /* search1181_1 -> 3311 in the cache */
   /* search1181_2 -> 3312 in the cache */
   /* search1181 -> 3317 in the cache */

   /* replace1181_0_0 -> 3310 in the cache */
   /* replace1181_0_1 -> 3311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 3310, 3311 },
      -1,
   } },
   /* replace1181_1_0_0 -> 3312 in the cache */
   /* replace1181_1_0_1 -> 767 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 3312, 767 },
      -1,
   } },
   /* replace1181_1_1 -> 763 in the cache */
   /* replace1181_1_2_0_0 -> 316 in the cache */
   /* replace1181_1_2_0_1 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 316, 3312 },
      -1,
   } },
   /* replace1181_1_2_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 3366, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 3365, 763, 3367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3364, 3368 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value')) */
   /* search1182_0 -> 3310 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ifind_msb,
      -1, 0,
      { 3310 },
      -1,
   } },

   /* replace1182_0_0_0 -> 3310 in the cache */
   /* replace1182_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3310, 120 },
      -1,
   } },
   /* replace1182_0_1_0 -> 3310 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 3310 },
      -1,
   } },
   /* replace1182_0_2 -> 3310 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3371, 3372, 3310 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ufind_msb,
      -1, 0,
      { 3373 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value')) */
   /* search1183_0 -> 3310 in the cache */
   /* search1183 -> 3370 in the cache */

   /* replace1183_0_0_0 -> 3310 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 3310 },
      -1,
   } },
   /* replace1183_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3375, 120 },
      -1,
   } },
   /* replace1183_1_0 -> 19 in the cache */
   /* replace1183_1_1_0 -> 3310 in the cache */
   /* replace1183_1_1 -> 3375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 19, 3375 },
      -1,
   } },
   /* replace1183_2_0 -> 3310 in the cache */
   /* replace1183_2 -> 3375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3376, 3377, 3375 },
      -1,
   } },

   /* ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ufind_msb,
      -1, 0,
      { 3379 },
      -1,
   } },

   /* replace1184_0_0_0 -> 3379 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 3379 },
      -1,
   } },
   /* replace1184_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3381, 120 },
      -1,
   } },
   /* replace1184_1_0 -> 19 in the cache */
   /* replace1184_1_1_0 -> 3379 in the cache */
   /* replace1184_1_1 -> 3381 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 19, 3381 },
      -1,
   } },
   /* replace1184_2_0 -> 3379 in the cache */
   /* replace1184_2 -> 3381 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3382, 3383, 3381 },
      -1,
   } },

   /* ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value'))) */
   /* search1185_0 -> 3379 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_find_lsb,
      -1, 0,
      { 3379 },
      -1,
   } },

   /* replace1185_0_0 -> 3379 in the cache */
   /* replace1185_0_1_0 -> 3379 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 3379 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 3379, 3386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ufind_msb,
      -1, 1,
      { 3387 },
      -1,
   } },

   /* ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24) */
   /* search1186_0 -> 16 in the cache */
   /* search1186_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1186_0_0 -> 16 in the cache */
   /* replace1186_0_1_0_0 -> 325 in the cache */
   /* replace1186_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 325, 36 },
      -1,
   } },
   /* replace1186_0_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 3390, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 16, 3391 },
      -1,
   } },
   /* replace1186_1 -> 903 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 3392, 903 },
      -1,
   } },

   /* ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255) */
   /* search1187_0 -> 16 in the cache */
   /* search1187_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1187_0_0 -> 16 in the cache */
   /* replace1187_0_1_0 -> 36 in the cache */
   /* replace1187_0_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      1, 1,
      { 36, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 16, 3395 },
      -1,
   } },
   /* replace1187_1 -> 718 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3396, 718 },
      -1,
   } },

   /* ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16) */
   /* search1188_0 -> 16 in the cache */
   /* search1188_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1188_0_0 -> 16 in the cache */
   /* replace1188_0_1_0_0 -> 316 in the cache */
   /* replace1188_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 316, 36 },
      -1,
   } },
   /* replace1188_0_1_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 3399, 745 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 16, 3400 },
      -1,
   } },
   /* replace1188_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 3401, 745 },
      -1,
   } },

   /* ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535) */
   /* search1189_0 -> 16 in the cache */
   /* search1189_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1189_0_0 -> 16 in the cache */
   /* replace1189_0_1_0 -> 36 in the cache */
   /* replace1189_0_1_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      1, 1,
      { 36, 745 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 16, 3404 },
      -1,
   } },
   /* replace1189_1 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3405, 741 },
      -1,
   } },

   /* ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0)))) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* v */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_unorm_2x16,
      -1, 0,
      { 3407 },
      -1,
   } },

   /* replace1190_0_0_0_0_0 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 3407 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40efffe000000000 /* 65535.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 3409, 3410 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fround_even,
      -1, 1,
      { 3411 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2u32,
      -1, 1,
      { 3412 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_uvec2_to_uint,
      -1, 1,
      { 3413 },
      -1,
   } },

   /* ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0)))) */
   /* search1191_0 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_unorm_4x8,
      -1, 0,
      { 3407 },
      -1,
   } },

   /* replace1191_0_0_0_0_0 -> 3407 in the cache */
   /* replace1191_0_0_0_0 -> 3409 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x406fe00000000000 /* 255.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 3409, 3416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fround_even,
      -1, 1,
      { 3417 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2u32,
      -1, 1,
      { 3418 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_uvec4_to_uint,
      -1, 1,
      { 3419 },
      -1,
   } },

   /* ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0)))) */
   /* search1192_0 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_snorm_2x16,
      -1, 0,
      { 3407 },
      -1,
   } },

   /* replace1192_0_0_0_0_0 -> 474 in the cache */
   /* replace1192_0_0_0_0_1_0 -> 2681 in the cache */
   /* replace1192_0_0_0_0_1_1 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmax,
      2, 1,
      { 2681, 3407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmin,
      1, 2,
      { 474, 3422 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40dfffc000000000 /* 32767.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      0, 3,
      { 3423, 3424 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fround_even,
      -1, 3,
      { 3425 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2i32,
      -1, 3,
      { 3426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_uvec2_to_uint,
      -1, 3,
      { 3427 },
      -1,
   } },

   /* ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0)))) */
   /* search1193_0 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_snorm_4x8,
      -1, 0,
      { 3407 },
      -1,
   } },

   /* replace1193_0_0_0_0_0 -> 474 in the cache */
   /* replace1193_0_0_0_0_1_0 -> 2681 in the cache */
   /* replace1193_0_0_0_0_1_1 -> 3407 in the cache */
   /* replace1193_0_0_0_0_1 -> 3422 in the cache */
   /* replace1193_0_0_0_0 -> 3423 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x405fc00000000000 /* 127.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      0, 3,
      { 3423, 3430 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fround_even,
      -1, 3,
      { 3431 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2i32,
      -1, 3,
      { 3432 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_pack_uvec4_to_uint,
      -1, 3,
      { 3433 },
      -1,
   } },

   /* ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0) */
   /* search1194_0 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_unorm_2x16,
      -1, 0,
      { 3407 },
      -1,
   } },

   /* replace1194_0_0_0_0 -> 3407 in the cache */
   /* replace1194_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 3407, 120 },
      -1,
   } },
   /* replace1194_0_0_1_0 -> 3407 in the cache */
   /* replace1194_0_0_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 3407, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 3436, 3437 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2f32,
      -1, 0,
      { 3438 },
      -1,
   } },
   /* replace1194_1 -> 3410 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fdiv,
      -1, 0,
      { 3439, 3410 },
      -1,
   } },

   /* ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0) */
   /* search1195_0 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_unorm_4x8,
      -1, 0,
      { 3407 },
      -1,
   } },

   /* replace1195_0_0_0_0 -> 3407 in the cache */
   /* replace1195_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3407, 120 },
      -1,
   } },
   /* replace1195_0_0_1_0 -> 3407 in the cache */
   /* replace1195_0_0_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3407, 316 },
      -1,
   } },
   /* replace1195_0_0_2_0 -> 3407 in the cache */
   /* replace1195_0_0_2_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3407, 321 },
      -1,
   } },
   /* replace1195_0_0_3_0 -> 3407 in the cache */
   /* replace1195_0_0_3_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 3407, 325 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 3442, 3443, 3444, 3445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2f32,
      -1, 0,
      { 3446 },
      -1,
   } },
   /* replace1195_1 -> 3416 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fdiv,
      -1, 0,
      { 3447, 3416 },
      -1,
   } },

   /* ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0))) */
   /* search1196_0 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_snorm_2x16,
      -1, 0,
      { 3407 },
      -1,
   } },

   /* replace1196_0 -> 474 in the cache */
   /* replace1196_1_0 -> 2681 in the cache */
   /* replace1196_1_1_0_0_0_0 -> 3407 in the cache */
   /* replace1196_1_1_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 3407, 120 },
      -1,
   } },
   /* replace1196_1_1_0_0_1_0 -> 3407 in the cache */
   /* replace1196_1_1_0_0_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 3407, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 3450, 3451 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_i2f,
      -1, 0,
      { 3452 },
      -1,
   } },
   /* replace1196_1_1_1 -> 3424 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fdiv,
      -1, 0,
      { 3453, 3424 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 2681, 3454 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmin,
      0, 2,
      { 474, 3455 },
      -1,
   } },

   /* ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0))) */
   /* search1197_0 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_unpack_snorm_4x8,
      -1, 0,
      { 3407 },
      -1,
   } },

   /* replace1197_0 -> 474 in the cache */
   /* replace1197_1_0 -> 2681 in the cache */
   /* replace1197_1_1_0_0_0_0 -> 3407 in the cache */
   /* replace1197_1_1_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3407, 120 },
      -1,
   } },
   /* replace1197_1_1_0_0_1_0 -> 3407 in the cache */
   /* replace1197_1_1_0_0_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3407, 316 },
      -1,
   } },
   /* replace1197_1_1_0_0_2_0 -> 3407 in the cache */
   /* replace1197_1_1_0_0_2_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3407, 321 },
      -1,
   } },
   /* replace1197_1_1_0_0_3_0 -> 3407 in the cache */
   /* replace1197_1_1_0_0_3_1 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 3407, 325 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 3458, 3459, 3460, 3461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_search_op_i2f,
      -1, 0,
      { 3462 },
      -1,
   } },
   /* replace1197_1_1_1 -> 3430 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fdiv,
      -1, 0,
      { 3463, 3430 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 2681, 3464 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmin,
      0, 2,
      { 474, 3465 },
      -1,
   } },

   /* ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a'))) */
   /* search1198_0 -> 16 in the cache */
   /* search1198_1 -> 36 in the cache */
   /* search1198 -> 2957 in the cache */

   /* replace1198_0_0_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3467 },
      -1,
   } },
   /* replace1198_0_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 3468, 745 },
      -1,
   } },
   /* replace1198_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3470 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 3469, 3471 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a')) */
   /* search1199_0 -> 16 in the cache */
   /* search1199 -> 2922 in the cache */

   /* replace1199_0_0 -> 16 in the cache */
   /* replace1199_0 -> 2919 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 2919 },
      -1,
   } },

   /* ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16))) */
   /* search1200_0 -> 16 in the cache */
   /* search1200 -> 2929 in the cache */

   /* replace1200_0_0_0 -> 16 in the cache */
   /* replace1200_0_0_1 -> 745 in the cache */
   /* replace1200_0_0 -> 900 in the cache */
   /* replace1200_0 -> 2920 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 2920 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a')) */
   /* search1201_0 -> 11 in the cache */
   /* search1201_1 -> 207 in the cache */
   /* search1201 -> 2912 in the cache */

   /* replace1201_0_0_0 -> 207 in the cache */
   /* replace1201_0_0 -> 2913 in the cache */
   /* replace1201_0_1 -> 745 in the cache */
   /* replace1201_0 -> 2914 in the cache */
   /* replace1201_1_0 -> 11 in the cache */
   /* replace1201_1 -> 1673 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 2914, 1673 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a') */
   /* search1202_0 -> 16 in the cache */
   /* search1202 -> 2835 in the cache */

   /* replace1202_0 -> 16 in the cache */
   /* replace1202 -> 2919 in the cache */

   /* ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1203_0 -> 16 in the cache */
   /* search1203 -> 2837 in the cache */

   /* replace1203_0_0 -> 16 in the cache */
   /* replace1203_0_1 -> 745 in the cache */
   /* replace1203_0 -> 900 in the cache */
   /* replace1203 -> 2920 in the cache */

   /* ('isign', 'a') => ('imin', ('imax', 'a', -1), 1) */
   /* search1204_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_isign,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1204_0_0 -> 32 in the cache */
   /* replace1204_0_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imax,
      1, 1,
      { 32, 63 },
      -1,
   } },
   /* replace1204_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imin,
      0, 2,
      { 3477, 35 },
      -1,
   } },

   /* ('imin', ('imax', 'a', -1), 1) => ('isign', 'a') */
   /* search1205_0_0 -> 32 in the cache */
   /* search1205_0_1 -> 63 in the cache */
   /* search1205_0 -> 3477 in the cache */
   /* search1205_1 -> 35 in the cache */
   /* search1205 -> 3478 in the cache */

   /* replace1205_0 -> 32 in the cache */
   /* replace1205 -> 3476 in the cache */

   /* ('imax', ('imin', 'a', 1), -1) => ('isign', 'a') */
   /* search1206_0_0 -> 32 in the cache */
   /* search1206_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imin,
      1, 1,
      { 32, 35 },
      -1,
   } },
   /* search1206_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imax,
      0, 2,
      { 3479, 63 },
      -1,
   } },

   /* replace1206_0 -> 32 in the cache */
   /* replace1206 -> 3476 in the cache */

   /* ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0))) */
   /* search1207_0 -> 32 in the cache */
   /* search1207 -> 199 in the cache */

   /* replace1207_0_0_0 -> 113 in the cache */
   /* replace1207_0_0_1 -> 32 in the cache */
   /* replace1207_0_0 -> 1399 in the cache */
   /* replace1207_0 -> 1400 in the cache */
   /* replace1207_1_0_0 -> 32 in the cache */
   /* replace1207_1_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 3481 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsub,
      -1, 0,
      { 1400, 3482 },
      -1,
   } },

   /* ('amul', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1208_0 -> 0 in the cache */
   /* search1208_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_amul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1208_0 -> 0 in the cache */
   /* replace1208_1 -> 3 in the cache */
   /* replace1208 -> 844 in the cache */

   /* ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)) */
   /* search1209_0 -> 16 in the cache */
   /* search1209_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1209_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffff /* 16777215 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 1,
      { 16, 3486 },
      -1,
   } },
   /* replace1209_1_0 -> 36 in the cache */
   /* replace1209_1_1 -> 3486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      2, 1,
      { 36, 3486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 3,
      { 3487, 3488 },
      -1,
   } },

   /* ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c') */
   /* search1210_0 -> 16 in the cache */
   /* search1210_1 -> 36 in the cache */
   /* search1210_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umad24,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* replace1210_0_0_0 -> 16 in the cache */
   /* replace1210_0_0_1 -> 3486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      2, 1,
      { 16, 3486 },
      -1,
   } },
   /* replace1210_0_1_0 -> 36 in the cache */
   /* replace1210_0_1_1 -> 3486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      3, 1,
      { 36, 3486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      1, 3,
      { 3491, 3492 },
      -1,
   } },
   /* replace1210_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 4,
      { 3493, 250 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b') */
   /* search1211_0 -> 16 in the cache */
   /* search1211_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1211_0 -> 16 in the cache */
   /* replace1211_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1212_0 -> 16 in the cache */
   /* search1212_1 -> 36 in the cache */
   /* search1212 -> 3495 in the cache */

   /* replace1212_0 -> 16 in the cache */
   /* replace1212_1 -> 36 in the cache */
   /* replace1212 -> 49 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c') */
   /* search1213_0 -> 16 in the cache */
   /* search1213_1 -> 36 in the cache */
   /* search1213_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umad24_relaxed,
      0, 1,
      { 16, 36, 250 },
      -1,
   } },

   /* replace1213_0 -> 16 in the cache */
   /* replace1213_1 -> 36 in the cache */
   /* replace1213_2 -> 250 in the cache */
   /* replace1213 -> 3490 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c') */
   /* search1214_0 -> 16 in the cache */
   /* search1214_1 -> 36 in the cache */
   /* search1214_2 -> 250 in the cache */
   /* search1214 -> 3497 in the cache */

   /* replace1214_0_0 -> 16 in the cache */
   /* replace1214_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umul24_relaxed,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1214_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 3498, 250 },
      -1,
   } },

   /* ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b') */
   /* search1215_0 -> 16 in the cache */
   /* search1215_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1215_0 -> 16 in the cache */
   /* replace1215_1 -> 36 in the cache */
   /* replace1215 -> 3485 in the cache */

   /* ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1216_0 -> 16 in the cache */
   /* search1216_1 -> 36 in the cache */
   /* search1216 -> 3500 in the cache */

   /* replace1216_0 -> 16 in the cache */
   /* replace1216_1 -> 36 in the cache */
   /* replace1216 -> 49 in the cache */

   /* ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b') */
   /* search1217_0 -> 16 in the cache */
   /* search1217_1 -> 36 in the cache */
   /* search1217_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1217_0 -> 16 in the cache */
   /* replace1217_1 -> 36 in the cache */
   /* replace1217 -> 3496 in the cache */

   /* ('imad24_ir3', 'a', 0, 'c') => c */
   /* search1218_0 -> 16 in the cache */
   /* search1218_1 -> 120 in the cache */
   /* search1218_2 -> 477 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 120, 477 },
      -1,
   } },

   /* replace1218 -> 477 in the cache */

   /* ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c') */
   /* search1219_0 -> 16 in the cache */
   /* search1219_1 -> 316 in the cache */
   /* search1219_2 -> 477 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 316, 477 },
      -1,
   } },

   /* replace1219_0 -> 16 in the cache */
   /* replace1219_1 -> 477 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 16, 477 },
      -1,
   } },

   /* ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c') */
   /* search1220_0 -> 286 in the cache */
   /* search1220_1 -> 33 in the cache */
   /* search1220_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imad24_ir3,
      0, 1,
      { 286, 33, 250 },
      -1,
   } },

   /* replace1220_0_0 -> 16 in the cache */
   /* replace1220_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1220_1 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 3506, 250 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   /* search1221_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul24,
      0, 1,
      { 16, 3508 },
      -1,
   } },

   /* replace1221_0 -> 16 in the cache */
   /* replace1221_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_find_lsb,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 3510 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search1222_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul24,
      0, 1,
      { 16, 3512 },
      -1,
   } },

   /* replace1222_0_0 -> 16 in the cache */
   /* replace1222_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_find_lsb,
      -1, 0,
      { 3514 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 16, 3515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 3516 },
      -1,
   } },

   /* ('imul24', 'a', 0) => 0 */
   /* search1223_0 -> 16 in the cache */
   /* search1223_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul24,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace1223 -> 120 in the cache */

   /* ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search1224_0_0 -> 120 in the cache */
   /* search1224_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_slt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1224_1 -> 36 in the cache */
   /* search1224_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fcsel,
      -1, 0,
      { 3519, 36, 250 },
      -1,
   } },

   /* replace1224_0 -> 16 in the cache */
   /* replace1224_1 -> 36 in the cache */
   /* replace1224_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fcsel_gt,
      -1, 0,
      { 16, 36, 250 },
      -1,
   } },

   /* ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'c', 'b') */
   /* search1225_0_0 -> 16 in the cache */
   /* search1225_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_slt,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1225_1 -> 36 in the cache */
   /* search1225_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fcsel,
      -1, 0,
      { 3522, 36, 250 },
      -1,
   } },

   /* replace1225_0 -> 16 in the cache */
   /* replace1225_1 -> 250 in the cache */
   /* replace1225_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fcsel_ge,
      -1, 0,
      { 16, 250, 36 },
      -1,
   } },

   /* ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search1226_0_0 -> 16 in the cache */
   /* search1226_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1226_1 -> 36 in the cache */
   /* search1226_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fcsel,
      -1, 0,
      { 3525, 36, 250 },
      -1,
   } },

   /* replace1226_0 -> 16 in the cache */
   /* replace1226_1 -> 36 in the cache */
   /* replace1226_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fcsel_ge,
      -1, 0,
      { 16, 36, 250 },
      -1,
   } },

   /* ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'c', 'b') */
   /* search1227_0_0 -> 120 in the cache */
   /* search1227_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_sge,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1227_1 -> 36 in the cache */
   /* search1227_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fcsel,
      -1, 0,
      { 3528, 36, 250 },
      -1,
   } },

   /* replace1227_0 -> 16 in the cache */
   /* replace1227_1 -> 250 in the cache */
   /* replace1227_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fcsel_gt,
      -1, 0,
      { 16, 250, 36 },
      -1,
   } },

   /* ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c') */
   /* search1228_0_0 -> 120 in the cache */
   /* search1228_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1228_1 -> 36 in the cache */
   /* search1228_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3531, 36, 250 },
      -1,
   } },

   /* replace1228_0 -> 16 in the cache */
   /* replace1228_1 -> 36 in the cache */
   /* replace1228_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i32csel_gt,
      -1, 0,
      { 16, 36, 250 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b') */
   /* search1229_0_0 -> 16 in the cache */
   /* search1229_0_1 -> 120 in the cache */
   /* search1229_0 -> 1342 in the cache */
   /* search1229_1 -> 36 in the cache */
   /* search1229_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1342, 36, 250 },
      -1,
   } },

   /* replace1229_0 -> 16 in the cache */
   /* replace1229_1 -> 250 in the cache */
   /* replace1229_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i32csel_ge,
      -1, 0,
      { 16, 250, 36 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c') */
   /* search1230_0_0 -> 16 in the cache */
   /* search1230_0_1 -> 120 in the cache */
   /* search1230_0 -> 1339 in the cache */
   /* search1230_1 -> 36 in the cache */
   /* search1230_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1339, 36, 250 },
      -1,
   } },

   /* replace1230_0 -> 16 in the cache */
   /* replace1230_1 -> 36 in the cache */
   /* replace1230_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i32csel_ge,
      -1, 0,
      { 16, 36, 250 },
      -1,
   } },

   /* ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b') */
   /* search1231_0_0 -> 120 in the cache */
   /* search1231_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1231_1 -> 36 in the cache */
   /* search1231_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3538, 36, 250 },
      -1,
   } },

   /* replace1231_0 -> 16 in the cache */
   /* replace1231_1 -> 250 in the cache */
   /* replace1231_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i32csel_gt,
      -1, 0,
      { 16, 250, 36 },
      -1,
   } },

   /* ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search1232_0_0 -> 120 in the cache */
   /* search1232_0_1 -> 16 in the cache */
   /* search1232_0 -> 1769 in the cache */
   /* search1232_1 -> 36 in the cache */
   /* search1232_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1769, 36, 250 },
      -1,
   } },

   /* replace1232_0 -> 16 in the cache */
   /* replace1232_1 -> 36 in the cache */
   /* replace1232_2 -> 250 in the cache */
   /* replace1232 -> 3521 in the cache */

   /* ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'c', 'b') */
   /* search1233_0_0 -> 16 in the cache */
   /* search1233_0_1 -> 120 in the cache */
   /* search1233_0 -> 1771 in the cache */
   /* search1233_1 -> 36 in the cache */
   /* search1233_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1771, 36, 250 },
      -1,
   } },

   /* replace1233_0 -> 16 in the cache */
   /* replace1233_1 -> 250 in the cache */
   /* replace1233_2 -> 36 in the cache */
   /* replace1233 -> 3524 in the cache */

   /* ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search1234_0_0 -> 16 in the cache */
   /* search1234_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1234_1 -> 36 in the cache */
   /* search1234_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3543, 36, 250 },
      -1,
   } },

   /* replace1234_0 -> 16 in the cache */
   /* replace1234_1 -> 36 in the cache */
   /* replace1234_2 -> 250 in the cache */
   /* replace1234 -> 3527 in the cache */

   /* ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'c', 'b') */
   /* search1235_0_0 -> 120 in the cache */
   /* search1235_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1235_1 -> 36 in the cache */
   /* search1235_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3545, 36, 250 },
      -1,
   } },

   /* replace1235_0 -> 16 in the cache */
   /* replace1235_1 -> 250 in the cache */
   /* replace1235_2 -> 36 in the cache */
   /* replace1235 -> 3530 in the cache */

   /* ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b'))) */
   /* search1236_0 -> 6 in the cache */
   /* search1236_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_iadd_sat,
      0, 1,
      { 6, 1984 },
      -1,
   } },

   /* replace1236_0_0 -> 1984 in the cache */
   /* replace1236_0_1 -> 1303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1984, 1303 },
      -1,
   } },
   /* replace1236_1_0_0_0 -> 6 in the cache */
   /* replace1236_1_0_0_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 6, 1984 },
      -1,
   } },
   /* replace1236_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 3549, 6 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1236_1_2_0 -> 6 in the cache */
   /* replace1236_1_2_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 6, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 3550, 3551, 3552 },
      -1,
   } },
   /* replace1236_2_0_0 -> 6 in the cache */
   /* replace1236_2_0_1_0 -> 6 in the cache */
   /* replace1236_2_0_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_iadd,
      2, 1,
      { 6, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 6, 3554 },
      -1,
   } },
   /* replace1236_2_1 -> 7 in the cache */
   /* replace1236_2_2_0 -> 6 in the cache */
   /* replace1236_2_2_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_iadd,
      3, 1,
      { 6, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 3555, 7, 3556 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 3548, 3553, 3557 },
      -1,
   } },

   /* ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b'))) */
   /* search1237_0 -> 6 in the cache */
   /* search1237_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_isub_sat,
      -1, 0,
      { 6, 1984 },
      -1,
   } },

   /* replace1237_0_0 -> 1984 in the cache */
   /* replace1237_0_1 -> 726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1984, 726 },
      -1,
   } },
   /* replace1237_1_0_0_0 -> 6 in the cache */
   /* replace1237_1_0_0_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 6, 1984 },
      -1,
   } },
   /* replace1237_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3561, 6 },
      -1,
   } },
   /* replace1237_1_1 -> 3551 in the cache */
   /* replace1237_1_2_0 -> 6 in the cache */
   /* replace1237_1_2_1 -> 1984 in the cache */
   /* replace1237_1_2 -> 3561 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3562, 3551, 3561 },
      -1,
   } },
   /* replace1237_2_0_0 -> 6 in the cache */
   /* replace1237_2_0_1_0 -> 6 in the cache */
   /* replace1237_2_0_1_1 -> 1984 in the cache */
   /* replace1237_2_0_1 -> 3561 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 6, 3561 },
      -1,
   } },
   /* replace1237_2_1 -> 7 in the cache */
   /* replace1237_2_2_0 -> 6 in the cache */
   /* replace1237_2_2_1 -> 1984 in the cache */
   /* replace1237_2_2 -> 3561 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3564, 7, 3561 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3560, 3563, 3565 },
      -1,
   } },

   /* ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b'))) */
   /* search1238_0 -> 11 in the cache */
   /* search1238_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd_sat,
      0, 1,
      { 11, 207 },
      -1,
   } },

   /* replace1238_0_0 -> 207 in the cache */
   /* replace1238_0_1 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 207, 1325 },
      -1,
   } },
   /* replace1238_1_0_0_0 -> 11 in the cache */
   /* replace1238_1_0_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 11, 207 },
      -1,
   } },
   /* replace1238_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 3569, 11 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1238_1_2_0 -> 11 in the cache */
   /* replace1238_1_2_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 11, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 3570, 3571, 3572 },
      -1,
   } },
   /* replace1238_2_0_0 -> 11 in the cache */
   /* replace1238_2_0_1_0 -> 11 in the cache */
   /* replace1238_2_0_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      2, 1,
      { 11, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 11, 3574 },
      -1,
   } },
   /* replace1238_2_1 -> 12 in the cache */
   /* replace1238_2_2_0 -> 11 in the cache */
   /* replace1238_2_2_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      3, 1,
      { 11, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 3575, 12, 3576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 3568, 3573, 3577 },
      -1,
   } },

   /* ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b'))) */
   /* search1239_0 -> 11 in the cache */
   /* search1239_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_isub_sat,
      -1, 0,
      { 11, 207 },
      -1,
   } },

   /* replace1239_0_0 -> 207 in the cache */
   /* replace1239_0_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 207, 748 },
      -1,
   } },
   /* replace1239_1_0_0_0 -> 11 in the cache */
   /* replace1239_1_0_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 11, 207 },
      -1,
   } },
   /* replace1239_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3581, 11 },
      -1,
   } },
   /* replace1239_1_1 -> 3571 in the cache */
   /* replace1239_1_2_0 -> 11 in the cache */
   /* replace1239_1_2_1 -> 207 in the cache */
   /* replace1239_1_2 -> 3581 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3582, 3571, 3581 },
      -1,
   } },
   /* replace1239_2_0_0 -> 11 in the cache */
   /* replace1239_2_0_1_0 -> 11 in the cache */
   /* replace1239_2_0_1_1 -> 207 in the cache */
   /* replace1239_2_0_1 -> 3581 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 11, 3581 },
      -1,
   } },
   /* replace1239_2_1 -> 12 in the cache */
   /* replace1239_2_2_0 -> 11 in the cache */
   /* replace1239_2_2_1 -> 207 in the cache */
   /* replace1239_2_2 -> 3581 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3584, 12, 3581 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3580, 3583, 3585 },
      -1,
   } },

   /* ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b'))) */
   /* search1240_0 -> 16 in the cache */
   /* search1240_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd_sat,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1240_0_0 -> 36 in the cache */
   /* replace1240_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 36, 316 },
      -1,
   } },
   /* replace1240_1_0_0_0 -> 16 in the cache */
   /* replace1240_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1240_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 3589, 16 },
      -1,
   } },
   /* replace1240_1_1 -> 881 in the cache */
   /* replace1240_1_2_0 -> 16 in the cache */
   /* replace1240_1_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 3590, 881, 3591 },
      -1,
   } },
   /* replace1240_2_0_0 -> 16 in the cache */
   /* replace1240_2_0_1_0 -> 16 in the cache */
   /* replace1240_2_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      2, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 16, 3593 },
      -1,
   } },
   /* replace1240_2_1 -> 17 in the cache */
   /* replace1240_2_2_0 -> 16 in the cache */
   /* replace1240_2_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      3, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 3594, 17, 3595 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 3588, 3592, 3596 },
      -1,
   } },

   /* ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b'))) */
   /* search1241_0 -> 16 in the cache */
   /* search1241_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub_sat,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1241_0_0 -> 36 in the cache */
   /* replace1241_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   /* replace1241_1_0_0_0 -> 16 in the cache */
   /* replace1241_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   /* replace1241_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3600, 16 },
      -1,
   } },
   /* replace1241_1_1 -> 881 in the cache */
   /* replace1241_1_2_0 -> 16 in the cache */
   /* replace1241_1_2_1 -> 36 in the cache */
   /* replace1241_1_2 -> 3600 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3601, 881, 3600 },
      -1,
   } },
   /* replace1241_2_0_0 -> 16 in the cache */
   /* replace1241_2_0_1_0 -> 16 in the cache */
   /* replace1241_2_0_1_1 -> 36 in the cache */
   /* replace1241_2_0_1 -> 3600 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 16, 3600 },
      -1,
   } },
   /* replace1241_2_1 -> 17 in the cache */
   /* replace1241_2_2_0 -> 16 in the cache */
   /* replace1241_2_2_1 -> 36 in the cache */
   /* replace1241_2_2 -> 3600 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3603, 17, 3600 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3599, 3602, 3604 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b'))) */
   /* search1242_0 -> 21 in the cache */
   /* search1242_1 -> 41 in the cache */
   /* search1242 -> 3255 in the cache */

   /* replace1242_0_0 -> 41 in the cache */
   /* replace1242_0_1 -> 1367 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 41, 1367 },
      -1,
   } },
   /* replace1242_1_0_0_0 -> 21 in the cache */
   /* replace1242_1_0_0_1 -> 41 in the cache */
   /* replace1242_1_0_0 -> 3242 in the cache */
   /* replace1242_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 3242, 21 },
      -1,
   } },
   /* replace1242_1_1 -> 3266 in the cache */
   /* replace1242_1_2_0 -> 21 in the cache */
   /* replace1242_1_2_1 -> 41 in the cache */
   /* replace1242_1_2 -> 3244 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 3607, 3266, 3244 },
      -1,
   } },
   /* replace1242_2_0_0 -> 21 in the cache */
   /* replace1242_2_0_1_0 -> 21 in the cache */
   /* replace1242_2_0_1_1 -> 41 in the cache */
   /* replace1242_2_0_1 -> 3258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 1,
      { 21, 3258 },
      -1,
   } },
   /* replace1242_2_1 -> 22 in the cache */
   /* replace1242_2_2_0 -> 21 in the cache */
   /* replace1242_2_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iadd,
      3, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 3609, 22, 3610 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 4,
      { 3606, 3608, 3611 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b'))) */
   /* search1243_0 -> 21 in the cache */
   /* search1243_1 -> 41 in the cache */
   /* search1243 -> 3269 in the cache */

   /* replace1243_0_0 -> 41 in the cache */
   /* replace1243_0_1 -> 791 in the cache */
   /* replace1243_0 -> 3256 in the cache */
   /* replace1243_1_0_0_0 -> 21 in the cache */
   /* replace1243_1_0_0_1 -> 41 in the cache */
   /* replace1243_1_0_0 -> 3253 in the cache */
   /* replace1243_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3253, 21 },
      -1,
   } },
   /* replace1243_1_1 -> 3266 in the cache */
   /* replace1243_1_2_0 -> 21 in the cache */
   /* replace1243_1_2_1 -> 41 in the cache */
   /* replace1243_1_2 -> 3253 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3613, 3266, 3253 },
      -1,
   } },
   /* replace1243_2_0_0 -> 21 in the cache */
   /* replace1243_2_0_1_0 -> 21 in the cache */
   /* replace1243_2_0_1_1 -> 41 in the cache */
   /* replace1243_2_0_1 -> 3253 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 21, 3253 },
      -1,
   } },
   /* replace1243_2_1 -> 22 in the cache */
   /* replace1243_2_2_0 -> 21 in the cache */
   /* replace1243_2_2_1 -> 41 in the cache */
   /* replace1243_2_2 -> 3253 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3615, 22, 3253 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 3256, 3614, 3616 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1244_0_0_0 -> 0 in the cache */
   /* search1244_0_0_1 -> 3 in the cache */
   /* search1244_0_0 -> 965 in the cache */
   /* search1244_0_1_0 -> 144 in the cache */
   /* search1244_0_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      2, 1,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 965, 3618 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 3,
      { 3619 },
      -1,
   } },

   /* replace1244_0_0 -> 0 in the cache */
   /* replace1244_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1244_1_0 -> 144 in the cache */
   /* replace1244_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      2, 1,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 3621, 3622 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1245_0_0_0 -> 0 in the cache */
   /* search1245_0_0_1 -> 3 in the cache */
   /* search1245_0_0 -> 965 in the cache */
   /* search1245_0_1_0 -> 144 in the cache */
   /* search1245_0_1_1 -> 145 in the cache */
   /* search1245_0_1 -> 3618 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 965, 3618 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 3,
      { 3624 },
      -1,
   } },

   /* replace1245_0_0 -> 0 in the cache */
   /* replace1245_0_1 -> 3 in the cache */
   /* replace1245_0 -> 3621 in the cache */
   /* replace1245_1_0 -> 144 in the cache */
   /* replace1245_1_1 -> 145 in the cache */
   /* replace1245_1 -> 3622 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 3621, 3622 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1246_0_0_0 -> 0 in the cache */
   /* search1246_0_0_1 -> 3 in the cache */
   /* search1246_0_0 -> 965 in the cache */
   /* search1246_0_1_0 -> 144 in the cache */
   /* search1246_0_1_1 -> 145 in the cache */
   /* search1246_0_1 -> 3622 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 965, 3622 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 3,
      { 3627 },
      -1,
   } },

   /* replace1246_0_0 -> 0 in the cache */
   /* replace1246_0_1 -> 3 in the cache */
   /* replace1246_0 -> 3621 in the cache */
   /* replace1246_1_0 -> 144 in the cache */
   /* replace1246_1_1 -> 145 in the cache */
   /* replace1246_1 -> 3618 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 3621, 3618 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1247_0_0_0 -> 0 in the cache */
   /* search1247_0_0_1 -> 3 in the cache */
   /* search1247_0_0 -> 965 in the cache */
   /* search1247_0_1_0 -> 144 in the cache */
   /* search1247_0_1_1 -> 145 in the cache */
   /* search1247_0_1 -> 3622 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 965, 3622 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 3,
      { 3630 },
      -1,
   } },

   /* replace1247_0_0 -> 0 in the cache */
   /* replace1247_0_1 -> 3 in the cache */
   /* replace1247_0 -> 3621 in the cache */
   /* replace1247_1_0 -> 144 in the cache */
   /* replace1247_1_1 -> 145 in the cache */
   /* replace1247_1 -> 3618 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 3621, 3618 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1248_0_0_0 -> 0 in the cache */
   /* search1248_0_0_1 -> 3 in the cache */
   /* search1248_0_0 -> 3621 in the cache */
   /* search1248_0_1_0 -> 144 in the cache */
   /* search1248_0_1_1 -> 145 in the cache */
   /* search1248_0_1 -> 3622 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 3621, 3622 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 3,
      { 3633 },
      -1,
   } },

   /* replace1248_0_0 -> 0 in the cache */
   /* replace1248_0_1 -> 3 in the cache */
   /* replace1248_0 -> 965 in the cache */
   /* replace1248_1_0 -> 144 in the cache */
   /* replace1248_1_1 -> 145 in the cache */
   /* replace1248_1 -> 3618 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 965, 3618 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1249_0_0_0 -> 0 in the cache */
   /* search1249_0_0_1 -> 3 in the cache */
   /* search1249_0_0 -> 3621 in the cache */
   /* search1249_0_1_0 -> 144 in the cache */
   /* search1249_0_1_1 -> 145 in the cache */
   /* search1249_0_1 -> 3622 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 3621, 3622 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 3,
      { 3636 },
      -1,
   } },

   /* replace1249_0_0 -> 0 in the cache */
   /* replace1249_0_1 -> 3 in the cache */
   /* replace1249_0 -> 965 in the cache */
   /* replace1249_1_0 -> 144 in the cache */
   /* replace1249_1_1 -> 145 in the cache */
   /* replace1249_1 -> 3618 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 965, 3618 },
      -1,
   } },

   /* ('f2b1', ('b2f', 'a@1')) => a */
   /* search1250_0_0 -> 650 in the cache */
   /* search1250_0 -> 1014 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_f2b1,
      -1, 0,
      { 1014 },
      -1,
   } },

   /* replace1250 -> 650 in the cache */

   /* ('i2b1', ('b2i', 'a@1')) => a */
   /* search1251_0_0 -> 650 in the cache */
   /* search1251_0 -> 1112 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2b1,
      -1, 0,
      { 1112 },
      -1,
   } },

   /* replace1251 -> 650 in the cache */

   /* ('f2b8', ('b2f', 'a@8')) => a */
   /* search1252_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_f2b8,
      -1, 0,
      { 3641 },
      -1,
   } },

   /* replace1252 -> 6 in the cache */

   /* ('i2b8', ('b2i', 'a@8')) => a */
   /* search1253_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2i,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2b8,
      -1, 0,
      { 3643 },
      -1,
   } },

   /* replace1253 -> 6 in the cache */

   /* ('f2b16', ('b2f', 'a@16')) => a */
   /* search1254_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2b16,
      -1, 0,
      { 3645 },
      -1,
   } },

   /* replace1254 -> 11 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search1255_0_0 -> 11 in the cache */
   /* search1255_0 -> 2726 in the cache */
   /* search1255 -> 2727 in the cache */

   /* replace1255 -> 11 in the cache */

   /* ('f2b32', ('b2f', 'a@32')) => a */
   /* search1256_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2b32,
      -1, 0,
      { 3647 },
      -1,
   } },

   /* replace1256 -> 16 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search1257_0_0 -> 16 in the cache */
   /* search1257_0 -> 2728 in the cache */
   /* search1257 -> 2729 in the cache */

   /* replace1257 -> 16 in the cache */

   /* ('f2f', ('b2f', 'a')) => ('b2f', 'a') */
   /* search1258_0_0 -> 32 in the cache */
   /* search1258_0 -> 1401 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2f,
      -1, 0,
      { 1401 },
      -1,
   } },

   /* replace1258_0 -> 32 in the cache */
   /* replace1258 -> 1401 in the cache */

   /* ('f2u', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1259_0_0 -> 32 in the cache */
   /* search1259_0 -> 1401 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2u,
      -1, 0,
      { 1401 },
      -1,
   } },

   /* replace1259_0 -> 32 in the cache */
   /* replace1259 -> 2718 in the cache */

   /* ('f2i', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1260_0_0 -> 32 in the cache */
   /* search1260_0 -> 1401 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_f2i,
      -1, 0,
      { 1401 },
      -1,
   } },

   /* replace1260_0 -> 32 in the cache */
   /* replace1260 -> 2718 in the cache */

   /* ('u2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1261_0_0 -> 32 in the cache */
   /* search1261_0 -> 2718 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_u2f,
      -1, 0,
      { 2718 },
      -1,
   } },

   /* replace1261_0 -> 32 in the cache */
   /* replace1261 -> 1401 in the cache */

   /* ('u2u', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1262_0_0 -> 32 in the cache */
   /* search1262_0 -> 2718 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_u2u,
      -1, 0,
      { 2718 },
      -1,
   } },

   /* replace1262_0 -> 32 in the cache */
   /* replace1262 -> 2718 in the cache */

   /* ('i2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1263_0_0 -> 32 in the cache */
   /* search1263_0 -> 2718 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_i2f,
      -1, 0,
      { 2718 },
      -1,
   } },

   /* replace1263_0 -> 32 in the cache */
   /* replace1263 -> 1401 in the cache */

   /* ('i2i', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1264_0_0 -> 32 in the cache */
   /* search1264_0 -> 2718 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false, false,
      nir_search_op_i2i,
      -1, 0,
      { 2718 },
      -1,
   } },

   /* replace1264_0 -> 32 in the cache */
   /* replace1264 -> 2718 in the cache */

   /* ('i2i1', 'a@1') => a */
   /* search1265_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2i1,
      -1, 0,
      { 650 },
      -1,
   } },

   /* replace1265 -> 650 in the cache */

   /* ('i2i8', 'a@8') => a */
   /* search1266_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1266 -> 6 in the cache */

   /* ('i2i16', 'a@16') => a */
   /* search1267_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1267 -> 11 in the cache */

   /* ('i2i32', 'a@32') => a */
   /* search1268_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1268 -> 16 in the cache */

   /* ('i2i64', 'a@64') => a */
   /* search1269_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1269 -> 21 in the cache */

   /* ('u2u1', 'a@1') => a */
   /* search1270_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_u2u1,
      -1, 0,
      { 650 },
      -1,
   } },

   /* replace1270 -> 650 in the cache */

   /* ('u2u8', 'a@8') => a */
   /* search1271_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1271 -> 6 in the cache */

   /* ('u2u16', 'a@16') => a */
   /* search1272_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1272 -> 11 in the cache */

   /* ('u2u32', 'a@32') => a */
   /* search1273_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1273 -> 16 in the cache */

   /* ('u2u64', 'a@64') => a */
   /* search1274_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1274 -> 21 in the cache */

   /* ('f2f16', 'a@16') => a */
   /* search1275_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1275 -> 11 in the cache */

   /* ('f2f32', 'a@32') => a */
   /* search1276_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1276 -> 16 in the cache */

   /* ('f2f64', 'a@64') => a */
   /* search1277_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2f64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1277 -> 21 in the cache */

   /* ('b2b1', 'a@1') => a */
   /* search1278_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_b2b1,
      -1, 0,
      { 650 },
      -1,
   } },

   /* replace1278 -> 650 in the cache */

   /* ('b2b8', 'a@8') => a */
   /* search1279_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_b2b8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1279 -> 6 in the cache */

   /* ('b2b16', 'a@16') => a */
   /* search1280_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2b16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1280 -> 11 in the cache */

   /* ('b2b32', 'a@32') => a */
   /* search1281_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2b32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1281 -> 16 in the cache */

   /* ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1282_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2i1,
      -1, 0,
      { 3673 },
      -1,
   } },

   /* replace1282_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2i1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1283_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2i1,
      -1, 0,
      { 3676 },
      -1,
   } },

   /* replace1283_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_u2u1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1284_0_0 -> 32 in the cache */
   /* search1284_0 -> 3673 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_u2u1,
      -1, 0,
      { 3673 },
      -1,
   } },

   /* replace1284_0 -> 32 in the cache */
   /* replace1284 -> 3675 in the cache */

   /* ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1285_0_0 -> 32 in the cache */
   /* search1285_0 -> 3676 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_u2u1,
      -1, 0,
      { 3676 },
      -1,
   } },

   /* replace1285_0 -> 32 in the cache */
   /* replace1285 -> 3678 in the cache */

   /* ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1286_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2i1,
      -1, 0,
      { 3681 },
      -1,
   } },

   /* replace1286_0 -> 32 in the cache */
   /* replace1286 -> 3675 in the cache */

   /* ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1287_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2i1,
      -1, 0,
      { 3683 },
      -1,
   } },

   /* replace1287_0 -> 32 in the cache */
   /* replace1287 -> 3678 in the cache */

   /* ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1288_0_0 -> 32 in the cache */
   /* search1288_0 -> 3681 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_u2u1,
      -1, 0,
      { 3681 },
      -1,
   } },

   /* replace1288_0 -> 32 in the cache */
   /* replace1288 -> 3675 in the cache */

   /* ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1289_0_0 -> 32 in the cache */
   /* search1289_0 -> 3683 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_u2u1,
      -1, 0,
      { 3683 },
      -1,
   } },

   /* replace1289_0 -> 32 in the cache */
   /* replace1289 -> 3678 in the cache */

   /* ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1290_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2i1,
      -1, 0,
      { 3687 },
      -1,
   } },

   /* replace1290_0 -> 32 in the cache */
   /* replace1290 -> 3675 in the cache */

   /* ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1291_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2i1,
      -1, 0,
      { 3689 },
      -1,
   } },

   /* replace1291_0 -> 32 in the cache */
   /* replace1291 -> 3678 in the cache */

   /* ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1292_0_0 -> 32 in the cache */
   /* search1292_0 -> 3687 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_u2u1,
      -1, 0,
      { 3687 },
      -1,
   } },

   /* replace1292_0 -> 32 in the cache */
   /* replace1292 -> 3675 in the cache */

   /* ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1293_0_0 -> 32 in the cache */
   /* search1293_0 -> 3689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_u2u1,
      -1, 0,
      { 3689 },
      -1,
   } },

   /* replace1293_0 -> 32 in the cache */
   /* replace1293 -> 3678 in the cache */

   /* ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1294_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2i1,
      -1, 0,
      { 3693 },
      -1,
   } },

   /* replace1294_0 -> 32 in the cache */
   /* replace1294 -> 3675 in the cache */

   /* ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1295_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_i2i1,
      -1, 0,
      { 3695 },
      -1,
   } },

   /* replace1295_0 -> 32 in the cache */
   /* replace1295 -> 3678 in the cache */

   /* ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1296_0_0 -> 32 in the cache */
   /* search1296_0 -> 3693 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_u2u1,
      -1, 0,
      { 3693 },
      -1,
   } },

   /* replace1296_0 -> 32 in the cache */
   /* replace1296 -> 3675 in the cache */

   /* ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1297_0_0 -> 32 in the cache */
   /* search1297_0 -> 3695 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_u2u1,
      -1, 0,
      { 3695 },
      -1,
   } },

   /* replace1297_0 -> 32 in the cache */
   /* replace1297 -> 3678 in the cache */

   /* ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a') */
   /* search1298_0_0 -> 650 in the cache */
   /* search1298_0 -> 3656 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 3656 },
      -1,
   } },

   /* replace1298_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a') */
   /* search1299_0_0 -> 650 in the cache */
   /* search1299_0 -> 3661 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 3661 },
      -1,
   } },

   /* replace1299_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1300_0_0 -> 32 in the cache */
   /* search1300_0 -> 3681 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 3681 },
      -1,
   } },

   /* replace1300_0 -> 32 in the cache */
   /* replace1300 -> 3673 in the cache */

   /* ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1301_0_0 -> 32 in the cache */
   /* search1301_0 -> 3683 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 3683 },
      -1,
   } },

   /* replace1301_0 -> 32 in the cache */
   /* replace1301 -> 3676 in the cache */

   /* ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1302_0_0 -> 32 in the cache */
   /* search1302_0 -> 3681 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 3681 },
      -1,
   } },

   /* replace1302_0 -> 32 in the cache */
   /* replace1302 -> 3673 in the cache */

   /* ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1303_0_0 -> 32 in the cache */
   /* search1303_0 -> 3683 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 3683 },
      -1,
   } },

   /* replace1303_0 -> 32 in the cache */
   /* replace1303 -> 3676 in the cache */

   /* ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1304_0_0 -> 32 in the cache */
   /* search1304_0 -> 3687 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 3687 },
      -1,
   } },

   /* replace1304_0 -> 32 in the cache */
   /* replace1304 -> 3673 in the cache */

   /* ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1305_0_0 -> 32 in the cache */
   /* search1305_0 -> 3689 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 3689 },
      -1,
   } },

   /* replace1305_0 -> 32 in the cache */
   /* replace1305 -> 3676 in the cache */

   /* ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1306_0_0 -> 32 in the cache */
   /* search1306_0 -> 3687 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 3687 },
      -1,
   } },

   /* replace1306_0 -> 32 in the cache */
   /* replace1306 -> 3673 in the cache */

   /* ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1307_0_0 -> 32 in the cache */
   /* search1307_0 -> 3689 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 3689 },
      -1,
   } },

   /* replace1307_0 -> 32 in the cache */
   /* replace1307 -> 3676 in the cache */

   /* ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1308_0_0 -> 32 in the cache */
   /* search1308_0 -> 3693 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 3693 },
      -1,
   } },

   /* replace1308_0 -> 32 in the cache */
   /* replace1308 -> 3673 in the cache */

   /* ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1309_0_0 -> 32 in the cache */
   /* search1309_0 -> 3695 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 3695 },
      -1,
   } },

   /* replace1309_0 -> 32 in the cache */
   /* replace1309 -> 3676 in the cache */

   /* ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1310_0_0 -> 32 in the cache */
   /* search1310_0 -> 3693 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 3693 },
      -1,
   } },

   /* replace1310_0 -> 32 in the cache */
   /* replace1310 -> 3673 in the cache */

   /* ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1311_0_0 -> 32 in the cache */
   /* search1311_0 -> 3695 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 3695 },
      -1,
   } },

   /* replace1311_0 -> 32 in the cache */
   /* replace1311 -> 3676 in the cache */

   /* ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a') */
   /* search1312_0_0 -> 650 in the cache */
   /* search1312_0 -> 3656 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 3656 },
      -1,
   } },

   /* replace1312_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a') */
   /* search1313_0_0 -> 650 in the cache */
   /* search1313_0 -> 3661 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 3661 },
      -1,
   } },

   /* replace1313_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a') */
   /* search1314_0_0 -> 650 in the cache */
   /* search1314_0 -> 3700 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 3700 },
      -1,
   } },

   /* replace1314_0 -> 650 in the cache */
   /* replace1314 -> 3716 in the cache */

   /* ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a') */
   /* search1315_0_0 -> 650 in the cache */
   /* search1315_0 -> 3702 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 3702 },
      -1,
   } },

   /* replace1315_0 -> 650 in the cache */
   /* replace1315 -> 3718 in the cache */

   /* ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a') */
   /* search1316_0_0 -> 6 in the cache */
   /* search1316_0 -> 3657 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 3657 },
      -1,
   } },

   /* replace1316_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a') */
   /* search1317_0_0 -> 6 in the cache */
   /* search1317_0 -> 3662 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 3662 },
      -1,
   } },

   /* replace1317_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1318_0_0 -> 32 in the cache */
   /* search1318_0 -> 3687 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 3687 },
      -1,
   } },

   /* replace1318_0 -> 32 in the cache */
   /* replace1318 -> 3681 in the cache */

   /* ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1319_0_0 -> 32 in the cache */
   /* search1319_0 -> 3689 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 3689 },
      -1,
   } },

   /* replace1319_0 -> 32 in the cache */
   /* replace1319 -> 3683 in the cache */

   /* ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1320_0_0 -> 32 in the cache */
   /* search1320_0 -> 3687 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 3687 },
      -1,
   } },

   /* replace1320_0 -> 32 in the cache */
   /* replace1320 -> 3681 in the cache */

   /* ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1321_0_0 -> 32 in the cache */
   /* search1321_0 -> 3689 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 3689 },
      -1,
   } },

   /* replace1321_0 -> 32 in the cache */
   /* replace1321 -> 3683 in the cache */

   /* ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1322_0_0 -> 32 in the cache */
   /* search1322_0 -> 3693 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 3693 },
      -1,
   } },

   /* replace1322_0 -> 32 in the cache */
   /* replace1322 -> 3681 in the cache */

   /* ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1323_0_0 -> 32 in the cache */
   /* search1323_0 -> 3695 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 3695 },
      -1,
   } },

   /* replace1323_0 -> 32 in the cache */
   /* replace1323 -> 3683 in the cache */

   /* ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1324_0_0 -> 32 in the cache */
   /* search1324_0 -> 3693 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 3693 },
      -1,
   } },

   /* replace1324_0 -> 32 in the cache */
   /* replace1324 -> 3681 in the cache */

   /* ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1325_0_0 -> 32 in the cache */
   /* search1325_0 -> 3695 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 3695 },
      -1,
   } },

   /* replace1325_0 -> 32 in the cache */
   /* replace1325 -> 3683 in the cache */

   /* ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a') */
   /* search1326_0_0 -> 650 in the cache */
   /* search1326_0 -> 3656 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3656 },
      -1,
   } },

   /* replace1326_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a') */
   /* search1327_0_0 -> 650 in the cache */
   /* search1327_0 -> 3661 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3661 },
      -1,
   } },

   /* replace1327_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a') */
   /* search1328_0_0 -> 650 in the cache */
   /* search1328_0 -> 3700 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3700 },
      -1,
   } },

   /* replace1328_0 -> 650 in the cache */
   /* replace1328 -> 3734 in the cache */

   /* ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a') */
   /* search1329_0_0 -> 650 in the cache */
   /* search1329_0 -> 3702 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3702 },
      -1,
   } },

   /* replace1329_0 -> 650 in the cache */
   /* replace1329 -> 3736 in the cache */

   /* ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a') */
   /* search1330_0_0 -> 6 in the cache */
   /* search1330_0 -> 3657 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3657 },
      -1,
   } },

   /* replace1330_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a') */
   /* search1331_0_0 -> 6 in the cache */
   /* search1331_0 -> 3662 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3662 },
      -1,
   } },

   /* replace1331_0 -> 6 in the cache */
   /* replace1331 -> 2891 in the cache */

   /* ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a') */
   /* search1332_0_0 -> 650 in the cache */
   /* search1332_0 -> 3716 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3716 },
      -1,
   } },

   /* replace1332_0 -> 650 in the cache */
   /* replace1332 -> 3734 in the cache */

   /* ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a') */
   /* search1333_0_0 -> 650 in the cache */
   /* search1333_0 -> 3718 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3718 },
      -1,
   } },

   /* replace1333_0 -> 650 in the cache */
   /* replace1333 -> 3736 in the cache */

   /* ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a') */
   /* search1334_0_0 -> 6 in the cache */
   /* search1334_0 -> 3722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3722 },
      -1,
   } },

   /* replace1334_0 -> 6 in the cache */
   /* replace1334 -> 3740 in the cache */

   /* ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a') */
   /* search1335_0_0 -> 6 in the cache */
   /* search1335_0 -> 3724 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3724 },
      -1,
   } },

   /* replace1335_0 -> 6 in the cache */
   /* replace1335 -> 2891 in the cache */

   /* ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a') */
   /* search1336_0_0 -> 11 in the cache */
   /* search1336_0 -> 3658 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3658 },
      -1,
   } },

   /* replace1336_0 -> 11 in the cache */
   /* replace1336 -> 1671 in the cache */

   /* ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a') */
   /* search1337_0_0 -> 11 in the cache */
   /* search1337_0 -> 3663 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3663 },
      -1,
   } },

   /* replace1337_0 -> 11 in the cache */
   /* replace1337 -> 1673 in the cache */

   /* ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1338_0_0 -> 32 in the cache */
   /* search1338_0 -> 3693 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3693 },
      -1,
   } },

   /* replace1338_0 -> 32 in the cache */
   /* replace1338 -> 3687 in the cache */

   /* ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1339_0_0 -> 32 in the cache */
   /* search1339_0 -> 3695 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3695 },
      -1,
   } },

   /* replace1339_0 -> 32 in the cache */
   /* replace1339 -> 3689 in the cache */

   /* ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1340_0_0 -> 32 in the cache */
   /* search1340_0 -> 3693 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3693 },
      -1,
   } },

   /* replace1340_0 -> 32 in the cache */
   /* replace1340 -> 3687 in the cache */

   /* ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1341_0_0 -> 32 in the cache */
   /* search1341_0 -> 3695 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3695 },
      -1,
   } },

   /* replace1341_0 -> 32 in the cache */
   /* replace1341 -> 3689 in the cache */

   /* ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a') */
   /* search1342_0_0 -> 650 in the cache */
   /* search1342_0 -> 3656 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3656 },
      -1,
   } },

   /* replace1342_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a') */
   /* search1343_0_0 -> 650 in the cache */
   /* search1343_0 -> 3661 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 3661 },
      -1,
   } },

   /* replace1343_0 -> 650 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 650 },
      -1,
   } },

   /* ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a') */
   /* search1344_0_0 -> 650 in the cache */
   /* search1344_0 -> 3700 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3700 },
      -1,
   } },

   /* replace1344_0 -> 650 in the cache */
   /* replace1344 -> 3753 in the cache */

   /* ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a') */
   /* search1345_0_0 -> 650 in the cache */
   /* search1345_0 -> 3702 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 3702 },
      -1,
   } },

   /* replace1345_0 -> 650 in the cache */
   /* replace1345 -> 3755 in the cache */

   /* ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a') */
   /* search1346_0_0 -> 6 in the cache */
   /* search1346_0 -> 3657 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3657 },
      -1,
   } },

   /* replace1346_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a') */
   /* search1347_0_0 -> 6 in the cache */
   /* search1347_0 -> 3662 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 3662 },
      -1,
   } },

   /* replace1347_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a') */
   /* search1348_0_0 -> 650 in the cache */
   /* search1348_0 -> 3716 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3716 },
      -1,
   } },

   /* replace1348_0 -> 650 in the cache */
   /* replace1348 -> 3753 in the cache */

   /* ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a') */
   /* search1349_0_0 -> 650 in the cache */
   /* search1349_0 -> 3718 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 3718 },
      -1,
   } },

   /* replace1349_0 -> 650 in the cache */
   /* replace1349 -> 3755 in the cache */

   /* ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a') */
   /* search1350_0_0 -> 6 in the cache */
   /* search1350_0 -> 3722 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3722 },
      -1,
   } },

   /* replace1350_0 -> 6 in the cache */
   /* replace1350 -> 3759 in the cache */

   /* ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a') */
   /* search1351_0_0 -> 6 in the cache */
   /* search1351_0 -> 3724 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 3724 },
      -1,
   } },

   /* replace1351_0 -> 6 in the cache */
   /* replace1351 -> 3761 in the cache */

   /* ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a') */
   /* search1352_0_0 -> 11 in the cache */
   /* search1352_0 -> 3658 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3658 },
      -1,
   } },

   /* replace1352_0 -> 11 in the cache */
   /* replace1352 -> 1694 in the cache */

   /* ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a') */
   /* search1353_0_0 -> 11 in the cache */
   /* search1353_0 -> 3663 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 3663 },
      -1,
   } },

   /* replace1353_0 -> 11 in the cache */
   /* replace1353 -> 1696 in the cache */

   /* ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a') */
   /* search1354_0_0 -> 650 in the cache */
   /* search1354_0 -> 3734 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3734 },
      -1,
   } },

   /* replace1354_0 -> 650 in the cache */
   /* replace1354 -> 3753 in the cache */

   /* ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a') */
   /* search1355_0_0 -> 650 in the cache */
   /* search1355_0 -> 3736 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 3736 },
      -1,
   } },

   /* replace1355_0 -> 650 in the cache */
   /* replace1355 -> 3755 in the cache */

   /* ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a') */
   /* search1356_0_0 -> 6 in the cache */
   /* search1356_0 -> 3740 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3740 },
      -1,
   } },

   /* replace1356_0 -> 6 in the cache */
   /* replace1356 -> 3759 in the cache */

   /* ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a') */
   /* search1357_0_0 -> 6 in the cache */
   /* search1357_0 -> 2891 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 2891 },
      -1,
   } },

   /* replace1357_0 -> 6 in the cache */
   /* replace1357 -> 3761 in the cache */

   /* ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a') */
   /* search1358_0_0 -> 11 in the cache */
   /* search1358_0 -> 1671 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 1671 },
      -1,
   } },

   /* replace1358_0 -> 11 in the cache */
   /* replace1358 -> 1694 in the cache */

   /* ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a') */
   /* search1359_0_0 -> 11 in the cache */
   /* search1359_0 -> 1673 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 1673 },
      -1,
   } },

   /* replace1359_0 -> 11 in the cache */
   /* replace1359 -> 1696 in the cache */

   /* ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a') */
   /* search1360_0_0 -> 16 in the cache */
   /* search1360_0 -> 3659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3659 },
      -1,
   } },

   /* replace1360_0 -> 16 in the cache */
   /* replace1360 -> 1778 in the cache */

   /* ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a') */
   /* search1361_0_0 -> 16 in the cache */
   /* search1361_0 -> 3664 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 3664 },
      -1,
   } },

   /* replace1361_0 -> 16 in the cache */
   /* replace1361 -> 1780 in the cache */

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1362_0_0 -> 16 in the cache */
   /* search1362_0_1 -> 36 in the cache */
   /* search1362_0 -> 2817 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 2817 },
      -1,
   } },

   /* replace1362_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1363_0_0 -> 16 in the cache */
   /* search1363_0_1 -> 36 in the cache */
   /* search1363_0 -> 2817 in the cache */
   /* search1363 -> 3776 in the cache */

   /* replace1363_0 -> 16 in the cache */
   /* replace1363 -> 3777 in the cache */

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1364_0_0 -> 16 in the cache */
   /* search1364_0_1 -> 36 in the cache */
   /* search1364_0 -> 2817 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 2817 },
      -1,
   } },

   /* replace1364_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1365_0_0 -> 16 in the cache */
   /* search1365_0_1 -> 36 in the cache */
   /* search1365_0 -> 2817 in the cache */
   /* search1365 -> 3778 in the cache */

   /* replace1365_0 -> 16 in the cache */
   /* replace1365 -> 3779 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1366_0_0 -> 16 in the cache */
   /* search1366_0_1 -> 36 in the cache */
   /* search1366_0 -> 2817 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 2817 },
      -1,
   } },

   /* replace1366_0 -> 16 in the cache */
   /* replace1366 -> 3659 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1367_0_0 -> 16 in the cache */
   /* search1367_0_1 -> 36 in the cache */
   /* search1367_0 -> 2817 in the cache */
   /* search1367 -> 3780 in the cache */

   /* replace1367_0 -> 16 in the cache */
   /* replace1367 -> 3659 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1368_0_0 -> 16 in the cache */
   /* search1368_0_1 -> 36 in the cache */
   /* search1368_0 -> 2817 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 2817 },
      -1,
   } },

   /* replace1368_0 -> 16 in the cache */
   /* replace1368 -> 1897 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1369_0_0 -> 16 in the cache */
   /* search1369_0_1 -> 36 in the cache */
   /* search1369_0 -> 2817 in the cache */
   /* search1369 -> 3781 in the cache */

   /* replace1369_0 -> 16 in the cache */
   /* replace1369 -> 1897 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1370_0_0 -> 16 in the cache */
   /* search1370_0_1 -> 36 in the cache */
   /* search1370_0 -> 2817 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 2817 },
      -1,
   } },

   /* replace1370_0 -> 16 in the cache */
   /* replace1370 -> 2919 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1371_0_0 -> 16 in the cache */
   /* search1371_0_1 -> 36 in the cache */
   /* search1371_0 -> 2817 in the cache */
   /* search1371 -> 3782 in the cache */

   /* replace1371_0 -> 16 in the cache */
   /* replace1371 -> 2919 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1372_0_0 -> 16 in the cache */
   /* search1372_0_1 -> 36 in the cache */
   /* search1372_0 -> 2817 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 2817 },
      -1,
   } },

   /* replace1372_0 -> 16 in the cache */
   /* replace1372 -> 3664 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1373_0_0 -> 16 in the cache */
   /* search1373_0_1 -> 36 in the cache */
   /* search1373_0 -> 2817 in the cache */
   /* search1373 -> 3783 in the cache */

   /* replace1373_0 -> 16 in the cache */
   /* replace1373 -> 3664 in the cache */

   /* ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1374_0_0 -> 6 in the cache */
   /* search1374_0 -> 3722 in the cache */
   /* search1374_1_0 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3722, 3784 },
      -1,
   } },

   /* replace1374_0 -> 6 in the cache */
   /* replace1374_1_0 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 6, 3786 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1375_0_0 -> 6 in the cache */
   /* search1375_0 -> 3722 in the cache */
   /* search1375_1_0 -> 1984 in the cache */
   /* search1375_1 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3722, 3784 },
      -1,
   } },

   /* replace1375_0 -> 6 in the cache */
   /* replace1375_1_0 -> 1984 in the cache */
   /* replace1375_1 -> 3786 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 6, 3786 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1376_0_0 -> 6 in the cache */
   /* search1376_0 -> 3722 in the cache */
   /* search1376_1_0 -> 1984 in the cache */
   /* search1376_1 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3722, 3784 },
      -1,
   } },

   /* replace1376_0 -> 6 in the cache */
   /* replace1376_1_0 -> 1984 in the cache */
   /* replace1376_1 -> 3786 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 6, 3786 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1377_0_0 -> 6 in the cache */
   /* search1377_0 -> 3722 in the cache */
   /* search1377_1_0 -> 1984 in the cache */
   /* search1377_1 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3722, 3784 },
      -1,
   } },

   /* replace1377_0 -> 6 in the cache */
   /* replace1377_1_0 -> 1984 in the cache */
   /* replace1377_1 -> 3786 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 6, 3786 },
      -1,
   } },

   /* ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 3794 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 3796 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3795, 3797 },
      -1,
   } },

   /* replace1378_0_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 3794 },
      -1,
   } },
   /* replace1378_1 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3799, 3796 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1379_0_0 -> 3794 in the cache */
   /* search1379_0 -> 3795 in the cache */
   /* search1379_1_0 -> 3796 in the cache */
   /* search1379_1 -> 3797 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3795, 3797 },
      -1,
   } },

   /* replace1379_0_0 -> 3794 in the cache */
   /* replace1379_0 -> 3799 in the cache */
   /* replace1379_1 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3799, 3796 },
      -1,
   } },

   /* ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1380_0_0 -> 6 in the cache */
   /* search1380_0 -> 3722 in the cache */
   /* search1380_1 -> 1883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3722, 1883 },
      -1,
   } },

   /* replace1380_0_0 -> 6 in the cache */
   /* replace1380_0_1_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 6, 3804 },
      -1,
   } },
   /* replace1380_1_0_0_0 -> 207 in the cache */
   /* replace1380_1_0_0 -> 3804 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 3804 },
      -1,
   } },
   /* replace1380_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 3806, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 3805, 3807 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1381_0_0 -> 6 in the cache */
   /* search1381_0 -> 3722 in the cache */
   /* search1381_1 -> 1883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3722, 1883 },
      -1,
   } },

   /* replace1381_0_0 -> 6 in the cache */
   /* replace1381_0_1_0 -> 207 in the cache */
   /* replace1381_0_1 -> 3804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 6, 3804 },
      -1,
   } },
   /* replace1381_1_0_0_0 -> 207 in the cache */
   /* replace1381_1_0_0 -> 3804 in the cache */
   /* replace1381_1_0 -> 3806 in the cache */
   /* replace1381_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 3806, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 3810, 3811 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1382_0_0 -> 6 in the cache */
   /* search1382_0 -> 3722 in the cache */
   /* search1382_1 -> 1883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3722, 1883 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1382_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3814, 207 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1382_1_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3816, 207 },
      -1,
   } },
   /* replace1382_1_1_0 -> 6 in the cache */
   /* replace1382_1_1_1_0 -> 207 in the cache */
   /* replace1382_1_1_1 -> 3804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 6, 3804 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3817, 3818 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3815, 3819 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1383_1_0 -> 1984 in the cache */
   /* search1383_1 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3821, 3784 },
      -1,
   } },

   /* replace1383_0_0 -> 11 in the cache */
   /* replace1383_0_1 -> 3816 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 11, 3816 },
      -1,
   } },
   /* replace1383_1_0_0 -> 11 in the cache */
   /* replace1383_1_0_1 -> 3814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 11, 3814 },
      -1,
   } },
   /* replace1383_1_1_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 11 },
      -1,
   } },
   /* replace1383_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3825, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3824, 3826 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3823, 3827 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1384_0_0 -> 6 in the cache */
   /* search1384_0 -> 3722 in the cache */
   /* search1384_1 -> 1883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3722, 1883 },
      -1,
   } },

   /* replace1384_0_0 -> 3816 in the cache */
   /* replace1384_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3816, 207 },
      -1,
   } },
   /* replace1384_1_0_0 -> 3814 in the cache */
   /* replace1384_1_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3814, 207 },
      -1,
   } },
   /* replace1384_1_1_0 -> 6 in the cache */
   /* replace1384_1_1_1_0 -> 207 in the cache */
   /* replace1384_1_1_1 -> 3804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 6, 3804 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3831, 3832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3830, 3833 },
      -1,
   } },

   /* ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1385_0 -> 3821 in the cache */
   /* search1385_1_0 -> 1984 in the cache */
   /* search1385_1 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3821, 3784 },
      -1,
   } },

   /* replace1385_0_0 -> 11 in the cache */
   /* replace1385_0_1 -> 3814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 11, 3814 },
      -1,
   } },
   /* replace1385_1_0_0 -> 11 in the cache */
   /* replace1385_1_0_1 -> 3816 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 11, 3816 },
      -1,
   } },
   /* replace1385_1_1_0_0 -> 11 in the cache */
   /* replace1385_1_1_0 -> 3825 in the cache */
   /* replace1385_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3825, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3837, 3838 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3836, 3839 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1386_0_0 -> 6 in the cache */
   /* search1386_0 -> 3740 in the cache */
   /* search1386_1_0 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3740, 3841 },
      -1,
   } },

   /* replace1386_0 -> 6 in the cache */
   /* replace1386_1_0 -> 1984 in the cache */
   /* replace1386_1 -> 3786 in the cache */
   /* replace1386 -> 3787 in the cache */

   /* ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1387_0_0 -> 6 in the cache */
   /* search1387_0 -> 3740 in the cache */
   /* search1387_1_0 -> 1984 in the cache */
   /* search1387_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3740, 3841 },
      -1,
   } },

   /* replace1387_0 -> 6 in the cache */
   /* replace1387_1_0 -> 1984 in the cache */
   /* replace1387_1 -> 3786 in the cache */
   /* replace1387 -> 3789 in the cache */

   /* ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1388_0_0 -> 6 in the cache */
   /* search1388_0 -> 3740 in the cache */
   /* search1388_1_0 -> 1984 in the cache */
   /* search1388_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3740, 3841 },
      -1,
   } },

   /* replace1388_0 -> 6 in the cache */
   /* replace1388_1_0 -> 1984 in the cache */
   /* replace1388_1 -> 3786 in the cache */
   /* replace1388 -> 3791 in the cache */

   /* ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1389_0_0 -> 6 in the cache */
   /* search1389_0 -> 3740 in the cache */
   /* search1389_1_0 -> 1984 in the cache */
   /* search1389_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3740, 3841 },
      -1,
   } },

   /* replace1389_0 -> 6 in the cache */
   /* replace1389_1_0 -> 1984 in the cache */
   /* replace1389_1 -> 3786 in the cache */
   /* replace1389 -> 3793 in the cache */

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1390_0_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3794 },
      -1,
   } },
   /* search1390_1_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3796 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3846, 3847 },
      -1,
   } },

   /* replace1390_0_0 -> 3794 in the cache */
   /* replace1390_0 -> 3799 in the cache */
   /* replace1390_1 -> 3796 in the cache */
   /* replace1390 -> 3800 in the cache */

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1391_0_0 -> 3794 in the cache */
   /* search1391_0 -> 3846 in the cache */
   /* search1391_1_0 -> 3796 in the cache */
   /* search1391_1 -> 3847 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3846, 3847 },
      -1,
   } },

   /* replace1391_0_0 -> 3794 in the cache */
   /* replace1391_0 -> 3799 in the cache */
   /* replace1391_1 -> 3796 in the cache */
   /* replace1391 -> 3802 in the cache */

   /* ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1392_0_0 -> 6 in the cache */
   /* search1392_0 -> 3740 in the cache */
   /* search1392_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3740, 33 },
      -1,
   } },

   /* replace1392_0_0 -> 6 in the cache */
   /* replace1392_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 6, 3851 },
      -1,
   } },
   /* replace1392_1_0_0_0 -> 36 in the cache */
   /* replace1392_1_0_0 -> 3851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3851 },
      -1,
   } },
   /* replace1392_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 3853, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 3852, 3854 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1393_0_0 -> 6 in the cache */
   /* search1393_0 -> 3740 in the cache */
   /* search1393_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3740, 33 },
      -1,
   } },

   /* replace1393_0_0 -> 6 in the cache */
   /* replace1393_0_1_0 -> 36 in the cache */
   /* replace1393_0_1 -> 3851 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 6, 3851 },
      -1,
   } },
   /* replace1393_1_0_0_0 -> 36 in the cache */
   /* replace1393_1_0_0 -> 3851 in the cache */
   /* replace1393_1_0 -> 3853 in the cache */
   /* replace1393_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 3853, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 3857, 3858 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1394_0_0 -> 6 in the cache */
   /* search1394_0 -> 3740 in the cache */
   /* search1394_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3740, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1394_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3861, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1394_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3863, 36 },
      -1,
   } },
   /* replace1394_1_1_0 -> 6 in the cache */
   /* replace1394_1_1_1_0 -> 36 in the cache */
   /* replace1394_1_1_1 -> 3851 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 6, 3851 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3864, 3865 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3862, 3866 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   /* search1395_0 -> 286 in the cache */
   /* search1395_1_0 -> 1984 in the cache */
   /* search1395_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 286, 3841 },
      -1,
   } },

   /* replace1395_0_0 -> 16 in the cache */
   /* replace1395_0_1 -> 3863 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 16, 3863 },
      -1,
   } },
   /* replace1395_1_0_0 -> 16 in the cache */
   /* replace1395_1_0_1 -> 3861 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 16, 3861 },
      -1,
   } },
   /* replace1395_1_1_0_0 -> 16 in the cache */
   /* replace1395_1_1_0 -> 3777 in the cache */
   /* replace1395_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3777, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3870, 3871 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3869, 3872 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1396_0_0 -> 6 in the cache */
   /* search1396_0 -> 3740 in the cache */
   /* search1396_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3740, 33 },
      -1,
   } },

   /* replace1396_0_0 -> 3863 in the cache */
   /* replace1396_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3863, 36 },
      -1,
   } },
   /* replace1396_1_0_0 -> 3861 in the cache */
   /* replace1396_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3861, 36 },
      -1,
   } },
   /* replace1396_1_1_0 -> 6 in the cache */
   /* replace1396_1_1_1_0 -> 36 in the cache */
   /* replace1396_1_1_1 -> 3851 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 6, 3851 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3876, 3877 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3875, 3878 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1397_0 -> 286 in the cache */
   /* search1397_1_0 -> 1984 in the cache */
   /* search1397_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 286, 3841 },
      -1,
   } },

   /* replace1397_0_0 -> 16 in the cache */
   /* replace1397_0_1 -> 3861 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 16, 3861 },
      -1,
   } },
   /* replace1397_1_0_0 -> 16 in the cache */
   /* replace1397_1_0_1 -> 3863 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 16, 3863 },
      -1,
   } },
   /* replace1397_1_1_0_0 -> 16 in the cache */
   /* replace1397_1_1_0 -> 3777 in the cache */
   /* replace1397_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3777, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3882, 3883 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3881, 3884 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1398_0_0 -> 6 in the cache */
   /* search1398_0 -> 3759 in the cache */
   /* search1398_1_0 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3759, 3886 },
      -1,
   } },

   /* replace1398_0 -> 6 in the cache */
   /* replace1398_1_0 -> 1984 in the cache */
   /* replace1398_1 -> 3786 in the cache */
   /* replace1398 -> 3787 in the cache */

   /* ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1399_0_0 -> 6 in the cache */
   /* search1399_0 -> 3759 in the cache */
   /* search1399_1_0 -> 1984 in the cache */
   /* search1399_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3759, 3886 },
      -1,
   } },

   /* replace1399_0 -> 6 in the cache */
   /* replace1399_1_0 -> 1984 in the cache */
   /* replace1399_1 -> 3786 in the cache */
   /* replace1399 -> 3789 in the cache */

   /* ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1400_0_0 -> 6 in the cache */
   /* search1400_0 -> 3759 in the cache */
   /* search1400_1_0 -> 1984 in the cache */
   /* search1400_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3759, 3886 },
      -1,
   } },

   /* replace1400_0 -> 6 in the cache */
   /* replace1400_1_0 -> 1984 in the cache */
   /* replace1400_1 -> 3786 in the cache */
   /* replace1400 -> 3791 in the cache */

   /* ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1401_0_0 -> 6 in the cache */
   /* search1401_0 -> 3759 in the cache */
   /* search1401_1_0 -> 1984 in the cache */
   /* search1401_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3759, 3886 },
      -1,
   } },

   /* replace1401_0 -> 6 in the cache */
   /* replace1401_1_0 -> 1984 in the cache */
   /* replace1401_1 -> 3786 in the cache */
   /* replace1401 -> 3793 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1402_0_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3794 },
      -1,
   } },
   /* search1402_1_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3796 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3891, 3892 },
      -1,
   } },

   /* replace1402_0_0 -> 3794 in the cache */
   /* replace1402_0 -> 3799 in the cache */
   /* replace1402_1 -> 3796 in the cache */
   /* replace1402 -> 3800 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1403_0_0 -> 3794 in the cache */
   /* search1403_0 -> 3891 in the cache */
   /* search1403_1_0 -> 3796 in the cache */
   /* search1403_1 -> 3892 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3891, 3892 },
      -1,
   } },

   /* replace1403_0_0 -> 3794 in the cache */
   /* replace1403_0 -> 3799 in the cache */
   /* replace1403_1 -> 3796 in the cache */
   /* replace1403 -> 3802 in the cache */

   /* ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1404_0_0 -> 6 in the cache */
   /* search1404_0 -> 3759 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3759, 3895 },
      -1,
   } },

   /* replace1404_0_0 -> 6 in the cache */
   /* replace1404_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 6, 3897 },
      -1,
   } },
   /* replace1404_1_0_0_0 -> 41 in the cache */
   /* replace1404_1_0_0 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 3897 },
      -1,
   } },
   /* replace1404_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 3899, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 3898, 3900 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1405_0_0 -> 6 in the cache */
   /* search1405_0 -> 3759 in the cache */
   /* search1405_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3759, 3895 },
      -1,
   } },

   /* replace1405_0_0 -> 6 in the cache */
   /* replace1405_0_1_0 -> 41 in the cache */
   /* replace1405_0_1 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 6, 3897 },
      -1,
   } },
   /* replace1405_1_0_0_0 -> 41 in the cache */
   /* replace1405_1_0_0 -> 3897 in the cache */
   /* replace1405_1_0 -> 3899 in the cache */
   /* replace1405_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 3899, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 3903, 3904 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1406_0_0 -> 6 in the cache */
   /* search1406_0 -> 3759 in the cache */
   /* search1406_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3759, 3895 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1406_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3907, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1406_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3909, 41 },
      -1,
   } },
   /* replace1406_1_1_0 -> 6 in the cache */
   /* replace1406_1_1_1_0 -> 41 in the cache */
   /* replace1406_1_1_1 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 6, 3897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3910, 3911 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3908, 3912 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1407_1_0 -> 1984 in the cache */
   /* search1407_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3914, 3886 },
      -1,
   } },

   /* replace1407_0_0 -> 21 in the cache */
   /* replace1407_0_1 -> 3909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 21, 3909 },
      -1,
   } },
   /* replace1407_1_0_0 -> 21 in the cache */
   /* replace1407_1_0_1 -> 3907 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 21, 3907 },
      -1,
   } },
   /* replace1407_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1407_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3918, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3917, 3919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3916, 3920 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1408_0_0 -> 6 in the cache */
   /* search1408_0 -> 3759 in the cache */
   /* search1408_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3759, 3895 },
      -1,
   } },

   /* replace1408_0_0 -> 3909 in the cache */
   /* replace1408_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3909, 41 },
      -1,
   } },
   /* replace1408_1_0_0 -> 3907 in the cache */
   /* replace1408_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3907, 41 },
      -1,
   } },
   /* replace1408_1_1_0 -> 6 in the cache */
   /* replace1408_1_1_1_0 -> 41 in the cache */
   /* replace1408_1_1_1 -> 3897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 6, 3897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3924, 3925 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3923, 3926 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1409_0 -> 3914 in the cache */
   /* search1409_1_0 -> 1984 in the cache */
   /* search1409_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3914, 3886 },
      -1,
   } },

   /* replace1409_0_0 -> 21 in the cache */
   /* replace1409_0_1 -> 3907 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 21, 3907 },
      -1,
   } },
   /* replace1409_1_0_0 -> 21 in the cache */
   /* replace1409_1_0_1 -> 3909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 21, 3909 },
      -1,
   } },
   /* replace1409_1_1_0_0 -> 21 in the cache */
   /* replace1409_1_1_0 -> 3918 in the cache */
   /* replace1409_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3918, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3930, 3931 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3929, 3932 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1410_0_0 -> 11 in the cache */
   /* search1410_0 -> 1671 in the cache */
   /* search1410_1_0 -> 1984 in the cache */
   /* search1410_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1671, 3841 },
      -1,
   } },

   /* replace1410_0 -> 11 in the cache */
   /* replace1410_1_0 -> 1984 in the cache */
   /* replace1410_1 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 11, 3784 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1411_0_0 -> 11 in the cache */
   /* search1411_0 -> 1671 in the cache */
   /* search1411_1_0 -> 1984 in the cache */
   /* search1411_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1671, 3841 },
      -1,
   } },

   /* replace1411_0 -> 11 in the cache */
   /* replace1411_1_0 -> 1984 in the cache */
   /* replace1411_1 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 11, 3784 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1412_0_0 -> 11 in the cache */
   /* search1412_0 -> 1671 in the cache */
   /* search1412_1_0 -> 1984 in the cache */
   /* search1412_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1671, 3841 },
      -1,
   } },

   /* replace1412_0 -> 11 in the cache */
   /* replace1412_1_0 -> 1984 in the cache */
   /* replace1412_1 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 11, 3784 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1413_0_0 -> 11 in the cache */
   /* search1413_0 -> 1671 in the cache */
   /* search1413_1_0 -> 1984 in the cache */
   /* search1413_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1671, 3841 },
      -1,
   } },

   /* replace1413_0 -> 11 in the cache */
   /* replace1413_1_0 -> 1984 in the cache */
   /* replace1413_1 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 11, 3784 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1414_0_0 -> 3794 in the cache */
   /* search1414_0 -> 3846 in the cache */
   /* search1414_1_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3846, 3942 },
      -1,
   } },

   /* replace1414_0_0 -> 3794 in the cache */
   /* replace1414_0 -> 3795 in the cache */
   /* replace1414_1 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3795, 446 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1415_0_0 -> 3794 in the cache */
   /* search1415_0 -> 3846 in the cache */
   /* search1415_1_0 -> 446 in the cache */
   /* search1415_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3846, 3942 },
      -1,
   } },

   /* replace1415_0_0 -> 3794 in the cache */
   /* replace1415_0 -> 3795 in the cache */
   /* replace1415_1 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3795, 446 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1416_0_0 -> 11 in the cache */
   /* search1416_0 -> 1671 in the cache */
   /* search1416_1_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1671, 3947 },
      -1,
   } },

   /* replace1416_0 -> 11 in the cache */
   /* replace1416_1_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 11, 3949 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1417_0_0 -> 11 in the cache */
   /* search1417_0 -> 1671 in the cache */
   /* search1417_1_0 -> 207 in the cache */
   /* search1417_1 -> 3947 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1671, 3947 },
      -1,
   } },

   /* replace1417_0 -> 11 in the cache */
   /* replace1417_1_0 -> 207 in the cache */
   /* replace1417_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 11, 3949 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1418_0_0 -> 11 in the cache */
   /* search1418_0 -> 1671 in the cache */
   /* search1418_1_0 -> 207 in the cache */
   /* search1418_1 -> 3947 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1671, 3947 },
      -1,
   } },

   /* replace1418_0 -> 11 in the cache */
   /* replace1418_1_0 -> 207 in the cache */
   /* replace1418_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 11, 3949 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1419_0_0 -> 11 in the cache */
   /* search1419_0 -> 1671 in the cache */
   /* search1419_1_0 -> 207 in the cache */
   /* search1419_1 -> 3947 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1671, 3947 },
      -1,
   } },

   /* replace1419_0 -> 11 in the cache */
   /* replace1419_1_0 -> 207 in the cache */
   /* replace1419_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 11, 3949 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1420_0_0 -> 435 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 435 },
      -1,
   } },
   /* search1420_1_0 -> 446 in the cache */
   /* search1420_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3957, 3942 },
      -1,
   } },

   /* replace1420_0_0 -> 435 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 435 },
      -1,
   } },
   /* replace1420_1 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3959, 446 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1421_0_0 -> 435 in the cache */
   /* search1421_0 -> 3957 in the cache */
   /* search1421_1_0 -> 446 in the cache */
   /* search1421_1 -> 3942 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3957, 3942 },
      -1,
   } },

   /* replace1421_0_0 -> 435 in the cache */
   /* replace1421_0 -> 3959 in the cache */
   /* replace1421_1 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3959, 446 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1422_0_0 -> 11 in the cache */
   /* search1422_0 -> 1671 in the cache */
   /* search1422_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1671, 33 },
      -1,
   } },

   /* replace1422_0_0 -> 11 in the cache */
   /* replace1422_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 11, 3964 },
      -1,
   } },
   /* replace1422_1_0_0_0 -> 36 in the cache */
   /* replace1422_1_0_0 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3964 },
      -1,
   } },
   /* replace1422_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 3966, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 3965, 3967 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1423_0_0 -> 11 in the cache */
   /* search1423_0 -> 1671 in the cache */
   /* search1423_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1671, 33 },
      -1,
   } },

   /* replace1423_0_0 -> 11 in the cache */
   /* replace1423_0_1_0 -> 36 in the cache */
   /* replace1423_0_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 11, 3964 },
      -1,
   } },
   /* replace1423_1_0_0_0 -> 36 in the cache */
   /* replace1423_1_0_0 -> 3964 in the cache */
   /* replace1423_1_0 -> 3966 in the cache */
   /* replace1423_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 3966, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 3970, 3971 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1424_0_0 -> 11 in the cache */
   /* search1424_0 -> 1671 in the cache */
   /* search1424_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1671, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1424_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3974, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1424_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3976, 36 },
      -1,
   } },
   /* replace1424_1_1_0 -> 11 in the cache */
   /* replace1424_1_1_1_0 -> 36 in the cache */
   /* replace1424_1_1_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 11, 3964 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3977, 3978 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3975, 3979 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1425_0 -> 286 in the cache */
   /* search1425_1_0 -> 207 in the cache */
   /* search1425_1 -> 3947 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 286, 3947 },
      -1,
   } },

   /* replace1425_0_0 -> 16 in the cache */
   /* replace1425_0_1 -> 3976 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 16, 3976 },
      -1,
   } },
   /* replace1425_1_0_0 -> 16 in the cache */
   /* replace1425_1_0_1 -> 3974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 16, 3974 },
      -1,
   } },
   /* replace1425_1_1_0_0 -> 16 in the cache */
   /* replace1425_1_1_0 -> 3779 in the cache */
   /* replace1425_1_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3779, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3983, 3984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3982, 3985 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1426_0_0 -> 11 in the cache */
   /* search1426_0 -> 1671 in the cache */
   /* search1426_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1671, 33 },
      -1,
   } },

   /* replace1426_0_0 -> 3976 in the cache */
   /* replace1426_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3976, 36 },
      -1,
   } },
   /* replace1426_1_0_0 -> 3974 in the cache */
   /* replace1426_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3974, 36 },
      -1,
   } },
   /* replace1426_1_1_0 -> 11 in the cache */
   /* replace1426_1_1_1_0 -> 36 in the cache */
   /* replace1426_1_1_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 11, 3964 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3989, 3990 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3988, 3991 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1427_0 -> 286 in the cache */
   /* search1427_1_0 -> 207 in the cache */
   /* search1427_1 -> 3947 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 286, 3947 },
      -1,
   } },

   /* replace1427_0_0 -> 16 in the cache */
   /* replace1427_0_1 -> 3974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 16, 3974 },
      -1,
   } },
   /* replace1427_1_0_0 -> 16 in the cache */
   /* replace1427_1_0_1 -> 3976 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 16, 3976 },
      -1,
   } },
   /* replace1427_1_1_0_0 -> 16 in the cache */
   /* replace1427_1_1_0 -> 3779 in the cache */
   /* replace1427_1_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3779, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 3995, 3996 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 3994, 3997 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1428_0_0 -> 11 in the cache */
   /* search1428_0 -> 1694 in the cache */
   /* search1428_1_0 -> 1984 in the cache */
   /* search1428_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1694, 3886 },
      -1,
   } },

   /* replace1428_0 -> 11 in the cache */
   /* replace1428_1_0 -> 1984 in the cache */
   /* replace1428_1 -> 3784 in the cache */
   /* replace1428 -> 3935 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1429_0_0 -> 11 in the cache */
   /* search1429_0 -> 1694 in the cache */
   /* search1429_1_0 -> 1984 in the cache */
   /* search1429_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1694, 3886 },
      -1,
   } },

   /* replace1429_0 -> 11 in the cache */
   /* replace1429_1_0 -> 1984 in the cache */
   /* replace1429_1 -> 3784 in the cache */
   /* replace1429 -> 3937 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1430_0_0 -> 11 in the cache */
   /* search1430_0 -> 1694 in the cache */
   /* search1430_1_0 -> 1984 in the cache */
   /* search1430_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1694, 3886 },
      -1,
   } },

   /* replace1430_0 -> 11 in the cache */
   /* replace1430_1_0 -> 1984 in the cache */
   /* replace1430_1 -> 3784 in the cache */
   /* replace1430 -> 3939 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1431_0_0 -> 11 in the cache */
   /* search1431_0 -> 1694 in the cache */
   /* search1431_1_0 -> 1984 in the cache */
   /* search1431_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1694, 3886 },
      -1,
   } },

   /* replace1431_0 -> 11 in the cache */
   /* replace1431_1_0 -> 1984 in the cache */
   /* replace1431_1 -> 3784 in the cache */
   /* replace1431 -> 3941 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1432_0_0 -> 3794 in the cache */
   /* search1432_0 -> 3891 in the cache */
   /* search1432_1_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3891, 4003 },
      -1,
   } },

   /* replace1432_0_0 -> 3794 in the cache */
   /* replace1432_0 -> 3795 in the cache */
   /* replace1432_1 -> 446 in the cache */
   /* replace1432 -> 3944 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1433_0_0 -> 3794 in the cache */
   /* search1433_0 -> 3891 in the cache */
   /* search1433_1_0 -> 446 in the cache */
   /* search1433_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3891, 4003 },
      -1,
   } },

   /* replace1433_0_0 -> 3794 in the cache */
   /* replace1433_0 -> 3795 in the cache */
   /* replace1433_1 -> 446 in the cache */
   /* replace1433 -> 3946 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1434_0_0 -> 11 in the cache */
   /* search1434_0 -> 1694 in the cache */
   /* search1434_1_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1694, 4006 },
      -1,
   } },

   /* replace1434_0 -> 11 in the cache */
   /* replace1434_1_0 -> 207 in the cache */
   /* replace1434_1 -> 3949 in the cache */
   /* replace1434 -> 3950 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1435_0_0 -> 11 in the cache */
   /* search1435_0 -> 1694 in the cache */
   /* search1435_1_0 -> 207 in the cache */
   /* search1435_1 -> 4006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1694, 4006 },
      -1,
   } },

   /* replace1435_0 -> 11 in the cache */
   /* replace1435_1_0 -> 207 in the cache */
   /* replace1435_1 -> 3949 in the cache */
   /* replace1435 -> 3952 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1436_0_0 -> 11 in the cache */
   /* search1436_0 -> 1694 in the cache */
   /* search1436_1_0 -> 207 in the cache */
   /* search1436_1 -> 4006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1694, 4006 },
      -1,
   } },

   /* replace1436_0 -> 11 in the cache */
   /* replace1436_1_0 -> 207 in the cache */
   /* replace1436_1 -> 3949 in the cache */
   /* replace1436 -> 3954 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1437_0_0 -> 11 in the cache */
   /* search1437_0 -> 1694 in the cache */
   /* search1437_1_0 -> 207 in the cache */
   /* search1437_1 -> 4006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1694, 4006 },
      -1,
   } },

   /* replace1437_0 -> 11 in the cache */
   /* replace1437_1_0 -> 207 in the cache */
   /* replace1437_1 -> 3949 in the cache */
   /* replace1437 -> 3956 in the cache */

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1438_0_0 -> 435 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 435 },
      -1,
   } },
   /* search1438_1_0 -> 446 in the cache */
   /* search1438_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4011, 4003 },
      -1,
   } },

   /* replace1438_0_0 -> 435 in the cache */
   /* replace1438_0 -> 3959 in the cache */
   /* replace1438_1 -> 446 in the cache */
   /* replace1438 -> 3960 in the cache */

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1439_0_0 -> 435 in the cache */
   /* search1439_0 -> 4011 in the cache */
   /* search1439_1_0 -> 446 in the cache */
   /* search1439_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4011, 4003 },
      -1,
   } },

   /* replace1439_0_0 -> 435 in the cache */
   /* replace1439_0 -> 3959 in the cache */
   /* replace1439_1 -> 446 in the cache */
   /* replace1439 -> 3962 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1440_0_0 -> 11 in the cache */
   /* search1440_0 -> 1694 in the cache */
   /* search1440_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1694, 3895 },
      -1,
   } },

   /* replace1440_0_0 -> 11 in the cache */
   /* replace1440_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 11, 4015 },
      -1,
   } },
   /* replace1440_1_0_0_0 -> 41 in the cache */
   /* replace1440_1_0_0 -> 4015 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 4015 },
      -1,
   } },
   /* replace1440_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 4017, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 4016, 4018 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1441_0_0 -> 11 in the cache */
   /* search1441_0 -> 1694 in the cache */
   /* search1441_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1694, 3895 },
      -1,
   } },

   /* replace1441_0_0 -> 11 in the cache */
   /* replace1441_0_1_0 -> 41 in the cache */
   /* replace1441_0_1 -> 4015 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 11, 4015 },
      -1,
   } },
   /* replace1441_1_0_0_0 -> 41 in the cache */
   /* replace1441_1_0_0 -> 4015 in the cache */
   /* replace1441_1_0 -> 4017 in the cache */
   /* replace1441_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 4017, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 4021, 4022 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1442_0_0 -> 11 in the cache */
   /* search1442_0 -> 1694 in the cache */
   /* search1442_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1694, 3895 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1442_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4025, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1442_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4027, 41 },
      -1,
   } },
   /* replace1442_1_1_0 -> 11 in the cache */
   /* replace1442_1_1_1_0 -> 41 in the cache */
   /* replace1442_1_1_1 -> 4015 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 11, 4015 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4028, 4029 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4026, 4030 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1443_0 -> 3914 in the cache */
   /* search1443_1_0 -> 207 in the cache */
   /* search1443_1 -> 4006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3914, 4006 },
      -1,
   } },

   /* replace1443_0_0 -> 21 in the cache */
   /* replace1443_0_1 -> 4027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 21, 4027 },
      -1,
   } },
   /* replace1443_1_0_0 -> 21 in the cache */
   /* replace1443_1_0_1 -> 4025 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 21, 4025 },
      -1,
   } },
   /* replace1443_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1443_1_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4035, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4034, 4036 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4033, 4037 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1444_0_0 -> 11 in the cache */
   /* search1444_0 -> 1694 in the cache */
   /* search1444_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1694, 3895 },
      -1,
   } },

   /* replace1444_0_0 -> 4027 in the cache */
   /* replace1444_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4027, 41 },
      -1,
   } },
   /* replace1444_1_0_0 -> 4025 in the cache */
   /* replace1444_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4025, 41 },
      -1,
   } },
   /* replace1444_1_1_0 -> 11 in the cache */
   /* replace1444_1_1_1_0 -> 41 in the cache */
   /* replace1444_1_1_1 -> 4015 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 11, 4015 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4041, 4042 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4040, 4043 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1445_0 -> 3914 in the cache */
   /* search1445_1_0 -> 207 in the cache */
   /* search1445_1 -> 4006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3914, 4006 },
      -1,
   } },

   /* replace1445_0_0 -> 21 in the cache */
   /* replace1445_0_1 -> 4025 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 21, 4025 },
      -1,
   } },
   /* replace1445_1_0_0 -> 21 in the cache */
   /* replace1445_1_0_1 -> 4027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 21, 4027 },
      -1,
   } },
   /* replace1445_1_1_0_0 -> 21 in the cache */
   /* replace1445_1_1_0 -> 4035 in the cache */
   /* replace1445_1_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4035, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4047, 4048 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4046, 4049 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1446_0_0 -> 16 in the cache */
   /* search1446_0 -> 1778 in the cache */
   /* search1446_1_0 -> 1984 in the cache */
   /* search1446_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1778, 3886 },
      -1,
   } },

   /* replace1446_0 -> 16 in the cache */
   /* replace1446_1_0 -> 1984 in the cache */
   /* replace1446_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 16, 3841 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1447_0_0 -> 16 in the cache */
   /* search1447_0 -> 1778 in the cache */
   /* search1447_1_0 -> 1984 in the cache */
   /* search1447_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1778, 3886 },
      -1,
   } },

   /* replace1447_0 -> 16 in the cache */
   /* replace1447_1_0 -> 1984 in the cache */
   /* replace1447_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 16, 3841 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1448_0_0 -> 16 in the cache */
   /* search1448_0 -> 1778 in the cache */
   /* search1448_1_0 -> 1984 in the cache */
   /* search1448_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1778, 3886 },
      -1,
   } },

   /* replace1448_0 -> 16 in the cache */
   /* replace1448_1_0 -> 1984 in the cache */
   /* replace1448_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 16, 3841 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1449_0_0 -> 16 in the cache */
   /* search1449_0 -> 1778 in the cache */
   /* search1449_1_0 -> 1984 in the cache */
   /* search1449_1 -> 3886 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1778, 3886 },
      -1,
   } },

   /* replace1449_0 -> 16 in the cache */
   /* replace1449_1_0 -> 1984 in the cache */
   /* replace1449_1 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 16, 3841 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1450_0_0 -> 3794 in the cache */
   /* search1450_0 -> 3891 in the cache */
   /* search1450_1_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3891, 4059 },
      -1,
   } },

   /* replace1450_0_0 -> 3794 in the cache */
   /* replace1450_0 -> 3846 in the cache */
   /* replace1450_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3846, 517 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1451_0_0 -> 3794 in the cache */
   /* search1451_0 -> 3891 in the cache */
   /* search1451_1_0 -> 517 in the cache */
   /* search1451_1 -> 4059 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3891, 4059 },
      -1,
   } },

   /* replace1451_0_0 -> 3794 in the cache */
   /* replace1451_0 -> 3846 in the cache */
   /* replace1451_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3846, 517 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1452_0_0 -> 16 in the cache */
   /* search1452_0 -> 1778 in the cache */
   /* search1452_1_0 -> 207 in the cache */
   /* search1452_1 -> 4006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1778, 4006 },
      -1,
   } },

   /* replace1452_0 -> 16 in the cache */
   /* replace1452_1_0 -> 207 in the cache */
   /* replace1452_1 -> 3947 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 16, 3947 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1453_0_0 -> 16 in the cache */
   /* search1453_0 -> 1778 in the cache */
   /* search1453_1_0 -> 207 in the cache */
   /* search1453_1 -> 4006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1778, 4006 },
      -1,
   } },

   /* replace1453_0 -> 16 in the cache */
   /* replace1453_1_0 -> 207 in the cache */
   /* replace1453_1 -> 3947 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 16, 3947 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1454_0_0 -> 16 in the cache */
   /* search1454_0 -> 1778 in the cache */
   /* search1454_1_0 -> 207 in the cache */
   /* search1454_1 -> 4006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1778, 4006 },
      -1,
   } },

   /* replace1454_0 -> 16 in the cache */
   /* replace1454_1_0 -> 207 in the cache */
   /* replace1454_1 -> 3947 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 16, 3947 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1455_0_0 -> 16 in the cache */
   /* search1455_0 -> 1778 in the cache */
   /* search1455_1_0 -> 207 in the cache */
   /* search1455_1 -> 4006 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1778, 4006 },
      -1,
   } },

   /* replace1455_0 -> 16 in the cache */
   /* replace1455_1_0 -> 207 in the cache */
   /* replace1455_1 -> 3947 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 16, 3947 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1456_0_0 -> 435 in the cache */
   /* search1456_0 -> 4011 in the cache */
   /* search1456_1_0 -> 517 in the cache */
   /* search1456_1 -> 4059 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4011, 4059 },
      -1,
   } },

   /* replace1456_0_0 -> 435 in the cache */
   /* replace1456_0 -> 3957 in the cache */
   /* replace1456_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3957, 517 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1457_0_0 -> 435 in the cache */
   /* search1457_0 -> 4011 in the cache */
   /* search1457_1_0 -> 517 in the cache */
   /* search1457_1 -> 4059 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4011, 4059 },
      -1,
   } },

   /* replace1457_0_0 -> 435 in the cache */
   /* replace1457_0 -> 3957 in the cache */
   /* replace1457_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3957, 517 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1458_0_0 -> 16 in the cache */
   /* search1458_0 -> 1778 in the cache */
   /* search1458_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1778, 4076 },
      -1,
   } },

   /* replace1458_0 -> 16 in the cache */
   /* replace1458_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 16, 4078 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1459_0_0 -> 16 in the cache */
   /* search1459_0 -> 1778 in the cache */
   /* search1459_1_0 -> 36 in the cache */
   /* search1459_1 -> 4076 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1778, 4076 },
      -1,
   } },

   /* replace1459_0 -> 16 in the cache */
   /* replace1459_1_0 -> 36 in the cache */
   /* replace1459_1 -> 4078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 16, 4078 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1460_0_0 -> 16 in the cache */
   /* search1460_0 -> 1778 in the cache */
   /* search1460_1_0 -> 36 in the cache */
   /* search1460_1 -> 4076 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1778, 4076 },
      -1,
   } },

   /* replace1460_0 -> 16 in the cache */
   /* replace1460_1_0 -> 36 in the cache */
   /* replace1460_1 -> 4078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 16, 4078 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1461_0_0 -> 16 in the cache */
   /* search1461_0 -> 1778 in the cache */
   /* search1461_1_0 -> 36 in the cache */
   /* search1461_1 -> 4076 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1778, 4076 },
      -1,
   } },

   /* replace1461_0 -> 16 in the cache */
   /* replace1461_1_0 -> 36 in the cache */
   /* replace1461_1 -> 4078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 16, 4078 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1462_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 507 },
      -1,
   } },
   /* search1462_1_0 -> 517 in the cache */
   /* search1462_1 -> 4059 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4086, 4059 },
      -1,
   } },

   /* replace1462_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 507 },
      -1,
   } },
   /* replace1462_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4088, 517 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1463_0_0 -> 507 in the cache */
   /* search1463_0 -> 4086 in the cache */
   /* search1463_1_0 -> 517 in the cache */
   /* search1463_1 -> 4059 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4086, 4059 },
      -1,
   } },

   /* replace1463_0_0 -> 507 in the cache */
   /* replace1463_0 -> 4088 in the cache */
   /* replace1463_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4088, 517 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1464_0_0 -> 16 in the cache */
   /* search1464_0 -> 1778 in the cache */
   /* search1464_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1778, 3895 },
      -1,
   } },

   /* replace1464_0_0 -> 16 in the cache */
   /* replace1464_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 16, 4093 },
      -1,
   } },
   /* replace1464_1_0_0_0 -> 41 in the cache */
   /* replace1464_1_0_0 -> 4093 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_i2i64,
      -1, 0,
      { 4093 },
      -1,
   } },
   /* replace1464_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 4095, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 4094, 4096 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1465_0_0 -> 16 in the cache */
   /* search1465_0 -> 1778 in the cache */
   /* search1465_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1778, 3895 },
      -1,
   } },

   /* replace1465_0_0 -> 16 in the cache */
   /* replace1465_0_1_0 -> 41 in the cache */
   /* replace1465_0_1 -> 4093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 16, 4093 },
      -1,
   } },
   /* replace1465_1_0_0_0 -> 41 in the cache */
   /* replace1465_1_0_0 -> 4093 in the cache */
   /* replace1465_1_0 -> 4095 in the cache */
   /* replace1465_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 4095, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 4099, 4100 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b')))) */
   /* search1466_0_0 -> 16 in the cache */
   /* search1466_0 -> 1778 in the cache */
   /* search1466_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 1778, 3895 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80000000 /* -2147483648 */ },
   } },
   /* replace1466_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4103, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   /* replace1466_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4105, 41 },
      -1,
   } },
   /* replace1466_1_1_0 -> 16 in the cache */
   /* replace1466_1_1_1_0 -> 41 in the cache */
   /* replace1466_1_1_1 -> 4093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 16, 4093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4106, 4107 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4104, 4108 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b'))) */
   /* search1467_0 -> 3914 in the cache */
   /* search1467_1_0 -> 36 in the cache */
   /* search1467_1 -> 4076 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 3914, 4076 },
      -1,
   } },

   /* replace1467_0_0 -> 21 in the cache */
   /* replace1467_0_1 -> 4105 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 21, 4105 },
      -1,
   } },
   /* replace1467_1_0_0 -> 21 in the cache */
   /* replace1467_1_0_1 -> 4103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 21, 4103 },
      -1,
   } },
   /* replace1467_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1467_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4113, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4112, 4114 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4111, 4115 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b')))) */
   /* search1468_0_0 -> 16 in the cache */
   /* search1468_0 -> 1778 in the cache */
   /* search1468_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 1778, 3895 },
      -1,
   } },

   /* replace1468_0_0 -> 4105 in the cache */
   /* replace1468_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4105, 41 },
      -1,
   } },
   /* replace1468_1_0_0 -> 4103 in the cache */
   /* replace1468_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4103, 41 },
      -1,
   } },
   /* replace1468_1_1_0 -> 16 in the cache */
   /* replace1468_1_1_1_0 -> 41 in the cache */
   /* replace1468_1_1_1 -> 4093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 16, 4093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4119, 4120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4118, 4121 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b'))) */
   /* search1469_0 -> 3914 in the cache */
   /* search1469_1_0 -> 36 in the cache */
   /* search1469_1 -> 4076 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 3914, 4076 },
      -1,
   } },

   /* replace1469_0_0 -> 21 in the cache */
   /* replace1469_0_1 -> 4103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 21, 4103 },
      -1,
   } },
   /* replace1469_1_0_0 -> 21 in the cache */
   /* replace1469_1_0_1 -> 4105 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 21, 4105 },
      -1,
   } },
   /* replace1469_1_1_0_0 -> 21 in the cache */
   /* replace1469_1_1_0 -> 4113 in the cache */
   /* replace1469_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4113, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4125, 4126 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4124, 4127 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1470_0_0 -> 6 in the cache */
   /* search1470_0 -> 3724 in the cache */
   /* search1470_1_0 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3724, 4129 },
      -1,
   } },

   /* replace1470_0 -> 6 in the cache */
   /* replace1470_1_0 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 6, 4131 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1471_0_0 -> 6 in the cache */
   /* search1471_0 -> 3724 in the cache */
   /* search1471_1_0 -> 1984 in the cache */
   /* search1471_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3724, 4129 },
      -1,
   } },

   /* replace1471_0 -> 6 in the cache */
   /* replace1471_1_0 -> 1984 in the cache */
   /* replace1471_1 -> 4131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 6, 4131 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1472_0_0 -> 6 in the cache */
   /* search1472_0 -> 3724 in the cache */
   /* search1472_1_0 -> 1984 in the cache */
   /* search1472_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 3724, 4129 },
      -1,
   } },

   /* replace1472_0 -> 6 in the cache */
   /* replace1472_1_0 -> 1984 in the cache */
   /* replace1472_1 -> 4131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 6, 4131 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1473_0_0 -> 6 in the cache */
   /* search1473_0 -> 3724 in the cache */
   /* search1473_1_0 -> 1984 in the cache */
   /* search1473_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 3724, 4129 },
      -1,
   } },

   /* replace1473_0 -> 6 in the cache */
   /* replace1473_1_0 -> 1984 in the cache */
   /* replace1473_1 -> 4131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 6, 4131 },
      -1,
   } },

   /* ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1474_0_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 3794 },
      -1,
   } },
   /* search1474_1_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 3796 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4139, 4140 },
      -1,
   } },

   /* replace1474_0_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 3794 },
      -1,
   } },
   /* replace1474_1 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4142, 3796 },
      -1,
   } },

   /* ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1475_0_0 -> 3794 in the cache */
   /* search1475_0 -> 4139 in the cache */
   /* search1475_1_0 -> 3796 in the cache */
   /* search1475_1 -> 4140 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4139, 4140 },
      -1,
   } },

   /* replace1475_0_0 -> 3794 in the cache */
   /* replace1475_0 -> 4142 in the cache */
   /* replace1475_1 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4142, 3796 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1476_0_0 -> 6 in the cache */
   /* search1476_0 -> 3724 in the cache */
   /* search1476_1 -> 1883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3724, 1883 },
      -1,
   } },

   /* replace1476_0_0 -> 6 in the cache */
   /* replace1476_0_1_0 -> 207 in the cache */
   /* replace1476_0_1 -> 1891 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 6, 1891 },
      -1,
   } },
   /* replace1476_1_0_0_0 -> 207 in the cache */
   /* replace1476_1_0_0 -> 1891 in the cache */
   /* replace1476_1_0 -> 1892 in the cache */
   /* replace1476_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 1892, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 4147, 4148 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1477_0_0 -> 6 in the cache */
   /* search1477_0 -> 3724 in the cache */
   /* search1477_1 -> 1883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3724, 1883 },
      -1,
   } },

   /* replace1477_0_0 -> 6 in the cache */
   /* replace1477_0_1_0 -> 207 in the cache */
   /* replace1477_0_1 -> 1891 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 6, 1891 },
      -1,
   } },
   /* replace1477_1_0_0_0 -> 207 in the cache */
   /* replace1477_1_0_0 -> 1891 in the cache */
   /* replace1477_1_0 -> 1892 in the cache */
   /* replace1477_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 1892, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 4151, 4152 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1478_0_0 -> 6 in the cache */
   /* search1478_0 -> 3724 in the cache */
   /* search1478_1 -> 1883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 3724, 1883 },
      -1,
   } },

   /* replace1478_0_0 -> 748 in the cache */
   /* replace1478_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 748, 207 },
      -1,
   } },
   /* replace1478_1_0_0 -> 1885 in the cache */
   /* replace1478_1_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1885, 207 },
      -1,
   } },
   /* replace1478_1_1_0 -> 6 in the cache */
   /* replace1478_1_1_1_0 -> 207 in the cache */
   /* replace1478_1_1_1 -> 1891 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 6, 1891 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4156, 4157 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4155, 4158 },
      -1,
   } },

   /* ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1479_0 -> 3821 in the cache */
   /* search1479_1_0 -> 1984 in the cache */
   /* search1479_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 3821, 4129 },
      -1,
   } },

   /* replace1479_0_0 -> 11 in the cache */
   /* replace1479_0_1 -> 1885 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 11, 1885 },
      -1,
   } },
   /* replace1479_1_0_0 -> 11 in the cache */
   /* replace1479_1_0_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 11, 748 },
      -1,
   } },
   /* replace1479_1_1_0_0 -> 11 in the cache */
   /* replace1479_1_1_0 -> 1881 in the cache */
   /* replace1479_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1881, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4162, 4163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4161, 4164 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1480_0_0 -> 6 in the cache */
   /* search1480_0 -> 3724 in the cache */
   /* search1480_1 -> 1883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 3724, 1883 },
      -1,
   } },

   /* replace1480_0_0 -> 1885 in the cache */
   /* replace1480_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1885, 207 },
      -1,
   } },
   /* replace1480_1_0_0 -> 748 in the cache */
   /* replace1480_1_0_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 748, 207 },
      -1,
   } },
   /* replace1480_1_1_0 -> 6 in the cache */
   /* replace1480_1_1_1_0 -> 207 in the cache */
   /* replace1480_1_1_1 -> 1891 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 6, 1891 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4168, 4169 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4167, 4170 },
      -1,
   } },

   /* ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1481_0 -> 3821 in the cache */
   /* search1481_1_0 -> 1984 in the cache */
   /* search1481_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 3821, 4129 },
      -1,
   } },

   /* replace1481_0_0 -> 11 in the cache */
   /* replace1481_0_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 11, 748 },
      -1,
   } },
   /* replace1481_1_0_0 -> 11 in the cache */
   /* replace1481_1_0_1 -> 1885 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 11, 1885 },
      -1,
   } },
   /* replace1481_1_1_0_0 -> 11 in the cache */
   /* replace1481_1_1_0 -> 1881 in the cache */
   /* replace1481_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1881, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4174, 4175 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4173, 4176 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1482_0_0 -> 6 in the cache */
   /* search1482_0 -> 2891 in the cache */
   /* search1482_1_0 -> 1984 in the cache */
   /* search1482_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 2891, 2893 },
      -1,
   } },

   /* replace1482_0 -> 6 in the cache */
   /* replace1482_1_0 -> 1984 in the cache */
   /* replace1482_1 -> 4131 in the cache */
   /* replace1482 -> 4132 in the cache */

   /* ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1483_0_0 -> 6 in the cache */
   /* search1483_0 -> 2891 in the cache */
   /* search1483_1_0 -> 1984 in the cache */
   /* search1483_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 2891, 2893 },
      -1,
   } },

   /* replace1483_0 -> 6 in the cache */
   /* replace1483_1_0 -> 1984 in the cache */
   /* replace1483_1 -> 4131 in the cache */
   /* replace1483 -> 4134 in the cache */

   /* ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1484_0_0 -> 6 in the cache */
   /* search1484_0 -> 2891 in the cache */
   /* search1484_1_0 -> 1984 in the cache */
   /* search1484_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 2891, 2893 },
      -1,
   } },

   /* replace1484_0 -> 6 in the cache */
   /* replace1484_1_0 -> 1984 in the cache */
   /* replace1484_1 -> 4131 in the cache */
   /* replace1484 -> 4136 in the cache */

   /* ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1485_0_0 -> 6 in the cache */
   /* search1485_0 -> 2891 in the cache */
   /* search1485_1_0 -> 1984 in the cache */
   /* search1485_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 2891, 2893 },
      -1,
   } },

   /* replace1485_0 -> 6 in the cache */
   /* replace1485_1_0 -> 1984 in the cache */
   /* replace1485_1 -> 4131 in the cache */
   /* replace1485 -> 4138 in the cache */

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1486_0_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3794 },
      -1,
   } },
   /* search1486_1_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3796 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4182, 4183 },
      -1,
   } },

   /* replace1486_0_0 -> 3794 in the cache */
   /* replace1486_0 -> 4142 in the cache */
   /* replace1486_1 -> 3796 in the cache */
   /* replace1486 -> 4143 in the cache */

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1487_0_0 -> 3794 in the cache */
   /* search1487_0 -> 4182 in the cache */
   /* search1487_1_0 -> 3796 in the cache */
   /* search1487_1 -> 4183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4182, 4183 },
      -1,
   } },

   /* replace1487_0_0 -> 3794 in the cache */
   /* replace1487_0 -> 4142 in the cache */
   /* replace1487_1 -> 3796 in the cache */
   /* replace1487 -> 4145 in the cache */

   /* ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1488_0_0 -> 6 in the cache */
   /* search1488_0 -> 2891 in the cache */
   /* search1488_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 2891, 33 },
      -1,
   } },

   /* replace1488_0_0 -> 6 in the cache */
   /* replace1488_0_1_0 -> 36 in the cache */
   /* replace1488_0_1 -> 1899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 6, 1899 },
      -1,
   } },
   /* replace1488_1_0_0_0 -> 36 in the cache */
   /* replace1488_1_0_0 -> 1899 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 1899 },
      -1,
   } },
   /* replace1488_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 4188, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 4187, 4189 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1489_0_0 -> 6 in the cache */
   /* search1489_0 -> 2891 in the cache */
   /* search1489_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 2891, 33 },
      -1,
   } },

   /* replace1489_0_0 -> 6 in the cache */
   /* replace1489_0_1_0 -> 36 in the cache */
   /* replace1489_0_1 -> 1899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 6, 1899 },
      -1,
   } },
   /* replace1489_1_0_0_0 -> 36 in the cache */
   /* replace1489_1_0_0 -> 1899 in the cache */
   /* replace1489_1_0 -> 4188 in the cache */
   /* replace1489_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 4188, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 4192, 4193 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1490_0_0 -> 6 in the cache */
   /* search1490_0 -> 2891 in the cache */
   /* search1490_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 2891, 33 },
      -1,
   } },

   /* replace1490_0_0 -> 120 in the cache */
   /* replace1490_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   /* replace1490_1_0_0 -> 718 in the cache */
   /* replace1490_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 718, 36 },
      -1,
   } },
   /* replace1490_1_1_0 -> 6 in the cache */
   /* replace1490_1_1_1_0 -> 36 in the cache */
   /* replace1490_1_1_1 -> 1899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 6, 1899 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4197, 4198 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4196, 4199 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1491_0 -> 286 in the cache */
   /* search1491_1_0 -> 1984 in the cache */
   /* search1491_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 286, 2893 },
      -1,
   } },

   /* replace1491_0_0 -> 16 in the cache */
   /* replace1491_0_1 -> 718 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 16, 718 },
      -1,
   } },
   /* replace1491_1_0_0 -> 16 in the cache */
   /* replace1491_1_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace1491_1_1_0_0 -> 16 in the cache */
   /* replace1491_1_1_0 -> 1897 in the cache */
   /* replace1491_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1897, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4203, 4204 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4202, 4205 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1492_0_0 -> 6 in the cache */
   /* search1492_0 -> 2891 in the cache */
   /* search1492_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 2891, 33 },
      -1,
   } },

   /* replace1492_0_0 -> 718 in the cache */
   /* replace1492_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 718, 36 },
      -1,
   } },
   /* replace1492_1_0_0 -> 120 in the cache */
   /* replace1492_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   /* replace1492_1_1_0 -> 6 in the cache */
   /* replace1492_1_1_1_0 -> 36 in the cache */
   /* replace1492_1_1_1 -> 1899 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 6, 1899 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4209, 4210 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4208, 4211 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1493_0 -> 286 in the cache */
   /* search1493_1_0 -> 1984 in the cache */
   /* search1493_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 286, 2893 },
      -1,
   } },

   /* replace1493_0_0 -> 16 in the cache */
   /* replace1493_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace1493_1_0_0 -> 16 in the cache */
   /* replace1493_1_0_1 -> 718 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 16, 718 },
      -1,
   } },
   /* replace1493_1_1_0_0 -> 16 in the cache */
   /* replace1493_1_1_0 -> 1897 in the cache */
   /* replace1493_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1897, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4215, 4216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4214, 4217 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1494_0_0 -> 6 in the cache */
   /* search1494_0 -> 3761 in the cache */
   /* search1494_1_0 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3761, 4219 },
      -1,
   } },

   /* replace1494_0 -> 6 in the cache */
   /* replace1494_1_0 -> 1984 in the cache */
   /* replace1494_1 -> 4131 in the cache */
   /* replace1494 -> 4132 in the cache */

   /* ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1495_0_0 -> 6 in the cache */
   /* search1495_0 -> 3761 in the cache */
   /* search1495_1_0 -> 1984 in the cache */
   /* search1495_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3761, 4219 },
      -1,
   } },

   /* replace1495_0 -> 6 in the cache */
   /* replace1495_1_0 -> 1984 in the cache */
   /* replace1495_1 -> 4131 in the cache */
   /* replace1495 -> 4134 in the cache */

   /* ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1496_0_0 -> 6 in the cache */
   /* search1496_0 -> 3761 in the cache */
   /* search1496_1_0 -> 1984 in the cache */
   /* search1496_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 3761, 4219 },
      -1,
   } },

   /* replace1496_0 -> 6 in the cache */
   /* replace1496_1_0 -> 1984 in the cache */
   /* replace1496_1 -> 4131 in the cache */
   /* replace1496 -> 4136 in the cache */

   /* ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1497_0_0 -> 6 in the cache */
   /* search1497_0 -> 3761 in the cache */
   /* search1497_1_0 -> 1984 in the cache */
   /* search1497_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 3761, 4219 },
      -1,
   } },

   /* replace1497_0 -> 6 in the cache */
   /* replace1497_1_0 -> 1984 in the cache */
   /* replace1497_1 -> 4131 in the cache */
   /* replace1497 -> 4138 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1498_0_0 -> 3794 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 3794 },
      -1,
   } },
   /* search1498_1_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 3796 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4224, 4225 },
      -1,
   } },

   /* replace1498_0_0 -> 3794 in the cache */
   /* replace1498_0 -> 4142 in the cache */
   /* replace1498_1 -> 3796 in the cache */
   /* replace1498 -> 4143 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1499_0_0 -> 3794 in the cache */
   /* search1499_0 -> 4224 in the cache */
   /* search1499_1_0 -> 3796 in the cache */
   /* search1499_1 -> 4225 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4224, 4225 },
      -1,
   } },

   /* replace1499_0_0 -> 3794 in the cache */
   /* replace1499_0 -> 4142 in the cache */
   /* replace1499_1 -> 3796 in the cache */
   /* replace1499 -> 4145 in the cache */

   /* ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1500_0_0 -> 6 in the cache */
   /* search1500_0 -> 3761 in the cache */
   /* search1500_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 3761, 3895 },
      -1,
   } },

   /* replace1500_0_0 -> 6 in the cache */
   /* replace1500_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 6, 4229 },
      -1,
   } },
   /* replace1500_1_0_0_0 -> 41 in the cache */
   /* replace1500_1_0_0 -> 4229 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 4229 },
      -1,
   } },
   /* replace1500_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 4231, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 4230, 4232 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1501_0_0 -> 6 in the cache */
   /* search1501_0 -> 3761 in the cache */
   /* search1501_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 3761, 3895 },
      -1,
   } },

   /* replace1501_0_0 -> 6 in the cache */
   /* replace1501_0_1_0 -> 41 in the cache */
   /* replace1501_0_1 -> 4229 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 6, 4229 },
      -1,
   } },
   /* replace1501_1_0_0_0 -> 41 in the cache */
   /* replace1501_1_0_0 -> 4229 in the cache */
   /* replace1501_1_0 -> 4231 in the cache */
   /* replace1501_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 4231, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 4235, 4236 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1502_0_0 -> 6 in the cache */
   /* search1502_0 -> 3761 in the cache */
   /* search1502_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 3761, 3895 },
      -1,
   } },

   /* replace1502_0_0 -> 791 in the cache */
   /* replace1502_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 791, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace1502_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4240, 41 },
      -1,
   } },
   /* replace1502_1_1_0 -> 6 in the cache */
   /* replace1502_1_1_1_0 -> 41 in the cache */
   /* replace1502_1_1_1 -> 4229 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 6, 4229 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4241, 4242 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4239, 4243 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1503_0 -> 3914 in the cache */
   /* search1503_1_0 -> 1984 in the cache */
   /* search1503_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 3914, 4219 },
      -1,
   } },

   /* replace1503_0_0 -> 21 in the cache */
   /* replace1503_0_1 -> 4240 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 21, 4240 },
      -1,
   } },
   /* replace1503_1_0_0 -> 21 in the cache */
   /* replace1503_1_0_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 21, 791 },
      -1,
   } },
   /* replace1503_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1503_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4248, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4247, 4249 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4246, 4250 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1504_0_0 -> 6 in the cache */
   /* search1504_0 -> 3761 in the cache */
   /* search1504_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 3761, 3895 },
      -1,
   } },

   /* replace1504_0_0 -> 4240 in the cache */
   /* replace1504_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4240, 41 },
      -1,
   } },
   /* replace1504_1_0_0 -> 791 in the cache */
   /* replace1504_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 791, 41 },
      -1,
   } },
   /* replace1504_1_1_0 -> 6 in the cache */
   /* replace1504_1_1_1_0 -> 41 in the cache */
   /* replace1504_1_1_1 -> 4229 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 6, 4229 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4254, 4255 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4253, 4256 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1505_0 -> 3914 in the cache */
   /* search1505_1_0 -> 1984 in the cache */
   /* search1505_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 3914, 4219 },
      -1,
   } },

   /* replace1505_0_0 -> 21 in the cache */
   /* replace1505_0_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 21, 791 },
      -1,
   } },
   /* replace1505_1_0_0 -> 21 in the cache */
   /* replace1505_1_0_1 -> 4240 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 21, 4240 },
      -1,
   } },
   /* replace1505_1_1_0_0 -> 21 in the cache */
   /* replace1505_1_1_0 -> 4248 in the cache */
   /* replace1505_1_1_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4248, 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4260, 4261 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4259, 4262 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1506_0_0 -> 11 in the cache */
   /* search1506_0 -> 1673 in the cache */
   /* search1506_1_0 -> 1984 in the cache */
   /* search1506_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1673, 2893 },
      -1,
   } },

   /* replace1506_0 -> 11 in the cache */
   /* replace1506_1_0 -> 1984 in the cache */
   /* replace1506_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 11, 4129 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1507_0_0 -> 11 in the cache */
   /* search1507_0 -> 1673 in the cache */
   /* search1507_1_0 -> 1984 in the cache */
   /* search1507_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1673, 2893 },
      -1,
   } },

   /* replace1507_0 -> 11 in the cache */
   /* replace1507_1_0 -> 1984 in the cache */
   /* replace1507_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 11, 4129 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1508_0_0 -> 11 in the cache */
   /* search1508_0 -> 1673 in the cache */
   /* search1508_1_0 -> 1984 in the cache */
   /* search1508_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1673, 2893 },
      -1,
   } },

   /* replace1508_0 -> 11 in the cache */
   /* replace1508_1_0 -> 1984 in the cache */
   /* replace1508_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 11, 4129 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1509_0_0 -> 11 in the cache */
   /* search1509_0 -> 1673 in the cache */
   /* search1509_1_0 -> 1984 in the cache */
   /* search1509_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1673, 2893 },
      -1,
   } },

   /* replace1509_0 -> 11 in the cache */
   /* replace1509_1_0 -> 1984 in the cache */
   /* replace1509_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 11, 4129 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1510_0_0 -> 3794 in the cache */
   /* search1510_0 -> 4182 in the cache */
   /* search1510_1_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4182, 4272 },
      -1,
   } },

   /* replace1510_0_0 -> 3794 in the cache */
   /* replace1510_0 -> 4139 in the cache */
   /* replace1510_1 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4139, 446 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1511_0_0 -> 3794 in the cache */
   /* search1511_0 -> 4182 in the cache */
   /* search1511_1_0 -> 446 in the cache */
   /* search1511_1 -> 4272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4182, 4272 },
      -1,
   } },

   /* replace1511_0_0 -> 3794 in the cache */
   /* replace1511_0 -> 4139 in the cache */
   /* replace1511_1 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4139, 446 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1512_0_0 -> 11 in the cache */
   /* search1512_0 -> 1673 in the cache */
   /* search1512_1_0 -> 207 in the cache */
   /* search1512_1 -> 2913 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1673, 2913 },
      -1,
   } },

   /* replace1512_0 -> 11 in the cache */
   /* replace1512_1_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 11, 4278 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1513_0_0 -> 11 in the cache */
   /* search1513_0 -> 1673 in the cache */
   /* search1513_1_0 -> 207 in the cache */
   /* search1513_1 -> 2913 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1673, 2913 },
      -1,
   } },

   /* replace1513_0 -> 11 in the cache */
   /* replace1513_1_0 -> 207 in the cache */
   /* replace1513_1 -> 4278 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 11, 4278 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1514_0_0 -> 11 in the cache */
   /* search1514_0 -> 1673 in the cache */
   /* search1514_1_0 -> 207 in the cache */
   /* search1514_1 -> 2913 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1673, 2913 },
      -1,
   } },

   /* replace1514_0 -> 11 in the cache */
   /* replace1514_1_0 -> 207 in the cache */
   /* replace1514_1 -> 4278 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 11, 4278 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1515_0_0 -> 11 in the cache */
   /* search1515_0 -> 1673 in the cache */
   /* search1515_1_0 -> 207 in the cache */
   /* search1515_1 -> 2913 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1673, 2913 },
      -1,
   } },

   /* replace1515_0 -> 11 in the cache */
   /* replace1515_1_0 -> 207 in the cache */
   /* replace1515_1 -> 4278 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 11, 4278 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1516_0_0 -> 435 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 435 },
      -1,
   } },
   /* search1516_1_0 -> 446 in the cache */
   /* search1516_1 -> 4272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4286, 4272 },
      -1,
   } },

   /* replace1516_0_0 -> 435 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 435 },
      -1,
   } },
   /* replace1516_1 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4288, 446 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1517_0_0 -> 435 in the cache */
   /* search1517_0 -> 4286 in the cache */
   /* search1517_1_0 -> 446 in the cache */
   /* search1517_1 -> 4272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4286, 4272 },
      -1,
   } },

   /* replace1517_0_0 -> 435 in the cache */
   /* replace1517_0 -> 4288 in the cache */
   /* replace1517_1 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4288, 446 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1518_0_0 -> 11 in the cache */
   /* search1518_0 -> 1673 in the cache */
   /* search1518_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1673, 33 },
      -1,
   } },

   /* replace1518_0_0 -> 11 in the cache */
   /* replace1518_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 11, 4293 },
      -1,
   } },
   /* replace1518_1_0_0_0 -> 36 in the cache */
   /* replace1518_1_0_0 -> 4293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 4293 },
      -1,
   } },
   /* replace1518_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 4295, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 4294, 4296 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1519_0_0 -> 11 in the cache */
   /* search1519_0 -> 1673 in the cache */
   /* search1519_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1673, 33 },
      -1,
   } },

   /* replace1519_0_0 -> 11 in the cache */
   /* replace1519_0_1_0 -> 36 in the cache */
   /* replace1519_0_1 -> 4293 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 11, 4293 },
      -1,
   } },
   /* replace1519_1_0_0_0 -> 36 in the cache */
   /* replace1519_1_0_0 -> 4293 in the cache */
   /* replace1519_1_0 -> 4295 in the cache */
   /* replace1519_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 4295, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 4299, 4300 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1520_0_0 -> 11 in the cache */
   /* search1520_0 -> 1673 in the cache */
   /* search1520_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1673, 33 },
      -1,
   } },

   /* replace1520_0_0 -> 120 in the cache */
   /* replace1520_0_1 -> 36 in the cache */
   /* replace1520_0 -> 4196 in the cache */
   /* replace1520_1_0_0 -> 741 in the cache */
   /* replace1520_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 741, 36 },
      -1,
   } },
   /* replace1520_1_1_0 -> 11 in the cache */
   /* replace1520_1_1_1_0 -> 36 in the cache */
   /* replace1520_1_1_1 -> 4293 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 11, 4293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4303, 4304 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4196, 4305 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1521_0 -> 286 in the cache */
   /* search1521_1_0 -> 207 in the cache */
   /* search1521_1 -> 2913 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 286, 2913 },
      -1,
   } },

   /* replace1521_0_0 -> 16 in the cache */
   /* replace1521_0_1 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 16, 741 },
      -1,
   } },
   /* replace1521_1_0_0 -> 16 in the cache */
   /* replace1521_1_0_1 -> 120 in the cache */
   /* replace1521_1_0 -> 4203 in the cache */
   /* replace1521_1_1_0_0 -> 16 in the cache */
   /* replace1521_1_1_0 -> 2919 in the cache */
   /* replace1521_1_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 2919, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4203, 4309 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4308, 4310 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1522_0_0 -> 11 in the cache */
   /* search1522_0 -> 1673 in the cache */
   /* search1522_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1673, 33 },
      -1,
   } },

   /* replace1522_0_0 -> 741 in the cache */
   /* replace1522_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 741, 36 },
      -1,
   } },
   /* replace1522_1_0_0 -> 120 in the cache */
   /* replace1522_1_0_1 -> 36 in the cache */
   /* replace1522_1_0 -> 4209 in the cache */
   /* replace1522_1_1_0 -> 11 in the cache */
   /* replace1522_1_1_1_0 -> 36 in the cache */
   /* replace1522_1_1_1 -> 4293 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 11, 4293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4209, 4314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4313, 4315 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1523_0 -> 286 in the cache */
   /* search1523_1_0 -> 207 in the cache */
   /* search1523_1 -> 2913 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 286, 2913 },
      -1,
   } },

   /* replace1523_0_0 -> 16 in the cache */
   /* replace1523_0_1 -> 120 in the cache */
   /* replace1523_0 -> 4214 in the cache */
   /* replace1523_1_0_0 -> 16 in the cache */
   /* replace1523_1_0_1 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 16, 741 },
      -1,
   } },
   /* replace1523_1_1_0_0 -> 16 in the cache */
   /* replace1523_1_1_0 -> 2919 in the cache */
   /* replace1523_1_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 2919, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4318, 4319 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4214, 4320 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1524_0_0 -> 11 in the cache */
   /* search1524_0 -> 1696 in the cache */
   /* search1524_1_0 -> 1984 in the cache */
   /* search1524_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1696, 4219 },
      -1,
   } },

   /* replace1524_0 -> 11 in the cache */
   /* replace1524_1_0 -> 1984 in the cache */
   /* replace1524_1 -> 4129 in the cache */
   /* replace1524 -> 4265 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1525_0_0 -> 11 in the cache */
   /* search1525_0 -> 1696 in the cache */
   /* search1525_1_0 -> 1984 in the cache */
   /* search1525_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1696, 4219 },
      -1,
   } },

   /* replace1525_0 -> 11 in the cache */
   /* replace1525_1_0 -> 1984 in the cache */
   /* replace1525_1 -> 4129 in the cache */
   /* replace1525 -> 4267 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1526_0_0 -> 11 in the cache */
   /* search1526_0 -> 1696 in the cache */
   /* search1526_1_0 -> 1984 in the cache */
   /* search1526_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1696, 4219 },
      -1,
   } },

   /* replace1526_0 -> 11 in the cache */
   /* replace1526_1_0 -> 1984 in the cache */
   /* replace1526_1 -> 4129 in the cache */
   /* replace1526 -> 4269 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1527_0_0 -> 11 in the cache */
   /* search1527_0 -> 1696 in the cache */
   /* search1527_1_0 -> 1984 in the cache */
   /* search1527_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1696, 4219 },
      -1,
   } },

   /* replace1527_0 -> 11 in the cache */
   /* replace1527_1_0 -> 1984 in the cache */
   /* replace1527_1 -> 4129 in the cache */
   /* replace1527 -> 4271 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1528_0_0 -> 3794 in the cache */
   /* search1528_0 -> 4224 in the cache */
   /* search1528_1_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4224, 4326 },
      -1,
   } },

   /* replace1528_0_0 -> 3794 in the cache */
   /* replace1528_0 -> 4139 in the cache */
   /* replace1528_1 -> 446 in the cache */
   /* replace1528 -> 4274 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1529_0_0 -> 3794 in the cache */
   /* search1529_0 -> 4224 in the cache */
   /* search1529_1_0 -> 446 in the cache */
   /* search1529_1 -> 4326 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4224, 4326 },
      -1,
   } },

   /* replace1529_0_0 -> 3794 in the cache */
   /* replace1529_0 -> 4139 in the cache */
   /* replace1529_1 -> 446 in the cache */
   /* replace1529 -> 4276 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1530_0_0 -> 11 in the cache */
   /* search1530_0 -> 1696 in the cache */
   /* search1530_1_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1696, 4329 },
      -1,
   } },

   /* replace1530_0 -> 11 in the cache */
   /* replace1530_1_0 -> 207 in the cache */
   /* replace1530_1 -> 4278 in the cache */
   /* replace1530 -> 4279 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1531_0_0 -> 11 in the cache */
   /* search1531_0 -> 1696 in the cache */
   /* search1531_1_0 -> 207 in the cache */
   /* search1531_1 -> 4329 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1696, 4329 },
      -1,
   } },

   /* replace1531_0 -> 11 in the cache */
   /* replace1531_1_0 -> 207 in the cache */
   /* replace1531_1 -> 4278 in the cache */
   /* replace1531 -> 4281 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1532_0_0 -> 11 in the cache */
   /* search1532_0 -> 1696 in the cache */
   /* search1532_1_0 -> 207 in the cache */
   /* search1532_1 -> 4329 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1696, 4329 },
      -1,
   } },

   /* replace1532_0 -> 11 in the cache */
   /* replace1532_1_0 -> 207 in the cache */
   /* replace1532_1 -> 4278 in the cache */
   /* replace1532 -> 4283 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1533_0_0 -> 11 in the cache */
   /* search1533_0 -> 1696 in the cache */
   /* search1533_1_0 -> 207 in the cache */
   /* search1533_1 -> 4329 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1696, 4329 },
      -1,
   } },

   /* replace1533_0 -> 11 in the cache */
   /* replace1533_1_0 -> 207 in the cache */
   /* replace1533_1 -> 4278 in the cache */
   /* replace1533 -> 4285 in the cache */

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1534_0_0 -> 435 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 435 },
      -1,
   } },
   /* search1534_1_0 -> 446 in the cache */
   /* search1534_1 -> 4326 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4334, 4326 },
      -1,
   } },

   /* replace1534_0_0 -> 435 in the cache */
   /* replace1534_0 -> 4288 in the cache */
   /* replace1534_1 -> 446 in the cache */
   /* replace1534 -> 4289 in the cache */

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1535_0_0 -> 435 in the cache */
   /* search1535_0 -> 4334 in the cache */
   /* search1535_1_0 -> 446 in the cache */
   /* search1535_1 -> 4326 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4334, 4326 },
      -1,
   } },

   /* replace1535_0_0 -> 435 in the cache */
   /* replace1535_0 -> 4288 in the cache */
   /* replace1535_1 -> 446 in the cache */
   /* replace1535 -> 4291 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1536_0_0 -> 11 in the cache */
   /* search1536_0 -> 1696 in the cache */
   /* search1536_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1696, 3895 },
      -1,
   } },

   /* replace1536_0_0 -> 11 in the cache */
   /* replace1536_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 11, 4338 },
      -1,
   } },
   /* replace1536_1_0_0_0 -> 41 in the cache */
   /* replace1536_1_0_0 -> 4338 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 4338 },
      -1,
   } },
   /* replace1536_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 4340, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 4339, 4341 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1537_0_0 -> 11 in the cache */
   /* search1537_0 -> 1696 in the cache */
   /* search1537_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1696, 3895 },
      -1,
   } },

   /* replace1537_0_0 -> 11 in the cache */
   /* replace1537_0_1_0 -> 41 in the cache */
   /* replace1537_0_1 -> 4338 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 11, 4338 },
      -1,
   } },
   /* replace1537_1_0_0_0 -> 41 in the cache */
   /* replace1537_1_0_0 -> 4338 in the cache */
   /* replace1537_1_0 -> 4340 in the cache */
   /* replace1537_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 4340, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 4344, 4345 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1538_0_0 -> 11 in the cache */
   /* search1538_0 -> 1696 in the cache */
   /* search1538_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1696, 3895 },
      -1,
   } },

   /* replace1538_0_0 -> 791 in the cache */
   /* replace1538_0_1 -> 41 in the cache */
   /* replace1538_0 -> 4239 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace1538_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4348, 41 },
      -1,
   } },
   /* replace1538_1_1_0 -> 11 in the cache */
   /* replace1538_1_1_1_0 -> 41 in the cache */
   /* replace1538_1_1_1 -> 4338 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 11, 4338 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4349, 4350 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4239, 4351 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1539_0 -> 3914 in the cache */
   /* search1539_1_0 -> 207 in the cache */
   /* search1539_1 -> 4329 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 3914, 4329 },
      -1,
   } },

   /* replace1539_0_0 -> 21 in the cache */
   /* replace1539_0_1 -> 4348 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 21, 4348 },
      -1,
   } },
   /* replace1539_1_0_0 -> 21 in the cache */
   /* replace1539_1_0_1 -> 791 in the cache */
   /* replace1539_1_0 -> 4247 in the cache */
   /* replace1539_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1539_1_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4355, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4247, 4356 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4354, 4357 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1540_0_0 -> 11 in the cache */
   /* search1540_0 -> 1696 in the cache */
   /* search1540_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1696, 3895 },
      -1,
   } },

   /* replace1540_0_0 -> 4348 in the cache */
   /* replace1540_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4348, 41 },
      -1,
   } },
   /* replace1540_1_0_0 -> 791 in the cache */
   /* replace1540_1_0_1 -> 41 in the cache */
   /* replace1540_1_0 -> 4254 in the cache */
   /* replace1540_1_1_0 -> 11 in the cache */
   /* replace1540_1_1_1_0 -> 41 in the cache */
   /* replace1540_1_1_1 -> 4338 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 11, 4338 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4254, 4361 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4360, 4362 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1541_0 -> 3914 in the cache */
   /* search1541_1_0 -> 207 in the cache */
   /* search1541_1 -> 4329 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 3914, 4329 },
      -1,
   } },

   /* replace1541_0_0 -> 21 in the cache */
   /* replace1541_0_1 -> 791 in the cache */
   /* replace1541_0 -> 4259 in the cache */
   /* replace1541_1_0_0 -> 21 in the cache */
   /* replace1541_1_0_1 -> 4348 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 21, 4348 },
      -1,
   } },
   /* replace1541_1_1_0_0 -> 21 in the cache */
   /* replace1541_1_1_0 -> 4355 in the cache */
   /* replace1541_1_1_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4355, 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4365, 4366 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4259, 4367 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1542_0_0 -> 16 in the cache */
   /* search1542_0 -> 1780 in the cache */
   /* search1542_1_0 -> 1984 in the cache */
   /* search1542_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1780, 4219 },
      -1,
   } },

   /* replace1542_0 -> 16 in the cache */
   /* replace1542_1_0 -> 1984 in the cache */
   /* replace1542_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 16, 2893 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1543_0_0 -> 16 in the cache */
   /* search1543_0 -> 1780 in the cache */
   /* search1543_1_0 -> 1984 in the cache */
   /* search1543_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1780, 4219 },
      -1,
   } },

   /* replace1543_0 -> 16 in the cache */
   /* replace1543_1_0 -> 1984 in the cache */
   /* replace1543_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 16, 2893 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1544_0_0 -> 16 in the cache */
   /* search1544_0 -> 1780 in the cache */
   /* search1544_1_0 -> 1984 in the cache */
   /* search1544_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1780, 4219 },
      -1,
   } },

   /* replace1544_0 -> 16 in the cache */
   /* replace1544_1_0 -> 1984 in the cache */
   /* replace1544_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 16, 2893 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1545_0_0 -> 16 in the cache */
   /* search1545_0 -> 1780 in the cache */
   /* search1545_1_0 -> 1984 in the cache */
   /* search1545_1 -> 4219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1780, 4219 },
      -1,
   } },

   /* replace1545_0 -> 16 in the cache */
   /* replace1545_1_0 -> 1984 in the cache */
   /* replace1545_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 16, 2893 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1546_0_0 -> 3794 in the cache */
   /* search1546_0 -> 4224 in the cache */
   /* search1546_1_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4224, 4377 },
      -1,
   } },

   /* replace1546_0_0 -> 3794 in the cache */
   /* replace1546_0 -> 4182 in the cache */
   /* replace1546_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4182, 517 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1547_0_0 -> 3794 in the cache */
   /* search1547_0 -> 4224 in the cache */
   /* search1547_1_0 -> 517 in the cache */
   /* search1547_1 -> 4377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4224, 4377 },
      -1,
   } },

   /* replace1547_0_0 -> 3794 in the cache */
   /* replace1547_0 -> 4182 in the cache */
   /* replace1547_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4182, 517 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1548_0_0 -> 16 in the cache */
   /* search1548_0 -> 1780 in the cache */
   /* search1548_1_0 -> 207 in the cache */
   /* search1548_1 -> 4329 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1780, 4329 },
      -1,
   } },

   /* replace1548_0 -> 16 in the cache */
   /* replace1548_1_0 -> 207 in the cache */
   /* replace1548_1 -> 2913 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 16, 2913 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1549_0_0 -> 16 in the cache */
   /* search1549_0 -> 1780 in the cache */
   /* search1549_1_0 -> 207 in the cache */
   /* search1549_1 -> 4329 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1780, 4329 },
      -1,
   } },

   /* replace1549_0 -> 16 in the cache */
   /* replace1549_1_0 -> 207 in the cache */
   /* replace1549_1 -> 2913 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 16, 2913 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1550_0_0 -> 16 in the cache */
   /* search1550_0 -> 1780 in the cache */
   /* search1550_1_0 -> 207 in the cache */
   /* search1550_1 -> 4329 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1780, 4329 },
      -1,
   } },

   /* replace1550_0 -> 16 in the cache */
   /* replace1550_1_0 -> 207 in the cache */
   /* replace1550_1 -> 2913 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 16, 2913 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1551_0_0 -> 16 in the cache */
   /* search1551_0 -> 1780 in the cache */
   /* search1551_1_0 -> 207 in the cache */
   /* search1551_1 -> 4329 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1780, 4329 },
      -1,
   } },

   /* replace1551_0 -> 16 in the cache */
   /* replace1551_1_0 -> 207 in the cache */
   /* replace1551_1 -> 2913 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 16, 2913 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1552_0_0 -> 435 in the cache */
   /* search1552_0 -> 4334 in the cache */
   /* search1552_1_0 -> 517 in the cache */
   /* search1552_1 -> 4377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4334, 4377 },
      -1,
   } },

   /* replace1552_0_0 -> 435 in the cache */
   /* replace1552_0 -> 4286 in the cache */
   /* replace1552_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4286, 517 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1553_0_0 -> 435 in the cache */
   /* search1553_0 -> 4334 in the cache */
   /* search1553_1_0 -> 517 in the cache */
   /* search1553_1 -> 4377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4334, 4377 },
      -1,
   } },

   /* replace1553_0_0 -> 435 in the cache */
   /* replace1553_0 -> 4286 in the cache */
   /* replace1553_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4286, 517 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1554_0_0 -> 16 in the cache */
   /* search1554_0 -> 1780 in the cache */
   /* search1554_1_0 -> 36 in the cache */
   /* search1554_1 -> 2909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1780, 2909 },
      -1,
   } },

   /* replace1554_0 -> 16 in the cache */
   /* replace1554_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 16, 4395 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1555_0_0 -> 16 in the cache */
   /* search1555_0 -> 1780 in the cache */
   /* search1555_1_0 -> 36 in the cache */
   /* search1555_1 -> 2909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1780, 2909 },
      -1,
   } },

   /* replace1555_0 -> 16 in the cache */
   /* replace1555_1_0 -> 36 in the cache */
   /* replace1555_1 -> 4395 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 16, 4395 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1556_0_0 -> 16 in the cache */
   /* search1556_0 -> 1780 in the cache */
   /* search1556_1_0 -> 36 in the cache */
   /* search1556_1 -> 2909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1780, 2909 },
      -1,
   } },

   /* replace1556_0 -> 16 in the cache */
   /* replace1556_1_0 -> 36 in the cache */
   /* replace1556_1 -> 4395 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 16, 4395 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1557_0_0 -> 16 in the cache */
   /* search1557_0 -> 1780 in the cache */
   /* search1557_1_0 -> 36 in the cache */
   /* search1557_1 -> 2909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1780, 2909 },
      -1,
   } },

   /* replace1557_0 -> 16 in the cache */
   /* replace1557_1_0 -> 36 in the cache */
   /* replace1557_1 -> 4395 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 16, 4395 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1558_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 507 },
      -1,
   } },
   /* search1558_1_0 -> 517 in the cache */
   /* search1558_1 -> 4377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4403, 4377 },
      -1,
   } },

   /* replace1558_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 507 },
      -1,
   } },
   /* replace1558_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4405, 517 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1559_0_0 -> 507 in the cache */
   /* search1559_0 -> 4403 in the cache */
   /* search1559_1_0 -> 517 in the cache */
   /* search1559_1 -> 4377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4403, 4377 },
      -1,
   } },

   /* replace1559_0_0 -> 507 in the cache */
   /* replace1559_0 -> 4405 in the cache */
   /* replace1559_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4405, 517 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1560_0_0 -> 16 in the cache */
   /* search1560_0 -> 1780 in the cache */
   /* search1560_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 1780, 3895 },
      -1,
   } },

   /* replace1560_0_0 -> 16 in the cache */
   /* replace1560_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 16, 4410 },
      -1,
   } },
   /* replace1560_1_0_0_0 -> 41 in the cache */
   /* replace1560_1_0_0 -> 4410 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_u2u64,
      -1, 0,
      { 4410 },
      -1,
   } },
   /* replace1560_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 4412, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 4411, 4413 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1561_0_0 -> 16 in the cache */
   /* search1561_0 -> 1780 in the cache */
   /* search1561_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 1780, 3895 },
      -1,
   } },

   /* replace1561_0_0 -> 16 in the cache */
   /* replace1561_0_1_0 -> 41 in the cache */
   /* replace1561_0_1 -> 4410 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 16, 4410 },
      -1,
   } },
   /* replace1561_1_0_0_0 -> 41 in the cache */
   /* replace1561_1_0_0 -> 4410 in the cache */
   /* replace1561_1_0 -> 4412 in the cache */
   /* replace1561_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 4412, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 4416, 4417 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b')))) */
   /* search1562_0_0 -> 16 in the cache */
   /* search1562_0 -> 1780 in the cache */
   /* search1562_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 1780, 3895 },
      -1,
   } },

   /* replace1562_0_0 -> 791 in the cache */
   /* replace1562_0_1 -> 41 in the cache */
   /* replace1562_0 -> 4239 in the cache */
   /* replace1562_1_0_0 -> 2924 in the cache */
   /* replace1562_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 2924, 41 },
      -1,
   } },
   /* replace1562_1_1_0 -> 16 in the cache */
   /* replace1562_1_1_1_0 -> 41 in the cache */
   /* replace1562_1_1_1 -> 4410 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 16, 4410 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4420, 4421 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4239, 4422 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b'))) */
   /* search1563_0 -> 3914 in the cache */
   /* search1563_1_0 -> 36 in the cache */
   /* search1563_1 -> 2909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 3914, 2909 },
      -1,
   } },

   /* replace1563_0_0 -> 21 in the cache */
   /* replace1563_0_1 -> 2924 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 21, 2924 },
      -1,
   } },
   /* replace1563_1_0_0 -> 21 in the cache */
   /* replace1563_1_0_1 -> 791 in the cache */
   /* replace1563_1_0 -> 4247 in the cache */
   /* replace1563_1_1_0_0 -> 21 in the cache */
   /* replace1563_1_1_0 -> 2916 in the cache */
   /* replace1563_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 2916, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4247, 4426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4425, 4427 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b')))) */
   /* search1564_0_0 -> 16 in the cache */
   /* search1564_0 -> 1780 in the cache */
   /* search1564_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 1780, 3895 },
      -1,
   } },

   /* replace1564_0_0 -> 2924 in the cache */
   /* replace1564_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 2924, 41 },
      -1,
   } },
   /* replace1564_1_0_0 -> 791 in the cache */
   /* replace1564_1_0_1 -> 41 in the cache */
   /* replace1564_1_0 -> 4254 in the cache */
   /* replace1564_1_1_0 -> 16 in the cache */
   /* replace1564_1_1_1_0 -> 41 in the cache */
   /* replace1564_1_1_1 -> 4410 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 16, 4410 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4254, 4431 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4430, 4432 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b'))) */
   /* search1565_0 -> 3914 in the cache */
   /* search1565_1_0 -> 36 in the cache */
   /* search1565_1 -> 2909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 3914, 2909 },
      -1,
   } },

   /* replace1565_0_0 -> 21 in the cache */
   /* replace1565_0_1 -> 791 in the cache */
   /* replace1565_0 -> 4259 in the cache */
   /* replace1565_1_0_0 -> 21 in the cache */
   /* replace1565_1_0_1 -> 2924 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 21, 2924 },
      -1,
   } },
   /* replace1565_1_1_0_0 -> 21 in the cache */
   /* replace1565_1_1_0 -> 2916 in the cache */
   /* replace1565_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 2916, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      1, 1,
      { 4435, 4436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4259, 4437 },
      -1,
   } },

   /* ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1566_0_0 -> 11 in the cache */
   /* search1566_0 -> 1669 in the cache */
   /* search1566_1_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1669, 4439 },
      -1,
   } },

   /* replace1566_0 -> 11 in the cache */
   /* replace1566_1_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 11, 4441 },
      -1,
   } },

   /* ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1567_0_0 -> 11 in the cache */
   /* search1567_0 -> 1669 in the cache */
   /* search1567_1_0 -> 207 in the cache */
   /* search1567_1 -> 4439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1669, 4439 },
      -1,
   } },

   /* replace1567_0 -> 11 in the cache */
   /* replace1567_1_0 -> 207 in the cache */
   /* replace1567_1 -> 4441 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 11, 4441 },
      -1,
   } },

   /* ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1568_0_0 -> 11 in the cache */
   /* search1568_0 -> 1669 in the cache */
   /* search1568_1_0 -> 207 in the cache */
   /* search1568_1 -> 4439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1669, 4439 },
      -1,
   } },

   /* replace1568_0 -> 11 in the cache */
   /* replace1568_1_0 -> 207 in the cache */
   /* replace1568_1 -> 4441 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 11, 4441 },
      -1,
   } },

   /* ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1569_0_0 -> 11 in the cache */
   /* search1569_0 -> 1669 in the cache */
   /* search1569_1_0 -> 207 in the cache */
   /* search1569_1 -> 4439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1669, 4439 },
      -1,
   } },

   /* replace1569_0 -> 11 in the cache */
   /* replace1569_1_0 -> 207 in the cache */
   /* replace1569_1 -> 4441 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 11, 4441 },
      -1,
   } },

   /* ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1570_0_0 -> 435 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 435 },
      -1,
   } },
   /* search1570_1_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 4449, 4450 },
      -1,
   } },

   /* replace1570_0_0 -> 435 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 435 },
      -1,
   } },
   /* replace1570_1 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 4452, 446 },
      -1,
   } },

   /* ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1571_0_0 -> 435 in the cache */
   /* search1571_0 -> 4449 in the cache */
   /* search1571_1_0 -> 446 in the cache */
   /* search1571_1 -> 4450 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 4449, 4450 },
      -1,
   } },

   /* replace1571_0_0 -> 435 in the cache */
   /* replace1571_0 -> 4452 in the cache */
   /* replace1571_1 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 4452, 446 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1572_0_0 -> 11 in the cache */
   /* search1572_0 -> 1692 in the cache */
   /* search1572_1_0 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2f64,
      -1, 0,
      { 207 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1692, 4456 },
      -1,
   } },

   /* replace1572_0 -> 11 in the cache */
   /* replace1572_1_0 -> 207 in the cache */
   /* replace1572_1 -> 4441 in the cache */
   /* replace1572 -> 4442 in the cache */

   /* ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1573_0_0 -> 11 in the cache */
   /* search1573_0 -> 1692 in the cache */
   /* search1573_1_0 -> 207 in the cache */
   /* search1573_1 -> 4456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1692, 4456 },
      -1,
   } },

   /* replace1573_0 -> 11 in the cache */
   /* replace1573_1_0 -> 207 in the cache */
   /* replace1573_1 -> 4441 in the cache */
   /* replace1573 -> 4444 in the cache */

   /* ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1574_0_0 -> 11 in the cache */
   /* search1574_0 -> 1692 in the cache */
   /* search1574_1_0 -> 207 in the cache */
   /* search1574_1 -> 4456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1692, 4456 },
      -1,
   } },

   /* replace1574_0 -> 11 in the cache */
   /* replace1574_1_0 -> 207 in the cache */
   /* replace1574_1 -> 4441 in the cache */
   /* replace1574 -> 4446 in the cache */

   /* ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1575_0_0 -> 11 in the cache */
   /* search1575_0 -> 1692 in the cache */
   /* search1575_1_0 -> 207 in the cache */
   /* search1575_1 -> 4456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1692, 4456 },
      -1,
   } },

   /* replace1575_0 -> 11 in the cache */
   /* replace1575_1_0 -> 207 in the cache */
   /* replace1575_1 -> 4441 in the cache */
   /* replace1575 -> 4448 in the cache */

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1576_0_0 -> 435 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2f64,
      -1, 0,
      { 435 },
      -1,
   } },
   /* search1576_1_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2f64,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 4461, 4462 },
      -1,
   } },

   /* replace1576_0_0 -> 435 in the cache */
   /* replace1576_0 -> 4452 in the cache */
   /* replace1576_1 -> 446 in the cache */
   /* replace1576 -> 4453 in the cache */

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1577_0_0 -> 435 in the cache */
   /* search1577_0 -> 4461 in the cache */
   /* search1577_1_0 -> 446 in the cache */
   /* search1577_1 -> 4462 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 4461, 4462 },
      -1,
   } },

   /* replace1577_0_0 -> 435 in the cache */
   /* replace1577_0 -> 4452 in the cache */
   /* replace1577_1 -> 446 in the cache */
   /* replace1577 -> 4455 in the cache */

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1578_0_0 -> 16 in the cache */
   /* search1578_0 -> 1776 in the cache */
   /* search1578_1_0 -> 207 in the cache */
   /* search1578_1 -> 4456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1776, 4456 },
      -1,
   } },

   /* replace1578_0 -> 16 in the cache */
   /* replace1578_1_0 -> 207 in the cache */
   /* replace1578_1 -> 4439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 16, 4439 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1579_0_0 -> 16 in the cache */
   /* search1579_0 -> 1776 in the cache */
   /* search1579_1_0 -> 207 in the cache */
   /* search1579_1 -> 4456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1776, 4456 },
      -1,
   } },

   /* replace1579_0 -> 16 in the cache */
   /* replace1579_1_0 -> 207 in the cache */
   /* replace1579_1 -> 4439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 16, 4439 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1580_0_0 -> 16 in the cache */
   /* search1580_0 -> 1776 in the cache */
   /* search1580_1_0 -> 207 in the cache */
   /* search1580_1 -> 4456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1776, 4456 },
      -1,
   } },

   /* replace1580_0 -> 16 in the cache */
   /* replace1580_1_0 -> 207 in the cache */
   /* replace1580_1 -> 4439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 16, 4439 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1581_0_0 -> 16 in the cache */
   /* search1581_0 -> 1776 in the cache */
   /* search1581_1_0 -> 207 in the cache */
   /* search1581_1 -> 4456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1776, 4456 },
      -1,
   } },

   /* replace1581_0 -> 16 in the cache */
   /* replace1581_1_0 -> 207 in the cache */
   /* replace1581_1 -> 4439 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 16, 4439 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1582_0_0 -> 435 in the cache */
   /* search1582_0 -> 4461 in the cache */
   /* search1582_1_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2f64,
      -1, 0,
      { 517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 4461, 4473 },
      -1,
   } },

   /* replace1582_0_0 -> 435 in the cache */
   /* replace1582_0 -> 4449 in the cache */
   /* replace1582_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 4449, 517 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1583_0_0 -> 435 in the cache */
   /* search1583_0 -> 4461 in the cache */
   /* search1583_1_0 -> 517 in the cache */
   /* search1583_1 -> 4473 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 4461, 4473 },
      -1,
   } },

   /* replace1583_0_0 -> 435 in the cache */
   /* replace1583_0 -> 4449 in the cache */
   /* replace1583_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 4449, 517 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1584_0_0 -> 16 in the cache */
   /* search1584_0 -> 1776 in the cache */
   /* search1584_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2f64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1776, 4478 },
      -1,
   } },

   /* replace1584_0 -> 16 in the cache */
   /* replace1584_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 16, 4480 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1585_0_0 -> 16 in the cache */
   /* search1585_0 -> 1776 in the cache */
   /* search1585_1_0 -> 36 in the cache */
   /* search1585_1 -> 4478 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1776, 4478 },
      -1,
   } },

   /* replace1585_0 -> 16 in the cache */
   /* replace1585_1_0 -> 36 in the cache */
   /* replace1585_1 -> 4480 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 16, 4480 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1586_0_0 -> 16 in the cache */
   /* search1586_0 -> 1776 in the cache */
   /* search1586_1_0 -> 36 in the cache */
   /* search1586_1 -> 4478 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1776, 4478 },
      -1,
   } },

   /* replace1586_0 -> 16 in the cache */
   /* replace1586_1_0 -> 36 in the cache */
   /* replace1586_1 -> 4480 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 16, 4480 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1587_0_0 -> 16 in the cache */
   /* search1587_0 -> 1776 in the cache */
   /* search1587_1_0 -> 36 in the cache */
   /* search1587_1 -> 4478 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1776, 4478 },
      -1,
   } },

   /* replace1587_0 -> 16 in the cache */
   /* replace1587_1_0 -> 36 in the cache */
   /* replace1587_1 -> 4480 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 16, 4480 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1588_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_f2f64,
      -1, 0,
      { 507 },
      -1,
   } },
   /* search1588_1_0 -> 517 in the cache */
   /* search1588_1 -> 4473 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 4488, 4473 },
      -1,
   } },

   /* replace1588_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_f2f32,
      -1, 0,
      { 507 },
      -1,
   } },
   /* replace1588_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 4490, 517 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1589_0_0 -> 507 in the cache */
   /* search1589_0 -> 4488 in the cache */
   /* search1589_1_0 -> 517 in the cache */
   /* search1589_1 -> 4473 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 4488, 4473 },
      -1,
   } },

   /* replace1589_0_0 -> 507 in the cache */
   /* replace1589_0 -> 4490 in the cache */
   /* replace1589_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 4490, 517 },
      -1,
   } },

   /* ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a') */
   /* search1590_0_0 -> 21 in the cache */
   /* search1590_0_1 -> 2924 in the cache */
   /* search1590_0 -> 2925 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 1,
      { 2925 },
      -1,
   } },

   /* replace1590_0 -> 21 in the cache */
   /* replace1590 -> 2916 in the cache */

   /* ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a') */
   /* search1591_0_0 -> 16 in the cache */
   /* search1591_0_1 -> 741 in the cache */
   /* search1591_0 -> 895 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 1,
      { 895 },
      -1,
   } },

   /* replace1591_0 -> 16 in the cache */
   /* replace1591 -> 2919 in the cache */

   /* ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a') */
   /* search1592_0_0 -> 21 in the cache */
   /* search1592_0_1 -> 4348 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iand,
      0, 1,
      { 21, 4348 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 1,
      { 4496 },
      -1,
   } },

   /* replace1592_0 -> 21 in the cache */
   /* replace1592 -> 4355 in the cache */

   /* ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a') */
   /* search1593_0_0 -> 11 in the cache */
   /* search1593_0_1 -> 1885 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 11, 1885 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 1,
      { 4498 },
      -1,
   } },

   /* replace1593_0 -> 11 in the cache */
   /* replace1593 -> 1881 in the cache */

   /* ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a') */
   /* search1594_0_0 -> 16 in the cache */
   /* search1594_0_1 -> 718 in the cache */
   /* search1594_0 -> 902 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 1,
      { 902 },
      -1,
   } },

   /* replace1594_0 -> 16 in the cache */
   /* replace1594 -> 1897 in the cache */

   /* ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a') */
   /* search1595_0_0 -> 21 in the cache */
   /* search1595_0_1 -> 4240 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_iand,
      0, 1,
      { 21, 4240 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 1,
      { 4501 },
      -1,
   } },

   /* replace1595_0 -> 21 in the cache */
   /* replace1595 -> 4248 in the cache */

   /* ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1596_0_0 -> 11 in the cache */
   /* search1596_0 -> 1881 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 1881 },
      6,
   } },

   /* replace1596 -> 11 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1597_0 -> 11 in the cache */
   /* search1597_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 748 },
      6,
   } },

   /* replace1597 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1598_0 -> 441 in the cache */
   /* search1598_1_0_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 4505 },
      -1,
   } },
   /* search1598_2 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4506, 408 },
      6,
   } },

   /* replace1598_0 -> 441 in the cache */
   /* replace1598_1 -> 446 in the cache */
   /* replace1598_2 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 446, 408 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1599_0 -> 441 in the cache */
   /* search1599_1_0_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 4509 },
      -1,
   } },
   /* search1599_2 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4510, 408 },
      6,
   } },

   /* replace1599_0 -> 441 in the cache */
   /* replace1599_1 -> 446 in the cache */
   /* replace1599_2 -> 408 in the cache */
   /* replace1599 -> 4508 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1600_0 -> 441 in the cache */
   /* search1600_1_0 -> 446 in the cache */
   /* search1600_1_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 446, 748 },
      -1,
   } },
   /* search1600_2 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4512, 408 },
      6,
   } },

   /* replace1600_0 -> 441 in the cache */
   /* replace1600_1 -> 446 in the cache */
   /* replace1600_2 -> 408 in the cache */
   /* replace1600 -> 4508 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1601_0_0_0 -> 11 in the cache */
   /* search1601_0_0 -> 1881 in the cache */
   /* search1601_0 -> 1882 in the cache */
   /* search1601_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 1882, 207 },
      6,
   } },

   /* replace1601_0 -> 11 in the cache */
   /* replace1601_1 -> 207 in the cache */
   /* replace1601 -> 3569 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1602_0_0_0 -> 11 in the cache */
   /* search1602_0_0 -> 3825 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 3825 },
      -1,
   } },
   /* search1602_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 4515, 207 },
      6,
   } },

   /* replace1602_0 -> 11 in the cache */
   /* replace1602_1 -> 207 in the cache */
   /* replace1602 -> 3569 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1603_0_0 -> 11 in the cache */
   /* search1603_0_1 -> 748 in the cache */
   /* search1603_0 -> 3027 in the cache */
   /* search1603_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 3027, 207 },
      6,
   } },

   /* replace1603_0 -> 11 in the cache */
   /* replace1603_1 -> 207 in the cache */
   /* replace1603 -> 3569 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1604_0_0_0 -> 11 in the cache */
   /* search1604_0_0 -> 1881 in the cache */
   /* search1604_0 -> 1882 in the cache */
   /* search1604_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_imul,
      0, 1,
      { 1882, 207 },
      6,
   } },

   /* replace1604_0 -> 11 in the cache */
   /* replace1604_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_imul,
      0, 1,
      { 11, 207 },
      -1,
   } },

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1605_0_0_0 -> 11 in the cache */
   /* search1605_0_0 -> 3825 in the cache */
   /* search1605_0 -> 4515 in the cache */
   /* search1605_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_imul,
      0, 1,
      { 4515, 207 },
      6,
   } },

   /* replace1605_0 -> 11 in the cache */
   /* replace1605_1 -> 207 in the cache */
   /* replace1605 -> 4519 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1606_0_0 -> 11 in the cache */
   /* search1606_0_1 -> 748 in the cache */
   /* search1606_0 -> 3027 in the cache */
   /* search1606_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_imul,
      0, 1,
      { 3027, 207 },
      6,
   } },

   /* replace1606_0 -> 11 in the cache */
   /* replace1606_1 -> 207 in the cache */
   /* replace1606 -> 4519 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1607_0_0_0 -> 11 in the cache */
   /* search1607_0_0 -> 1881 in the cache */
   /* search1607_0 -> 1882 in the cache */
   /* search1607_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 1882, 207 },
      6,
   } },

   /* replace1607_0 -> 11 in the cache */
   /* replace1607_1 -> 207 in the cache */
   /* replace1607 -> 1895 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1608_0_0_0 -> 11 in the cache */
   /* search1608_0_0 -> 3825 in the cache */
   /* search1608_0 -> 4515 in the cache */
   /* search1608_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4515, 207 },
      6,
   } },

   /* replace1608_0 -> 11 in the cache */
   /* replace1608_1 -> 207 in the cache */
   /* replace1608 -> 1895 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1609_0_0 -> 11 in the cache */
   /* search1609_0_1 -> 748 in the cache */
   /* search1609_0 -> 3027 in the cache */
   /* search1609_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 3027, 207 },
      6,
   } },

   /* replace1609_0 -> 11 in the cache */
   /* replace1609_1 -> 207 in the cache */
   /* replace1609 -> 1895 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1610_0_0_0 -> 11 in the cache */
   /* search1610_0_0 -> 1881 in the cache */
   /* search1610_0 -> 1882 in the cache */
   /* search1610_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 1,
      { 1882, 207 },
      6,
   } },

   /* replace1610_0 -> 11 in the cache */
   /* replace1610_1 -> 207 in the cache */
   /* replace1610 -> 1937 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1611_0_0_0 -> 11 in the cache */
   /* search1611_0_0 -> 3825 in the cache */
   /* search1611_0 -> 4515 in the cache */
   /* search1611_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 1,
      { 4515, 207 },
      6,
   } },

   /* replace1611_0 -> 11 in the cache */
   /* replace1611_1 -> 207 in the cache */
   /* replace1611 -> 1937 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1612_0_0 -> 11 in the cache */
   /* search1612_0_1 -> 748 in the cache */
   /* search1612_0 -> 3027 in the cache */
   /* search1612_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 1,
      { 3027, 207 },
      6,
   } },

   /* replace1612_0 -> 11 in the cache */
   /* replace1612_1 -> 207 in the cache */
   /* replace1612 -> 1937 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1613_0_0_0 -> 11 in the cache */
   /* search1613_0_0 -> 1881 in the cache */
   /* search1613_0 -> 1882 in the cache */
   /* search1613_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 1882, 207 },
      6,
   } },

   /* replace1613_0 -> 11 in the cache */
   /* replace1613_1 -> 207 in the cache */
   /* replace1613 -> 1961 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1614_0_0_0 -> 11 in the cache */
   /* search1614_0_0 -> 3825 in the cache */
   /* search1614_0 -> 4515 in the cache */
   /* search1614_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 4515, 207 },
      6,
   } },

   /* replace1614_0 -> 11 in the cache */
   /* replace1614_1 -> 207 in the cache */
   /* replace1614 -> 1961 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1615_0_0 -> 11 in the cache */
   /* search1615_0_1 -> 748 in the cache */
   /* search1615_0 -> 3027 in the cache */
   /* search1615_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 3027, 207 },
      6,
   } },

   /* replace1615_0 -> 11 in the cache */
   /* replace1615_1 -> 207 in the cache */
   /* replace1615 -> 1961 in the cache */

   /* ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1616_0_0 -> 11 in the cache */
   /* search1616_0 -> 1881 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 1881 },
      6,
   } },

   /* replace1616 -> 11 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1617_0 -> 11 in the cache */
   /* search1617_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 748 },
      6,
   } },

   /* replace1617 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1618_0 -> 441 in the cache */
   /* search1618_1_0_0 -> 446 in the cache */
   /* search1618_1_0 -> 4505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 4505 },
      -1,
   } },
   /* search1618_2 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4533, 408 },
      6,
   } },

   /* replace1618_0 -> 441 in the cache */
   /* replace1618_1 -> 446 in the cache */
   /* replace1618_2 -> 408 in the cache */
   /* replace1618 -> 4508 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1619_0 -> 441 in the cache */
   /* search1619_1_0_0 -> 446 in the cache */
   /* search1619_1_0 -> 4509 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 4509 },
      -1,
   } },
   /* search1619_2 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4535, 408 },
      6,
   } },

   /* replace1619_0 -> 441 in the cache */
   /* replace1619_1 -> 446 in the cache */
   /* replace1619_2 -> 408 in the cache */
   /* replace1619 -> 4508 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1620_0 -> 441 in the cache */
   /* search1620_1_0 -> 446 in the cache */
   /* search1620_1_1 -> 748 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 446, 748 },
      -1,
   } },
   /* search1620_2 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4537, 408 },
      6,
   } },

   /* replace1620_0 -> 441 in the cache */
   /* replace1620_1 -> 446 in the cache */
   /* replace1620_2 -> 408 in the cache */
   /* replace1620 -> 4508 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1621_0_0_0 -> 11 in the cache */
   /* search1621_0_0 -> 1881 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 1881 },
      -1,
   } },
   /* search1621_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 4539, 207 },
      6,
   } },

   /* replace1621_0 -> 11 in the cache */
   /* replace1621_1 -> 207 in the cache */
   /* replace1621 -> 3569 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1622_0_0_0 -> 11 in the cache */
   /* search1622_0_0 -> 3825 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 3825 },
      -1,
   } },
   /* search1622_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 4541, 207 },
      6,
   } },

   /* replace1622_0 -> 11 in the cache */
   /* replace1622_1 -> 207 in the cache */
   /* replace1622 -> 3569 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1623_0_0 -> 11 in the cache */
   /* search1623_0_1 -> 748 in the cache */
   /* search1623_0 -> 3048 in the cache */
   /* search1623_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 3048, 207 },
      6,
   } },

   /* replace1623_0 -> 11 in the cache */
   /* replace1623_1 -> 207 in the cache */
   /* replace1623 -> 3569 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1624_0_0_0 -> 11 in the cache */
   /* search1624_0_0 -> 1881 in the cache */
   /* search1624_0 -> 4539 in the cache */
   /* search1624_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_imul,
      0, 1,
      { 4539, 207 },
      6,
   } },

   /* replace1624_0 -> 11 in the cache */
   /* replace1624_1 -> 207 in the cache */
   /* replace1624 -> 4519 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1625_0_0_0 -> 11 in the cache */
   /* search1625_0_0 -> 3825 in the cache */
   /* search1625_0 -> 4541 in the cache */
   /* search1625_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_imul,
      0, 1,
      { 4541, 207 },
      6,
   } },

   /* replace1625_0 -> 11 in the cache */
   /* replace1625_1 -> 207 in the cache */
   /* replace1625 -> 4519 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1626_0_0 -> 11 in the cache */
   /* search1626_0_1 -> 748 in the cache */
   /* search1626_0 -> 3048 in the cache */
   /* search1626_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_imul,
      0, 1,
      { 3048, 207 },
      6,
   } },

   /* replace1626_0 -> 11 in the cache */
   /* replace1626_1 -> 207 in the cache */
   /* replace1626 -> 4519 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1627_0_0_0 -> 11 in the cache */
   /* search1627_0_0 -> 1881 in the cache */
   /* search1627_0 -> 4539 in the cache */
   /* search1627_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4539, 207 },
      6,
   } },

   /* replace1627_0 -> 11 in the cache */
   /* replace1627_1 -> 207 in the cache */
   /* replace1627 -> 1895 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1628_0_0_0 -> 11 in the cache */
   /* search1628_0_0 -> 3825 in the cache */
   /* search1628_0 -> 4541 in the cache */
   /* search1628_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4541, 207 },
      6,
   } },

   /* replace1628_0 -> 11 in the cache */
   /* replace1628_1 -> 207 in the cache */
   /* replace1628 -> 1895 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1629_0_0 -> 11 in the cache */
   /* search1629_0_1 -> 748 in the cache */
   /* search1629_0 -> 3048 in the cache */
   /* search1629_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_iand,
      0, 1,
      { 3048, 207 },
      6,
   } },

   /* replace1629_0 -> 11 in the cache */
   /* replace1629_1 -> 207 in the cache */
   /* replace1629 -> 1895 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1630_0_0_0 -> 11 in the cache */
   /* search1630_0_0 -> 1881 in the cache */
   /* search1630_0 -> 4539 in the cache */
   /* search1630_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 1,
      { 4539, 207 },
      6,
   } },

   /* replace1630_0 -> 11 in the cache */
   /* replace1630_1 -> 207 in the cache */
   /* replace1630 -> 1937 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1631_0_0_0 -> 11 in the cache */
   /* search1631_0_0 -> 3825 in the cache */
   /* search1631_0 -> 4541 in the cache */
   /* search1631_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 1,
      { 4541, 207 },
      6,
   } },

   /* replace1631_0 -> 11 in the cache */
   /* replace1631_1 -> 207 in the cache */
   /* replace1631 -> 1937 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1632_0_0 -> 11 in the cache */
   /* search1632_0_1 -> 748 in the cache */
   /* search1632_0 -> 3048 in the cache */
   /* search1632_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ior,
      0, 1,
      { 3048, 207 },
      6,
   } },

   /* replace1632_0 -> 11 in the cache */
   /* replace1632_1 -> 207 in the cache */
   /* replace1632 -> 1937 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1633_0_0_0 -> 11 in the cache */
   /* search1633_0_0 -> 1881 in the cache */
   /* search1633_0 -> 4539 in the cache */
   /* search1633_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 4539, 207 },
      6,
   } },

   /* replace1633_0 -> 11 in the cache */
   /* replace1633_1 -> 207 in the cache */
   /* replace1633 -> 1961 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1634_0_0_0 -> 11 in the cache */
   /* search1634_0_0 -> 3825 in the cache */
   /* search1634_0 -> 4541 in the cache */
   /* search1634_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 4541, 207 },
      6,
   } },

   /* replace1634_0 -> 11 in the cache */
   /* replace1634_1 -> 207 in the cache */
   /* replace1634 -> 1961 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1635_0_0 -> 11 in the cache */
   /* search1635_0_1 -> 748 in the cache */
   /* search1635_0 -> 3048 in the cache */
   /* search1635_1 -> 207 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 3048, 207 },
      6,
   } },

   /* replace1635_0 -> 11 in the cache */
   /* replace1635_1 -> 207 in the cache */
   /* replace1635 -> 1961 in the cache */

   /* ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1636_0_0 -> 16 in the cache */
   /* search1636_0 -> 1897 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 1897 },
      6,
   } },

   /* replace1636 -> 16 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1637_0 -> 16 in the cache */
   /* search1637_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 120 },
      6,
   } },

   /* replace1637 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1638_0 -> 441 in the cache */
   /* search1638_1_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 4558 },
      -1,
   } },
   /* search1638_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4559, 481 },
      6,
   } },

   /* replace1638_0 -> 441 in the cache */
   /* replace1638_1 -> 517 in the cache */
   /* replace1638_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 517, 481 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1639_0 -> 441 in the cache */
   /* search1639_1_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 4562 },
      -1,
   } },
   /* search1639_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4563, 481 },
      6,
   } },

   /* replace1639_0 -> 441 in the cache */
   /* replace1639_1 -> 517 in the cache */
   /* replace1639_2 -> 481 in the cache */
   /* replace1639 -> 4561 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1640_0 -> 441 in the cache */
   /* search1640_1_0 -> 517 in the cache */
   /* search1640_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 517, 120 },
      -1,
   } },
   /* search1640_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4565, 481 },
      6,
   } },

   /* replace1640_0 -> 441 in the cache */
   /* replace1640_1 -> 517 in the cache */
   /* replace1640_2 -> 481 in the cache */
   /* replace1640 -> 4561 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1641_0_0_0 -> 16 in the cache */
   /* search1641_0_0 -> 1897 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 1897 },
      -1,
   } },
   /* search1641_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 4567, 36 },
      6,
   } },

   /* replace1641_0 -> 16 in the cache */
   /* replace1641_1 -> 36 in the cache */
   /* replace1641 -> 3589 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1642_0_0_0 -> 16 in the cache */
   /* search1642_0_0 -> 3777 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3777 },
      -1,
   } },
   /* search1642_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 4569, 36 },
      6,
   } },

   /* replace1642_0 -> 16 in the cache */
   /* replace1642_1 -> 36 in the cache */
   /* replace1642 -> 3589 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1643_0_0 -> 16 in the cache */
   /* search1643_0_1 -> 120 in the cache */
   /* search1643_0 -> 332 in the cache */
   /* search1643_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 332, 36 },
      6,
   } },

   /* replace1643_0 -> 16 in the cache */
   /* replace1643_1 -> 36 in the cache */
   /* replace1643 -> 3589 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1644_0_0_0 -> 16 in the cache */
   /* search1644_0_0 -> 1897 in the cache */
   /* search1644_0 -> 4567 in the cache */
   /* search1644_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 4567, 36 },
      6,
   } },

   /* replace1644_0 -> 16 in the cache */
   /* replace1644_1 -> 36 in the cache */
   /* replace1644 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1645_0_0_0 -> 16 in the cache */
   /* search1645_0_0 -> 3777 in the cache */
   /* search1645_0 -> 4569 in the cache */
   /* search1645_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 4569, 36 },
      6,
   } },

   /* replace1645_0 -> 16 in the cache */
   /* replace1645_1 -> 36 in the cache */
   /* replace1645 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1646_0_0 -> 16 in the cache */
   /* search1646_0_1 -> 120 in the cache */
   /* search1646_0 -> 332 in the cache */
   /* search1646_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 332, 36 },
      6,
   } },

   /* replace1646_0 -> 16 in the cache */
   /* replace1646_1 -> 36 in the cache */
   /* replace1646 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1647_0_0_0 -> 16 in the cache */
   /* search1647_0_0 -> 1897 in the cache */
   /* search1647_0 -> 4567 in the cache */
   /* search1647_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4567, 36 },
      6,
   } },

   /* replace1647_0 -> 16 in the cache */
   /* replace1647_1 -> 36 in the cache */
   /* replace1647 -> 1903 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1648_0_0_0 -> 16 in the cache */
   /* search1648_0_0 -> 3777 in the cache */
   /* search1648_0 -> 4569 in the cache */
   /* search1648_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4569, 36 },
      6,
   } },

   /* replace1648_0 -> 16 in the cache */
   /* replace1648_1 -> 36 in the cache */
   /* replace1648 -> 1903 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1649_0_0 -> 16 in the cache */
   /* search1649_0_1 -> 120 in the cache */
   /* search1649_0 -> 332 in the cache */
   /* search1649_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 332, 36 },
      6,
   } },

   /* replace1649_0 -> 16 in the cache */
   /* replace1649_1 -> 36 in the cache */
   /* replace1649 -> 1903 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1650_0_0_0 -> 16 in the cache */
   /* search1650_0_0 -> 1897 in the cache */
   /* search1650_0 -> 4567 in the cache */
   /* search1650_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 4567, 36 },
      6,
   } },

   /* replace1650_0 -> 16 in the cache */
   /* replace1650_1 -> 36 in the cache */
   /* replace1650 -> 1941 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1651_0_0_0 -> 16 in the cache */
   /* search1651_0_0 -> 3777 in the cache */
   /* search1651_0 -> 4569 in the cache */
   /* search1651_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 4569, 36 },
      6,
   } },

   /* replace1651_0 -> 16 in the cache */
   /* replace1651_1 -> 36 in the cache */
   /* replace1651 -> 1941 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1652_0_0 -> 16 in the cache */
   /* search1652_0_1 -> 120 in the cache */
   /* search1652_0 -> 332 in the cache */
   /* search1652_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 332, 36 },
      6,
   } },

   /* replace1652_0 -> 16 in the cache */
   /* replace1652_1 -> 36 in the cache */
   /* replace1652 -> 1941 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1653_0_0_0 -> 16 in the cache */
   /* search1653_0_0 -> 1897 in the cache */
   /* search1653_0 -> 4567 in the cache */
   /* search1653_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 4567, 36 },
      6,
   } },

   /* replace1653_0 -> 16 in the cache */
   /* replace1653_1 -> 36 in the cache */
   /* replace1653 -> 1965 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1654_0_0_0 -> 16 in the cache */
   /* search1654_0_0 -> 3777 in the cache */
   /* search1654_0 -> 4569 in the cache */
   /* search1654_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 4569, 36 },
      6,
   } },

   /* replace1654_0 -> 16 in the cache */
   /* replace1654_1 -> 36 in the cache */
   /* replace1654 -> 1965 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1655_0_0 -> 16 in the cache */
   /* search1655_0_1 -> 120 in the cache */
   /* search1655_0 -> 332 in the cache */
   /* search1655_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 332, 36 },
      6,
   } },

   /* replace1655_0 -> 16 in the cache */
   /* replace1655_1 -> 36 in the cache */
   /* replace1655 -> 1965 in the cache */

   /* ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1656_0_0 -> 16 in the cache */
   /* search1656_0 -> 1897 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 1897 },
      6,
   } },

   /* replace1656 -> 16 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1657_0 -> 16 in the cache */
   /* search1657_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 120 },
      6,
   } },

   /* replace1657 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1658_0 -> 441 in the cache */
   /* search1658_1_0_0 -> 517 in the cache */
   /* search1658_1_0 -> 4558 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 4558 },
      -1,
   } },
   /* search1658_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4586, 481 },
      6,
   } },

   /* replace1658_0 -> 441 in the cache */
   /* replace1658_1 -> 517 in the cache */
   /* replace1658_2 -> 481 in the cache */
   /* replace1658 -> 4561 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1659_0 -> 441 in the cache */
   /* search1659_1_0_0 -> 517 in the cache */
   /* search1659_1_0 -> 4562 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 4562 },
      -1,
   } },
   /* search1659_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4588, 481 },
      6,
   } },

   /* replace1659_0 -> 441 in the cache */
   /* replace1659_1 -> 517 in the cache */
   /* replace1659_2 -> 481 in the cache */
   /* replace1659 -> 4561 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1660_0 -> 441 in the cache */
   /* search1660_1_0 -> 517 in the cache */
   /* search1660_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 517, 120 },
      -1,
   } },
   /* search1660_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4590, 481 },
      6,
   } },

   /* replace1660_0 -> 441 in the cache */
   /* replace1660_1 -> 517 in the cache */
   /* replace1660_2 -> 481 in the cache */
   /* replace1660 -> 4561 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1661_0_0_0 -> 16 in the cache */
   /* search1661_0_0 -> 1897 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 1897 },
      -1,
   } },
   /* search1661_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 4592, 36 },
      6,
   } },

   /* replace1661_0 -> 16 in the cache */
   /* replace1661_1 -> 36 in the cache */
   /* replace1661 -> 3589 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1662_0_0_0 -> 16 in the cache */
   /* search1662_0_0 -> 3777 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3777 },
      -1,
   } },
   /* search1662_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 4594, 36 },
      6,
   } },

   /* replace1662_0 -> 16 in the cache */
   /* replace1662_1 -> 36 in the cache */
   /* replace1662 -> 3589 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1663_0_0 -> 16 in the cache */
   /* search1663_0_1 -> 120 in the cache */
   /* search1663_0 -> 313 in the cache */
   /* search1663_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 313, 36 },
      6,
   } },

   /* replace1663_0 -> 16 in the cache */
   /* replace1663_1 -> 36 in the cache */
   /* replace1663 -> 3589 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1664_0_0_0 -> 16 in the cache */
   /* search1664_0_0 -> 1897 in the cache */
   /* search1664_0 -> 4592 in the cache */
   /* search1664_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 4592, 36 },
      6,
   } },

   /* replace1664_0 -> 16 in the cache */
   /* replace1664_1 -> 36 in the cache */
   /* replace1664 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1665_0_0_0 -> 16 in the cache */
   /* search1665_0_0 -> 3777 in the cache */
   /* search1665_0 -> 4594 in the cache */
   /* search1665_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 4594, 36 },
      6,
   } },

   /* replace1665_0 -> 16 in the cache */
   /* replace1665_1 -> 36 in the cache */
   /* replace1665 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1666_0_0 -> 16 in the cache */
   /* search1666_0_1 -> 120 in the cache */
   /* search1666_0 -> 313 in the cache */
   /* search1666_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 313, 36 },
      6,
   } },

   /* replace1666_0 -> 16 in the cache */
   /* replace1666_1 -> 36 in the cache */
   /* replace1666 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1667_0_0_0 -> 16 in the cache */
   /* search1667_0_0 -> 1897 in the cache */
   /* search1667_0 -> 4592 in the cache */
   /* search1667_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4592, 36 },
      6,
   } },

   /* replace1667_0 -> 16 in the cache */
   /* replace1667_1 -> 36 in the cache */
   /* replace1667 -> 1903 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1668_0_0_0 -> 16 in the cache */
   /* search1668_0_0 -> 3777 in the cache */
   /* search1668_0 -> 4594 in the cache */
   /* search1668_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4594, 36 },
      6,
   } },

   /* replace1668_0 -> 16 in the cache */
   /* replace1668_1 -> 36 in the cache */
   /* replace1668 -> 1903 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1669_0_0 -> 16 in the cache */
   /* search1669_0_1 -> 120 in the cache */
   /* search1669_0 -> 313 in the cache */
   /* search1669_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 313, 36 },
      6,
   } },

   /* replace1669_0 -> 16 in the cache */
   /* replace1669_1 -> 36 in the cache */
   /* replace1669 -> 1903 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1670_0_0_0 -> 16 in the cache */
   /* search1670_0_0 -> 1897 in the cache */
   /* search1670_0 -> 4592 in the cache */
   /* search1670_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 4592, 36 },
      6,
   } },

   /* replace1670_0 -> 16 in the cache */
   /* replace1670_1 -> 36 in the cache */
   /* replace1670 -> 1941 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1671_0_0_0 -> 16 in the cache */
   /* search1671_0_0 -> 3777 in the cache */
   /* search1671_0 -> 4594 in the cache */
   /* search1671_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 4594, 36 },
      6,
   } },

   /* replace1671_0 -> 16 in the cache */
   /* replace1671_1 -> 36 in the cache */
   /* replace1671 -> 1941 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1672_0_0 -> 16 in the cache */
   /* search1672_0_1 -> 120 in the cache */
   /* search1672_0 -> 313 in the cache */
   /* search1672_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 313, 36 },
      6,
   } },

   /* replace1672_0 -> 16 in the cache */
   /* replace1672_1 -> 36 in the cache */
   /* replace1672 -> 1941 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1673_0_0_0 -> 16 in the cache */
   /* search1673_0_0 -> 1897 in the cache */
   /* search1673_0 -> 4592 in the cache */
   /* search1673_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 4592, 36 },
      6,
   } },

   /* replace1673_0 -> 16 in the cache */
   /* replace1673_1 -> 36 in the cache */
   /* replace1673 -> 1965 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1674_0_0_0 -> 16 in the cache */
   /* search1674_0_0 -> 3777 in the cache */
   /* search1674_0 -> 4594 in the cache */
   /* search1674_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 4594, 36 },
      6,
   } },

   /* replace1674_0 -> 16 in the cache */
   /* replace1674_1 -> 36 in the cache */
   /* replace1674 -> 1965 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1675_0_0 -> 16 in the cache */
   /* search1675_0_1 -> 120 in the cache */
   /* search1675_0 -> 313 in the cache */
   /* search1675_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 313, 36 },
      6,
   } },

   /* replace1675_0 -> 16 in the cache */
   /* replace1675_1 -> 36 in the cache */
   /* replace1675 -> 1965 in the cache */

   /* ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1676_0_0 -> 16 in the cache */
   /* search1676_0 -> 2919 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 2919 },
      7,
   } },

   /* replace1676 -> 16 in the cache */

   /* ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1677_0 -> 16 in the cache */
   /* search1677_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 120 },
      7,
   } },

   /* replace1677 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1678_0 -> 441 in the cache */
   /* search1678_1_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 4611 },
      -1,
   } },
   /* search1678_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4612, 481 },
      7,
   } },

   /* replace1678_0 -> 441 in the cache */
   /* replace1678_1 -> 517 in the cache */
   /* replace1678_2 -> 481 in the cache */
   /* replace1678 -> 4561 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1679_0 -> 441 in the cache */
   /* search1679_1_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 4614 },
      -1,
   } },
   /* search1679_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4615, 481 },
      7,
   } },

   /* replace1679_0 -> 441 in the cache */
   /* replace1679_1 -> 517 in the cache */
   /* replace1679_2 -> 481 in the cache */
   /* replace1679 -> 4561 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1680_0 -> 441 in the cache */
   /* search1680_1_0 -> 517 in the cache */
   /* search1680_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 517, 120 },
      -1,
   } },
   /* search1680_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4617, 481 },
      7,
   } },

   /* replace1680_0 -> 441 in the cache */
   /* replace1680_1 -> 517 in the cache */
   /* replace1680_2 -> 481 in the cache */
   /* replace1680 -> 4561 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1681_0_0_0 -> 16 in the cache */
   /* search1681_0_0 -> 2919 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 2919 },
      -1,
   } },
   /* search1681_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 4619, 36 },
      7,
   } },

   /* replace1681_0 -> 16 in the cache */
   /* replace1681_1 -> 36 in the cache */
   /* replace1681 -> 3589 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1682_0_0_0 -> 16 in the cache */
   /* search1682_0_0 -> 3779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 3779 },
      -1,
   } },
   /* search1682_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 4621, 36 },
      7,
   } },

   /* replace1682_0 -> 16 in the cache */
   /* replace1682_1 -> 36 in the cache */
   /* replace1682 -> 3589 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1683_0_0 -> 16 in the cache */
   /* search1683_0_1 -> 120 in the cache */
   /* search1683_0 -> 364 in the cache */
   /* search1683_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 364, 36 },
      7,
   } },

   /* replace1683_0 -> 16 in the cache */
   /* replace1683_1 -> 36 in the cache */
   /* replace1683 -> 3589 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1684_0_0_0 -> 16 in the cache */
   /* search1684_0_0 -> 2919 in the cache */
   /* search1684_0 -> 4619 in the cache */
   /* search1684_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 4619, 36 },
      7,
   } },

   /* replace1684_0 -> 16 in the cache */
   /* replace1684_1 -> 36 in the cache */
   /* replace1684 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1685_0_0_0 -> 16 in the cache */
   /* search1685_0_0 -> 3779 in the cache */
   /* search1685_0 -> 4621 in the cache */
   /* search1685_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 4621, 36 },
      7,
   } },

   /* replace1685_0 -> 16 in the cache */
   /* replace1685_1 -> 36 in the cache */
   /* replace1685 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1686_0_0 -> 16 in the cache */
   /* search1686_0_1 -> 120 in the cache */
   /* search1686_0 -> 364 in the cache */
   /* search1686_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 364, 36 },
      7,
   } },

   /* replace1686_0 -> 16 in the cache */
   /* replace1686_1 -> 36 in the cache */
   /* replace1686 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1687_0_0_0 -> 16 in the cache */
   /* search1687_0_0 -> 2919 in the cache */
   /* search1687_0 -> 4619 in the cache */
   /* search1687_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4619, 36 },
      7,
   } },

   /* replace1687_0 -> 16 in the cache */
   /* replace1687_1 -> 36 in the cache */
   /* replace1687 -> 1903 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1688_0_0_0 -> 16 in the cache */
   /* search1688_0_0 -> 3779 in the cache */
   /* search1688_0 -> 4621 in the cache */
   /* search1688_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4621, 36 },
      7,
   } },

   /* replace1688_0 -> 16 in the cache */
   /* replace1688_1 -> 36 in the cache */
   /* replace1688 -> 1903 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1689_0_0 -> 16 in the cache */
   /* search1689_0_1 -> 120 in the cache */
   /* search1689_0 -> 364 in the cache */
   /* search1689_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 364, 36 },
      7,
   } },

   /* replace1689_0 -> 16 in the cache */
   /* replace1689_1 -> 36 in the cache */
   /* replace1689 -> 1903 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1690_0_0_0 -> 16 in the cache */
   /* search1690_0_0 -> 2919 in the cache */
   /* search1690_0 -> 4619 in the cache */
   /* search1690_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 4619, 36 },
      7,
   } },

   /* replace1690_0 -> 16 in the cache */
   /* replace1690_1 -> 36 in the cache */
   /* replace1690 -> 1941 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1691_0_0_0 -> 16 in the cache */
   /* search1691_0_0 -> 3779 in the cache */
   /* search1691_0 -> 4621 in the cache */
   /* search1691_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 4621, 36 },
      7,
   } },

   /* replace1691_0 -> 16 in the cache */
   /* replace1691_1 -> 36 in the cache */
   /* replace1691 -> 1941 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1692_0_0 -> 16 in the cache */
   /* search1692_0_1 -> 120 in the cache */
   /* search1692_0 -> 364 in the cache */
   /* search1692_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 364, 36 },
      7,
   } },

   /* replace1692_0 -> 16 in the cache */
   /* replace1692_1 -> 36 in the cache */
   /* replace1692 -> 1941 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1693_0_0_0 -> 16 in the cache */
   /* search1693_0_0 -> 2919 in the cache */
   /* search1693_0 -> 4619 in the cache */
   /* search1693_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 4619, 36 },
      7,
   } },

   /* replace1693_0 -> 16 in the cache */
   /* replace1693_1 -> 36 in the cache */
   /* replace1693 -> 1965 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1694_0_0_0 -> 16 in the cache */
   /* search1694_0_0 -> 3779 in the cache */
   /* search1694_0 -> 4621 in the cache */
   /* search1694_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 4621, 36 },
      7,
   } },

   /* replace1694_0 -> 16 in the cache */
   /* replace1694_1 -> 36 in the cache */
   /* replace1694 -> 1965 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1695_0_0 -> 16 in the cache */
   /* search1695_0_1 -> 120 in the cache */
   /* search1695_0 -> 364 in the cache */
   /* search1695_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 364, 36 },
      7,
   } },

   /* replace1695_0 -> 16 in the cache */
   /* replace1695_1 -> 36 in the cache */
   /* replace1695 -> 1965 in the cache */

   /* ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1696_0_0 -> 16 in the cache */
   /* search1696_0 -> 2919 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 2919 },
      7,
   } },

   /* replace1696 -> 16 in the cache */

   /* ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1697_0 -> 16 in the cache */
   /* search1697_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 120 },
      7,
   } },

   /* replace1697 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1698_0 -> 441 in the cache */
   /* search1698_1_0_0 -> 517 in the cache */
   /* search1698_1_0 -> 4611 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 4611 },
      -1,
   } },
   /* search1698_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4638, 481 },
      7,
   } },

   /* replace1698_0 -> 441 in the cache */
   /* replace1698_1 -> 517 in the cache */
   /* replace1698_2 -> 481 in the cache */
   /* replace1698 -> 4561 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1699_0 -> 441 in the cache */
   /* search1699_1_0_0 -> 517 in the cache */
   /* search1699_1_0 -> 4614 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 4614 },
      -1,
   } },
   /* search1699_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4640, 481 },
      7,
   } },

   /* replace1699_0 -> 441 in the cache */
   /* replace1699_1 -> 517 in the cache */
   /* replace1699_2 -> 481 in the cache */
   /* replace1699 -> 4561 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1700_0 -> 441 in the cache */
   /* search1700_1_0 -> 517 in the cache */
   /* search1700_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 517, 120 },
      -1,
   } },
   /* search1700_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 4642, 481 },
      7,
   } },

   /* replace1700_0 -> 441 in the cache */
   /* replace1700_1 -> 517 in the cache */
   /* replace1700_2 -> 481 in the cache */
   /* replace1700 -> 4561 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1701_0_0_0 -> 16 in the cache */
   /* search1701_0_0 -> 2919 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 2919 },
      -1,
   } },
   /* search1701_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 4644, 36 },
      7,
   } },

   /* replace1701_0 -> 16 in the cache */
   /* replace1701_1 -> 36 in the cache */
   /* replace1701 -> 3589 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1702_0_0_0 -> 16 in the cache */
   /* search1702_0_0 -> 3779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 3779 },
      -1,
   } },
   /* search1702_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 4646, 36 },
      7,
   } },

   /* replace1702_0 -> 16 in the cache */
   /* replace1702_1 -> 36 in the cache */
   /* replace1702 -> 3589 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1703_0_0 -> 16 in the cache */
   /* search1703_0_1 -> 120 in the cache */
   /* search1703_0 -> 356 in the cache */
   /* search1703_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 356, 36 },
      7,
   } },

   /* replace1703_0 -> 16 in the cache */
   /* replace1703_1 -> 36 in the cache */
   /* replace1703 -> 3589 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1704_0_0_0 -> 16 in the cache */
   /* search1704_0_0 -> 2919 in the cache */
   /* search1704_0 -> 4644 in the cache */
   /* search1704_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 4644, 36 },
      7,
   } },

   /* replace1704_0 -> 16 in the cache */
   /* replace1704_1 -> 36 in the cache */
   /* replace1704 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1705_0_0_0 -> 16 in the cache */
   /* search1705_0_0 -> 3779 in the cache */
   /* search1705_0 -> 4646 in the cache */
   /* search1705_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 4646, 36 },
      7,
   } },

   /* replace1705_0 -> 16 in the cache */
   /* replace1705_1 -> 36 in the cache */
   /* replace1705 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1706_0_0 -> 16 in the cache */
   /* search1706_0_1 -> 120 in the cache */
   /* search1706_0 -> 356 in the cache */
   /* search1706_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imul,
      0, 1,
      { 356, 36 },
      7,
   } },

   /* replace1706_0 -> 16 in the cache */
   /* replace1706_1 -> 36 in the cache */
   /* replace1706 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1707_0_0_0 -> 16 in the cache */
   /* search1707_0_0 -> 2919 in the cache */
   /* search1707_0 -> 4644 in the cache */
   /* search1707_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4644, 36 },
      7,
   } },

   /* replace1707_0 -> 16 in the cache */
   /* replace1707_1 -> 36 in the cache */
   /* replace1707 -> 1903 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1708_0_0_0 -> 16 in the cache */
   /* search1708_0_0 -> 3779 in the cache */
   /* search1708_0 -> 4646 in the cache */
   /* search1708_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4646, 36 },
      7,
   } },

   /* replace1708_0 -> 16 in the cache */
   /* replace1708_1 -> 36 in the cache */
   /* replace1708 -> 1903 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1709_0_0 -> 16 in the cache */
   /* search1709_0_1 -> 120 in the cache */
   /* search1709_0 -> 356 in the cache */
   /* search1709_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 356, 36 },
      7,
   } },

   /* replace1709_0 -> 16 in the cache */
   /* replace1709_1 -> 36 in the cache */
   /* replace1709 -> 1903 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1710_0_0_0 -> 16 in the cache */
   /* search1710_0_0 -> 2919 in the cache */
   /* search1710_0 -> 4644 in the cache */
   /* search1710_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 4644, 36 },
      7,
   } },

   /* replace1710_0 -> 16 in the cache */
   /* replace1710_1 -> 36 in the cache */
   /* replace1710 -> 1941 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1711_0_0_0 -> 16 in the cache */
   /* search1711_0_0 -> 3779 in the cache */
   /* search1711_0 -> 4646 in the cache */
   /* search1711_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 4646, 36 },
      7,
   } },

   /* replace1711_0 -> 16 in the cache */
   /* replace1711_1 -> 36 in the cache */
   /* replace1711 -> 1941 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1712_0_0 -> 16 in the cache */
   /* search1712_0_1 -> 120 in the cache */
   /* search1712_0 -> 356 in the cache */
   /* search1712_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 1,
      { 356, 36 },
      7,
   } },

   /* replace1712_0 -> 16 in the cache */
   /* replace1712_1 -> 36 in the cache */
   /* replace1712 -> 1941 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1713_0_0_0 -> 16 in the cache */
   /* search1713_0_0 -> 2919 in the cache */
   /* search1713_0 -> 4644 in the cache */
   /* search1713_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 4644, 36 },
      7,
   } },

   /* replace1713_0 -> 16 in the cache */
   /* replace1713_1 -> 36 in the cache */
   /* replace1713 -> 1965 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1714_0_0_0 -> 16 in the cache */
   /* search1714_0_0 -> 3779 in the cache */
   /* search1714_0 -> 4646 in the cache */
   /* search1714_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 4646, 36 },
      7,
   } },

   /* replace1714_0 -> 16 in the cache */
   /* replace1714_1 -> 36 in the cache */
   /* replace1714 -> 1965 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1715_0_0 -> 16 in the cache */
   /* search1715_0_1 -> 120 in the cache */
   /* search1715_0 -> 356 in the cache */
   /* search1715_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 356, 36 },
      7,
   } },

   /* replace1715_0 -> 16 in the cache */
   /* replace1715_1 -> 36 in the cache */
   /* replace1715 -> 1965 in the cache */

   /* ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* exp */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ldexp,
      -1, 0,
      { 4661, 4662 },
      -1,
   } },

   /* replace1716_0_0 -> 4661 in the cache */
   /* replace1716_0_1_0_0_0_0_0_0 -> 4662 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1e /* -30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imax,
      4, 1,
      { 4662, 4664 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1e /* 30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      3, 2,
      { 4665, 4666 },
      -1,
   } },
   /* replace1716_0_1_0_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 2,
      { 4667, 316 },
      -1,
   } },
   /* replace1716_0_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      2, 3,
      { 4668, 14 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xa /* 10 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 3,
      { 4669, 4670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 3,
      { 4671 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      1, 4,
      { 4661, 4672 },
      -1,
   } },
   /* replace1716_1_0_0_0_0_0_0 -> 4662 in the cache */
   /* replace1716_1_0_0_0_0_0_1 -> 4664 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imax,
      7, 1,
      { 4662, 4664 },
      -1,
   } },
   /* replace1716_1_0_0_0_0_1 -> 4666 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      6, 2,
      { 4674, 4666 },
      -1,
   } },
   /* replace1716_1_0_0_0_1_0_0_0 -> 4662 in the cache */
   /* replace1716_1_0_0_0_1_0_0_1 -> 4664 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imax,
      9, 1,
      { 4662, 4664 },
      -1,
   } },
   /* replace1716_1_0_0_0_1_0_1 -> 4666 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      8, 2,
      { 4676, 4666 },
      -1,
   } },
   /* replace1716_1_0_0_0_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 2,
      { 4677, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 4,
      { 4675, 4678 },
      -1,
   } },
   /* replace1716_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      5, 5,
      { 4679, 14 },
      -1,
   } },
   /* replace1716_1_0_1 -> 4670 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 5,
      { 4680, 4670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 5,
      { 4681 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      0, 10,
      { 4673, 4682 },
      -1,
   } },

   /* ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23)) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1717_1 -> 4662 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ldexp,
      -1, 0,
      { 4684, 4662 },
      -1,
   } },

   /* replace1717_0_0 -> 4684 in the cache */
   /* replace1717_0_1_0_0_0_0_0 -> 4662 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0xfe /* -254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imax,
      4, 1,
      { 4662, 4686 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfe /* 254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      3, 2,
      { 4687, 4688 },
      -1,
   } },
   /* replace1717_0_1_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 2,
      { 4689, 316 },
      -1,
   } },
   /* replace1717_0_1_0_1 -> 3863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      2, 3,
      { 4690, 3863 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x17 /* 23 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 3,
      { 4691, 4692 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 4,
      { 4684, 4693 },
      -1,
   } },
   /* replace1717_1_0_0_0_0_0 -> 4662 in the cache */
   /* replace1717_1_0_0_0_0_1 -> 4686 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imax,
      7, 1,
      { 4662, 4686 },
      -1,
   } },
   /* replace1717_1_0_0_0_1 -> 4688 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      6, 2,
      { 4695, 4688 },
      -1,
   } },
   /* replace1717_1_0_0_1_0_0_0 -> 4662 in the cache */
   /* replace1717_1_0_0_1_0_0_1 -> 4686 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imax,
      9, 1,
      { 4662, 4686 },
      -1,
   } },
   /* replace1717_1_0_0_1_0_1 -> 4688 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      8, 2,
      { 4697, 4688 },
      -1,
   } },
   /* replace1717_1_0_0_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 2,
      { 4698, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 4,
      { 4696, 4699 },
      -1,
   } },
   /* replace1717_1_0_1 -> 3863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      5, 5,
      { 4700, 3863 },
      -1,
   } },
   /* replace1717_1_1 -> 4692 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 5,
      { 4701, 4692 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      0, 10,
      { 4694, 4702 },
      -1,
   } },

   /* ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1718_1 -> 4662 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ldexp,
      -1, 0,
      { 4704, 4662 },
      -1,
   } },

   /* replace1718_0_0 -> 4704 in the cache */
   /* replace1718_0_1_0 -> 120 in the cache */
   /* replace1718_0_1_1_0_0_0_0_0 -> 4662 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x7fe /* -2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imax,
      4, 1,
      { 4662, 4706 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fe /* 2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      3, 2,
      { 4707, 4708 },
      -1,
   } },
   /* replace1718_0_1_1_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 2,
      { 4709, 316 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3ff /* 1023 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      2, 3,
      { 4710, 4711 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x14 /* 20 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 3,
      { 4712, 4713 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_pack_64_2x32_split,
      -1, 3,
      { 120, 4714 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      1, 4,
      { 4704, 4715 },
      -1,
   } },
   /* replace1718_1_0 -> 120 in the cache */
   /* replace1718_1_1_0_0_0_0_0 -> 4662 in the cache */
   /* replace1718_1_1_0_0_0_0_1 -> 4706 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imax,
      7, 1,
      { 4662, 4706 },
      -1,
   } },
   /* replace1718_1_1_0_0_0_1 -> 4708 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      6, 2,
      { 4717, 4708 },
      -1,
   } },
   /* replace1718_1_1_0_0_1_0_0_0 -> 4662 in the cache */
   /* replace1718_1_1_0_0_1_0_0_1 -> 4706 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imax,
      9, 1,
      { 4662, 4706 },
      -1,
   } },
   /* replace1718_1_1_0_0_1_0_1 -> 4708 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imin,
      8, 2,
      { 4719, 4708 },
      -1,
   } },
   /* replace1718_1_1_0_0_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 2,
      { 4720, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_isub,
      -1, 4,
      { 4718, 4721 },
      -1,
   } },
   /* replace1718_1_1_0_1 -> 4711 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      5, 5,
      { 4722, 4711 },
      -1,
   } },
   /* replace1718_1_1_1 -> 4713 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 5,
      { 4723, 4713 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_pack_64_2x32_split,
      -1, 5,
      { 120, 4724 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      0, 10,
      { 4716, 4725 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x') */
   /* search1719_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1719_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 4684, 745 },
      -1,
   } },
   /* search1719_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1719_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 745 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 4684, 745 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      8, 1,
      { 4727, 4728 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff /* 16711935 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      7, 2,
      { 4729, 4730 },
      -1,
   } },
   /* search1719_0_0_0_0_0_0_0_0_0_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 2,
      { 4731, 722 },
      -1,
   } },
   /* search1719_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1719_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1719_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1719_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1719_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1719_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      10, 1,
      { 4727, 4728 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff00 /* 4278255360 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      9, 2,
      { 4733, 4734 },
      -1,
   } },
   /* search1719_0_0_0_0_0_0_0_0_0_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 2,
      { 4735, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      6, 5,
      { 4732, 4736 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f /* 252645135 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      5, 6,
      { 4737, 4738 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 6,
      { 4739, 4740 },
      -1,
   } },
   /* search1719_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1719_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1719_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1719_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1719_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1719_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      14, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_0_0_0_0_0_0_1_0_0_0_0_1 -> 4730 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      13, 2,
      { 4742, 4730 },
      -1,
   } },
   /* search1719_0_0_0_0_0_0_1_0_0_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 2,
      { 4743, 722 },
      -1,
   } },
   /* search1719_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1719_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1719_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1719_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1719_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1719_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      16, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_0_0_0_0_0_0_1_0_0_1_0_1 -> 4734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      15, 2,
      { 4745, 4734 },
      -1,
   } },
   /* search1719_0_0_0_0_0_0_1_0_0_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 2,
      { 4746, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      12, 5,
      { 4744, 4747 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f0 /* 4042322160 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      11, 6,
      { 4748, 4749 },
      -1,
   } },
   /* search1719_0_0_0_0_0_0_1_1 -> 4740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 6,
      { 4750, 4740 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      4, 13,
      { 4741, 4751 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x33333333 /* 858993459 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      3, 14,
      { 4752, 4753 },
      -1,
   } },
   /* search1719_0_0_0_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 14,
      { 4754, 321 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1719_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1719_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1719_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1719_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1719_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      22, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_0_0_0_0_0_1 -> 4730 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      21, 2,
      { 4756, 4730 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_0_0_0_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 2,
      { 4757, 722 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1719_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1719_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1719_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1719_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1719_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      24, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_0_0_0_1_0_1 -> 4734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      23, 2,
      { 4759, 4734 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_0_0_0_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 2,
      { 4760, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      20, 5,
      { 4758, 4761 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_0_0_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      19, 6,
      { 4762, 4738 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_0_1 -> 4740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 6,
      { 4763, 4740 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1719_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1719_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1719_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1719_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1719_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      28, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_1_0_0_0_0_1 -> 4730 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      27, 2,
      { 4765, 4730 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_1_0_0_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 2,
      { 4766, 722 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1719_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1719_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1719_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1719_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1719_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      30, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_1_0_0_1_0_1 -> 4734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      29, 2,
      { 4768, 4734 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_1_0_0_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 2,
      { 4769, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      26, 5,
      { 4767, 4770 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_1_0_1 -> 4749 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      25, 6,
      { 4771, 4749 },
      -1,
   } },
   /* search1719_0_0_0_1_0_0_1_1 -> 4740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 6,
      { 4772, 4740 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      18, 13,
      { 4764, 4773 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xcccccccc /* 3435973836 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      17, 14,
      { 4774, 4775 },
      -1,
   } },
   /* search1719_0_0_0_1_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 14,
      { 4776, 321 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      2, 29,
      { 4755, 4777 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x55555555 /* 1431655765 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 30,
      { 4778, 4779 },
      -1,
   } },
   /* search1719_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 30,
      { 4780, 316 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1719_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1719_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1719_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1719_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1719_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      38, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_0_0_0_0_0_1 -> 4730 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      37, 2,
      { 4782, 4730 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_0_0_0_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 2,
      { 4783, 722 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1719_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1719_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1719_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1719_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1719_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      40, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_0_0_0_1_0_1 -> 4734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      39, 2,
      { 4785, 4734 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_0_0_0_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 2,
      { 4786, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      36, 5,
      { 4784, 4787 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_0_0_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      35, 6,
      { 4788, 4738 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_0_1 -> 4740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 6,
      { 4789, 4740 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1719_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1719_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1719_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1719_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1719_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      44, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_1_0_0_0_0_1 -> 4730 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      43, 2,
      { 4791, 4730 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_1_0_0_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 2,
      { 4792, 722 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1719_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1719_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1719_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1719_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1719_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      46, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_1_0_0_1_0_1 -> 4734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      45, 2,
      { 4794, 4734 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_1_0_0_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 2,
      { 4795, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      42, 5,
      { 4793, 4796 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_1_0_1 -> 4749 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      41, 6,
      { 4797, 4749 },
      -1,
   } },
   /* search1719_1_0_0_0_0_0_1_1 -> 4740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 6,
      { 4798, 4740 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      34, 13,
      { 4790, 4799 },
      -1,
   } },
   /* search1719_1_0_0_0_0_1 -> 4753 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      33, 14,
      { 4800, 4753 },
      -1,
   } },
   /* search1719_1_0_0_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 14,
      { 4801, 321 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1719_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1719_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1719_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1719_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1719_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      52, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_0_0_0_0_0_1 -> 4730 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      51, 2,
      { 4803, 4730 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_0_0_0_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 2,
      { 4804, 722 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1719_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1719_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1719_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1719_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1719_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      54, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_0_0_0_1_0_1 -> 4734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      53, 2,
      { 4806, 4734 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_0_0_0_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 2,
      { 4807, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      50, 5,
      { 4805, 4808 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_0_0_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      49, 6,
      { 4809, 4738 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_0_1 -> 4740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 6,
      { 4810, 4740 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1719_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1719_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1719_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1719_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1719_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      58, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_1_0_0_0_0_1 -> 4730 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      57, 2,
      { 4812, 4730 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_1_0_0_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 2,
      { 4813, 722 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1719_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1719_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1719_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1719_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1719_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 4728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      60, 1,
      { 4727, 4728 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_1_0_0_1_0_1 -> 4734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      59, 2,
      { 4815, 4734 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_1_0_0_1_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 2,
      { 4816, 722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      56, 5,
      { 4814, 4817 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_1_0_1 -> 4749 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      55, 6,
      { 4818, 4749 },
      -1,
   } },
   /* search1719_1_0_0_1_0_0_1_1 -> 4740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 6,
      { 4819, 4740 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      48, 13,
      { 4811, 4820 },
      -1,
   } },
   /* search1719_1_0_0_1_0_1 -> 4775 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      47, 14,
      { 4821, 4775 },
      -1,
   } },
   /* search1719_1_0_0_1_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 14,
      { 4822, 321 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      32, 29,
      { 4802, 4823 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xaaaaaaaa /* 2863311530 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      31, 30,
      { 4824, 4825 },
      -1,
   } },
   /* search1719_1_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 30,
      { 4826, 316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 61,
      { 4781, 4827 },
      -1,
   } },

   /* replace1719_0 -> 4684 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 4684 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x') */
   /* search1720_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 4728 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_0_0_0 -> 4729 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 4729, 316 },
      -1,
   } },
   /* search1720_0_0_0_0_0_0_0_0_0_0_1 -> 4825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      7, 2,
      { 4830, 4825 },
      -1,
   } },
   /* search1720_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 4728 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_1_0_0 -> 4733 in the cache */
   /* search1720_0_0_0_0_0_0_0_0_0_1_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 4733, 316 },
      -1,
   } },
   /* search1720_0_0_0_0_0_0_0_0_0_1_1 -> 4779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      9, 2,
      { 4832, 4779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      6, 5,
      { 4831, 4833 },
      -1,
   } },
   /* search1720_0_0_0_0_0_0_0_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 5,
      { 4834, 321 },
      -1,
   } },
   /* search1720_0_0_0_0_0_0_0_1 -> 4775 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      5, 6,
      { 4835, 4775 },
      -1,
   } },
   /* search1720_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 4728 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_0_0_0 -> 4742 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 4742, 316 },
      -1,
   } },
   /* search1720_0_0_0_0_0_0_1_0_0_0_1 -> 4825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      13, 2,
      { 4837, 4825 },
      -1,
   } },
   /* search1720_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 4728 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_1_0_0 -> 4745 in the cache */
   /* search1720_0_0_0_0_0_0_1_0_0_1_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 4745, 316 },
      -1,
   } },
   /* search1720_0_0_0_0_0_0_1_0_0_1_1 -> 4779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      15, 2,
      { 4839, 4779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      12, 5,
      { 4838, 4840 },
      -1,
   } },
   /* search1720_0_0_0_0_0_0_1_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 5,
      { 4841, 321 },
      -1,
   } },
   /* search1720_0_0_0_0_0_0_1_1 -> 4753 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      11, 6,
      { 4842, 4753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      4, 13,
      { 4836, 4843 },
      -1,
   } },
   /* search1720_0_0_0_0_0_1 -> 4740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 13,
      { 4844, 4740 },
      -1,
   } },
   /* search1720_0_0_0_0_1 -> 4749 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      3, 14,
      { 4845, 4749 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 4728 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_0_0_0 -> 4756 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 4756, 316 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_0_0_0_0_1 -> 4825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      21, 2,
      { 4847, 4825 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 4728 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_1_0_0 -> 4759 in the cache */
   /* search1720_0_0_0_1_0_0_0_0_0_1_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 4759, 316 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_0_0_0_1_1 -> 4779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      23, 2,
      { 4849, 4779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      20, 5,
      { 4848, 4850 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_0_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 5,
      { 4851, 321 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_0_1 -> 4775 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      19, 6,
      { 4852, 4775 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 4728 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_0_0_0 -> 4765 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 4765, 316 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_1_0_0_0_1 -> 4825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      27, 2,
      { 4854, 4825 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 4728 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_1_0_0 -> 4768 in the cache */
   /* search1720_0_0_0_1_0_0_1_0_0_1_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 4768, 316 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_1_0_0_1_1 -> 4779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      29, 2,
      { 4856, 4779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      26, 5,
      { 4855, 4857 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_1_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 5,
      { 4858, 321 },
      -1,
   } },
   /* search1720_0_0_0_1_0_0_1_1 -> 4753 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      25, 6,
      { 4859, 4753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      18, 13,
      { 4853, 4860 },
      -1,
   } },
   /* search1720_0_0_0_1_0_1 -> 4740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 13,
      { 4861, 4740 },
      -1,
   } },
   /* search1720_0_0_0_1_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      17, 14,
      { 4862, 4738 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      2, 29,
      { 4846, 4863 },
      -1,
   } },
   /* search1720_0_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 29,
      { 4864, 722 },
      -1,
   } },
   /* search1720_0_1 -> 4734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      1, 30,
      { 4865, 4734 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 4728 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_0_0_0 -> 4782 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 4782, 316 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_0_0_0_0_1 -> 4825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      37, 2,
      { 4867, 4825 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 4728 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_1_0_0 -> 4785 in the cache */
   /* search1720_1_0_0_0_0_0_0_0_0_1_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 4785, 316 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_0_0_0_1_1 -> 4779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      39, 2,
      { 4869, 4779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      36, 5,
      { 4868, 4870 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_0_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 5,
      { 4871, 321 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_0_1 -> 4775 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      35, 6,
      { 4872, 4775 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 4728 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_0_0_0 -> 4791 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 4791, 316 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_1_0_0_0_1 -> 4825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      43, 2,
      { 4874, 4825 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 4728 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_1_0_0 -> 4794 in the cache */
   /* search1720_1_0_0_0_0_0_1_0_0_1_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 4794, 316 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_1_0_0_1_1 -> 4779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      45, 2,
      { 4876, 4779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      42, 5,
      { 4875, 4877 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_1_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 5,
      { 4878, 321 },
      -1,
   } },
   /* search1720_1_0_0_0_0_0_1_1 -> 4753 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      41, 6,
      { 4879, 4753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      34, 13,
      { 4873, 4880 },
      -1,
   } },
   /* search1720_1_0_0_0_0_1 -> 4740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 13,
      { 4881, 4740 },
      -1,
   } },
   /* search1720_1_0_0_0_1 -> 4749 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      33, 14,
      { 4882, 4749 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 4728 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_0_0_0 -> 4803 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 4803, 316 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_0_0_0_0_1 -> 4825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      51, 2,
      { 4884, 4825 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 4728 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_1_0_0 -> 4806 in the cache */
   /* search1720_1_0_0_1_0_0_0_0_0_1_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 4806, 316 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_0_0_0_1_1 -> 4779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      53, 2,
      { 4886, 4779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      50, 5,
      { 4885, 4887 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_0_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 5,
      { 4888, 321 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_0_1 -> 4775 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      49, 6,
      { 4889, 4775 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4684 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 745 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 4727 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4684 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 745 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 4728 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_0_0_0 -> 4812 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_0_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 4812, 316 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_1_0_0_0_1 -> 4825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      57, 2,
      { 4891, 4825 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4684 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 745 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 4727 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4684 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 745 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 4728 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_1_0_0 -> 4815 in the cache */
   /* search1720_1_0_0_1_0_0_1_0_0_1_0_1 -> 316 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 1,
      { 4815, 316 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_1_0_0_1_1 -> 4779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      59, 2,
      { 4893, 4779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      56, 5,
      { 4892, 4894 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_1_0_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 5,
      { 4895, 321 },
      -1,
   } },
   /* search1720_1_0_0_1_0_0_1_1 -> 4753 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      55, 6,
      { 4896, 4753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      48, 13,
      { 4890, 4897 },
      -1,
   } },
   /* search1720_1_0_0_1_0_1 -> 4740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 13,
      { 4898, 4740 },
      -1,
   } },
   /* search1720_1_0_0_1_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      47, 14,
      { 4899, 4738 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      32, 29,
      { 4883, 4900 },
      -1,
   } },
   /* search1720_1_0_1 -> 722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 29,
      { 4901, 722 },
      -1,
   } },
   /* search1720_1_1 -> 4730 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      31, 30,
      { 4902, 4730 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ior,
      0, 61,
      { 4866, 4903 },
      -1,
   } },

   /* replace1720_0 -> 4684 in the cache */
   /* replace1720 -> 4829 in the cache */

   /* ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b') */
   /* search1721_0_0 -> 0 in the cache */
   /* search1721_0_1 -> 3 in the cache */
   /* search1721_0 -> 971 in the cache */
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal2,
      0, 2,
      { 971, 4905 },
      -1,
   } },

   /* replace1721_0 -> 0 in the cache */
   /* replace1721_1 -> 3 in the cache */
   /* replace1721 -> 2283 in the cache */

   /* ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b') */
   /* search1722_0_0 -> 0 in the cache */
   /* search1722_0_1 -> 3 in the cache */
   /* search1722_0 -> 965 in the cache */
   /* search1722_1 -> 4905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal2,
      0, 2,
      { 965, 4905 },
      -1,
   } },

   /* replace1722_0 -> 0 in the cache */
   /* replace1722_1 -> 3 in the cache */
   /* replace1722 -> 2318 in the cache */

   /* ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b') */
   /* search1723_0_0 -> 0 in the cache */
   /* search1723_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal2,
      0, 2,
      { 4908, 4909 },
      -1,
   } },

   /* replace1723_0 -> 0 in the cache */
   /* replace1723_1 -> 3 in the cache */
   /* replace1723 -> 2303 in the cache */

   /* ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b') */
   /* search1724_0_0 -> 0 in the cache */
   /* search1724_0_1 -> 3 in the cache */
   /* search1724_0 -> 3621 in the cache */
   /* search1724_1 -> 4909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal2,
      0, 2,
      { 3621, 4909 },
      -1,
   } },

   /* replace1724_0 -> 0 in the cache */
   /* replace1724_1 -> 3 in the cache */
   /* replace1724 -> 2333 in the cache */

   /* ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b') */
   /* search1725_0_0 -> 0 in the cache */
   /* search1725_0_1 -> 3 in the cache */
   /* search1725_0 -> 971 in the cache */
   /* search1725_1 -> 4905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal3,
      0, 2,
      { 971, 4905 },
      -1,
   } },

   /* replace1725_0 -> 0 in the cache */
   /* replace1725_1 -> 3 in the cache */
   /* replace1725 -> 2289 in the cache */

   /* ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b') */
   /* search1726_0_0 -> 0 in the cache */
   /* search1726_0_1 -> 3 in the cache */
   /* search1726_0 -> 965 in the cache */
   /* search1726_1 -> 4905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal3,
      0, 2,
      { 965, 4905 },
      -1,
   } },

   /* replace1726_0 -> 0 in the cache */
   /* replace1726_1 -> 3 in the cache */
   /* replace1726 -> 2322 in the cache */

   /* ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b') */
   /* search1727_0_0 -> 0 in the cache */
   /* search1727_0_1 -> 3 in the cache */
   /* search1727_0 -> 4908 in the cache */
   /* search1727_1 -> 4909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal3,
      0, 2,
      { 4908, 4909 },
      -1,
   } },

   /* replace1727_0 -> 0 in the cache */
   /* replace1727_1 -> 3 in the cache */
   /* replace1727 -> 2307 in the cache */

   /* ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b') */
   /* search1728_0_0 -> 0 in the cache */
   /* search1728_0_1 -> 3 in the cache */
   /* search1728_0 -> 3621 in the cache */
   /* search1728_1 -> 4909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal3,
      0, 2,
      { 3621, 4909 },
      -1,
   } },

   /* replace1728_0 -> 0 in the cache */
   /* replace1728_1 -> 3 in the cache */
   /* replace1728 -> 2337 in the cache */

   /* ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b') */
   /* search1729_0_0 -> 0 in the cache */
   /* search1729_0_1 -> 3 in the cache */
   /* search1729_0 -> 971 in the cache */
   /* search1729_1 -> 4905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal4,
      0, 2,
      { 971, 4905 },
      -1,
   } },

   /* replace1729_0 -> 0 in the cache */
   /* replace1729_1 -> 3 in the cache */
   /* replace1729 -> 2296 in the cache */

   /* ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b') */
   /* search1730_0_0 -> 0 in the cache */
   /* search1730_0_1 -> 3 in the cache */
   /* search1730_0 -> 965 in the cache */
   /* search1730_1 -> 4905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal4,
      0, 2,
      { 965, 4905 },
      -1,
   } },

   /* replace1730_0 -> 0 in the cache */
   /* replace1730_1 -> 3 in the cache */
   /* replace1730 -> 2328 in the cache */

   /* ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b') */
   /* search1731_0_0 -> 0 in the cache */
   /* search1731_0_1 -> 3 in the cache */
   /* search1731_0 -> 4908 in the cache */
   /* search1731_1 -> 4909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal4,
      0, 2,
      { 4908, 4909 },
      -1,
   } },

   /* replace1731_0 -> 0 in the cache */
   /* replace1731_1 -> 3 in the cache */
   /* replace1731 -> 2313 in the cache */

   /* ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b') */
   /* search1732_0_0 -> 0 in the cache */
   /* search1732_0_1 -> 3 in the cache */
   /* search1732_0 -> 3621 in the cache */
   /* search1732_1 -> 4909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal4,
      0, 2,
      { 3621, 4909 },
      -1,
   } },

   /* replace1732_0 -> 0 in the cache */
   /* replace1732_1 -> 3 in the cache */
   /* replace1732 -> 2343 in the cache */

   /* ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b') */
   /* search1733_0_0 -> 0 in the cache */
   /* search1733_0_1 -> 3 in the cache */
   /* search1733_0 -> 971 in the cache */
   /* search1733_1 -> 4905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal8,
      0, 2,
      { 971, 4905 },
      -1,
   } },

   /* replace1733_0 -> 0 in the cache */
   /* replace1733_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b') */
   /* search1734_0_0 -> 0 in the cache */
   /* search1734_0_1 -> 3 in the cache */
   /* search1734_0 -> 965 in the cache */
   /* search1734_1 -> 4905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal8,
      0, 2,
      { 965, 4905 },
      -1,
   } },

   /* replace1734_0 -> 0 in the cache */
   /* replace1734_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_fequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b') */
   /* search1735_0_0 -> 0 in the cache */
   /* search1735_0_1 -> 3 in the cache */
   /* search1735_0 -> 4908 in the cache */
   /* search1735_1 -> 4909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal8,
      0, 2,
      { 4908, 4909 },
      -1,
   } },

   /* replace1735_0 -> 0 in the cache */
   /* replace1735_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b') */
   /* search1736_0_0 -> 0 in the cache */
   /* search1736_0_1 -> 3 in the cache */
   /* search1736_0 -> 3621 in the cache */
   /* search1736_1 -> 4909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal8,
      0, 2,
      { 3621, 4909 },
      -1,
   } },

   /* replace1736_0 -> 0 in the cache */
   /* replace1736_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_fnequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b') */
   /* search1737_0_0 -> 0 in the cache */
   /* search1737_0_1 -> 3 in the cache */
   /* search1737_0 -> 971 in the cache */
   /* search1737_1 -> 4905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal16,
      0, 2,
      { 971, 4905 },
      -1,
   } },

   /* replace1737_0 -> 0 in the cache */
   /* replace1737_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b') */
   /* search1738_0_0 -> 0 in the cache */
   /* search1738_0_1 -> 3 in the cache */
   /* search1738_0 -> 965 in the cache */
   /* search1738_1 -> 4905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_iequal16,
      0, 2,
      { 965, 4905 },
      -1,
   } },

   /* replace1738_0 -> 0 in the cache */
   /* replace1738_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ball_fequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b') */
   /* search1739_0_0 -> 0 in the cache */
   /* search1739_0_1 -> 3 in the cache */
   /* search1739_0 -> 4908 in the cache */
   /* search1739_1 -> 4909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal16,
      0, 2,
      { 4908, 4909 },
      -1,
   } },

   /* replace1739_0 -> 0 in the cache */
   /* replace1739_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b') */
   /* search1740_0_0 -> 0 in the cache */
   /* search1740_0_1 -> 3 in the cache */
   /* search1740_0 -> 3621 in the cache */
   /* search1740_1 -> 4909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_inequal16,
      0, 2,
      { 3621, 4909 },
      -1,
   } },

   /* replace1740_0 -> 0 in the cache */
   /* replace1740_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bany_fnequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b') */
   /* search1741_0_0 -> 0 in the cache */
   /* search1741_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1741_1_0 -> 0 in the cache */
   /* search1741_1_1 -> 3 in the cache */
   /* search1741_1 -> 940 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4936, 940 },
      -1,
   } },

   /* replace1741_0 -> 0 in the cache */
   /* replace1741_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a') */
   /* search1742_0_0 -> 32 in the cache */
   /* search1742_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   /* search1742_1_0 -> 2126 in the cache */
   /* search1742_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 2126, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4939, 4940 },
      -1,
   } },

   /* replace1742_0 -> 2126 in the cache */
   /* replace1742_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_flt,
      -1, 0,
      { 2126, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b') */
   /* search1743_0_0 -> 0 in the cache */
   /* search1743_0_1 -> 0 in the cache */
   /* search1743_0 -> 4936 in the cache */
   /* search1743_1_0 -> 0 in the cache */
   /* search1743_1_1 -> 3 in the cache */
   /* search1743_1 -> 937 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4936, 937 },
      -1,
   } },

   /* replace1743_0 -> 0 in the cache */
   /* replace1743_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a') */
   /* search1744_0_0 -> 32 in the cache */
   /* search1744_0_1 -> 32 in the cache */
   /* search1744_0 -> 4939 in the cache */
   /* search1744_1_0 -> 2126 in the cache */
   /* search1744_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 2126, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 4939, 4945 },
      -1,
   } },

   /* replace1744_0 -> 2126 in the cache */
   /* replace1744_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_fge,
      -1, 0,
      { 2126, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b') */
   /* search1745_0_0 -> 0 in the cache */
   /* search1745_0_1 -> 0 in the cache */
   /* search1745_0 -> 4936 in the cache */
   /* search1745_1_0 -> 0 in the cache */
   /* search1745_1_1 -> 3 in the cache */
   /* search1745_1 -> 965 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4936, 965 },
      -1,
   } },

   /* replace1745_0 -> 0 in the cache */
   /* replace1745_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a') */
   /* search1746_0_0 -> 32 in the cache */
   /* search1746_0_1 -> 32 in the cache */
   /* search1746_0 -> 4939 in the cache */
   /* search1746_1_0 -> 2126 in the cache */
   /* search1746_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      1, 1,
      { 2126, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 4939, 4950 },
      -1,
   } },

   /* replace1746_0 -> 2126 in the cache */
   /* replace1746_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_feq,
      0, 1,
      { 2126, 32 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd')) */
   /* search1747_0_0 -> 650 in the cache */
   /* search1747_0_1 -> 919 in the cache */
   /* search1747_0_2 -> 3096 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 919, 3096 },
      -1,
   } },
   /* search1747_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 4953, 922 },
      -1,
   } },

   /* replace1747_0 -> 650 in the cache */
   /* replace1747_1_0 -> 142 in the cache */
   /* replace1747_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 142, 145 },
      -1,
   } },
   /* replace1747_2_0 -> 144 in the cache */
   /* replace1747_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      1, 1,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 4955, 4956 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd')) */
   /* search1748_0_0 -> 650 in the cache */
   /* search1748_0_1 -> 919 in the cache */
   /* search1748_0_2 -> 3096 in the cache */
   /* search1748_0 -> 4953 in the cache */
   /* search1748_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 4953, 922 },
      -1,
   } },

   /* replace1748_0 -> 650 in the cache */
   /* replace1748_1_0 -> 142 in the cache */
   /* replace1748_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 142, 145 },
      -1,
   } },
   /* replace1748_2_0 -> 144 in the cache */
   /* replace1748_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      1, 1,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 4959, 4960 },
      -1,
   } },

   /* ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd')) */
   /* search1749_0_0 -> 650 in the cache */
   /* search1749_0_1 -> 919 in the cache */
   /* search1749_0_2 -> 3096 in the cache */
   /* search1749_0 -> 4953 in the cache */
   /* search1749_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 4953, 922 },
      -1,
   } },

   /* replace1749_0 -> 650 in the cache */
   /* replace1749_1_0 -> 142 in the cache */
   /* replace1749_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 1,
      { 142, 145 },
      -1,
   } },
   /* replace1749_2_0 -> 144 in the cache */
   /* replace1749_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 4963, 4964 },
      -1,
   } },

   /* ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd')) */
   /* search1750_0_0 -> 650 in the cache */
   /* search1750_0_1 -> 919 in the cache */
   /* search1750_0_2 -> 3096 in the cache */
   /* search1750_0 -> 4953 in the cache */
   /* search1750_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 4953, 922 },
      -1,
   } },

   /* replace1750_0 -> 650 in the cache */
   /* replace1750_1_0 -> 142 in the cache */
   /* replace1750_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 1,
      { 142, 145 },
      -1,
   } },
   /* replace1750_2_0 -> 144 in the cache */
   /* replace1750_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 4967, 4968 },
      -1,
   } },

   /* ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd')) */
   /* search1751_0_0 -> 650 in the cache */
   /* search1751_0_1 -> 919 in the cache */
   /* search1751_0_2 -> 3096 in the cache */
   /* search1751_0 -> 4953 in the cache */
   /* search1751_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 4953, 922 },
      -1,
   } },

   /* replace1751_0 -> 650 in the cache */
   /* replace1751_1_0 -> 142 in the cache */
   /* replace1751_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 142, 145 },
      -1,
   } },
   /* replace1751_2_0 -> 144 in the cache */
   /* replace1751_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 4971, 4972 },
      -1,
   } },

   /* ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1752_1_0 -> 1060 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1060, 4975, 4976 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 4974, 4977 },
      -1,
   } },

   /* replace1752_0 -> 1060 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 4979, 4980 },
      -1,
   } },
   /* replace1752_2_0 -> 4979 in the cache */
   /* replace1752_2_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 4979, 1594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1060, 4981, 4982 },
      -1,
   } },

   /* ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd')) */
   /* search1753_0_0 -> 650 in the cache */
   /* search1753_0_1 -> 919 in the cache */
   /* search1753_0_2 -> 3096 in the cache */
   /* search1753_0 -> 4953 in the cache */
   /* search1753_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 4953, 922 },
      -1,
   } },

   /* replace1753_0 -> 650 in the cache */
   /* replace1753_1_0 -> 142 in the cache */
   /* replace1753_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 142, 145 },
      -1,
   } },
   /* replace1753_2_0 -> 144 in the cache */
   /* replace1753_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 4985, 4986 },
      -1,
   } },

   /* ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c')) */
   /* search1754_0 -> 4974 in the cache */
   /* search1754_1_0 -> 1060 in the cache */
   /* search1754_1_1 -> 4975 in the cache */
   /* search1754_1_2 -> 4976 in the cache */
   /* search1754_1 -> 4977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 4974, 4977 },
      -1,
   } },

   /* replace1754_0 -> 1060 in the cache */
   /* replace1754_1_0 -> 4979 in the cache */
   /* replace1754_1_1 -> 4980 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 4979, 4980 },
      -1,
   } },
   /* replace1754_2_0 -> 4979 in the cache */
   /* replace1754_2_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 4979, 1594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1060, 4989, 4990 },
      -1,
   } },

   /* ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd')) */
   /* search1755_0_0 -> 650 in the cache */
   /* search1755_0_1 -> 919 in the cache */
   /* search1755_0_2 -> 3096 in the cache */
   /* search1755_0 -> 4953 in the cache */
   /* search1755_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4953, 922 },
      -1,
   } },

   /* replace1755_0 -> 650 in the cache */
   /* replace1755_1_0 -> 142 in the cache */
   /* replace1755_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 142, 145 },
      -1,
   } },
   /* replace1755_2_0 -> 144 in the cache */
   /* replace1755_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 4993, 4994 },
      -1,
   } },

   /* ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c')) */
   /* search1756_0 -> 4974 in the cache */
   /* search1756_1_0 -> 1060 in the cache */
   /* search1756_1_1 -> 4975 in the cache */
   /* search1756_1_2 -> 4976 in the cache */
   /* search1756_1 -> 4977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4974, 4977 },
      -1,
   } },

   /* replace1756_0 -> 1060 in the cache */
   /* replace1756_1_0 -> 4979 in the cache */
   /* replace1756_1_1 -> 4980 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4979, 4980 },
      -1,
   } },
   /* replace1756_2_0 -> 4979 in the cache */
   /* replace1756_2_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ilt,
      -1, 0,
      { 4979, 1594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1060, 4997, 4998 },
      -1,
   } },

   /* ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd')) */
   /* search1757_0_0 -> 650 in the cache */
   /* search1757_0_1 -> 919 in the cache */
   /* search1757_0_2 -> 3096 in the cache */
   /* search1757_0 -> 4953 in the cache */
   /* search1757_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4953, 922 },
      -1,
   } },

   /* replace1757_0 -> 650 in the cache */
   /* replace1757_1_0 -> 142 in the cache */
   /* replace1757_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 142, 145 },
      -1,
   } },
   /* replace1757_2_0 -> 144 in the cache */
   /* replace1757_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5001, 5002 },
      -1,
   } },

   /* ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c')) */
   /* search1758_0 -> 4974 in the cache */
   /* search1758_1_0 -> 1060 in the cache */
   /* search1758_1_1 -> 4975 in the cache */
   /* search1758_1_2 -> 4976 in the cache */
   /* search1758_1 -> 4977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4974, 4977 },
      -1,
   } },

   /* replace1758_0 -> 1060 in the cache */
   /* replace1758_1_0 -> 4979 in the cache */
   /* replace1758_1_1 -> 4980 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4979, 4980 },
      -1,
   } },
   /* replace1758_2_0 -> 4979 in the cache */
   /* replace1758_2_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ige,
      -1, 0,
      { 4979, 1594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1060, 5005, 5006 },
      -1,
   } },

   /* ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd')) */
   /* search1759_0_0 -> 650 in the cache */
   /* search1759_0_1 -> 919 in the cache */
   /* search1759_0_2 -> 3096 in the cache */
   /* search1759_0 -> 4953 in the cache */
   /* search1759_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4953, 922 },
      -1,
   } },

   /* replace1759_0 -> 650 in the cache */
   /* replace1759_1_0 -> 142 in the cache */
   /* replace1759_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 142, 145 },
      -1,
   } },
   /* replace1759_2_0 -> 144 in the cache */
   /* replace1759_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5009, 5010 },
      -1,
   } },

   /* ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c')) */
   /* search1760_0 -> 4974 in the cache */
   /* search1760_1_0 -> 1060 in the cache */
   /* search1760_1_1 -> 4975 in the cache */
   /* search1760_1_2 -> 4976 in the cache */
   /* search1760_1 -> 4977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4974, 4977 },
      -1,
   } },

   /* replace1760_0 -> 1060 in the cache */
   /* replace1760_1_0 -> 4979 in the cache */
   /* replace1760_1_1 -> 4980 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4979, 4980 },
      -1,
   } },
   /* replace1760_2_0 -> 4979 in the cache */
   /* replace1760_2_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 0,
      { 4979, 1594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1060, 5013, 5014 },
      -1,
   } },

   /* ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd')) */
   /* search1761_0_0 -> 650 in the cache */
   /* search1761_0_1 -> 919 in the cache */
   /* search1761_0_2 -> 3096 in the cache */
   /* search1761_0 -> 4953 in the cache */
   /* search1761_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4953, 922 },
      -1,
   } },

   /* replace1761_0 -> 650 in the cache */
   /* replace1761_1_0 -> 142 in the cache */
   /* replace1761_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 142, 145 },
      -1,
   } },
   /* replace1761_2_0 -> 144 in the cache */
   /* replace1761_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5017, 5018 },
      -1,
   } },

   /* ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c')) */
   /* search1762_0 -> 4974 in the cache */
   /* search1762_1_0 -> 1060 in the cache */
   /* search1762_1_1 -> 4975 in the cache */
   /* search1762_1_2 -> 4976 in the cache */
   /* search1762_1 -> 4977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4974, 4977 },
      -1,
   } },

   /* replace1762_0 -> 1060 in the cache */
   /* replace1762_1_0 -> 4979 in the cache */
   /* replace1762_1_1 -> 4980 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4979, 4980 },
      -1,
   } },
   /* replace1762_2_0 -> 4979 in the cache */
   /* replace1762_2_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_uge,
      -1, 0,
      { 4979, 1594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 1060, 5021, 5022 },
      -1,
   } },

   /* ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd')) */
   /* search1763_0_0 -> 650 in the cache */
   /* search1763_0_1 -> 919 in the cache */
   /* search1763_0_2 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 919, 144 },
      0,
   } },
   /* search1763_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 5024, 922 },
      -1,
   } },

   /* replace1763_0 -> 650 in the cache */
   /* replace1763_1_0 -> 142 in the cache */
   /* replace1763_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 142, 145 },
      -1,
   } },
   /* replace1763_2_0 -> 144 in the cache */
   /* replace1763_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5026, 5027 },
      -1,
   } },

   /* ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd')) */
   /* search1764_0_0 -> 650 in the cache */
   /* search1764_0_1 -> 919 in the cache */
   /* search1764_0_2 -> 144 in the cache */
   /* search1764_0 -> 5024 in the cache */
   /* search1764_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 5024, 922 },
      -1,
   } },

   /* replace1764_0 -> 650 in the cache */
   /* replace1764_1_0 -> 142 in the cache */
   /* replace1764_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 142, 145 },
      -1,
   } },
   /* replace1764_2_0 -> 144 in the cache */
   /* replace1764_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5030, 5031 },
      -1,
   } },

   /* ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd')) */
   /* search1765_0_0 -> 650 in the cache */
   /* search1765_0_1 -> 919 in the cache */
   /* search1765_0_2 -> 144 in the cache */
   /* search1765_0 -> 5024 in the cache */
   /* search1765_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 5024, 922 },
      -1,
   } },

   /* replace1765_0 -> 650 in the cache */
   /* replace1765_1_0 -> 142 in the cache */
   /* replace1765_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 142, 145 },
      -1,
   } },
   /* replace1765_2_0 -> 144 in the cache */
   /* replace1765_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5034, 5035 },
      -1,
   } },

   /* ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd')) */
   /* search1766_0_0 -> 650 in the cache */
   /* search1766_0_1 -> 919 in the cache */
   /* search1766_0_2 -> 144 in the cache */
   /* search1766_0 -> 5024 in the cache */
   /* search1766_1 -> 922 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      0, 1,
      { 5024, 922 },
      -1,
   } },

   /* replace1766_0 -> 650 in the cache */
   /* replace1766_1_0 -> 142 in the cache */
   /* replace1766_1_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      0, 1,
      { 142, 145 },
      -1,
   } },
   /* replace1766_2_0 -> 144 in the cache */
   /* replace1766_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      1, 1,
      { 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5038, 5039 },
      -1,
   } },

   /* ('fddx', 'a') => 0.0 */
   /* search1767_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fddx,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1767 -> 113 in the cache */

   /* ('fddx_fine', 'a') => 0.0 */
   /* search1768_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fddx_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1768 -> 113 in the cache */

   /* ('fddx_coarse', 'a') => 0.0 */
   /* search1769_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fddx_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1769 -> 113 in the cache */

   /* ('fddy', 'a') => 0.0 */
   /* search1770_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fddy,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1770 -> 113 in the cache */

   /* ('fddy_fine', 'a') => 0.0 */
   /* search1771_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fddy_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1771 -> 113 in the cache */

   /* ('fddy_coarse', 'a') => 0.0 */
   /* search1772_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fddy_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1772 -> 113 in the cache */

   /* ('umul_low', '#a(is_lower_half_zero)', 'b') => 0 */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      27,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1773_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umul_low,
      0, 1,
      { 5047, 36 },
      -1,
   } },

   /* replace1773 -> 120 in the cache */

   /* ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c */
   /* search1774_0 -> 5047 in the cache */
   /* search1774_1 -> 36 in the cache */
   /* search1774_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 5047, 36, 250 },
      -1,
   } },

   /* replace1774 -> 250 in the cache */

   /* ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c */
   /* search1775_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      28,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1775_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 16, 5050, 250 },
      -1,
   } },

   /* replace1775 -> 250 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1776_0 -> 650 in the cache */
   /* search1776_1_0 -> 642 in the cache */
   /* search1776_1_1 -> 643 in the cache */
   /* search1776_1_2 -> 652 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 642, 643, 652 },
      0,
   } },
   /* search1776_2_0 -> 642 in the cache */
   /* search1776_2_1 -> 643 in the cache */
   /* search1776_2_2 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 642, 643, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5052, 5053 },
      -1,
   } },

   /* replace1776_0 -> 642 in the cache */
   /* replace1776_1 -> 643 in the cache */
   /* replace1776_2_0 -> 650 in the cache */
   /* replace1776_2_1 -> 652 in the cache */
   /* replace1776_2_2 -> 654 in the cache */
   /* replace1776_2 -> 1186 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 642, 643, 1186 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1777_0 -> 650 in the cache */
   /* search1777_1_0 -> 642 in the cache */
   /* search1777_1_1 -> 643 in the cache */
   /* search1777_1_2 -> 652 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 642, 643, 652 },
      -1,
   } },
   /* search1777_2_0 -> 642 in the cache */
   /* search1777_2_1 -> 643 in the cache */
   /* search1777_2_2 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 642, 643, 654 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5056, 5057 },
      -1,
   } },

   /* replace1777_0 -> 642 in the cache */
   /* replace1777_1 -> 643 in the cache */
   /* replace1777_2_0 -> 650 in the cache */
   /* replace1777_2_1 -> 652 in the cache */
   /* replace1777_2_2 -> 654 in the cache */
   /* replace1777_2 -> 1186 in the cache */
   /* replace1777 -> 5055 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1778_0 -> 650 in the cache */
   /* search1778_1_0 -> 642 in the cache */
   /* search1778_1_1 -> 643 in the cache */
   /* search1778_1_2 -> 652 in the cache */
   /* search1778_1 -> 5052 in the cache */
   /* search1778_2_0 -> 642 in the cache */
   /* search1778_2_1 -> 654 in the cache */
   /* search1778_2_2 -> 652 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 642, 654, 652 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5052, 5059 },
      -1,
   } },

   /* replace1778_0 -> 642 in the cache */
   /* replace1778_1_0 -> 650 in the cache */
   /* replace1778_1_1 -> 643 in the cache */
   /* replace1778_1_2 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 643, 654 },
      -1,
   } },
   /* replace1778_2 -> 652 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 642, 5061, 652 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1779_0 -> 650 in the cache */
   /* search1779_1_0 -> 642 in the cache */
   /* search1779_1_1 -> 643 in the cache */
   /* search1779_1_2 -> 652 in the cache */
   /* search1779_1 -> 5056 in the cache */
   /* search1779_2_0 -> 642 in the cache */
   /* search1779_2_1 -> 654 in the cache */
   /* search1779_2_2 -> 652 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 642, 654, 652 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5056, 5063 },
      -1,
   } },

   /* replace1779_0 -> 642 in the cache */
   /* replace1779_1_0 -> 650 in the cache */
   /* replace1779_1_1 -> 643 in the cache */
   /* replace1779_1_2 -> 654 in the cache */
   /* replace1779_1 -> 5061 in the cache */
   /* replace1779_2 -> 652 in the cache */
   /* replace1779 -> 5062 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1780_0 -> 650 in the cache */
   /* search1780_1_0 -> 142 in the cache */
   /* search1780_1_1 -> 144 in the cache */
   /* search1780_1_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 142, 144, 145 },
      0,
   } },
   /* search1780_2_0 -> 1192 in the cache */
   /* search1780_2_1 -> 144 in the cache */
   /* search1780_2_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 1192, 144, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5065, 5066 },
      -1,
   } },

   /* replace1780_0_0 -> 650 in the cache */
   /* replace1780_0_1 -> 142 in the cache */
   /* replace1780_0_2 -> 1192 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 142, 1192 },
      -1,
   } },
   /* replace1780_1 -> 144 in the cache */
   /* replace1780_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 5068, 144, 145 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1781_0 -> 650 in the cache */
   /* search1781_1_0 -> 142 in the cache */
   /* search1781_1_1 -> 144 in the cache */
   /* search1781_1_2 -> 145 in the cache */
   /* search1781_1 -> 607 in the cache */
   /* search1781_2_0 -> 1192 in the cache */
   /* search1781_2_1 -> 144 in the cache */
   /* search1781_2_2 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 1192, 144, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 607, 5070 },
      -1,
   } },

   /* replace1781_0_0 -> 650 in the cache */
   /* replace1781_0_1 -> 142 in the cache */
   /* replace1781_0_2 -> 1192 in the cache */
   /* replace1781_0 -> 5068 in the cache */
   /* replace1781_1 -> 144 in the cache */
   /* replace1781_2 -> 145 in the cache */
   /* replace1781 -> 5069 in the cache */

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1782_0 -> 650 in the cache */
   /* search1782_1_0 -> 142 in the cache */
   /* search1782_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1782_2_0 -> 142 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5072, 5074 },
      -1,
   } },

   /* replace1782_0 -> 142 in the cache */
   /* replace1782_1_0 -> 650 in the cache */
   /* replace1782_1_1 -> 144 in the cache */
   /* replace1782_1_2 -> 145 in the cache */
   /* replace1782_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1783_0 -> 650 in the cache */
   /* search1783_1_0 -> 142 in the cache */
   /* search1783_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1783_2_0 -> 142 in the cache */
   /* search1783_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5077, 5078 },
      -1,
   } },

   /* replace1783_0 -> 142 in the cache */
   /* replace1783_1_0 -> 650 in the cache */
   /* replace1783_1_1 -> 144 in the cache */
   /* replace1783_1_2 -> 145 in the cache */
   /* replace1783_1 -> 1181 in the cache */
   /* replace1783 -> 5076 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1784_0 -> 650 in the cache */
   /* search1784_1_0 -> 142 in the cache */
   /* search1784_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1784_2_0 -> 142 in the cache */
   /* search1784_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5080, 5081 },
      -1,
   } },

   /* replace1784_0 -> 142 in the cache */
   /* replace1784_1_0 -> 650 in the cache */
   /* replace1784_1_1 -> 144 in the cache */
   /* replace1784_1_2 -> 145 in the cache */
   /* replace1784_1 -> 1181 in the cache */
   /* replace1784 -> 5076 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1785_0 -> 650 in the cache */
   /* search1785_1_0 -> 142 in the cache */
   /* search1785_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1785_2_0 -> 142 in the cache */
   /* search1785_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5083, 5084 },
      -1,
   } },

   /* replace1785_0 -> 142 in the cache */
   /* replace1785_1_0 -> 650 in the cache */
   /* replace1785_1_1 -> 144 in the cache */
   /* replace1785_1_2 -> 145 in the cache */
   /* replace1785_1 -> 1181 in the cache */
   /* replace1785 -> 5076 in the cache */

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1786_0 -> 650 in the cache */
   /* search1786_1_0 -> 142 in the cache */
   /* search1786_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1786_2_0 -> 142 in the cache */
   /* search1786_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5086, 5087 },
      -1,
   } },

   /* replace1786_0 -> 142 in the cache */
   /* replace1786_1_0 -> 650 in the cache */
   /* replace1786_1_1 -> 144 in the cache */
   /* replace1786_1_2 -> 145 in the cache */
   /* replace1786_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1787_0 -> 650 in the cache */
   /* search1787_1_0 -> 142 in the cache */
   /* search1787_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1787_2_0 -> 142 in the cache */
   /* search1787_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5090, 5091 },
      -1,
   } },

   /* replace1787_0 -> 142 in the cache */
   /* replace1787_1_0 -> 650 in the cache */
   /* replace1787_1_1 -> 144 in the cache */
   /* replace1787_1_2 -> 145 in the cache */
   /* replace1787_1 -> 1181 in the cache */
   /* replace1787 -> 5089 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1788_0 -> 650 in the cache */
   /* search1788_1_0 -> 142 in the cache */
   /* search1788_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1788_2_0 -> 142 in the cache */
   /* search1788_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5093, 5094 },
      -1,
   } },

   /* replace1788_0 -> 142 in the cache */
   /* replace1788_1_0 -> 650 in the cache */
   /* replace1788_1_1 -> 144 in the cache */
   /* replace1788_1_2 -> 145 in the cache */
   /* replace1788_1 -> 1181 in the cache */
   /* replace1788 -> 5089 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1789_0 -> 650 in the cache */
   /* search1789_1_0 -> 142 in the cache */
   /* search1789_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1789_2_0 -> 142 in the cache */
   /* search1789_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5096, 5097 },
      -1,
   } },

   /* replace1789_0 -> 142 in the cache */
   /* replace1789_1_0 -> 650 in the cache */
   /* replace1789_1_1 -> 144 in the cache */
   /* replace1789_1_2 -> 145 in the cache */
   /* replace1789_1 -> 1181 in the cache */
   /* replace1789 -> 5089 in the cache */

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1790_0 -> 650 in the cache */
   /* search1790_1_0 -> 142 in the cache */
   /* search1790_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1790_2_0 -> 142 in the cache */
   /* search1790_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5099, 5100 },
      -1,
   } },

   /* replace1790_0 -> 142 in the cache */
   /* replace1790_1_0 -> 650 in the cache */
   /* replace1790_1_1 -> 144 in the cache */
   /* replace1790_1_2 -> 145 in the cache */
   /* replace1790_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1791_0 -> 650 in the cache */
   /* search1791_1_0 -> 142 in the cache */
   /* search1791_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1791_2_0 -> 142 in the cache */
   /* search1791_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5103, 5104 },
      -1,
   } },

   /* replace1791_0 -> 142 in the cache */
   /* replace1791_1_0 -> 650 in the cache */
   /* replace1791_1_1 -> 144 in the cache */
   /* replace1791_1_2 -> 145 in the cache */
   /* replace1791_1 -> 1181 in the cache */
   /* replace1791 -> 5102 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1792_0 -> 650 in the cache */
   /* search1792_1_0 -> 142 in the cache */
   /* search1792_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1792_2_0 -> 142 in the cache */
   /* search1792_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5106, 5107 },
      -1,
   } },

   /* replace1792_0 -> 142 in the cache */
   /* replace1792_1_0 -> 650 in the cache */
   /* replace1792_1_1 -> 144 in the cache */
   /* replace1792_1_2 -> 145 in the cache */
   /* replace1792_1 -> 1181 in the cache */
   /* replace1792 -> 5102 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1793_0 -> 650 in the cache */
   /* search1793_1_0 -> 142 in the cache */
   /* search1793_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1793_2_0 -> 142 in the cache */
   /* search1793_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imul,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5109, 5110 },
      -1,
   } },

   /* replace1793_0 -> 142 in the cache */
   /* replace1793_1_0 -> 650 in the cache */
   /* replace1793_1_1 -> 144 in the cache */
   /* replace1793_1_2 -> 145 in the cache */
   /* replace1793_1 -> 1181 in the cache */
   /* replace1793 -> 5102 in the cache */

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1794_0 -> 650 in the cache */
   /* search1794_1_0 -> 142 in the cache */
   /* search1794_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iand,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1794_2_0 -> 142 in the cache */
   /* search1794_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iand,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5112, 5113 },
      -1,
   } },

   /* replace1794_0 -> 142 in the cache */
   /* replace1794_1_0 -> 650 in the cache */
   /* replace1794_1_1 -> 144 in the cache */
   /* replace1794_1_2 -> 145 in the cache */
   /* replace1794_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iand,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1795_0 -> 650 in the cache */
   /* search1795_1_0 -> 142 in the cache */
   /* search1795_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iand,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1795_2_0 -> 142 in the cache */
   /* search1795_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iand,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5116, 5117 },
      -1,
   } },

   /* replace1795_0 -> 142 in the cache */
   /* replace1795_1_0 -> 650 in the cache */
   /* replace1795_1_1 -> 144 in the cache */
   /* replace1795_1_2 -> 145 in the cache */
   /* replace1795_1 -> 1181 in the cache */
   /* replace1795 -> 5115 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1796_0 -> 650 in the cache */
   /* search1796_1_0 -> 142 in the cache */
   /* search1796_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iand,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1796_2_0 -> 142 in the cache */
   /* search1796_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iand,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5119, 5120 },
      -1,
   } },

   /* replace1796_0 -> 142 in the cache */
   /* replace1796_1_0 -> 650 in the cache */
   /* replace1796_1_1 -> 144 in the cache */
   /* replace1796_1_2 -> 145 in the cache */
   /* replace1796_1 -> 1181 in the cache */
   /* replace1796 -> 5115 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1797_0 -> 650 in the cache */
   /* search1797_1_0 -> 142 in the cache */
   /* search1797_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iand,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1797_2_0 -> 142 in the cache */
   /* search1797_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_iand,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5122, 5123 },
      -1,
   } },

   /* replace1797_0 -> 142 in the cache */
   /* replace1797_1_0 -> 650 in the cache */
   /* replace1797_1_1 -> 144 in the cache */
   /* replace1797_1_2 -> 145 in the cache */
   /* replace1797_1 -> 1181 in the cache */
   /* replace1797 -> 5115 in the cache */

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1798_0 -> 650 in the cache */
   /* search1798_1_0 -> 142 in the cache */
   /* search1798_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ior,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1798_2_0 -> 142 in the cache */
   /* search1798_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ior,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5125, 5126 },
      -1,
   } },

   /* replace1798_0 -> 142 in the cache */
   /* replace1798_1_0 -> 650 in the cache */
   /* replace1798_1_1 -> 144 in the cache */
   /* replace1798_1_2 -> 145 in the cache */
   /* replace1798_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ior,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1799_0 -> 650 in the cache */
   /* search1799_1_0 -> 142 in the cache */
   /* search1799_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ior,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1799_2_0 -> 142 in the cache */
   /* search1799_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ior,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5129, 5130 },
      -1,
   } },

   /* replace1799_0 -> 142 in the cache */
   /* replace1799_1_0 -> 650 in the cache */
   /* replace1799_1_1 -> 144 in the cache */
   /* replace1799_1_2 -> 145 in the cache */
   /* replace1799_1 -> 1181 in the cache */
   /* replace1799 -> 5128 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1800_0 -> 650 in the cache */
   /* search1800_1_0 -> 142 in the cache */
   /* search1800_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ior,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1800_2_0 -> 142 in the cache */
   /* search1800_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ior,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5132, 5133 },
      -1,
   } },

   /* replace1800_0 -> 142 in the cache */
   /* replace1800_1_0 -> 650 in the cache */
   /* replace1800_1_1 -> 144 in the cache */
   /* replace1800_1_2 -> 145 in the cache */
   /* replace1800_1 -> 1181 in the cache */
   /* replace1800 -> 5128 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1801_0 -> 650 in the cache */
   /* search1801_1_0 -> 142 in the cache */
   /* search1801_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ior,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1801_2_0 -> 142 in the cache */
   /* search1801_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ior,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5135, 5136 },
      -1,
   } },

   /* replace1801_0 -> 142 in the cache */
   /* replace1801_1_0 -> 650 in the cache */
   /* replace1801_1_1 -> 144 in the cache */
   /* replace1801_1_2 -> 145 in the cache */
   /* replace1801_1 -> 1181 in the cache */
   /* replace1801 -> 5128 in the cache */

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1802_0 -> 650 in the cache */
   /* search1802_1_0 -> 142 in the cache */
   /* search1802_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1802_2_0 -> 142 in the cache */
   /* search1802_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ixor,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5138, 5139 },
      -1,
   } },

   /* replace1802_0 -> 142 in the cache */
   /* replace1802_1_0 -> 650 in the cache */
   /* replace1802_1_1 -> 144 in the cache */
   /* replace1802_1_2 -> 145 in the cache */
   /* replace1802_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1803_0 -> 650 in the cache */
   /* search1803_1_0 -> 142 in the cache */
   /* search1803_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1803_2_0 -> 142 in the cache */
   /* search1803_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ixor,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5142, 5143 },
      -1,
   } },

   /* replace1803_0 -> 142 in the cache */
   /* replace1803_1_0 -> 650 in the cache */
   /* replace1803_1_1 -> 144 in the cache */
   /* replace1803_1_2 -> 145 in the cache */
   /* replace1803_1 -> 1181 in the cache */
   /* replace1803 -> 5141 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1804_0 -> 650 in the cache */
   /* search1804_1_0 -> 142 in the cache */
   /* search1804_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1804_2_0 -> 142 in the cache */
   /* search1804_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ixor,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5145, 5146 },
      -1,
   } },

   /* replace1804_0 -> 142 in the cache */
   /* replace1804_1_0 -> 650 in the cache */
   /* replace1804_1_1 -> 144 in the cache */
   /* replace1804_1_2 -> 145 in the cache */
   /* replace1804_1 -> 1181 in the cache */
   /* replace1804 -> 5141 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1805_0 -> 650 in the cache */
   /* search1805_1_0 -> 142 in the cache */
   /* search1805_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ixor,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1805_2_0 -> 142 in the cache */
   /* search1805_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_ixor,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5148, 5149 },
      -1,
   } },

   /* replace1805_0 -> 142 in the cache */
   /* replace1805_1_0 -> 650 in the cache */
   /* replace1805_1_1 -> 144 in the cache */
   /* replace1805_1_2 -> 145 in the cache */
   /* replace1805_1 -> 1181 in the cache */
   /* replace1805 -> 5141 in the cache */

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1806_0 -> 650 in the cache */
   /* search1806_1_0 -> 142 in the cache */
   /* search1806_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1806_2_0 -> 142 in the cache */
   /* search1806_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmin,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5151, 5152 },
      -1,
   } },

   /* replace1806_0 -> 142 in the cache */
   /* replace1806_1_0 -> 650 in the cache */
   /* replace1806_1_1 -> 144 in the cache */
   /* replace1806_1_2 -> 145 in the cache */
   /* replace1806_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1807_0 -> 650 in the cache */
   /* search1807_1_0 -> 142 in the cache */
   /* search1807_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1807_2_0 -> 142 in the cache */
   /* search1807_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmin,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5155, 5156 },
      -1,
   } },

   /* replace1807_0 -> 142 in the cache */
   /* replace1807_1_0 -> 650 in the cache */
   /* replace1807_1_1 -> 144 in the cache */
   /* replace1807_1_2 -> 145 in the cache */
   /* replace1807_1 -> 1181 in the cache */
   /* replace1807 -> 5154 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1808_0 -> 650 in the cache */
   /* search1808_1_0 -> 142 in the cache */
   /* search1808_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1808_2_0 -> 142 in the cache */
   /* search1808_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmin,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5158, 5159 },
      -1,
   } },

   /* replace1808_0 -> 142 in the cache */
   /* replace1808_1_0 -> 650 in the cache */
   /* replace1808_1_1 -> 144 in the cache */
   /* replace1808_1_2 -> 145 in the cache */
   /* replace1808_1 -> 1181 in the cache */
   /* replace1808 -> 5154 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1809_0 -> 650 in the cache */
   /* search1809_1_0 -> 142 in the cache */
   /* search1809_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1809_2_0 -> 142 in the cache */
   /* search1809_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmin,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5161, 5162 },
      -1,
   } },

   /* replace1809_0 -> 142 in the cache */
   /* replace1809_1_0 -> 650 in the cache */
   /* replace1809_1_1 -> 144 in the cache */
   /* replace1809_1_2 -> 145 in the cache */
   /* replace1809_1 -> 1181 in the cache */
   /* replace1809 -> 5154 in the cache */

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1810_0 -> 650 in the cache */
   /* search1810_1_0 -> 142 in the cache */
   /* search1810_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1810_2_0 -> 142 in the cache */
   /* search1810_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5164, 5165 },
      -1,
   } },

   /* replace1810_0 -> 142 in the cache */
   /* replace1810_1_0 -> 650 in the cache */
   /* replace1810_1_1 -> 144 in the cache */
   /* replace1810_1_2 -> 145 in the cache */
   /* replace1810_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1811_0 -> 650 in the cache */
   /* search1811_1_0 -> 142 in the cache */
   /* search1811_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1811_2_0 -> 142 in the cache */
   /* search1811_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5168, 5169 },
      -1,
   } },

   /* replace1811_0 -> 142 in the cache */
   /* replace1811_1_0 -> 650 in the cache */
   /* replace1811_1_1 -> 144 in the cache */
   /* replace1811_1_2 -> 145 in the cache */
   /* replace1811_1 -> 1181 in the cache */
   /* replace1811 -> 5167 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1812_0 -> 650 in the cache */
   /* search1812_1_0 -> 142 in the cache */
   /* search1812_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1812_2_0 -> 142 in the cache */
   /* search1812_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5171, 5172 },
      -1,
   } },

   /* replace1812_0 -> 142 in the cache */
   /* replace1812_1_0 -> 650 in the cache */
   /* replace1812_1_1 -> 144 in the cache */
   /* replace1812_1_2 -> 145 in the cache */
   /* replace1812_1 -> 1181 in the cache */
   /* replace1812 -> 5167 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1813_0 -> 650 in the cache */
   /* search1813_1_0 -> 142 in the cache */
   /* search1813_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1813_2_0 -> 142 in the cache */
   /* search1813_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5174, 5175 },
      -1,
   } },

   /* replace1813_0 -> 142 in the cache */
   /* replace1813_1_0 -> 650 in the cache */
   /* replace1813_1_1 -> 144 in the cache */
   /* replace1813_1_2 -> 145 in the cache */
   /* replace1813_1 -> 1181 in the cache */
   /* replace1813 -> 5167 in the cache */

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1814_0 -> 650 in the cache */
   /* search1814_1_0 -> 142 in the cache */
   /* search1814_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imin,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1814_2_0 -> 142 in the cache */
   /* search1814_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imin,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5177, 5178 },
      -1,
   } },

   /* replace1814_0 -> 142 in the cache */
   /* replace1814_1_0 -> 650 in the cache */
   /* replace1814_1_1 -> 144 in the cache */
   /* replace1814_1_2 -> 145 in the cache */
   /* replace1814_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imin,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1815_0 -> 650 in the cache */
   /* search1815_1_0 -> 142 in the cache */
   /* search1815_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imin,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1815_2_0 -> 142 in the cache */
   /* search1815_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imin,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5181, 5182 },
      -1,
   } },

   /* replace1815_0 -> 142 in the cache */
   /* replace1815_1_0 -> 650 in the cache */
   /* replace1815_1_1 -> 144 in the cache */
   /* replace1815_1_2 -> 145 in the cache */
   /* replace1815_1 -> 1181 in the cache */
   /* replace1815 -> 5180 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1816_0 -> 650 in the cache */
   /* search1816_1_0 -> 142 in the cache */
   /* search1816_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imin,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1816_2_0 -> 142 in the cache */
   /* search1816_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imin,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5184, 5185 },
      -1,
   } },

   /* replace1816_0 -> 142 in the cache */
   /* replace1816_1_0 -> 650 in the cache */
   /* replace1816_1_1 -> 144 in the cache */
   /* replace1816_1_2 -> 145 in the cache */
   /* replace1816_1 -> 1181 in the cache */
   /* replace1816 -> 5180 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1817_0 -> 650 in the cache */
   /* search1817_1_0 -> 142 in the cache */
   /* search1817_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imin,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1817_2_0 -> 142 in the cache */
   /* search1817_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imin,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5187, 5188 },
      -1,
   } },

   /* replace1817_0 -> 142 in the cache */
   /* replace1817_1_0 -> 650 in the cache */
   /* replace1817_1_1 -> 144 in the cache */
   /* replace1817_1_2 -> 145 in the cache */
   /* replace1817_1 -> 1181 in the cache */
   /* replace1817 -> 5180 in the cache */

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1818_0 -> 650 in the cache */
   /* search1818_1_0 -> 142 in the cache */
   /* search1818_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imax,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1818_2_0 -> 142 in the cache */
   /* search1818_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imax,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5190, 5191 },
      -1,
   } },

   /* replace1818_0 -> 142 in the cache */
   /* replace1818_1_0 -> 650 in the cache */
   /* replace1818_1_1 -> 144 in the cache */
   /* replace1818_1_2 -> 145 in the cache */
   /* replace1818_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imax,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1819_0 -> 650 in the cache */
   /* search1819_1_0 -> 142 in the cache */
   /* search1819_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imax,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1819_2_0 -> 142 in the cache */
   /* search1819_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imax,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5194, 5195 },
      -1,
   } },

   /* replace1819_0 -> 142 in the cache */
   /* replace1819_1_0 -> 650 in the cache */
   /* replace1819_1_1 -> 144 in the cache */
   /* replace1819_1_2 -> 145 in the cache */
   /* replace1819_1 -> 1181 in the cache */
   /* replace1819 -> 5193 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1820_0 -> 650 in the cache */
   /* search1820_1_0 -> 142 in the cache */
   /* search1820_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imax,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1820_2_0 -> 142 in the cache */
   /* search1820_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imax,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5197, 5198 },
      -1,
   } },

   /* replace1820_0 -> 142 in the cache */
   /* replace1820_1_0 -> 650 in the cache */
   /* replace1820_1_1 -> 144 in the cache */
   /* replace1820_1_2 -> 145 in the cache */
   /* replace1820_1 -> 1181 in the cache */
   /* replace1820 -> 5193 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1821_0 -> 650 in the cache */
   /* search1821_1_0 -> 142 in the cache */
   /* search1821_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imax,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1821_2_0 -> 142 in the cache */
   /* search1821_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_imax,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5200, 5201 },
      -1,
   } },

   /* replace1821_0 -> 142 in the cache */
   /* replace1821_1_0 -> 650 in the cache */
   /* replace1821_1_1 -> 144 in the cache */
   /* replace1821_1_2 -> 145 in the cache */
   /* replace1821_1 -> 1181 in the cache */
   /* replace1821 -> 5193 in the cache */

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1822_0 -> 650 in the cache */
   /* search1822_1_0 -> 142 in the cache */
   /* search1822_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umin,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1822_2_0 -> 142 in the cache */
   /* search1822_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umin,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5203, 5204 },
      -1,
   } },

   /* replace1822_0 -> 142 in the cache */
   /* replace1822_1_0 -> 650 in the cache */
   /* replace1822_1_1 -> 144 in the cache */
   /* replace1822_1_2 -> 145 in the cache */
   /* replace1822_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umin,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1823_0 -> 650 in the cache */
   /* search1823_1_0 -> 142 in the cache */
   /* search1823_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umin,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1823_2_0 -> 142 in the cache */
   /* search1823_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umin,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5207, 5208 },
      -1,
   } },

   /* replace1823_0 -> 142 in the cache */
   /* replace1823_1_0 -> 650 in the cache */
   /* replace1823_1_1 -> 144 in the cache */
   /* replace1823_1_2 -> 145 in the cache */
   /* replace1823_1 -> 1181 in the cache */
   /* replace1823 -> 5206 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1824_0 -> 650 in the cache */
   /* search1824_1_0 -> 142 in the cache */
   /* search1824_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umin,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1824_2_0 -> 142 in the cache */
   /* search1824_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umin,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5210, 5211 },
      -1,
   } },

   /* replace1824_0 -> 142 in the cache */
   /* replace1824_1_0 -> 650 in the cache */
   /* replace1824_1_1 -> 144 in the cache */
   /* replace1824_1_2 -> 145 in the cache */
   /* replace1824_1 -> 1181 in the cache */
   /* replace1824 -> 5206 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1825_0 -> 650 in the cache */
   /* search1825_1_0 -> 142 in the cache */
   /* search1825_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umin,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1825_2_0 -> 142 in the cache */
   /* search1825_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umin,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5213, 5214 },
      -1,
   } },

   /* replace1825_0 -> 142 in the cache */
   /* replace1825_1_0 -> 650 in the cache */
   /* replace1825_1_1 -> 144 in the cache */
   /* replace1825_1_2 -> 145 in the cache */
   /* replace1825_1 -> 1181 in the cache */
   /* replace1825 -> 5206 in the cache */

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1826_0 -> 650 in the cache */
   /* search1826_1_0 -> 142 in the cache */
   /* search1826_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umax,
      0, 1,
      { 142, 144 },
      0,
   } },
   /* search1826_2_0 -> 142 in the cache */
   /* search1826_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umax,
      1, 1,
      { 142, 5073 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5216, 5217 },
      -1,
   } },

   /* replace1826_0 -> 142 in the cache */
   /* replace1826_1_0 -> 650 in the cache */
   /* replace1826_1_1 -> 144 in the cache */
   /* replace1826_1_2 -> 145 in the cache */
   /* replace1826_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umax,
      0, 1,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1827_0 -> 650 in the cache */
   /* search1827_1_0 -> 142 in the cache */
   /* search1827_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umax,
      0, 1,
      { 142, 3107 },
      0,
   } },
   /* search1827_2_0 -> 142 in the cache */
   /* search1827_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umax,
      1, 1,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5220, 5221 },
      -1,
   } },

   /* replace1827_0 -> 142 in the cache */
   /* replace1827_1_0 -> 650 in the cache */
   /* replace1827_1_1 -> 144 in the cache */
   /* replace1827_1_2 -> 145 in the cache */
   /* replace1827_1 -> 1181 in the cache */
   /* replace1827 -> 5219 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1828_0 -> 650 in the cache */
   /* search1828_1_0 -> 142 in the cache */
   /* search1828_1_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umax,
      0, 1,
      { 142, 3107 },
      -1,
   } },
   /* search1828_2_0 -> 142 in the cache */
   /* search1828_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umax,
      1, 1,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5223, 5224 },
      -1,
   } },

   /* replace1828_0 -> 142 in the cache */
   /* replace1828_1_0 -> 650 in the cache */
   /* replace1828_1_1 -> 144 in the cache */
   /* replace1828_1_2 -> 145 in the cache */
   /* replace1828_1 -> 1181 in the cache */
   /* replace1828 -> 5219 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1829_0 -> 650 in the cache */
   /* search1829_1_0 -> 142 in the cache */
   /* search1829_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umax,
      0, 1,
      { 142, 144 },
      -1,
   } },
   /* search1829_2_0 -> 142 in the cache */
   /* search1829_2_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_umax,
      1, 1,
      { 142, 5073 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 650, 5226, 5227 },
      -1,
   } },

   /* replace1829_0 -> 142 in the cache */
   /* replace1829_1_0 -> 650 in the cache */
   /* replace1829_1_1 -> 144 in the cache */
   /* replace1829_1_2 -> 145 in the cache */
   /* replace1829_1 -> 1181 in the cache */
   /* replace1829 -> 5219 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1830_0 -> 650 in the cache */
   /* search1830_1_0 -> 142 in the cache */
   /* search1830_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 142, 144 },
      0,
   } },
   /* search1830_2_0 -> 142 in the cache */
   /* search1830_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 142, 145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5229, 5230 },
      -1,
   } },

   /* replace1830_0 -> 142 in the cache */
   /* replace1830_1_0 -> 650 in the cache */
   /* replace1830_1_1 -> 144 in the cache */
   /* replace1830_1_2 -> 145 in the cache */
   /* replace1830_1 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 142, 1181 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1831_0 -> 650 in the cache */
   /* search1831_1_0 -> 142 in the cache */
   /* search1831_1_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 142, 144 },
      -1,
   } },
   /* search1831_2_0 -> 142 in the cache */
   /* search1831_2_1 -> 145 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 142, 145 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5233, 5234 },
      -1,
   } },

   /* replace1831_0 -> 142 in the cache */
   /* replace1831_1_0 -> 650 in the cache */
   /* replace1831_1_1 -> 144 in the cache */
   /* replace1831_1_2 -> 145 in the cache */
   /* replace1831_1 -> 1181 in the cache */
   /* replace1831 -> 5232 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1832_0 -> 650 in the cache */
   /* search1832_1_0 -> 125 in the cache */
   /* search1832_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 125, 127 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1832_2_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 5237, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5236, 5238 },
      -1,
   } },

   /* replace1832_0_0 -> 650 in the cache */
   /* replace1832_0_1 -> 125 in the cache */
   /* replace1832_0_2 -> 5237 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 125, 5237 },
      -1,
   } },
   /* replace1832_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 5240, 127 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1833_0 -> 650 in the cache */
   /* search1833_1_0 -> 125 in the cache */
   /* search1833_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   /* search1833_2_0 -> 5237 in the cache */
   /* search1833_2_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 5237, 127 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 650, 5242, 5243 },
      -1,
   } },

   /* replace1833_0_0 -> 650 in the cache */
   /* replace1833_0_1 -> 125 in the cache */
   /* replace1833_0_2 -> 5237 in the cache */
   /* replace1833_0 -> 5240 in the cache */
   /* replace1833_1 -> 127 in the cache */
   /* replace1833 -> 5241 in the cache */

   /* ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b')) */
   /* search1834_0 -> 441 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_frcp,
      -1, 0,
      { 5245 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_frcp,
      -1, 0,
      { 5247 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5246, 5248 },
      -1,
   } },

   /* replace1834_0_0 -> 441 in the cache */
   /* replace1834_0_1 -> 5245 in the cache */
   /* replace1834_0_2 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5245, 5247 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_frcp,
      -1, 0,
      { 5250 },
      -1,
   } },

   /* ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b')) */
   /* search1835_0 -> 441 in the cache */
   /* search1835_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_frsq,
      -1, 0,
      { 5245 },
      0,
   } },
   /* search1835_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_frsq,
      -1, 0,
      { 5247 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5252, 5253 },
      -1,
   } },

   /* replace1835_0_0 -> 441 in the cache */
   /* replace1835_0_1 -> 5245 in the cache */
   /* replace1835_0_2 -> 5247 in the cache */
   /* replace1835_0 -> 5250 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_frsq,
      -1, 0,
      { 5250 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b')) */
   /* search1836_0 -> 441 in the cache */
   /* search1836_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fsqrt,
      -1, 0,
      { 5245 },
      0,
   } },
   /* search1836_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fsqrt,
      -1, 0,
      { 5247 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5256, 5257 },
      -1,
   } },

   /* replace1836_0_0 -> 441 in the cache */
   /* replace1836_0_1 -> 5245 in the cache */
   /* replace1836_0_2 -> 5247 in the cache */
   /* replace1836_0 -> 5250 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fsqrt,
      -1, 0,
      { 5250 },
      -1,
   } },

   /* ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b')) */
   /* search1837_0 -> 441 in the cache */
   /* search1837_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fexp2,
      -1, 0,
      { 5245 },
      0,
   } },
   /* search1837_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fexp2,
      -1, 0,
      { 5247 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5260, 5261 },
      -1,
   } },

   /* replace1837_0_0 -> 441 in the cache */
   /* replace1837_0_1 -> 5245 in the cache */
   /* replace1837_0_2 -> 5247 in the cache */
   /* replace1837_0 -> 5250 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fexp2,
      -1, 0,
      { 5250 },
      -1,
   } },

   /* ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b')) */
   /* search1838_0 -> 441 in the cache */
   /* search1838_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_flog2,
      -1, 0,
      { 5245 },
      0,
   } },
   /* search1838_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_flog2,
      -1, 0,
      { 5247 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5264, 5265 },
      -1,
   } },

   /* replace1838_0_0 -> 441 in the cache */
   /* replace1838_0_1 -> 5245 in the cache */
   /* replace1838_0_2 -> 5247 in the cache */
   /* replace1838_0 -> 5250 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_flog2,
      -1, 0,
      { 5250 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1839_0 -> 441 in the cache */
   /* search1839_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 5245 },
      0,
   } },
   /* search1839_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 5247 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5268, 5269 },
      -1,
   } },

   /* replace1839_0_0 -> 441 in the cache */
   /* replace1839_0_1 -> 5245 in the cache */
   /* replace1839_0_2 -> 5247 in the cache */
   /* replace1839_0 -> 5250 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 5250 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b')) */
   /* search1840_0 -> 441 in the cache */
   /* search1840_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fsin,
      -1, 0,
      { 5245 },
      0,
   } },
   /* search1840_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fsin,
      -1, 0,
      { 5247 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5272, 5273 },
      -1,
   } },

   /* replace1840_0_0 -> 441 in the cache */
   /* replace1840_0_1 -> 5245 in the cache */
   /* replace1840_0_2 -> 5247 in the cache */
   /* replace1840_0 -> 5250 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fsin,
      -1, 0,
      { 5250 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b')) */
   /* search1841_0 -> 441 in the cache */
   /* search1841_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fcos,
      -1, 0,
      { 5245 },
      0,
   } },
   /* search1841_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fcos,
      -1, 0,
      { 5247 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5276, 5277 },
      -1,
   } },

   /* replace1841_0_0 -> 441 in the cache */
   /* replace1841_0_1 -> 5245 in the cache */
   /* replace1841_0_2 -> 5247 in the cache */
   /* replace1841_0 -> 5250 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fcos,
      -1, 0,
      { 5250 },
      -1,
   } },

   /* ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b')) */
   /* search1842_0 -> 441 in the cache */
   /* search1842_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 5245 },
      0,
   } },
   /* search1842_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 5247 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5280, 5281 },
      -1,
   } },

   /* replace1842_0_0 -> 441 in the cache */
   /* replace1842_0_1 -> 5245 in the cache */
   /* replace1842_0_2 -> 5247 in the cache */
   /* replace1842_0 -> 5250 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 5250 },
      -1,
   } },

   /* ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b')) */
   /* search1843_0 -> 441 in the cache */
   /* search1843_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 5245 },
      0,
   } },
   /* search1843_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 5247 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5284, 5285 },
      -1,
   } },

   /* replace1843_0_0 -> 441 in the cache */
   /* replace1843_0_1 -> 5245 in the cache */
   /* replace1843_0_2 -> 5247 in the cache */
   /* replace1843_0 -> 5250 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 5250 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1844_0 -> 441 in the cache */
   /* search1844_1_0 -> 5245 in the cache */
   /* search1844_1 -> 5268 in the cache */
   /* search1844_2_0 -> 5247 in the cache */
   /* search1844_2 -> 5269 in the cache */
   /* search1844 -> 5270 in the cache */

   /* replace1844_0_0 -> 441 in the cache */
   /* replace1844_0_1 -> 5245 in the cache */
   /* replace1844_0_2 -> 5247 in the cache */
   /* replace1844_0 -> 5250 in the cache */
   /* replace1844 -> 5271 in the cache */

   /* ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b')) */
   /* search1845_0_0 -> 441 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5288, 5289 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 5290 },
      -1,
   } },

   /* replace1845_0 -> 441 in the cache */
   /* replace1845_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 5245 },
      -1,
   } },
   /* replace1845_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 5247 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5292, 5293 },
      -1,
   } },

   /* ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b')) */
   /* search1846_0_0 -> 441 in the cache */
   /* search1846_0_1 -> 5288 in the cache */
   /* search1846_0_2 -> 5289 in the cache */
   /* search1846_0 -> 5290 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 5290 },
      -1,
   } },

   /* replace1846_0 -> 441 in the cache */
   /* replace1846_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 5245 },
      -1,
   } },
   /* replace1846_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 5247 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5296, 5297 },
      -1,
   } },

   /* ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b')) */
   /* search1847_0_0 -> 441 in the cache */
   /* search1847_0_1 -> 5288 in the cache */
   /* search1847_0_2 -> 5289 in the cache */
   /* search1847_0 -> 5290 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 5290 },
      -1,
   } },

   /* replace1847_0 -> 441 in the cache */
   /* replace1847_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 5245 },
      -1,
   } },
   /* replace1847_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 5247 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5300, 5301 },
      -1,
   } },

   /* ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b')) */
   /* search1848_0_0 -> 441 in the cache */
   /* search1848_0_1 -> 5288 in the cache */
   /* search1848_0_2 -> 5289 in the cache */
   /* search1848_0 -> 5290 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_isign,
      -1, 0,
      { 5290 },
      -1,
   } },

   /* replace1848_0 -> 441 in the cache */
   /* replace1848_1_0 -> 5245 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_isign,
      -1, 0,
      { 5245 },
      -1,
   } },
   /* replace1848_2_0 -> 5247 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_isign,
      -1, 0,
      { 5247 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 441, 5304, 5305 },
      -1,
   } },

   /* ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216)) */
   /* search1849_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fisnormal,
      -1, 0,
      { 16 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1ffffff /* 33554431 */ },
   } },
   /* replace1849_1_0_0 -> 16 in the cache */
   /* replace1849_1_0_1 -> 316 in the cache */
   /* replace1849_1_0 -> 884 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1000000 /* 16777216 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 884, 5309 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ult,
      -1, 1,
      { 5308, 5310 },
      -1,
   } },

   /* ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b')) */
   /* search1850_0_0 -> 16 in the cache */
   /* search1850_0_1 -> 36 in the cache */
   /* search1850_0 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 2821 },
      -1,
   } },

   /* replace1850_0_0 -> 16 in the cache */
   /* replace1850_0 -> 3470 in the cache */
   /* replace1850_1_0 -> 36 in the cache */
   /* replace1850_1 -> 3467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 3470, 3467 },
      -1,
   } },

   /* ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b')) */
   /* search1851_0_0 -> 16 in the cache */
   /* search1851_0_1 -> 36 in the cache */
   /* search1851_0 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 2821 },
      -1,
   } },

   /* replace1851_0_0 -> 16 in the cache */
   /* replace1851_0 -> 1865 in the cache */
   /* replace1851_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 1865, 5315 },
      -1,
   } },

   /* ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b')) */
   /* search1852_0_0 -> 16 in the cache */
   /* search1852_0_1 -> 36 in the cache */
   /* search1852_0 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 2821 },
      -1,
   } },

   /* replace1852_0_0 -> 16 in the cache */
   /* replace1852_0 -> 2919 in the cache */
   /* replace1852_1_0 -> 36 in the cache */
   /* replace1852_1 -> 4293 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 2919, 4293 },
      -1,
   } },

   /* ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b')) */
   /* search1853_0_0 -> 16 in the cache */
   /* search1853_0_1 -> 36 in the cache */
   /* search1853_0 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 2821 },
      -1,
   } },

   /* replace1853_0_0 -> 16 in the cache */
   /* replace1853_0 -> 3779 in the cache */
   /* replace1853_1_0 -> 36 in the cache */
   /* replace1853_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 3779, 3964 },
      -1,
   } },

   /* ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b')) */
   /* search1854_0_0 -> 16 in the cache */
   /* search1854_0_1 -> 36 in the cache */
   /* search1854_0 -> 2821 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 2821 },
      -1,
   } },

   /* replace1854_0_0 -> 16 in the cache */
   /* replace1854_0 -> 1876 in the cache */
   /* replace1854_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 1876, 5322 },
      -1,
   } },

   /* ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c')) */
   /* search1855_0_0 -> 16 in the cache */
   /* search1855_0_1 -> 36 in the cache */
   /* search1855_0_2 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_vec3,
      -1, 0,
      { 16, 36, 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 5324 },
      -1,
   } },

   /* replace1855_0_0 -> 16 in the cache */
   /* replace1855_0 -> 3470 in the cache */
   /* replace1855_1_0 -> 36 in the cache */
   /* replace1855_1 -> 3467 in the cache */
   /* replace1855_2_0 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec3,
      -1, 0,
      { 3470, 3467, 5326 },
      -1,
   } },

   /* ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c')) */
   /* search1856_0_0 -> 16 in the cache */
   /* search1856_0_1 -> 36 in the cache */
   /* search1856_0_2 -> 250 in the cache */
   /* search1856_0 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 5324 },
      -1,
   } },

   /* replace1856_0_0 -> 16 in the cache */
   /* replace1856_0 -> 1865 in the cache */
   /* replace1856_1_0 -> 36 in the cache */
   /* replace1856_1 -> 5315 in the cache */
   /* replace1856_2_0 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec3,
      -1, 0,
      { 1865, 5315, 5329 },
      -1,
   } },

   /* ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c')) */
   /* search1857_0_0 -> 16 in the cache */
   /* search1857_0_1 -> 36 in the cache */
   /* search1857_0_2 -> 250 in the cache */
   /* search1857_0 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 5324 },
      -1,
   } },

   /* replace1857_0_0 -> 16 in the cache */
   /* replace1857_0 -> 2919 in the cache */
   /* replace1857_1_0 -> 36 in the cache */
   /* replace1857_1 -> 4293 in the cache */
   /* replace1857_2_0 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec3,
      -1, 0,
      { 2919, 4293, 5332 },
      -1,
   } },

   /* ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c')) */
   /* search1858_0_0 -> 16 in the cache */
   /* search1858_0_1 -> 36 in the cache */
   /* search1858_0_2 -> 250 in the cache */
   /* search1858_0 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 5324 },
      -1,
   } },

   /* replace1858_0_0 -> 16 in the cache */
   /* replace1858_0 -> 3779 in the cache */
   /* replace1858_1_0 -> 36 in the cache */
   /* replace1858_1 -> 3964 in the cache */
   /* replace1858_2_0 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec3,
      -1, 0,
      { 3779, 3964, 5335 },
      -1,
   } },

   /* ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c')) */
   /* search1859_0_0 -> 16 in the cache */
   /* search1859_0_1 -> 36 in the cache */
   /* search1859_0_2 -> 250 in the cache */
   /* search1859_0 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 5324 },
      -1,
   } },

   /* replace1859_0_0 -> 16 in the cache */
   /* replace1859_0 -> 1876 in the cache */
   /* replace1859_1_0 -> 36 in the cache */
   /* replace1859_1 -> 5322 in the cache */
   /* replace1859_2_0 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec3,
      -1, 0,
      { 1876, 5322, 5338 },
      -1,
   } },

   /* ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd')) */
   /* search1860_0_0 -> 16 in the cache */
   /* search1860_0_1 -> 36 in the cache */
   /* search1860_0_2 -> 250 in the cache */
   /* search1860_0_3 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 16, 36, 250, 251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 5340 },
      -1,
   } },

   /* replace1860_0_0 -> 16 in the cache */
   /* replace1860_0 -> 3470 in the cache */
   /* replace1860_1_0 -> 36 in the cache */
   /* replace1860_1 -> 3467 in the cache */
   /* replace1860_2_0 -> 250 in the cache */
   /* replace1860_2 -> 5326 in the cache */
   /* replace1860_3_0 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 3470, 3467, 5326, 5342 },
      -1,
   } },

   /* ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd')) */
   /* search1861_0_0 -> 16 in the cache */
   /* search1861_0_1 -> 36 in the cache */
   /* search1861_0_2 -> 250 in the cache */
   /* search1861_0_3 -> 251 in the cache */
   /* search1861_0 -> 5340 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 5340 },
      -1,
   } },

   /* replace1861_0_0 -> 16 in the cache */
   /* replace1861_0 -> 1865 in the cache */
   /* replace1861_1_0 -> 36 in the cache */
   /* replace1861_1 -> 5315 in the cache */
   /* replace1861_2_0 -> 250 in the cache */
   /* replace1861_2 -> 5329 in the cache */
   /* replace1861_3_0 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 1865, 5315, 5329, 5345 },
      -1,
   } },

   /* ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd')) */
   /* search1862_0_0 -> 16 in the cache */
   /* search1862_0_1 -> 36 in the cache */
   /* search1862_0_2 -> 250 in the cache */
   /* search1862_0_3 -> 251 in the cache */
   /* search1862_0 -> 5340 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 5340 },
      -1,
   } },

   /* replace1862_0_0 -> 16 in the cache */
   /* replace1862_0 -> 2919 in the cache */
   /* replace1862_1_0 -> 36 in the cache */
   /* replace1862_1 -> 4293 in the cache */
   /* replace1862_2_0 -> 250 in the cache */
   /* replace1862_2 -> 5332 in the cache */
   /* replace1862_3_0 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 2919, 4293, 5332, 5348 },
      -1,
   } },

   /* ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd')) */
   /* search1863_0_0 -> 16 in the cache */
   /* search1863_0_1 -> 36 in the cache */
   /* search1863_0_2 -> 250 in the cache */
   /* search1863_0_3 -> 251 in the cache */
   /* search1863_0 -> 5340 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 5340 },
      -1,
   } },

   /* replace1863_0_0 -> 16 in the cache */
   /* replace1863_0 -> 3779 in the cache */
   /* replace1863_1_0 -> 36 in the cache */
   /* replace1863_1 -> 3964 in the cache */
   /* replace1863_2_0 -> 250 in the cache */
   /* replace1863_2 -> 5335 in the cache */
   /* replace1863_3_0 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 3779, 3964, 5335, 5351 },
      -1,
   } },

   /* ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd')) */
   /* search1864_0_0 -> 16 in the cache */
   /* search1864_0_1 -> 36 in the cache */
   /* search1864_0_2 -> 250 in the cache */
   /* search1864_0_3 -> 251 in the cache */
   /* search1864_0 -> 5340 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 5340 },
      -1,
   } },

   /* replace1864_0_0 -> 16 in the cache */
   /* replace1864_0 -> 1876 in the cache */
   /* replace1864_1_0 -> 36 in the cache */
   /* replace1864_1 -> 5322 in the cache */
   /* replace1864_2_0 -> 250 in the cache */
   /* replace1864_2 -> 5338 in the cache */
   /* replace1864_3_0 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 251 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec4,
      -1, 0,
      { 1876, 5322, 5338, 5354 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_expression_cond[] = {
   (is_used_once),
   (is_only_used_as_float),
   (is_used_by_if),
   (is_not_used_by_if),
   (is_used_by_non_fsat),
   (no_signed_wrap),
   (only_lower_8_bits_used),
   (only_lower_16_bits_used),
};

static const nir_search_variable_cond nir_opt_algebraic_variable_cond[] = {
   (is_pos_power_of_two),
   (is_neg_power_of_two),
   (is_bitcount2),
   (is_not_const),
   (is_ult_0xfffc07fc),
   (is_not_fmul),
   (is_first_5_bits_uge_2),
   (is_unsigned_multiple_of_4),
   (is_unsigned_multiple_of_2),
   (is_unsigned_multiple_of_8),
   (is_unsigned_multiple_of_16),
   (is_unsigned_multiple_of_32),
   (is_unsigned_multiple_of_64),
   (is_a_number),
   (is_gt_0_and_lt_1),
   (is_zero_to_one),
   (is_not_negative),
   (is_integral),
   (is_not_positive),
   (is_not_zero),
   (is_a_number_not_negative),
   (is_a_number_not_positive),
   (is_gt_zero),
   (is_lt_zero),
   (is_a_number_gt_zero),
   (is_a_number_lt_zero),
   (is_fmul),
   (is_lower_half_zero),
   (is_upper_half_zero),
};

static const struct transform nir_opt_algebraic_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2396, 1113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2396, 1113, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2826, 2916, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 54, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 57, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 32, 0 },
   { 67, 68, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 61, 0 },
   { 78, 81, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 62, 61, 0 },
   { 64, 61, 0 },
   { 82, 81, 1 },
   { 83, 88, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 61, 0 },
   { 66, 61, 0 },
   { 89, 95, 1 },
   { 96, 97, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2768, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2769, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 2655, 0 },
   { 2656, 2657, 0 },
   { 2658, 1117, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 121, 16, 0 },
   { 123, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 210, 211, 0 },
   { 212, 213, 5 },
   { 214, 215, 6 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 210, 211, 0 },
   { 212, 213, 5 },
   { 214, 215, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 224, 225, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 210, 211, 0 },
   { 212, 213, 5 },
   { 214, 215, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 224, 225, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 1390, 35 },
   { 2771, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 120, 0 },
   { 191, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 199, 3483, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 0, 0 },
   { 227, 3, 0 },
   { 228, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 610, 612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 0, 0 },
   { 227, 3, 0 },
   { 228, 0, 0 },
   { 610, 612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 229, 211, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 0, 0 },
   { 227, 3, 0 },
   { 228, 0, 0 },
   { 229, 211, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 229, 211, 0 },
   { 610, 612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 0, 0 },
   { 227, 3, 0 },
   { 228, 0, 0 },
   { 229, 211, 0 },
   { 610, 612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 270, 331, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 270, 331, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 36, 0 },
   { 270, 331, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 36, 0 },
   { 270, 331, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 36, 0 },
   { 288, 290, 0 },
   { 270, 331, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 36, 0 },
   { 288, 290, 0 },
   { 270, 331, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 273, 347, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 273, 347, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 36, 0 },
   { 273, 347, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 36, 0 },
   { 273, 347, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 36, 0 },
   { 291, 293, 0 },
   { 273, 347, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 36, 0 },
   { 291, 293, 0 },
   { 273, 347, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 376, 377, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 236, 36, 0 },
   { 376, 377, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 236, 36, 0 },
   { 303, 304, 7 },
   { 376, 377, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 374, 375, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 373, 273, 0 },
   { 374, 375, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 36, 0 },
   { 374, 375, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 36, 0 },
   { 373, 273, 0 },
   { 374, 375, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 36, 0 },
   { 305, 306, 8 },
   { 374, 375, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 36, 0 },
   { 305, 306, 8 },
   { 373, 273, 0 },
   { 374, 375, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 363, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 363, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 238, 36, 0 },
   { 282, 363, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 238, 36, 0 },
   { 282, 363, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 238, 36, 0 },
   { 297, 299, 0 },
   { 282, 363, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 238, 36, 0 },
   { 297, 299, 0 },
   { 282, 363, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 371, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 371, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 36, 0 },
   { 285, 371, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 36, 0 },
   { 285, 371, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 36, 0 },
   { 300, 302, 0 },
   { 285, 371, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 36, 0 },
   { 300, 302, 0 },
   { 285, 371, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 382, 383, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 36, 0 },
   { 382, 383, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 36, 0 },
   { 309, 310, 7 },
   { 382, 383, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 380, 381, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 241, 36, 0 },
   { 380, 381, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 241, 36, 0 },
   { 311, 312, 8 },
   { 380, 381, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 355, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 355, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 36, 0 },
   { 276, 355, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 36, 0 },
   { 276, 355, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 243, 36, 0 },
   { 276, 355, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 243, 36, 0 },
   { 276, 355, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 36, 0 },
   { 243, 36, 0 },
   { 294, 296, 0 },
   { 276, 355, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 36, 0 },
   { 243, 36, 0 },
   { 294, 296, 0 },
   { 276, 355, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 378, 379, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 36, 0 },
   { 378, 379, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 245, 36, 0 },
   { 378, 379, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 36, 0 },
   { 245, 36, 0 },
   { 307, 308, 7 },
   { 378, 379, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 613, 617, 19 },
   { 2765, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 618, 620, 20 },
   { 2763, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 619, 623, 22 },
   { 2766, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 624, 626, 23 },
   { 2764, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 658, 663, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 694, 695, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 692, 693, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 690, 691, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 686, 689, 0 },
   { 690, 691, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 696, 689, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2400, 1113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2400, 1113, 0 },
   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2399, 32, 0 },
   { 2849, 2850, 52 },
   { 2851, 326, 52 },
   { 2852, 2853, 52 },
   { 2883, 359, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2398, 1113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2398, 1113, 0 },
   { 2399, 32, 0 },
   { 2849, 2850, 52 },
   { 2851, 326, 52 },
   { 2852, 2853, 52 },
   { 2883, 359, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2373, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2374, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 1362, 3291, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 1362, 3291, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2368, 968, 0 },
   { 2816, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2368, 968, 0 },
   { 2815, 1121, 0 },
   { 3298, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2368, 968, 0 },
   { 2815, 1121, 0 },
   { 2816, 968, 0 },
   { 3298, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 1359, 3292, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 1359, 3292, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2367, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1209, 61, 0 },
   { 1210, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 32, 0 },
   { 1212, 32, 0 },
   { 1213, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3394, 3397, 78 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3394, 3397, 78 },
   { 4504, 11, 0 },
   { 4557, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3666, 11, 0 },
   { 3667, 16, 0 },
   { 3668, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3389, 3393, 78 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3389, 3393, 78 },
   { 4532, 11, 0 },
   { 4585, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3398, 3402, 79 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3398, 3402, 79 },
   { 4637, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3403, 3406, 79 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3403, 3406, 79 },
   { 4610, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 2382, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2225, 2234, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2225, 2234, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2225, 2234, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2225, 2234, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2227, 2235, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2227, 2235, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2227, 2235, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2227, 2235, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 2237, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2231, 2239, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2259, 2266, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2267, 2269, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2270, 2272, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2273, 2276, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2277, 2279, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2280, 2282, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 2288, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2289, 2295, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2296, 2302, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2303, 2306, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2307, 2312, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2313, 2317, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2318, 2321, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2322, 2327, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2328, 2332, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2333, 2336, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2337, 2342, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2343, 2347, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3070, 3071, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3070, 3071, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2406, 2409, 44 },
   { 2413, 2416, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2419, 2421, 44 },
   { 2424, 2426, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 2434, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 2434, 45 },
   { 2456, 32, 0 },
   { 2457, 200, 0 },
   { 2458, 2455, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 2434, 45 },
   { 2459, 2429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 2434, 45 },
   { 2456, 32, 0 },
   { 2457, 200, 0 },
   { 2458, 2455, 0 },
   { 2459, 2429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 2499, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2494, 2496, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2493, 2477, 0 },
   { 2494, 2496, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2501, 2583, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2584, 2653, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2698, 36, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2817, 2911, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2827, 2918, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2835, 2919, 58 },
   { 2835, 2919, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2837, 2920, 58 },
   { 2837, 2920, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3335, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2871, 332, 52 },
   { 2872, 335, 52 },
   { 2873, 339, 52 },
   { 2874, 342, 52 },
   { 2887, 364, 53 },
   { 2888, 367, 53 },
   { 3335, 120, 0 },
   { 3337, 3339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3336, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2875, 313, 52 },
   { 2876, 317, 52 },
   { 2877, 322, 52 },
   { 2878, 326, 52 },
   { 2889, 356, 53 },
   { 2890, 359, 53 },
   { 3336, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2912, 2915, 56 },
   { 2912, 3475, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2922, 3473, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2929, 3474, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2957, 3472, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2957, 3472, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2957, 3472, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2957, 3472, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3066, 16, 0 },
   { 3067, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3068, 3069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3072, 3074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3075, 3076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3385, 3388, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3370, 3374, 75 },
   { 3370, 3378, 76 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3380, 3384, 76 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3187, 3190, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3191, 3194, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3195, 3198, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3199, 3201, 61 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3206, 3210, 62 },
   { 3206, 3307, 71 },
   { 3206, 3309, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3211, 3214, 63 },
   { 3225, 3229, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3215, 3217, 63 },
   { 3230, 3232, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3218, 3221, 63 },
   { 3233, 3237, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3222, 3224, 63 },
   { 3238, 3240, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3241, 3245, 65 },
   { 3246, 3248, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3249, 3250, 66 },
   { 3251, 3254, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3255, 3268, 68 },
   { 3547, 3558, 99 },
   { 3567, 3578, 99 },
   { 3587, 3597, 99 },
   { 3255, 3612, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3269, 3277, 68 },
   { 3559, 3566, 99 },
   { 3579, 3586, 99 },
   { 3598, 3605, 99 },
   { 3269, 3617, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3313, 3316, 73 },
   { 3313, 3363, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3317, 3319, 73 },
   { 3317, 3369, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3320, 2389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3408, 3414, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3415, 3420, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3421, 3428, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3429, 3434, 83 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3435, 3440, 84 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3441, 3448, 85 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3449, 3456, 86 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3457, 3466, 87 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3476, 3478, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 844, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3485, 3489, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3490, 3494, 94 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3495, 3496, 95 },
   { 3495, 49, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3497, 3490, 96 },
   { 3497, 3499, 94 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3500, 3485, 97 },
   { 3500, 49, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3501, 3496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3502, 477, 0 },
   { 3503, 3504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3501, 3496, 0 },
   { 3502, 477, 0 },
   { 3503, 3504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3502, 477, 0 },
   { 3503, 3504, 0 },
   { 3505, 3507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3501, 3496, 0 },
   { 3502, 477, 0 },
   { 3503, 3504, 0 },
   { 3505, 3507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3509, 3511, 1 },
   { 3513, 3517, 1 },
   { 3518, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3669, 650, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3670, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3671, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3672, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4663, 4683, 102 },
   { 4685, 4703, 102 },
   { 4705, 4726, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5041, 113, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5042, 113, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5043, 113, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5044, 113, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5045, 113, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5046, 113, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5048, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5051, 250, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5049, 250, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5049, 250, 0 },
   { 5051, 250, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5307, 5311, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3082, 3083, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4521, 4519, 0 },
   { 4574, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4546, 4519, 0 },
   { 4599, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4651, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4626, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 3091, 3092, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 3091, 3092, 0 },
   { 3121, 3092, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 3082, 3083, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 915, 918, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 5037, 5040, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 4521, 4519, 0 },
   { 4574, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 4546, 4519, 0 },
   { 4599, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 4651, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 4626, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3082, 3083, 0 },
   { 4521, 4519, 0 },
   { 4574, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3082, 3083, 0 },
   { 4546, 4519, 0 },
   { 4599, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3082, 3083, 0 },
   { 4651, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3082, 3083, 0 },
   { 4626, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2350, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4521, 4519, 0 },
   { 4546, 4519, 0 },
   { 4574, 49, 0 },
   { 4599, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4521, 4519, 0 },
   { 4574, 49, 0 },
   { 4651, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4521, 4519, 0 },
   { 4574, 49, 0 },
   { 4626, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4546, 4519, 0 },
   { 4599, 49, 0 },
   { 4651, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4546, 4519, 0 },
   { 4599, 49, 0 },
   { 4626, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4626, 49, 0 },
   { 4651, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3158, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { 3158, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 171, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3113, 3114, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3113, 3114, 0 },
   { 3140, 3114, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 249, 253, 0 },
   { 269, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 255, 256, 0 },
   { 272, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 262, 263, 0 },
   { 281, 282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 265, 266, 0 },
   { 284, 285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 258, 260, 0 },
   { 275, 276, 0 },
   { 279, 276, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 5033, 5036, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 157, 159, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 174, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 174, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 269, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 272, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 281, 282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 284, 285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 275, 276, 0 },
   { 279, 276, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 272, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 281, 282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 284, 285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 275, 276, 0 },
   { 279, 276, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { 281, 282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { 284, 285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { 275, 276, 0 },
   { 279, 276, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 0 },
   { 284, 285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { 281, 282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 0 },
   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 0 },
   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { 284, 285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 285, 0 },
   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 285, 0 },
   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 285, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 285, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4517, 3569, 0 },
   { 4543, 3569, 0 },
   { 4571, 3589, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4623, 3589, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2956, 2957, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2489, 2491, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3180, 103, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3180, 103, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3180, 103, 0 },
   { 3542, 3524, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3180, 103, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2489, 2491, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3180, 103, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3180, 103, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3180, 103, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3180, 103, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3546, 3530, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3546, 3530, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3546, 3530, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3546, 3530, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3534, 3535, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3534, 3535, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3534, 3535, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3534, 3535, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3539, 3540, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3539, 3540, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3539, 3540, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3539, 3540, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2663, 650, 0 },
   { 2664, 1016, 0 },
   { 2667, 2668, 0 },
   { 2669, 2670, 0 },
   { 2673, 2674, 0 },
   { 2675, 2676, 0 },
   { 2677, 2678, 0 },
   { 2679, 2680, 0 },
   { 2683, 2684, 0 },
   { 2685, 2686, 0 },
   { 2687, 2688, 51 },
   { 2689, 2690, 51 },
   { 2693, 2694, 51 },
   { 2695, 2696, 51 },
   { 2697, 3, 0 },
   { 2700, 2103, 0 },
   { 2701, 2703, 0 },
   { 2705, 1112, 0 },
   { 2706, 2702, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5101, 5102, 0 },
   { 5105, 5102, 0 },
   { 5108, 5102, 0 },
   { 5111, 5102, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5282, 5283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5286, 5287, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5088, 5089, 0 },
   { 5092, 5089, 0 },
   { 5095, 5089, 0 },
   { 5098, 5089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5075, 5076, 0 },
   { 5079, 5076, 0 },
   { 5082, 5076, 0 },
   { 5085, 5076, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5114, 5115, 0 },
   { 5118, 5115, 0 },
   { 5121, 5115, 0 },
   { 5124, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5127, 5128, 0 },
   { 5131, 5128, 0 },
   { 5134, 5128, 0 },
   { 5137, 5128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5270, 5271, 0 },
   { 5270, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5054, 5055, 0 },
   { 5058, 5055, 0 },
   { 5060, 5062, 0 },
   { 5064, 5062, 0 },
   { 5067, 5069, 0 },
   { 5071, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1645, 1647, 0 },
   { 1752, 1754, 0 },
   { 1835, 1837, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1180, 0 },
   { 1182, 1180, 0 },
   { 1185, 1187, 0 },
   { 1190, 1187, 0 },
   { 1194, 1196, 0 },
   { 1199, 1196, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3181, 3182, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5153, 5154, 0 },
   { 5157, 5154, 0 },
   { 5160, 5154, 0 },
   { 5163, 5154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5166, 5167, 0 },
   { 5170, 5167, 0 },
   { 5173, 5167, 0 },
   { 5176, 5167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5179, 5180, 0 },
   { 5183, 5180, 0 },
   { 5186, 5180, 0 },
   { 5189, 5180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5192, 5193, 0 },
   { 5196, 5193, 0 },
   { 5199, 5193, 0 },
   { 5202, 5193, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5205, 5206, 0 },
   { 5209, 5206, 0 },
   { 5212, 5206, 0 },
   { 5215, 5206, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4513, 4508, 0 },
   { 4566, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4538, 4508, 0 },
   { 4591, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4643, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4618, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5140, 5141, 0 },
   { 5144, 5141, 0 },
   { 5147, 5141, 0 },
   { 5150, 5141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5262, 5263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5266, 5267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5239, 5241, 0 },
   { 5244, 5241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5258, 5259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5249, 5251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5254, 5255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5274, 5275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 5278, 5279, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3168, 3159, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3170, 3162, 0 },
   { 3173, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3171, 3165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2004, 2005, 0 },
   { 2030, 2031, 0 },
   { 2056, 839, 0 },
   { 2081, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2004, 2005, 0 },
   { 2030, 2031, 0 },
   { 2056, 839, 0 },
   { 2081, 2082, 0 },
   { 2396, 1113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2396, 1113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 713, 715, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 717, 727, 0 },
   { 740, 749, 0 },
   { 762, 770, 0 },
   { 783, 792, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 911, 913, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 883, 884, 0 },
   { 890, 891, 0 },
   { 896, 897, 0 },
   { 904, 905, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 804, 807, 0 },
   { 812, 815, 0 },
   { 820, 822, 0 },
   { 827, 830, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 804, 807, 0 },
   { 812, 815, 0 },
   { 820, 822, 0 },
   { 827, 830, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 804, 807, 0 },
   { 812, 815, 0 },
   { 820, 822, 0 },
   { 827, 830, 0 },
   { 2004, 2005, 0 },
   { 2030, 2031, 0 },
   { 2056, 839, 0 },
   { 2081, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 804, 807, 0 },
   { 812, 815, 0 },
   { 820, 822, 0 },
   { 827, 830, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 808, 807, 0 },
   { 816, 815, 0 },
   { 823, 822, 0 },
   { 831, 830, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 808, 807, 0 },
   { 816, 815, 0 },
   { 823, 822, 0 },
   { 831, 830, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 808, 807, 0 },
   { 816, 815, 0 },
   { 823, 822, 0 },
   { 831, 830, 0 },
   { 2004, 2005, 0 },
   { 2030, 2031, 0 },
   { 2056, 839, 0 },
   { 2081, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 808, 807, 0 },
   { 816, 815, 0 },
   { 823, 822, 0 },
   { 831, 830, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2397, 32, 0 },
   { 2951, 2952, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2388, 2389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4524, 1895, 0 },
   { 4577, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4549, 1895, 0 },
   { 4602, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 843, 844, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 838, 839, 0 },
   { 885, 884, 0 },
   { 892, 891, 0 },
   { 899, 897, 0 },
   { 907, 905, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 848, 850, 0 },
   { 854, 856, 0 },
   { 860, 862, 0 },
   { 866, 868, 0 },
   { 872, 874, 0 },
   { 878, 880, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2388, 2389, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2388, 2389, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { 3142, 3144, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2387, 3, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 887, 886, 0 },
   { 894, 893, 0 },
   { 901, 900, 0 },
   { 909, 908, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { 4524, 1895, 0 },
   { 4577, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { 4549, 1895, 0 },
   { 4602, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1933, 1934, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 2388, 2389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2388, 2389, 0 },
   { 4524, 1895, 0 },
   { 4577, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2388, 2389, 0 },
   { 4549, 1895, 0 },
   { 4602, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2388, 2389, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2388, 2389, 0 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 162, 164, 0 },
   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4524, 1895, 0 },
   { 4577, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4549, 1895, 0 },
   { 4602, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2352, 2351, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1924, 1926, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1929, 1930, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2392, 2393, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 970, 968, 0 },
   { 1496, 1498, 0 },
   { 1499, 1501, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4937, 4938, 0 },
   { 4941, 4942, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 970, 968, 0 },
   { 1496, 1498, 0 },
   { 1499, 1501, 0 },
   { 1512, 1498, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 970, 968, 0 },
   { 1496, 1498, 0 },
   { 1499, 1501, 0 },
   { 1622, 1623, 0 },
   { 1624, 1623, 0 },
   { 1729, 1730, 0 },
   { 1731, 1730, 0 },
   { 1812, 1813, 0 },
   { 1814, 1813, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 970, 968, 0 },
   { 1496, 1498, 0 },
   { 1499, 1501, 0 },
   { 1512, 1498, 0 },
   { 1622, 1623, 0 },
   { 1624, 1623, 0 },
   { 1729, 1730, 0 },
   { 1731, 1730, 0 },
   { 1812, 1813, 0 },
   { 1814, 1813, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 970, 968, 0 },
   { 1496, 1498, 0 },
   { 1499, 1501, 0 },
   { 1517, 1501, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 970, 968, 0 },
   { 1496, 1498, 0 },
   { 1499, 1501, 0 },
   { 1517, 1501, 0 },
   { 1622, 1623, 0 },
   { 1624, 1623, 0 },
   { 1729, 1730, 0 },
   { 1731, 1730, 0 },
   { 1812, 1813, 0 },
   { 1814, 1813, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 970, 968, 0 },
   { 1496, 1498, 0 },
   { 1499, 1501, 0 },
   { 1512, 1498, 0 },
   { 1517, 1501, 0 },
   { 1622, 1623, 0 },
   { 1624, 1623, 0 },
   { 1729, 1730, 0 },
   { 1731, 1730, 0 },
   { 1812, 1813, 0 },
   { 1814, 1813, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1502, 1504, 0 },
   { 1505, 1507, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4943, 4944, 0 },
   { 4946, 4947, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1502, 1504, 0 },
   { 1505, 1507, 0 },
   { 1520, 1504, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1145, 1146, 33 },
   { 1502, 1504, 0 },
   { 1505, 1507, 0 },
   { 1625, 1626, 0 },
   { 1627, 1626, 0 },
   { 1732, 1733, 0 },
   { 1734, 1733, 0 },
   { 1815, 1816, 0 },
   { 1817, 1816, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1145, 1146, 33 },
   { 1502, 1504, 0 },
   { 1505, 1507, 0 },
   { 1520, 1504, 0 },
   { 1625, 1626, 0 },
   { 1627, 1626, 0 },
   { 1732, 1733, 0 },
   { 1734, 1733, 0 },
   { 1815, 1816, 0 },
   { 1817, 1816, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1502, 1504, 0 },
   { 1505, 1507, 0 },
   { 1523, 1507, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1145, 1146, 33 },
   { 1502, 1504, 0 },
   { 1505, 1507, 0 },
   { 1523, 1507, 0 },
   { 1625, 1626, 0 },
   { 1627, 1626, 0 },
   { 1732, 1733, 0 },
   { 1734, 1733, 0 },
   { 1815, 1816, 0 },
   { 1817, 1816, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1145, 1146, 33 },
   { 1502, 1504, 0 },
   { 1505, 1507, 0 },
   { 1520, 1504, 0 },
   { 1523, 1507, 0 },
   { 1625, 1626, 0 },
   { 1627, 1626, 0 },
   { 1732, 1733, 0 },
   { 1734, 1733, 0 },
   { 1815, 1816, 0 },
   { 1817, 1816, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4948, 4949, 0 },
   { 4951, 4952, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 967, 968, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 975, 968, 0 },
   { 1564, 1565, 0 },
   { 1566, 1567, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 977, 968, 0 },
   { 1572, 1573, 0 },
   { 1574, 1575, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1568, 1569, 0 },
   { 1570, 1571, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1576, 1577, 0 },
   { 1578, 1579, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 973, 968, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1986, 1988, 37 },
   { 1986, 1994, 39 },
   { 2012, 2014, 37 },
   { 2012, 2020, 39 },
   { 2038, 2040, 37 },
   { 2038, 2046, 39 },
   { 2063, 2065, 37 },
   { 2063, 2071, 39 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1998, 1999, 40 },
   { 2024, 2025, 40 },
   { 2050, 2051, 40 },
   { 2075, 2076, 40 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1912, 1913, 0 },
   { 2375, 32, 0 },
   { 4524, 1895, 0 },
   { 4577, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4524, 1895, 0 },
   { 4549, 1895, 0 },
   { 4577, 1903, 0 },
   { 4602, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4524, 1895, 0 },
   { 4577, 1903, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4524, 1895, 0 },
   { 4577, 1903, 0 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1907, 1909, 0 },
   { 2375, 32, 0 },
   { 4549, 1895, 0 },
   { 4602, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4549, 1895, 0 },
   { 4602, 1903, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4549, 1895, 0 },
   { 4602, 1903, 0 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1916, 1917, 0 },
   { 2375, 32, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4629, 1903, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1920, 1921, 0 },
   { 2375, 32, 0 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4527, 1937, 0 },
   { 4580, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4552, 1937, 0 },
   { 4605, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { 2385, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { 2386, 2167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { 2386, 2167, 0 },
   { 3146, 3148, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { 4527, 1937, 0 },
   { 4580, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { 4552, 1937, 0 },
   { 4605, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1957, 1958, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 169, 0 },
   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { 2386, 2167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { 4527, 1937, 0 },
   { 4580, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { 4552, 1937, 0 },
   { 4605, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { 4527, 1937, 0 },
   { 4580, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { 4552, 1937, 0 },
   { 4605, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2353, 2354, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1952, 1954, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1955, 1956, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 2394, 2395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 4527, 1937, 0 },
   { 4580, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 4552, 1937, 0 },
   { 4605, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1463, 1465, 0 },
   { 1469, 1471, 0 },
   { 1605, 943, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4527, 1937, 0 },
   { 4580, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4552, 1937, 0 },
   { 4605, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1463, 1465, 0 },
   { 1469, 1471, 0 },
   { 1484, 1465, 0 },
   { 1605, 943, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1463, 1465, 0 },
   { 1469, 1471, 0 },
   { 1605, 943, 0 },
   { 1608, 1610, 0 },
   { 1613, 1610, 0 },
   { 1715, 1717, 0 },
   { 1720, 1717, 0 },
   { 1798, 1800, 0 },
   { 1803, 1800, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1463, 1465, 0 },
   { 1469, 1471, 0 },
   { 1484, 1465, 0 },
   { 1605, 943, 0 },
   { 1608, 1610, 0 },
   { 1613, 1610, 0 },
   { 1715, 1717, 0 },
   { 1720, 1717, 0 },
   { 1798, 1800, 0 },
   { 1803, 1800, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1463, 1465, 0 },
   { 1469, 1471, 0 },
   { 1489, 1471, 0 },
   { 1605, 943, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1463, 1465, 0 },
   { 1469, 1471, 0 },
   { 1489, 1471, 0 },
   { 1605, 943, 0 },
   { 1608, 1610, 0 },
   { 1613, 1610, 0 },
   { 1715, 1717, 0 },
   { 1720, 1717, 0 },
   { 1798, 1800, 0 },
   { 1803, 1800, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1463, 1465, 0 },
   { 1469, 1471, 0 },
   { 1484, 1465, 0 },
   { 1489, 1471, 0 },
   { 1605, 943, 0 },
   { 1608, 1610, 0 },
   { 1613, 1610, 0 },
   { 1715, 1717, 0 },
   { 1720, 1717, 0 },
   { 1798, 1800, 0 },
   { 1803, 1800, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1474, 1476, 0 },
   { 1479, 1481, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1474, 1476, 0 },
   { 1479, 1481, 0 },
   { 1492, 1476, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1474, 1476, 0 },
   { 1479, 1481, 0 },
   { 1616, 1618, 0 },
   { 1621, 1618, 0 },
   { 1723, 1725, 0 },
   { 1728, 1725, 0 },
   { 1806, 1808, 0 },
   { 1811, 1808, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1474, 1476, 0 },
   { 1479, 1481, 0 },
   { 1492, 1476, 0 },
   { 1616, 1618, 0 },
   { 1621, 1618, 0 },
   { 1723, 1725, 0 },
   { 1728, 1725, 0 },
   { 1806, 1808, 0 },
   { 1811, 1808, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1474, 1476, 0 },
   { 1479, 1481, 0 },
   { 1495, 1481, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1474, 1476, 0 },
   { 1479, 1481, 0 },
   { 1495, 1481, 0 },
   { 1616, 1618, 0 },
   { 1621, 1618, 0 },
   { 1723, 1725, 0 },
   { 1728, 1725, 0 },
   { 1806, 1808, 0 },
   { 1811, 1808, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1474, 1476, 0 },
   { 1479, 1481, 0 },
   { 1492, 1476, 0 },
   { 1495, 1481, 0 },
   { 1616, 1618, 0 },
   { 1621, 1618, 0 },
   { 1723, 1725, 0 },
   { 1728, 1725, 0 },
   { 1806, 1808, 0 },
   { 1811, 1808, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1526, 1528, 0 },
   { 1531, 1533, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1546, 1548, 0 },
   { 1551, 1553, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1536, 1538, 0 },
   { 1541, 1543, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1556, 1558, 0 },
   { 1561, 1563, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2093, 2094, 0 },
   { 2097, 2098, 0 },
   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1995, 1997, 40 },
   { 2021, 2023, 40 },
   { 2047, 2049, 40 },
   { 2072, 2074, 40 },
   { 2089, 2090, 0 },
   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { 4527, 1937, 0 },
   { 4580, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { 4552, 1937, 0 },
   { 4605, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1991, 1992, 38 },
   { 1991, 2000, 39 },
   { 2017, 2018, 38 },
   { 2017, 2026, 39 },
   { 2043, 2044, 38 },
   { 2043, 2052, 39 },
   { 2068, 2069, 38 },
   { 2068, 2077, 39 },
   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1946, 1947, 0 },
   { 2378, 32, 0 },
   { 4527, 1937, 0 },
   { 4580, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4527, 1937, 0 },
   { 4552, 1937, 0 },
   { 4580, 1941, 0 },
   { 4605, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4527, 1937, 0 },
   { 4580, 1941, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4527, 1937, 0 },
   { 4580, 1941, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1943, 1945, 0 },
   { 2378, 32, 0 },
   { 4552, 1937, 0 },
   { 4605, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4552, 1937, 0 },
   { 4605, 1941, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4552, 1937, 0 },
   { 4605, 1941, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1948, 1949, 0 },
   { 2378, 32, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4632, 1941, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1950, 1951, 0 },
   { 2378, 32, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2958, 2957, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4530, 1961, 0 },
   { 4583, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4555, 1961, 0 },
   { 4608, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4660, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4635, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 2382, 32, 0 },
   { 4530, 1961, 0 },
   { 4583, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 2382, 32, 0 },
   { 4555, 1961, 0 },
   { 4608, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 2382, 32, 0 },
   { 4660, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 2382, 32, 0 },
   { 4635, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 2382, 32, 0 },
   { 3150, 3152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1981, 1982, 0 },
   { 2381, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1976, 1978, 0 },
   { 2381, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1979, 1980, 0 },
   { 2381, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1970, 1971, 0 },
   { 2381, 61, 0 },
   { 4530, 1961, 0 },
   { 4583, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4530, 1961, 0 },
   { 4555, 1961, 0 },
   { 4583, 1965, 0 },
   { 4608, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4530, 1961, 0 },
   { 4583, 1965, 0 },
   { 4660, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4530, 1961, 0 },
   { 4583, 1965, 0 },
   { 4635, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1967, 1969, 0 },
   { 2381, 61, 0 },
   { 4555, 1961, 0 },
   { 4608, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4555, 1961, 0 },
   { 4608, 1965, 0 },
   { 4660, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4555, 1961, 0 },
   { 4608, 1965, 0 },
   { 4635, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1972, 1973, 0 },
   { 2381, 61, 0 },
   { 4660, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4635, 1965, 0 },
   { 4660, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1974, 1975, 0 },
   { 2381, 61, 0 },
   { 4635, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2008, 2009, 0 },
   { 2034, 2035, 0 },
   { 2059, 2060, 0 },
   { 2085, 2086, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2008, 2009, 0 },
   { 2034, 2035, 0 },
   { 2059, 2060, 0 },
   { 2085, 2086, 0 },
   { 2400, 1113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2400, 1113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 809, 811, 0 },
   { 817, 819, 0 },
   { 824, 826, 0 },
   { 832, 834, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 809, 811, 0 },
   { 817, 819, 0 },
   { 824, 826, 0 },
   { 832, 834, 0 },
   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 2881, 364, 53 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 809, 811, 0 },
   { 817, 819, 0 },
   { 824, 826, 0 },
   { 832, 834, 0 },
   { 2008, 2009, 0 },
   { 2034, 2035, 0 },
   { 2059, 2060, 0 },
   { 2085, 2086, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 809, 811, 0 },
   { 817, 819, 0 },
   { 824, 826, 0 },
   { 832, 834, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 729, 731, 0 },
   { 751, 753, 0 },
   { 772, 774, 0 },
   { 794, 796, 0 },
   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { 2953, 2950, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2006, 2007, 0 },
   { 2032, 2033, 0 },
   { 2057, 2058, 0 },
   { 2083, 2084, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2006, 2007, 0 },
   { 2032, 2033, 0 },
   { 2057, 2058, 0 },
   { 2083, 2084, 0 },
   { 2398, 1113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2399, 32, 0 },
   { 2849, 2850, 52 },
   { 2851, 326, 52 },
   { 2852, 2853, 52 },
   { 2882, 356, 53 },
   { 2883, 359, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2399, 32, 0 },
   { 2849, 2850, 52 },
   { 2851, 326, 52 },
   { 2852, 2853, 52 },
   { 2883, 359, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2006, 2007, 0 },
   { 2032, 2033, 0 },
   { 2057, 2058, 0 },
   { 2083, 2084, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 733, 738, 0 },
   { 755, 760, 0 },
   { 776, 781, 0 },
   { 798, 803, 0 },
   { 2399, 32, 0 },
   { 2849, 2850, 52 },
   { 2851, 326, 52 },
   { 2852, 2853, 52 },
   { 2883, 359, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3026, 3027, 0 },
   { 3029, 339, 0 },
   { 3030, 335, 0 },
   { 3031, 332, 0 },
   { 3033, 3004, 0 },
   { 3035, 2999, 0 },
   { 3037, 2994, 0 },
   { 3039, 2991, 0 },
   { 3041, 2987, 0 },
   { 3043, 2983, 0 },
   { 3045, 3046, 0 },
   { 3394, 3397, 78 },
   { 4504, 11, 0 },
   { 4557, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2976, 2844, 0 },
   { 2978, 335, 0 },
   { 2979, 339, 0 },
   { 2980, 342, 0 },
   { 2982, 2983, 0 },
   { 2985, 2987, 0 },
   { 2989, 2991, 0 },
   { 2992, 2994, 0 },
   { 2997, 2999, 0 },
   { 3002, 3004, 0 },
   { 3005, 2848, 0 },
   { 3394, 3397, 78 },
   { 4504, 11, 0 },
   { 4557, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3006, 2844, 0 },
   { 3008, 335, 0 },
   { 3009, 339, 0 },
   { 3010, 342, 0 },
   { 3012, 2983, 0 },
   { 3014, 2987, 0 },
   { 3016, 2991, 0 },
   { 3018, 2994, 0 },
   { 3020, 2999, 0 },
   { 3022, 3004, 0 },
   { 3023, 2848, 0 },
   { 3394, 3397, 78 },
   { 4504, 11, 0 },
   { 4557, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2880, 2864, 0 },
   { 3394, 3397, 78 },
   { 4504, 11, 0 },
   { 4557, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2879, 2864, 0 },
   { 3394, 3397, 78 },
   { 4504, 11, 0 },
   { 4557, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3024, 2858, 0 },
   { 3394, 3397, 78 },
   { 4504, 11, 0 },
   { 4557, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2968, 2969, 0 },
   { 2970, 2971, 0 },
   { 2972, 2973, 0 },
   { 2974, 2975, 0 },
   { 3394, 3397, 78 },
   { 4504, 11, 0 },
   { 4557, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3047, 3048, 0 },
   { 3049, 322, 0 },
   { 3050, 317, 0 },
   { 3051, 313, 0 },
   { 3052, 3053, 0 },
   { 3054, 3055, 0 },
   { 3056, 3057, 0 },
   { 3058, 3059, 0 },
   { 3060, 3061, 0 },
   { 3062, 3063, 0 },
   { 3064, 3065, 0 },
   { 3389, 3393, 78 },
   { 4532, 11, 0 },
   { 4585, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2960, 2961, 0 },
   { 2962, 2963, 0 },
   { 2964, 2965, 0 },
   { 2966, 2967, 0 },
   { 3389, 3393, 78 },
   { 4532, 11, 0 },
   { 4585, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2828, 21, 0 },
   { 2817, 2911, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 48, 49, 0 },
   { 2826, 2916, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 51, 49, 0 },
   { 2826, 2916, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2826, 2916, 57 },
   { 2926, 2826, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2818, 16, 0 },
   { 2826, 2916, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 99, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 0 },
   { 2768, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 104, 0 },
   { 2768, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2768, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2226, 2225, 0 },
   { 2768, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 2227, 0 },
   { 2768, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 2229, 0 },
   { 2768, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2232, 2231, 0 },
   { 2768, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2768, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 109, 110, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3639, 650, 0 },
   { 3642, 6, 0 },
   { 3646, 11, 0 },
   { 3648, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 170, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3102, 3104, 0 },
   { 3106, 3104, 0 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3102, 3104, 0 },
   { 3106, 3104, 0 },
   { 3123, 3104, 0 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3109, 3111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3109, 3111, 0 },
   { 3130, 3132, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 5025, 5028, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { 179, 3, 0 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 149, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { 3087, 3089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { 3087, 3089, 0 },
   { 3116, 3089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { 5029, 5032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { 5029, 5032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 201, 202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2355, 1152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2487, 2488, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2492, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 210, 211, 0 },
   { 212, 213, 5 },
   { 214, 215, 6 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 152, 154, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 224, 225, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 224, 225, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 210, 211, 0 },
   { 212, 213, 5 },
   { 214, 215, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3097, 3099, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 210, 211, 0 },
   { 212, 213, 5 },
   { 214, 215, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3097, 3099, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 152, 154, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3097, 3099, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3097, 3099, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3097, 3099, 0 },
   { 3119, 3099, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 210, 211, 0 },
   { 212, 213, 5 },
   { 214, 215, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3097, 3099, 0 },
   { 3119, 3099, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 152, 154, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3097, 3099, 0 },
   { 3119, 3099, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3097, 3099, 0 },
   { 3119, 3099, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3080, 3081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 210, 211, 0 },
   { 212, 213, 5 },
   { 214, 215, 6 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3080, 3081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3080, 3081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { 3080, 3081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 152, 154, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 210, 211, 0 },
   { 212, 213, 5 },
   { 214, 215, 6 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 1390, 35 },
   { 2771, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 1390, 35 },
   { 1403, 182, 0 },
   { 2771, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1398, 1400, 0 },
   { 182, 1390, 35 },
   { 2771, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1402, 1401, 0 },
   { 182, 1390, 35 },
   { 2771, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1056, 614, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2134, 968, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2128, 2129, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 988, 989, 0 },
   { 1056, 614, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1138, 1139, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1125, 1126, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1001, 1003, 0 },
   { 1011, 1012, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { 4978, 4983, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2134, 968, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1136, 1137, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2128, 2129, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 986, 987, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 979, 969, 0 },
   { 1056, 614, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1124, 968, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1072, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1072, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1056, 614, 0 },
   { 1071, 1072, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1072, 0 },
   { 2134, 968, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1072, 0 },
   { 2128, 2129, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1072, 0 },
   { 1080, 1083, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { 4970, 4973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2130, 969, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2130, 969, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1056, 614, 0 },
   { 2130, 969, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2130, 969, 0 },
   { 2134, 968, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2128, 2129, 0 },
   { 2130, 969, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1134, 1135, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2135, 968, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2135, 968, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1056, 614, 0 },
   { 2135, 968, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2134, 968, 0 },
   { 2135, 968, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2128, 2129, 0 },
   { 2135, 968, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { 4447, 4448, 101 },
   { 4454, 4455, 101 },
   { 4460, 4448, 101 },
   { 4464, 4455, 101 },
   { 4471, 4472, 0 },
   { 4476, 4477, 0 },
   { 4486, 4487, 0 },
   { 4492, 4493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1057, 1058, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2132, 1121, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2136, 2137, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 992, 993, 0 },
   { 1057, 1058, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1142, 1143, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1122, 1123, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1015, 1016, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { 4988, 4991, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2132, 1121, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1132, 1133, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2136, 2137, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 990, 991, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 980, 981, 0 },
   { 1057, 1058, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1120, 1121, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1073, 1074, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1073, 1074, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1057, 1058, 0 },
   { 1073, 1074, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1073, 1074, 0 },
   { 2132, 1121, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1073, 1074, 0 },
   { 2136, 2137, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1073, 1074, 0 },
   { 1089, 1090, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1006, 937, 0 },
   { 1010, 993, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { 4984, 4987, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2138, 981, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2138, 981, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1057, 1058, 0 },
   { 2138, 981, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2132, 1121, 0 },
   { 2138, 981, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2136, 2137, 0 },
   { 2138, 981, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1130, 1131, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2133, 1121, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2133, 1121, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1057, 1058, 0 },
   { 2133, 1121, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2132, 1121, 0 },
   { 2133, 1121, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2133, 1121, 0 },
   { 2136, 2137, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { 4445, 4446, 101 },
   { 4451, 4453, 101 },
   { 4459, 4446, 101 },
   { 4463, 4453, 101 },
   { 4469, 4470, 0 },
   { 4474, 4475, 0 },
   { 4484, 4485, 0 },
   { 4489, 4491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2349, 1143, 0 },
   { 2373, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1075, 1076, 0 },
   { 2373, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 996, 997, 0 },
   { 2349, 1143, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1118, 1119, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1075, 1076, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1075, 1076, 0 },
   { 1094, 1096, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1007, 946, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1110, 1016, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { 4954, 4957, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1129, 1119, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 982, 983, 0 },
   { 2349, 1143, 0 },
   { 2373, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1075, 1076, 0 },
   { 2349, 1143, 0 },
   { 2373, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1048, 1047, 0 },
   { 1279, 1047, 0 },
   { 1283, 1047, 0 },
   { 1287, 1047, 0 },
   { 2373, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2373, 1121, 0 },
   { 4440, 4442, 101 },
   { 4457, 4442, 101 },
   { 4465, 4466, 0 },
   { 4479, 4481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2348, 1139, 0 },
   { 2374, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1077, 1078, 0 },
   { 2374, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 995, 0 },
   { 2348, 1139, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1116, 1117, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1077, 1078, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1077, 1078, 0 },
   { 1102, 1103, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1008, 943, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1111, 650, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { 4958, 4961, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1128, 1117, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 984, 985, 0 },
   { 2348, 1139, 0 },
   { 2374, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1077, 1078, 0 },
   { 2348, 1139, 0 },
   { 2374, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1037, 1036, 0 },
   { 1280, 1264, 0 },
   { 1284, 1264, 0 },
   { 1288, 1264, 0 },
   { 2374, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2374, 968, 0 },
   { 4443, 4444, 101 },
   { 4458, 4444, 101 },
   { 4467, 4468, 0 },
   { 4482, 4483, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1380, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1380, 32, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1439, 1440, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1158, 1161, 0 },
   { 1204, 32, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1390, 182, 33 },
   { 1394, 1395, 33 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1380, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1375, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1380, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1380, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1154, 1152, 0 },
   { 1204, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1384, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1384, 103, 0 },
   { 1388, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1437, 1438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1392, 182, 33 },
   { 1397, 1395, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1384, 103, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { 1384, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1148, 1149, 0 },
   { 1205, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 101, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2002, 6, 0 },
   { 2028, 11, 0 },
   { 2054, 16, 0 },
   { 2079, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5291, 5294, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 106, 0 },
   { 2769, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 107, 106, 0 },
   { 2769, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2769, 32, 0 },
   { 5295, 5298, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 112, 0 },
   { 2654, 2655, 0 },
   { 2656, 2657, 0 },
   { 2658, 1117, 0 },
   { 111, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 2655, 0 },
   { 2656, 2657, 0 },
   { 2658, 1117, 0 },
   { 2734, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 2655, 0 },
   { 2656, 2657, 0 },
   { 2658, 1117, 0 },
   { 2727, 11, 0 },
   { 2729, 16, 0 },
   { 3640, 650, 0 },
   { 3644, 6, 0 },
   { 2727, 11, 0 },
   { 2729, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 2655, 0 },
   { 2656, 2657, 0 },
   { 2658, 1117, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 2655, 0 },
   { 2656, 2657, 0 },
   { 2658, 1117, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1376, 1377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1381, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1376, 1377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1381, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 3478, 3476, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1376, 1377, 0 },
   { 1381, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { 1376, 1377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1376, 1377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { 1381, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1381, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1385, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1385, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 3480, 3476, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1385, 106, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { 1385, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1654, 11, 0 },
   { 1761, 16, 0 },
   { 1844, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3651, 2718, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2730, 2731, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1652, 11, 0 },
   { 1759, 16, 0 },
   { 1842, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1680, 1681, 0 },
   { 1703, 1704, 0 },
   { 1787, 1788, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1868, 1869, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1656, 11, 0 },
   { 1763, 16, 0 },
   { 1846, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3650, 2718, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2732, 2733, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1655, 11, 0 },
   { 1762, 16, 0 },
   { 1845, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1678, 1679, 0 },
   { 1701, 1702, 0 },
   { 1785, 1786, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1866, 1867, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1683, 1684, 0 },
   { 1706, 1684, 0 },
   { 1789, 1682, 0 },
   { 3666, 11, 0 },
   { 3667, 16, 0 },
   { 3668, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1675, 1277, 0 },
   { 1698, 1277, 0 },
   { 1782, 1281, 0 },
   { 3649, 1401, 0 },
   { 3666, 11, 0 },
   { 3667, 16, 0 },
   { 3668, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3666, 11, 0 },
   { 3667, 16, 0 },
   { 3668, 21, 0 },
   { 5341, 5343, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3666, 11, 0 },
   { 3667, 16, 0 },
   { 3668, 21, 0 },
   { 5325, 5327, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3666, 11, 0 },
   { 3667, 16, 0 },
   { 3668, 21, 0 },
   { 5312, 5313, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1686, 1687, 0 },
   { 1708, 1687, 0 },
   { 1790, 1685, 0 },
   { 3666, 11, 0 },
   { 3667, 16, 0 },
   { 3668, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1670, 11, 0 },
   { 1693, 11, 0 },
   { 1777, 16, 0 },
   { 2761, 16, 0 },
   { 3666, 11, 0 },
   { 3667, 16, 0 },
   { 3668, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2754, 16, 0 },
   { 3666, 11, 0 },
   { 3667, 16, 0 },
   { 3668, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2759, 1862, 0 },
   { 3666, 11, 0 },
   { 3667, 16, 0 },
   { 3668, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2760, 1859, 0 },
   { 3666, 11, 0 },
   { 3667, 16, 0 },
   { 3668, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1860, 1861, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2748, 1277, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5344, 5346, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5328, 5330, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5314, 5316, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1863, 1864, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2737, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2736, 1143, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2383, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 936, 937, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 939, 940, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 942, 943, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 945, 946, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 948, 949, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 951, 952, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 954, 955, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 957, 958, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 960, 961, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 963, 964, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5299, 5302, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 386, 387, 13 },
   { 461, 462, 15 },
   { 532, 533, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 386, 387, 13 },
   { 461, 462, 15 },
   { 532, 533, 17 },
   { 610, 612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 231, 233, 0 },
   { 390, 392, 13 },
   { 464, 466, 15 },
   { 536, 538, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 0, 0 },
   { 227, 3, 0 },
   { 228, 0, 0 },
   { 231, 233, 0 },
   { 390, 392, 13 },
   { 464, 466, 15 },
   { 536, 538, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 231, 233, 0 },
   { 386, 387, 13 },
   { 390, 392, 13 },
   { 461, 462, 15 },
   { 464, 466, 15 },
   { 532, 533, 17 },
   { 536, 538, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 400, 403, 13 },
   { 473, 476, 15 },
   { 546, 549, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 0, 0 },
   { 227, 3, 0 },
   { 228, 0, 0 },
   { 400, 403, 13 },
   { 473, 476, 15 },
   { 546, 549, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 386, 387, 13 },
   { 400, 403, 13 },
   { 461, 462, 15 },
   { 473, 476, 15 },
   { 532, 533, 17 },
   { 546, 549, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 229, 211, 0 },
   { 386, 387, 13 },
   { 461, 462, 15 },
   { 532, 533, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 229, 211, 0 },
   { 386, 387, 13 },
   { 461, 462, 15 },
   { 532, 533, 17 },
   { 610, 612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 229, 211, 0 },
   { 231, 233, 0 },
   { 390, 392, 13 },
   { 464, 466, 15 },
   { 536, 538, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 0, 0 },
   { 227, 3, 0 },
   { 228, 0, 0 },
   { 229, 211, 0 },
   { 231, 233, 0 },
   { 390, 392, 13 },
   { 464, 466, 15 },
   { 536, 538, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 229, 211, 0 },
   { 231, 233, 0 },
   { 386, 387, 13 },
   { 390, 392, 13 },
   { 461, 462, 15 },
   { 464, 466, 15 },
   { 532, 533, 17 },
   { 536, 538, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 229, 211, 0 },
   { 400, 403, 13 },
   { 473, 476, 15 },
   { 546, 549, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 0, 0 },
   { 227, 3, 0 },
   { 228, 0, 0 },
   { 229, 211, 0 },
   { 400, 403, 13 },
   { 473, 476, 15 },
   { 546, 549, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 229, 211, 0 },
   { 386, 387, 13 },
   { 400, 403, 13 },
   { 461, 462, 15 },
   { 473, 476, 15 },
   { 532, 533, 17 },
   { 546, 549, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 231, 233, 0 },
   { 390, 392, 13 },
   { 396, 398, 13 },
   { 464, 466, 15 },
   { 469, 471, 15 },
   { 536, 538, 17 },
   { 542, 544, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 0, 0 },
   { 227, 3, 0 },
   { 228, 0, 0 },
   { 231, 233, 0 },
   { 390, 392, 13 },
   { 396, 398, 13 },
   { 464, 466, 15 },
   { 469, 471, 15 },
   { 536, 538, 17 },
   { 542, 544, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 231, 233, 0 },
   { 386, 387, 13 },
   { 390, 392, 13 },
   { 396, 398, 13 },
   { 461, 462, 15 },
   { 464, 466, 15 },
   { 469, 471, 15 },
   { 532, 533, 17 },
   { 536, 538, 17 },
   { 542, 544, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 400, 403, 13 },
   { 473, 476, 15 },
   { 546, 549, 17 },
   { 606, 608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 0, 0 },
   { 227, 3, 0 },
   { 228, 0, 0 },
   { 400, 403, 13 },
   { 473, 476, 15 },
   { 546, 549, 17 },
   { 606, 608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 0, 0 },
   { 386, 387, 13 },
   { 400, 403, 13 },
   { 461, 462, 15 },
   { 473, 476, 15 },
   { 532, 533, 17 },
   { 546, 549, 17 },
   { 606, 608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1106, 1107, 0 },
   { 2366, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1106, 1107, 0 },
   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1294, 1295, 0 },
   { 1299, 1298, 0 },
   { 1316, 1317, 0 },
   { 1321, 1320, 0 },
   { 1338, 1339, 0 },
   { 1343, 1342, 0 },
   { 1358, 1359, 0 },
   { 1363, 1362, 0 },
   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1114, 1016, 0 },
   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1295, 0 },
   { 1304, 1298, 0 },
   { 1324, 1317, 0 },
   { 1326, 1320, 0 },
   { 1346, 1339, 0 },
   { 1347, 1342, 0 },
   { 1366, 1359, 0 },
   { 1368, 1362, 0 },
   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1295, 0 },
   { 1309, 1298, 0 },
   { 1329, 1317, 0 },
   { 1331, 1320, 0 },
   { 1350, 1339, 0 },
   { 1351, 1342, 0 },
   { 1371, 1359, 0 },
   { 1373, 1362, 0 },
   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { 4962, 4965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { 3803, 3808, 100 },
   { 3850, 3855, 100 },
   { 3896, 3901, 100 },
   { 3963, 3968, 101 },
   { 4014, 4019, 101 },
   { 4092, 4097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { 4146, 4149, 100 },
   { 4186, 4190, 100 },
   { 4228, 4233, 100 },
   { 4292, 4297, 101 },
   { 4337, 4342, 101 },
   { 4409, 4414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { 3357, 3354, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { 3353, 3354, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1047, 0 },
   { 1267, 1047, 0 },
   { 1271, 1047, 0 },
   { 1275, 1047, 0 },
   { 2366, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 3785, 3787, 100 },
   { 3842, 3787, 100 },
   { 3887, 3787, 100 },
   { 3934, 3935, 101 },
   { 3948, 3950, 101 },
   { 3999, 3935, 101 },
   { 4007, 3950, 101 },
   { 4051, 4052, 0 },
   { 4064, 4065, 0 },
   { 4077, 4079, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 4130, 4132, 100 },
   { 4178, 4132, 100 },
   { 4220, 4132, 100 },
   { 4264, 4265, 101 },
   { 4277, 4279, 101 },
   { 4322, 4265, 101 },
   { 4330, 4279, 101 },
   { 4369, 4370, 0 },
   { 4382, 4383, 0 },
   { 4394, 4396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1108, 1109, 0 },
   { 2367, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1108, 1109, 0 },
   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1296, 1295, 0 },
   { 1297, 1298, 0 },
   { 1318, 1317, 0 },
   { 1319, 1320, 0 },
   { 1340, 1339, 0 },
   { 1341, 1342, 0 },
   { 1360, 1359, 0 },
   { 1361, 1362, 0 },
   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1115, 650, 0 },
   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1301, 1298, 0 },
   { 1305, 1295, 0 },
   { 1323, 1320, 0 },
   { 1327, 1317, 0 },
   { 1345, 1342, 0 },
   { 1348, 1339, 0 },
   { 1365, 1362, 0 },
   { 1369, 1359, 0 },
   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1306, 1298, 0 },
   { 1310, 1295, 0 },
   { 1328, 1320, 0 },
   { 1332, 1317, 0 },
   { 1349, 1342, 0 },
   { 1352, 1339, 0 },
   { 1370, 1362, 0 },
   { 1374, 1359, 0 },
   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { 4966, 4969, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { 3809, 3812, 100 },
   { 3856, 3859, 100 },
   { 3902, 3905, 100 },
   { 3969, 3972, 101 },
   { 4020, 4023, 101 },
   { 4098, 4101, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { 4150, 4153, 100 },
   { 4191, 4194, 100 },
   { 4234, 4237, 100 },
   { 4298, 4301, 101 },
   { 4343, 4346, 101 },
   { 4415, 4418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { 3356, 3352, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { 3347, 3352, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1263, 1264, 0 },
   { 1268, 1264, 0 },
   { 1272, 1264, 0 },
   { 1276, 1264, 0 },
   { 2367, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2367, 968, 0 },
   { 3788, 3789, 100 },
   { 3843, 3789, 100 },
   { 3888, 3789, 100 },
   { 3936, 3937, 101 },
   { 3951, 3952, 101 },
   { 4000, 3937, 101 },
   { 4008, 3952, 101 },
   { 4053, 4054, 0 },
   { 4066, 4067, 0 },
   { 4080, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2367, 968, 0 },
   { 4133, 4134, 100 },
   { 4179, 4134, 100 },
   { 4221, 4134, 100 },
   { 4266, 4267, 101 },
   { 4280, 4281, 101 },
   { 4323, 4267, 101 },
   { 4331, 4281, 101 },
   { 4371, 4372, 0 },
   { 4384, 4385, 0 },
   { 4397, 4398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2166, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2159, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2147, 2148, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2166, 968, 0 },
   { 2368, 968, 0 },
   { 2815, 1121, 0 },
   { 3298, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2368, 968, 0 },
   { 2815, 1121, 0 },
   { 3298, 3295, 70 },
   { 5012, 5015, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2159, 968, 0 },
   { 2368, 968, 0 },
   { 2815, 1121, 0 },
   { 3298, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2159, 968, 0 },
   { 2211, 2212, 0 },
   { 2368, 968, 0 },
   { 2815, 1121, 0 },
   { 3298, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2147, 2148, 0 },
   { 2368, 968, 0 },
   { 2815, 1121, 0 },
   { 3298, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2147, 2148, 0 },
   { 2188, 2190, 0 },
   { 2368, 968, 0 },
   { 2815, 1121, 0 },
   { 3298, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2368, 968, 0 },
   { 2815, 1121, 0 },
   { 3298, 3295, 70 },
   { 4160, 4165, 100 },
   { 4201, 4206, 100 },
   { 4245, 4251, 100 },
   { 4307, 4311, 101 },
   { 4353, 4358, 101 },
   { 4424, 4428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2168, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2168, 968, 0 },
   { 2368, 968, 0 },
   { 2816, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2166, 968, 0 },
   { 2168, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2159, 968, 0 },
   { 2168, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2147, 2148, 0 },
   { 2168, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2368, 968, 0 },
   { 2816, 968, 0 },
   { 5008, 5011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2149, 976, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2149, 976, 0 },
   { 2368, 968, 0 },
   { 2816, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2149, 976, 0 },
   { 2166, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2149, 976, 0 },
   { 2159, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2147, 2148, 0 },
   { 2149, 976, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2149, 976, 0 },
   { 2192, 2194, 0 },
   { 2368, 968, 0 },
   { 2816, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2160, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2160, 968, 0 },
   { 2368, 968, 0 },
   { 2816, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2160, 968, 0 },
   { 2166, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2159, 968, 0 },
   { 2160, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2147, 2148, 0 },
   { 2160, 968, 0 },
   { 2368, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2160, 968, 0 },
   { 2213, 2214, 0 },
   { 2368, 968, 0 },
   { 2816, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2368, 968, 0 },
   { 2816, 968, 0 },
   { 4154, 4159, 100 },
   { 4195, 4200, 100 },
   { 4238, 4244, 100 },
   { 4302, 4306, 101 },
   { 4347, 4352, 101 },
   { 4419, 4423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2368, 968, 0 },
   { 4137, 4138, 100 },
   { 4144, 4145, 100 },
   { 4181, 4138, 100 },
   { 4185, 4145, 100 },
   { 4223, 4138, 100 },
   { 4227, 4145, 100 },
   { 4270, 4271, 101 },
   { 4275, 4276, 101 },
   { 4284, 4285, 101 },
   { 4290, 4291, 101 },
   { 4325, 4271, 101 },
   { 4328, 4276, 101 },
   { 4333, 4285, 101 },
   { 4336, 4291, 101 },
   { 4375, 4376, 0 },
   { 4380, 4381, 0 },
   { 4388, 4389, 0 },
   { 4392, 4393, 0 },
   { 4401, 4402, 0 },
   { 4407, 4408, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2151, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 2162, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2369, 1121, 0 },
   { 5020, 5023, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2151, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2151, 1121, 0 },
   { 2196, 2198, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 2162, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 2162, 0 },
   { 2215, 2216, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2369, 1121, 0 },
   { 4172, 4177, 100 },
   { 4213, 4218, 100 },
   { 4258, 4263, 100 },
   { 4317, 4321, 101 },
   { 4364, 4368, 101 },
   { 4434, 4438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1121, 0 },
   { 2170, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2151, 1121, 0 },
   { 2170, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 2162, 0 },
   { 2170, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2369, 1121, 0 },
   { 5016, 5019, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 2164, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 2164, 0 },
   { 2169, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2151, 1121, 0 },
   { 2163, 2164, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2161, 2162, 0 },
   { 2163, 2164, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 2164, 0 },
   { 2217, 2218, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2152, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2152, 1121, 0 },
   { 2169, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2151, 1121, 0 },
   { 2152, 1121, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2152, 1121, 0 },
   { 2161, 2162, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2152, 1121, 0 },
   { 2200, 2202, 0 },
   { 2369, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2369, 1121, 0 },
   { 4166, 4171, 100 },
   { 4207, 4212, 100 },
   { 4252, 4257, 100 },
   { 4312, 4316, 101 },
   { 4359, 4363, 101 },
   { 4429, 4433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2369, 1121, 0 },
   { 4135, 4136, 100 },
   { 4141, 4143, 100 },
   { 4180, 4136, 100 },
   { 4184, 4143, 100 },
   { 4222, 4136, 100 },
   { 4226, 4143, 100 },
   { 4268, 4269, 101 },
   { 4273, 4274, 101 },
   { 4282, 4283, 101 },
   { 4287, 4289, 101 },
   { 4324, 4269, 101 },
   { 4327, 4274, 101 },
   { 4332, 4283, 101 },
   { 4335, 4289, 101 },
   { 4373, 4374, 0 },
   { 4378, 4379, 0 },
   { 4386, 4387, 0 },
   { 4390, 4391, 0 },
   { 4399, 4400, 0 },
   { 4404, 4406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3322, 3323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3320, 2389, 0 },
   { 3322, 3323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { 4494, 2916, 0 },
   { 4495, 2919, 0 },
   { 4497, 4355, 0 },
   { 4499, 1881, 0 },
   { 4500, 1897, 0 },
   { 4502, 4248, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1676, 1265, 0 },
   { 1699, 1265, 0 },
   { 1783, 1269, 0 },
   { 3655, 2718, 0 },
   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { 5350, 5352, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { 5334, 5336, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { 5319, 5320, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1672, 11, 0 },
   { 1695, 11, 0 },
   { 1779, 16, 0 },
   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { 3674, 3675, 0 },
   { 3682, 3675, 0 },
   { 3688, 3675, 0 },
   { 3694, 3675, 0 },
   { 3699, 3700, 0 },
   { 3703, 3673, 0 },
   { 3707, 3673, 0 },
   { 3711, 3673, 0 },
   { 3715, 3716, 0 },
   { 3719, 3716, 0 },
   { 3721, 3722, 0 },
   { 3725, 3681, 0 },
   { 3729, 3681, 0 },
   { 3733, 3734, 0 },
   { 3737, 3734, 0 },
   { 3739, 3740, 0 },
   { 3742, 3734, 0 },
   { 3744, 3740, 0 },
   { 3746, 1671, 0 },
   { 3748, 3687, 0 },
   { 3752, 3753, 0 },
   { 3756, 3753, 0 },
   { 3758, 3759, 0 },
   { 3762, 3753, 0 },
   { 3764, 3759, 0 },
   { 3766, 1694, 0 },
   { 3768, 3753, 0 },
   { 3770, 3759, 0 },
   { 3772, 1694, 0 },
   { 3774, 1778, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { 3677, 3678, 0 },
   { 3684, 3678, 0 },
   { 3690, 3678, 0 },
   { 3696, 3678, 0 },
   { 3704, 3676, 0 },
   { 3708, 3676, 0 },
   { 3712, 3676, 0 },
   { 3726, 3683, 0 },
   { 3730, 3683, 0 },
   { 3749, 3689, 0 },
   { 4531, 11, 0 },
   { 4584, 16, 0 },
   { 4636, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2755, 16, 0 },
   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2757, 1873, 0 },
   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { 3776, 3777, 0 },
   { 3776, 3777, 0 },
   { 3778, 3779, 0 },
   { 3778, 3779, 0 },
   { 3780, 3659, 0 },
   { 3780, 3659, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1677, 1265, 0 },
   { 1700, 1265, 0 },
   { 1784, 1269, 0 },
   { 3653, 2718, 0 },
   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { 5347, 5349, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { 5331, 5333, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { 5317, 5318, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2861, 2863, 52 },
   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { 3679, 3675, 0 },
   { 3685, 3675, 0 },
   { 3691, 3675, 0 },
   { 3697, 3675, 0 },
   { 3705, 3673, 0 },
   { 3709, 3673, 0 },
   { 3713, 3673, 0 },
   { 3727, 3681, 0 },
   { 3731, 3681, 0 },
   { 3750, 3687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1674, 11, 0 },
   { 1697, 11, 0 },
   { 1781, 16, 0 },
   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { 3680, 3678, 0 },
   { 3686, 3678, 0 },
   { 3692, 3678, 0 },
   { 3698, 3678, 0 },
   { 3701, 3702, 0 },
   { 3706, 3676, 0 },
   { 3710, 3676, 0 },
   { 3714, 3676, 0 },
   { 3717, 3718, 0 },
   { 3720, 3718, 0 },
   { 3723, 3724, 0 },
   { 3728, 3683, 0 },
   { 3732, 3683, 0 },
   { 3735, 3736, 0 },
   { 3738, 3736, 0 },
   { 3741, 2891, 0 },
   { 3743, 3736, 0 },
   { 3745, 2891, 0 },
   { 3747, 1673, 0 },
   { 3751, 3689, 0 },
   { 3754, 3755, 0 },
   { 3757, 3755, 0 },
   { 3760, 3761, 0 },
   { 3763, 3755, 0 },
   { 3765, 3761, 0 },
   { 3767, 1696, 0 },
   { 3769, 3755, 0 },
   { 3771, 3761, 0 },
   { 3773, 1696, 0 },
   { 3775, 1780, 0 },
   { 4503, 11, 0 },
   { 4556, 16, 0 },
   { 4609, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2756, 16, 0 },
   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2857, 2859, 52 },
   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2758, 1870, 0 },
   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { 3781, 1897, 0 },
   { 3781, 1897, 0 },
   { 3782, 2919, 0 },
   { 3782, 2919, 0 },
   { 3783, 3664, 0 },
   { 3783, 3664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2827, 2918, 57 },
   { 2933, 2827, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2819, 36, 0 },
   { 2827, 2918, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2835, 2919, 58 },
   { 2923, 2835, 0 },
   { 2835, 2919, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2835, 2919, 58 },
   { 2937, 2835, 0 },
   { 2938, 2837, 0 },
   { 2835, 2919, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2837, 2920, 58 },
   { 2930, 2837, 0 },
   { 2837, 2920, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3325, 3318, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3327, 3318, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3327, 3318, 0 },
   { 3335, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3325, 3318, 0 },
   { 3327, 3318, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3328, 3315, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3329, 3315, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3329, 3315, 0 },
   { 3336, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3328, 3315, 0 },
   { 3329, 3315, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2921, 2922, 0 },
   { 2922, 3473, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2936, 2929, 0 },
   { 2922, 3473, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2934, 2922, 0 },
   { 2935, 2929, 0 },
   { 2922, 3473, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2928, 2929, 0 },
   { 2929, 3474, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3331, 3332, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3334, 3332, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3331, 3332, 0 },
   { 3334, 3332, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2750, 1265, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2740, 2741, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2751, 1265, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2742, 2743, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3652, 1401, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1688, 1689, 0 },
   { 1709, 1710, 0 },
   { 1791, 1792, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1877, 1878, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3654, 1401, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1649, 1650, 0 },
   { 1756, 1757, 0 },
   { 1839, 1840, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1690, 1691, 0 },
   { 1711, 1712, 0 },
   { 1793, 1794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1879, 1880, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2749, 1265, 0 },
   { 2749, 1265, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5353, 5355, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5337, 5339, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5321, 5323, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1874, 1875, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1871, 1872, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2738, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2739, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2752, 1277, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2744, 2745, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2753, 1277, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2746, 2747, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 666, 668, 31 },
   { 678, 679, 0 },
   { 694, 695, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 666, 668, 31 },
   { 673, 675, 0 },
   { 678, 679, 0 },
   { 694, 695, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 666, 668, 31 },
   { 670, 211, 0 },
   { 673, 675, 0 },
   { 678, 679, 0 },
   { 694, 695, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 683, 675, 0 },
   { 692, 693, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 681, 211, 0 },
   { 683, 675, 0 },
   { 692, 693, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 685, 211, 0 },
   { 690, 691, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 685, 211, 0 },
   { 686, 689, 0 },
   { 690, 691, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2107, 2108, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 2288, 42 },
   { 4907, 2318, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 2288, 42 },
   { 4906, 2283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2289, 2295, 42 },
   { 4913, 2322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2289, 2295, 42 },
   { 4912, 2289, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2296, 2302, 42 },
   { 4917, 2328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2296, 2302, 42 },
   { 4916, 2296, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4922, 4923, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4920, 4921, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4930, 4931, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4928, 4929, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2303, 2306, 42 },
   { 4911, 2333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2303, 2306, 42 },
   { 4910, 2303, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2307, 2312, 42 },
   { 4915, 2337, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2307, 2312, 42 },
   { 4914, 2307, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2313, 2317, 42 },
   { 4919, 2343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2313, 2317, 42 },
   { 4918, 2313, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4926, 4927, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4924, 4925, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4934, 4935, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4932, 4933, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2153, 968, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2140, 2141, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 4996, 4999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2153, 968, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2153, 968, 0 },
   { 2203, 2204, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2140, 2141, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2140, 2141, 0 },
   { 2172, 2174, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 3822, 3828, 100 },
   { 3868, 3873, 100 },
   { 3915, 3921, 100 },
   { 3981, 3986, 101 },
   { 4032, 4038, 101 },
   { 4110, 4116, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 1362, 3291, 70 },
   { 4992, 4995, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2142, 974, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2142, 974, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 3284, 3286, 69 },
   { 1362, 3291, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2142, 974, 0 },
   { 2153, 968, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2140, 2141, 0 },
   { 2142, 974, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2142, 974, 0 },
   { 2176, 2178, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 3284, 3286, 69 },
   { 1362, 3291, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2154, 968, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2154, 968, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 3279, 3282, 69 },
   { 1362, 3291, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2153, 968, 0 },
   { 2154, 968, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2140, 2141, 0 },
   { 2154, 968, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2154, 968, 0 },
   { 2205, 2206, 0 },
   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 3279, 3282, 69 },
   { 1362, 3291, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 1362, 3291, 70 },
   { 3813, 3820, 100 },
   { 3860, 3867, 100 },
   { 3906, 3913, 100 },
   { 3973, 3980, 101 },
   { 4024, 4031, 101 },
   { 4102, 4109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 968, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 3792, 3793, 100 },
   { 3801, 3802, 100 },
   { 3845, 3793, 100 },
   { 3849, 3802, 100 },
   { 3890, 3793, 100 },
   { 3894, 3802, 100 },
   { 3940, 3941, 101 },
   { 3945, 3946, 101 },
   { 3955, 3956, 101 },
   { 3961, 3962, 101 },
   { 4002, 3941, 101 },
   { 4005, 3946, 101 },
   { 4010, 3956, 101 },
   { 4013, 3962, 101 },
   { 4057, 4058, 0 },
   { 4062, 4063, 0 },
   { 4070, 4071, 0 },
   { 4074, 4075, 0 },
   { 4084, 4085, 0 },
   { 4090, 4091, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2144, 1121, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2155, 2156, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 5004, 5007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2144, 1121, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2144, 1121, 0 },
   { 2180, 2182, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2155, 2156, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2155, 2156, 0 },
   { 2207, 2208, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 3835, 3840, 100 },
   { 3880, 3885, 100 },
   { 3928, 3933, 100 },
   { 3993, 3998, 101 },
   { 4045, 4050, 101 },
   { 4123, 4128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 1359, 3292, 70 },
   { 5000, 5003, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2157, 2158, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2157, 2158, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 3289, 3290, 69 },
   { 1359, 3292, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2144, 1121, 0 },
   { 2157, 2158, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2155, 2156, 0 },
   { 2157, 2158, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2157, 2158, 0 },
   { 2209, 2210, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 3289, 3290, 69 },
   { 1359, 3292, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2145, 1121, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2145, 1121, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 3287, 3288, 69 },
   { 1359, 3292, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2144, 1121, 0 },
   { 2145, 1121, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2145, 1121, 0 },
   { 2155, 2156, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2145, 1121, 0 },
   { 2184, 2186, 0 },
   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 3287, 3288, 69 },
   { 1359, 3292, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 1359, 3292, 70 },
   { 3829, 3834, 100 },
   { 3874, 3879, 100 },
   { 3922, 3927, 100 },
   { 3987, 3992, 101 },
   { 4039, 4044, 101 },
   { 4117, 4122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 3790, 3791, 100 },
   { 3798, 3800, 100 },
   { 3844, 3791, 100 },
   { 3848, 3800, 100 },
   { 3889, 3791, 100 },
   { 3893, 3800, 100 },
   { 3938, 3939, 101 },
   { 3943, 3944, 101 },
   { 3953, 3954, 101 },
   { 3958, 3960, 101 },
   { 4001, 3939, 101 },
   { 4004, 3944, 101 },
   { 4009, 3954, 101 },
   { 4012, 3960, 101 },
   { 4055, 4056, 0 },
   { 4060, 4061, 0 },
   { 4068, 4069, 0 },
   { 4072, 4073, 0 },
   { 4082, 4083, 0 },
   { 4087, 4089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 1359, 3292, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 1359, 3292, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 1359, 3292, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3476, 3478, 89 },
   { 5303, 5306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1225, 1226, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1209, 61, 0 },
   { 1210, 32, 0 },
   { 1225, 1226, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1209, 61, 0 },
   { 1210, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1225, 1226, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 32, 0 },
   { 1217, 1218, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 32, 0 },
   { 1212, 32, 0 },
   { 1213, 63, 0 },
   { 1217, 1218, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2906, 2907, 0 },
   { 3403, 3406, 79 },
   { 4610, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2908, 2907, 0 },
   { 3403, 3406, 79 },
   { 4610, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2954, 2950, 0 },
   { 3403, 3406, 79 },
   { 4610, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 2237, 41 },
   { 2244, 2225, 0 },
   { 2253, 2245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 2237, 41 },
   { 2246, 2245, 0 },
   { 2254, 2225, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 2237, 41 },
   { 2241, 2229, 0 },
   { 2251, 2231, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 2237, 41 },
   { 2243, 2231, 0 },
   { 2252, 2229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2231, 2239, 41 },
   { 2249, 2225, 0 },
   { 2257, 2245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2231, 2239, 41 },
   { 2250, 2245, 0 },
   { 2258, 2225, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2231, 2239, 41 },
   { 2247, 2229, 0 },
   { 2255, 2231, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2231, 2239, 41 },
   { 2248, 2231, 0 },
   { 2256, 2229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2698, 36, 0 },
   { 3523, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2698, 36, 0 },
   { 3520, 3521, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2698, 36, 0 },
   { 3520, 3521, 98 },
   { 3523, 3524, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2698, 36, 0 },
   { 3526, 3527, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2698, 36, 0 },
   { 3529, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2698, 36, 0 },
   { 3526, 3527, 98 },
   { 3529, 3530, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2430, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2483, 2484, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2475, 2476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2478, 2479, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2481, 2482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2466, 2468, 0 },
   { 2448, 2499, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 2470, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2498, 2480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2497, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2500, 2448, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2471, 2474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2428, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 2434, 45 },
   { 2456, 32, 0 },
   { 2457, 200, 0 },
   { 2458, 2455, 0 },
   { 2463, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2820, 2821, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2823, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2832, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2834, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2825, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 176, 3, 0 },
   { 3113, 3114, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 176, 3, 0 },
   { 3113, 3114, 0 },
   { 3140, 3114, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 174, 3, 0 },
   { 176, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 174, 3, 0 },
   { 176, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 269, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 269, 270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 269, 270, 0 },
   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 272, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 272, 273, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 272, 273, 0 },
   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 281, 282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 281, 282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 0 },
   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 0 },
   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 0 },
   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 281, 282, 0 },
   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 284, 285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 284, 285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 285, 0 },
   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 285, 0 },
   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 285, 0 },
   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 285, 0 },
   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 275, 276, 0 },
   { 279, 276, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 275, 276, 0 },
   { 279, 276, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 275, 276, 0 },
   { 279, 276, 0 },
   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4517, 3569, 0 },
   { 4571, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4517, 3569, 0 },
   { 4542, 3569, 0 },
   { 4571, 3589, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4517, 3569, 0 },
   { 4540, 3569, 0 },
   { 4571, 3589, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4516, 3569, 0 },
   { 4517, 3569, 0 },
   { 4570, 3589, 0 },
   { 4571, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4514, 3569, 0 },
   { 4517, 3569, 0 },
   { 4568, 3589, 0 },
   { 4571, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4543, 3569, 0 },
   { 4596, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4542, 3569, 0 },
   { 4543, 3569, 0 },
   { 4595, 3589, 0 },
   { 4596, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4540, 3569, 0 },
   { 4543, 3569, 0 },
   { 4593, 3589, 0 },
   { 4596, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4516, 3569, 0 },
   { 4543, 3569, 0 },
   { 4570, 3589, 0 },
   { 4596, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4514, 3569, 0 },
   { 4543, 3569, 0 },
   { 4568, 3589, 0 },
   { 4596, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { 4648, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4623, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4623, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { 4623, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4542, 3569, 0 },
   { 4595, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4540, 3569, 0 },
   { 4593, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4516, 3569, 0 },
   { 4570, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 176, 3, 0 },
   { 4514, 3569, 0 },
   { 4568, 3589, 0 },
   { 4620, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4540, 3569, 0 },
   { 4542, 3569, 0 },
   { 4593, 3589, 0 },
   { 4595, 3589, 0 },
   { 4645, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4516, 3569, 0 },
   { 4542, 3569, 0 },
   { 4570, 3589, 0 },
   { 4595, 3589, 0 },
   { 4622, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4514, 3569, 0 },
   { 4542, 3569, 0 },
   { 4568, 3589, 0 },
   { 4595, 3589, 0 },
   { 4620, 3589, 0 },
   { 4647, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4516, 3569, 0 },
   { 4540, 3569, 0 },
   { 4570, 3589, 0 },
   { 4593, 3589, 0 },
   { 4622, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4514, 3569, 0 },
   { 4540, 3569, 0 },
   { 4568, 3589, 0 },
   { 4593, 3589, 0 },
   { 4620, 3589, 0 },
   { 4645, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4514, 3569, 0 },
   { 4516, 3569, 0 },
   { 4568, 3589, 0 },
   { 4570, 3589, 0 },
   { 4620, 3589, 0 },
   { 4622, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2947, 2948, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4545, 4519, 0 },
   { 4598, 49, 0 },
   { 4650, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4544, 4519, 0 },
   { 4597, 49, 0 },
   { 4649, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4520, 4519, 0 },
   { 4573, 49, 0 },
   { 4625, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4518, 4519, 0 },
   { 4572, 49, 0 },
   { 4624, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 923, 927, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 915, 918, 0 },
   { 923, 927, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 4545, 4519, 0 },
   { 4598, 49, 0 },
   { 4650, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 4544, 4519, 0 },
   { 4597, 49, 0 },
   { 4649, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 4520, 4519, 0 },
   { 4573, 49, 0 },
   { 4625, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 189, 61, 0 },
   { 195, 32, 0 },
   { 198, 100, 0 },
   { 4518, 4519, 0 },
   { 4572, 49, 0 },
   { 4624, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3082, 3083, 0 },
   { 4545, 4519, 0 },
   { 4598, 49, 0 },
   { 4650, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3082, 3083, 0 },
   { 4544, 4519, 0 },
   { 4597, 49, 0 },
   { 4649, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3082, 3083, 0 },
   { 4520, 4519, 0 },
   { 4573, 49, 0 },
   { 4625, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3082, 3083, 0 },
   { 4518, 4519, 0 },
   { 4572, 49, 0 },
   { 4624, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4521, 4519, 0 },
   { 4545, 4519, 0 },
   { 4574, 49, 0 },
   { 4598, 49, 0 },
   { 4650, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4521, 4519, 0 },
   { 4544, 4519, 0 },
   { 4574, 49, 0 },
   { 4597, 49, 0 },
   { 4649, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4520, 4519, 0 },
   { 4521, 4519, 0 },
   { 4573, 49, 0 },
   { 4574, 49, 0 },
   { 4625, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4518, 4519, 0 },
   { 4521, 4519, 0 },
   { 4572, 49, 0 },
   { 4574, 49, 0 },
   { 4624, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4545, 4519, 0 },
   { 4546, 4519, 0 },
   { 4598, 49, 0 },
   { 4599, 49, 0 },
   { 4650, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4544, 4519, 0 },
   { 4546, 4519, 0 },
   { 4597, 49, 0 },
   { 4599, 49, 0 },
   { 4649, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4520, 4519, 0 },
   { 4546, 4519, 0 },
   { 4573, 49, 0 },
   { 4599, 49, 0 },
   { 4625, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4518, 4519, 0 },
   { 4546, 4519, 0 },
   { 4572, 49, 0 },
   { 4599, 49, 0 },
   { 4624, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4545, 4519, 0 },
   { 4598, 49, 0 },
   { 4650, 49, 0 },
   { 4651, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4544, 4519, 0 },
   { 4597, 49, 0 },
   { 4649, 49, 0 },
   { 4651, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4520, 4519, 0 },
   { 4573, 49, 0 },
   { 4625, 49, 0 },
   { 4651, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4518, 4519, 0 },
   { 4572, 49, 0 },
   { 4624, 49, 0 },
   { 4651, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4545, 4519, 0 },
   { 4598, 49, 0 },
   { 4626, 49, 0 },
   { 4650, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4544, 4519, 0 },
   { 4597, 49, 0 },
   { 4626, 49, 0 },
   { 4649, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4520, 4519, 0 },
   { 4573, 49, 0 },
   { 4625, 49, 0 },
   { 4626, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4518, 4519, 0 },
   { 4572, 49, 0 },
   { 4624, 49, 0 },
   { 4626, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4544, 4519, 0 },
   { 4545, 4519, 0 },
   { 4597, 49, 0 },
   { 4598, 49, 0 },
   { 4649, 49, 0 },
   { 4650, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4520, 4519, 0 },
   { 4545, 4519, 0 },
   { 4573, 49, 0 },
   { 4598, 49, 0 },
   { 4625, 49, 0 },
   { 4650, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4518, 4519, 0 },
   { 4545, 4519, 0 },
   { 4572, 49, 0 },
   { 4598, 49, 0 },
   { 4624, 49, 0 },
   { 4650, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4520, 4519, 0 },
   { 4544, 4519, 0 },
   { 4573, 49, 0 },
   { 4597, 49, 0 },
   { 4625, 49, 0 },
   { 4649, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4518, 4519, 0 },
   { 4544, 4519, 0 },
   { 4572, 49, 0 },
   { 4597, 49, 0 },
   { 4624, 49, 0 },
   { 4649, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4518, 4519, 0 },
   { 4520, 4519, 0 },
   { 4572, 49, 0 },
   { 4573, 49, 0 },
   { 4624, 49, 0 },
   { 4625, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2396, 1113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 804, 807, 0 },
   { 812, 815, 0 },
   { 820, 822, 0 },
   { 827, 830, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 808, 807, 0 },
   { 816, 815, 0 },
   { 823, 822, 0 },
   { 831, 830, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 929, 932, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 706, 710, 0 },
   { 911, 913, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 911, 913, 0 },
   { 929, 932, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2397, 32, 0 },
   { 2941, 2943, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2400, 1113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 809, 811, 0 },
   { 817, 819, 0 },
   { 824, 826, 0 },
   { 832, 834, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { 2944, 2940, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1041, 1040, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1045, 1044, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 996, 997, 0 },
   { 1098, 1101, 0 },
   { 2349, 1143, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1039, 1040, 0 },
   { 1075, 1076, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1043, 1044, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1042, 1040, 0 },
   { 2349, 1143, 0 },
   { 2373, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 982, 983, 0 },
   { 1049, 1047, 0 },
   { 2349, 1143, 0 },
   { 2373, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1026, 1023, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1033, 1031, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 995, 0 },
   { 1104, 1105, 0 },
   { 2348, 1139, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1022, 1023, 0 },
   { 1077, 1078, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1030, 1031, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1028, 1023, 0 },
   { 2348, 1139, 0 },
   { 2374, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 984, 985, 0 },
   { 1038, 1036, 0 },
   { 2348, 1139, 0 },
   { 2374, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4551, 1937, 0 },
   { 4604, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4550, 1937, 0 },
   { 4603, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4526, 1937, 0 },
   { 4579, 1941, 0 },
   { 4631, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4578, 1941, 0 },
   { 4630, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { 4551, 1937, 0 },
   { 4604, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { 4550, 1937, 0 },
   { 4603, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { 4526, 1937, 0 },
   { 4579, 1941, 0 },
   { 4631, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2379, 32, 0 },
   { 2380, 1121, 0 },
   { 4525, 1937, 0 },
   { 4578, 1941, 0 },
   { 4630, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2409, 2406, 43 },
   { 2416, 2413, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { 4551, 1937, 0 },
   { 4604, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { 4550, 1937, 0 },
   { 4603, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { 4526, 1937, 0 },
   { 4579, 1941, 0 },
   { 4631, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { 4525, 1937, 0 },
   { 4578, 1941, 0 },
   { 4630, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { 4551, 1937, 0 },
   { 4604, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { 4550, 1937, 0 },
   { 4603, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { 4526, 1937, 0 },
   { 4579, 1941, 0 },
   { 4631, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { 4525, 1937, 0 },
   { 4578, 1941, 0 },
   { 4630, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2421, 2419, 43 },
   { 2426, 2424, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 4551, 1937, 0 },
   { 4604, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 4550, 1937, 0 },
   { 4603, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 4526, 1937, 0 },
   { 4579, 1941, 0 },
   { 4631, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2102, 63, 0 },
   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4578, 1941, 0 },
   { 4630, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1584, 1587, 0 },
   { 1591, 1587, 0 },
   { 1596, 1599, 0 },
   { 1603, 1599, 0 },
   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4551, 1937, 0 },
   { 4604, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4550, 1937, 0 },
   { 4603, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4526, 1937, 0 },
   { 4579, 1941, 0 },
   { 4631, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4578, 1941, 0 },
   { 4630, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { 4551, 1937, 0 },
   { 4604, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { 4550, 1937, 0 },
   { 4603, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { 4526, 1937, 0 },
   { 4579, 1941, 0 },
   { 4631, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 1121, 0 },
   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4578, 1941, 0 },
   { 4630, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4527, 1937, 0 },
   { 4551, 1937, 0 },
   { 4580, 1941, 0 },
   { 4604, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4527, 1937, 0 },
   { 4550, 1937, 0 },
   { 4580, 1941, 0 },
   { 4603, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4526, 1937, 0 },
   { 4527, 1937, 0 },
   { 4579, 1941, 0 },
   { 4580, 1941, 0 },
   { 4631, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4527, 1937, 0 },
   { 4578, 1941, 0 },
   { 4580, 1941, 0 },
   { 4630, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4551, 1937, 0 },
   { 4552, 1937, 0 },
   { 4604, 1941, 0 },
   { 4605, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4550, 1937, 0 },
   { 4552, 1937, 0 },
   { 4603, 1941, 0 },
   { 4605, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4526, 1937, 0 },
   { 4552, 1937, 0 },
   { 4579, 1941, 0 },
   { 4605, 1941, 0 },
   { 4631, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4552, 1937, 0 },
   { 4578, 1941, 0 },
   { 4605, 1941, 0 },
   { 4630, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4551, 1937, 0 },
   { 4604, 1941, 0 },
   { 4656, 1941, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4550, 1937, 0 },
   { 4603, 1941, 0 },
   { 4655, 1941, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4526, 1937, 0 },
   { 4579, 1941, 0 },
   { 4631, 1941, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4578, 1941, 0 },
   { 4630, 1941, 0 },
   { 4657, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4551, 1937, 0 },
   { 4604, 1941, 0 },
   { 4632, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4550, 1937, 0 },
   { 4603, 1941, 0 },
   { 4632, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4526, 1937, 0 },
   { 4579, 1941, 0 },
   { 4631, 1941, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4578, 1941, 0 },
   { 4630, 1941, 0 },
   { 4632, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2409, 2406, 43 },
   { 2416, 2413, 43 },
   { 2421, 2419, 43 },
   { 2426, 2424, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4526, 1937, 0 },
   { 4579, 1941, 0 },
   { 4631, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4578, 1941, 0 },
   { 4630, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2709, 2710, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4550, 1937, 0 },
   { 4551, 1937, 0 },
   { 4603, 1941, 0 },
   { 4604, 1941, 0 },
   { 4655, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4526, 1937, 0 },
   { 4551, 1937, 0 },
   { 4579, 1941, 0 },
   { 4604, 1941, 0 },
   { 4631, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4551, 1937, 0 },
   { 4578, 1941, 0 },
   { 4604, 1941, 0 },
   { 4630, 1941, 0 },
   { 4656, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4526, 1937, 0 },
   { 4550, 1937, 0 },
   { 4579, 1941, 0 },
   { 4603, 1941, 0 },
   { 4631, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4550, 1937, 0 },
   { 4578, 1941, 0 },
   { 4603, 1941, 0 },
   { 4630, 1941, 0 },
   { 4655, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4526, 1937, 0 },
   { 4578, 1941, 0 },
   { 4579, 1941, 0 },
   { 4630, 1941, 0 },
   { 4631, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4525, 1937, 0 },
   { 4578, 1941, 0 },
   { 4630, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2949, 2948, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3625, 3626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3631, 3632, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3637, 3638, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3620, 3623, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3628, 3629, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3634, 3635, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4548, 1895, 0 },
   { 4601, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4547, 1895, 0 },
   { 4600, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4523, 1895, 0 },
   { 4576, 1903, 0 },
   { 4628, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4522, 1895, 0 },
   { 4575, 1903, 0 },
   { 4627, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2387, 3, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2387, 3, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2720, 1401, 0 },
   { 2721, 2718, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { 4548, 1895, 0 },
   { 4601, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { 4547, 1895, 0 },
   { 4600, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { 4523, 1895, 0 },
   { 4576, 1903, 0 },
   { 4628, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1884, 1887, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { 4522, 1895, 0 },
   { 4575, 1903, 0 },
   { 4627, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 2388, 2389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 2388, 2389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2388, 2389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2388, 2389, 0 },
   { 4548, 1895, 0 },
   { 4601, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2388, 2389, 0 },
   { 4547, 1895, 0 },
   { 4600, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2388, 2389, 0 },
   { 4523, 1895, 0 },
   { 4576, 1903, 0 },
   { 4628, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2388, 2389, 0 },
   { 4522, 1895, 0 },
   { 4575, 1903, 0 },
   { 4627, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 162, 164, 0 },
   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4548, 1895, 0 },
   { 4601, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4547, 1895, 0 },
   { 4600, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4523, 1895, 0 },
   { 4576, 1903, 0 },
   { 4628, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4522, 1895, 0 },
   { 4575, 1903, 0 },
   { 4627, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 2392, 2393, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1986, 1988, 37 },
   { 1986, 1994, 39 },
   { 2012, 2014, 37 },
   { 2012, 2020, 39 },
   { 2038, 2040, 37 },
   { 2038, 2046, 39 },
   { 2063, 2065, 37 },
   { 2063, 2071, 39 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 973, 968, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4524, 1895, 0 },
   { 4577, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 4524, 1895, 0 },
   { 4577, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4524, 1895, 0 },
   { 4577, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4524, 1895, 0 },
   { 4548, 1895, 0 },
   { 4577, 1903, 0 },
   { 4601, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4524, 1895, 0 },
   { 4547, 1895, 0 },
   { 4577, 1903, 0 },
   { 4600, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4523, 1895, 0 },
   { 4524, 1895, 0 },
   { 4576, 1903, 0 },
   { 4577, 1903, 0 },
   { 4628, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4522, 1895, 0 },
   { 4524, 1895, 0 },
   { 4575, 1903, 0 },
   { 4577, 1903, 0 },
   { 4627, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4549, 1895, 0 },
   { 4602, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 4549, 1895, 0 },
   { 4602, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4549, 1895, 0 },
   { 4602, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4548, 1895, 0 },
   { 4549, 1895, 0 },
   { 4601, 1903, 0 },
   { 4602, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4547, 1895, 0 },
   { 4549, 1895, 0 },
   { 4600, 1903, 0 },
   { 4602, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4523, 1895, 0 },
   { 4549, 1895, 0 },
   { 4576, 1903, 0 },
   { 4602, 1903, 0 },
   { 4628, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4522, 1895, 0 },
   { 4549, 1895, 0 },
   { 4575, 1903, 0 },
   { 4602, 1903, 0 },
   { 4627, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4548, 1895, 0 },
   { 4601, 1903, 0 },
   { 4653, 1903, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4547, 1895, 0 },
   { 4600, 1903, 0 },
   { 4652, 1903, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4523, 1895, 0 },
   { 4576, 1903, 0 },
   { 4628, 1903, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4522, 1895, 0 },
   { 4575, 1903, 0 },
   { 4627, 1903, 0 },
   { 4654, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4548, 1895, 0 },
   { 4601, 1903, 0 },
   { 4629, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4547, 1895, 0 },
   { 4600, 1903, 0 },
   { 4629, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4523, 1895, 0 },
   { 4576, 1903, 0 },
   { 4628, 1903, 0 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4522, 1895, 0 },
   { 4575, 1903, 0 },
   { 4627, 1903, 0 },
   { 4629, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4548, 1895, 0 },
   { 4601, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4547, 1895, 0 },
   { 4600, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4523, 1895, 0 },
   { 4576, 1903, 0 },
   { 4628, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2387, 3, 0 },
   { 4522, 1895, 0 },
   { 4575, 1903, 0 },
   { 4627, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 2707, 2708, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 4548, 1895, 0 },
   { 4601, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 4547, 1895, 0 },
   { 4600, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 4523, 1895, 0 },
   { 4576, 1903, 0 },
   { 4628, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1313, 1314, 0 },
   { 1335, 1336, 0 },
   { 1355, 1356, 0 },
   { 2375, 32, 0 },
   { 4522, 1895, 0 },
   { 4575, 1903, 0 },
   { 4627, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4548, 1895, 0 },
   { 4601, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4547, 1895, 0 },
   { 4600, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4523, 1895, 0 },
   { 4576, 1903, 0 },
   { 4628, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4522, 1895, 0 },
   { 4575, 1903, 0 },
   { 4627, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1986, 1988, 37 },
   { 1986, 1994, 39 },
   { 2012, 2014, 37 },
   { 2012, 2020, 39 },
   { 2038, 2040, 37 },
   { 2038, 2046, 39 },
   { 2063, 2065, 37 },
   { 2063, 2071, 39 },
   { 2375, 32, 0 },
   { 2840, 2842, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4547, 1895, 0 },
   { 4548, 1895, 0 },
   { 4600, 1903, 0 },
   { 4601, 1903, 0 },
   { 4652, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4523, 1895, 0 },
   { 4548, 1895, 0 },
   { 4576, 1903, 0 },
   { 4601, 1903, 0 },
   { 4628, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4522, 1895, 0 },
   { 4548, 1895, 0 },
   { 4575, 1903, 0 },
   { 4601, 1903, 0 },
   { 4627, 1903, 0 },
   { 4653, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4523, 1895, 0 },
   { 4547, 1895, 0 },
   { 4576, 1903, 0 },
   { 4600, 1903, 0 },
   { 4628, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4522, 1895, 0 },
   { 4547, 1895, 0 },
   { 4575, 1903, 0 },
   { 4600, 1903, 0 },
   { 4627, 1903, 0 },
   { 4652, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4522, 1895, 0 },
   { 4523, 1895, 0 },
   { 4575, 1903, 0 },
   { 4576, 1903, 0 },
   { 4627, 1903, 0 },
   { 4628, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 32, 0 },
   { 4522, 1895, 0 },
   { 4575, 1903, 0 },
   { 4627, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2224, 2223, 0 },
   { 2769, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2830, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1053, 1023, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 986, 987, 0 },
   { 1141, 1139, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 986, 987, 0 },
   { 1085, 1088, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 986, 987, 0 },
   { 2363, 650, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1072, 0 },
   { 1163, 940, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1072, 0 },
   { 1080, 1083, 0 },
   { 1163, 940, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1055, 1040, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 990, 991, 0 },
   { 1144, 1143, 0 },
   { 1144, 1143, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 990, 991, 0 },
   { 1091, 1092, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 990, 991, 0 },
   { 1018, 1016, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1378, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1449, 1451, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1247, 1249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1378, 1140, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1449, 1451, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1247, 1249, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1247, 1249, 0 },
   { 1375, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1378, 1140, 0 },
   { 1380, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1380, 32, 0 },
   { 1449, 1451, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1247, 1249, 0 },
   { 1380, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1375, 1140, 0 },
   { 1378, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1375, 1140, 0 },
   { 1449, 1451, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1378, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1449, 1451, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1247, 1249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1378, 1140, 0 },
   { 1449, 1451, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1247, 1249, 0 },
   { 1375, 1140, 0 },
   { 1378, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1155, 1156, 0 },
   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1247, 1249, 0 },
   { 1375, 1140, 0 },
   { 1449, 1451, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1382, 32, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1386, 103, 0 },
   { 1443, 1446, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { 1232, 1234, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1382, 32, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1386, 103, 0 },
   { 1443, 1446, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1455, 1456, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1392, 182, 33 },
   { 1397, 1395, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { 1232, 1234, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { 1232, 1234, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1382, 32, 0 },
   { 1384, 103, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1384, 103, 0 },
   { 1386, 103, 0 },
   { 1443, 1446, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1384, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { 1232, 1234, 0 },
   { 1384, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { 1382, 32, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { 1386, 103, 0 },
   { 1443, 1446, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1382, 32, 0 },
   { 1386, 103, 0 },
   { 1443, 1446, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1382, 32, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { 1232, 1234, 0 },
   { 1382, 32, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1151, 1153, 0 },
   { 1205, 32, 0 },
   { 1386, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1386, 103, 0 },
   { 1443, 1446, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { 1232, 1234, 0 },
   { 1386, 103, 0 },
   { 1443, 1446, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1215, 1167, 0 },
   { 1232, 1234, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 1390, 35 },
   { 1406, 1408, 33 },
   { 2771, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 1390, 35 },
   { 1411, 1413, 33 },
   { 2771, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 1390, 35 },
   { 1415, 1419, 33 },
   { 2771, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 1390, 35 },
   { 2771, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 1390, 35 },
   { 2356, 1149, 0 },
   { 2771, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { 622, 618, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 3, 0 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 170, 113, 0 },
   { 3125, 3128, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 170, 113, 0 },
   { 3134, 3138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 170, 113, 0 },
   { 700, 702, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 170, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 170, 113, 0 },
   { 622, 618, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 181, 3, 0 },
   { 3102, 3104, 0 },
   { 3106, 3104, 0 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 181, 3, 0 },
   { 3102, 3104, 0 },
   { 3106, 3104, 0 },
   { 3123, 3104, 0 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { 179, 3, 0 },
   { 181, 3, 0 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { 179, 3, 0 },
   { 622, 618, 21 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 184, 185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { 179, 3, 0 },
   { 181, 3, 0 },
   { 622, 618, 21 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { 204, 202, 0 },
   { 3087, 3089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { 204, 202, 0 },
   { 3087, 3089, 0 },
   { 3116, 3089, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 202, 0 },
   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 201, 202, 0 },
   { 204, 202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 202, 0 },
   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 2434, 45 },
   { 2456, 32, 0 },
   { 2457, 200, 0 },
   { 2458, 2455, 0 },
   { 2465, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 439, 440, 0 },
   { 511, 512, 0 },
   { 584, 585, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 439, 440, 0 },
   { 511, 512, 0 },
   { 584, 585, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 439, 440, 0 },
   { 511, 512, 0 },
   { 584, 585, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 444, 445, 0 },
   { 515, 516, 0 },
   { 588, 589, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 210, 211, 0 },
   { 212, 213, 5 },
   { 214, 215, 6 },
   { 444, 445, 0 },
   { 515, 516, 0 },
   { 588, 589, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 444, 445, 0 },
   { 515, 516, 0 },
   { 588, 589, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 444, 445, 0 },
   { 515, 516, 0 },
   { 588, 589, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { 439, 440, 0 },
   { 444, 445, 0 },
   { 511, 512, 0 },
   { 515, 516, 0 },
   { 584, 585, 0 },
   { 588, 589, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 450, 452, 0 },
   { 521, 523, 0 },
   { 594, 596, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 2431, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 2431, 46 },
   { 2447, 2448, 0 },
   { 2451, 200, 0 },
   { 2454, 2455, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1376, 1377, 0 },
   { 1379, 1377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { 1257, 1259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1376, 1377, 0 },
   { 1379, 1377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { 1257, 1259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { 1257, 1259, 0 },
   { 1376, 1377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1376, 1377, 0 },
   { 1379, 1377, 0 },
   { 1381, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { 1257, 1259, 0 },
   { 1381, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { 1376, 1377, 0 },
   { 1379, 1377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1376, 1377, 0 },
   { 1379, 1377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { 1257, 1259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { 1257, 1259, 0 },
   { 1376, 1377, 0 },
   { 1379, 1377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1376, 1377, 0 },
   { 2723, 2710, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1383, 32, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { 1242, 1244, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1383, 32, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 3480, 3476, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { 1242, 1244, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { 1242, 1244, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1383, 32, 0 },
   { 1385, 106, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1385, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { 1242, 1244, 0 },
   { 1385, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { 1383, 32, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1383, 32, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { 1242, 1244, 0 },
   { 1383, 32, 0 },
   { 1387, 106, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1387, 106, 34 },
   { 2722, 2708, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 32, 0 },
   { 1220, 1221, 0 },
   { 1242, 1244, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 968, 0 },
   { 2716, 650, 0 },
   { 2811, 968, 0 },
   { 2812, 1121, 0 },
   { 2813, 1121, 0 },
   { 1362, 3291, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2368, 968, 0 },
   { 2717, 650, 0 },
   { 2815, 1121, 0 },
   { 3298, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 1121, 0 },
   { 2715, 1016, 0 },
   { 2808, 1121, 0 },
   { 2809, 968, 0 },
   { 2810, 968, 0 },
   { 1359, 3292, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 1121, 0 },
   { 2659, 650, 0 },
   { 2662, 1016, 0 },
   { 2711, 1016, 0 },
   { 2712, 650, 0 },
   { 2807, 968, 0 },
   { 3296, 3297, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2367, 968, 0 },
   { 2660, 1016, 0 },
   { 2661, 650, 0 },
   { 2713, 650, 0 },
   { 2714, 1016, 0 },
   { 2806, 1121, 0 },
   { 3293, 3295, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2106, 1264, 0 },
   { 2367, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1225, 1226, 0 },
   { 1252, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1209, 61, 0 },
   { 1210, 32, 0 },
   { 1225, 1226, 0 },
   { 1252, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1225, 1226, 0 },
   { 1252, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 2725, 2708, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 32, 0 },
   { 1217, 1218, 0 },
   { 1237, 1239, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 32, 0 },
   { 1212, 32, 0 },
   { 1213, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 32, 0 },
   { 1212, 32, 0 },
   { 1213, 63, 0 },
   { 1217, 1218, 0 },
   { 1237, 1239, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 32, 0 },
   { 1217, 1218, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 32, 0 },
   { 2724, 2710, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 32, 0 },
   { 1217, 1218, 0 },
   { 1237, 1239, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2665, 1002, 0 },
   { 2666, 609, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3542, 3524, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3542, 3524, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1164, 1165, 0 },
   { 1166, 1167, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3541, 3521, 98 },
   { 3542, 3524, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3546, 3530, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3546, 3530, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3546, 3530, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3546, 3530, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3546, 3530, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1169, 0 },
   { 1171, 1172, 0 },
   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3544, 3527, 98 },
   { 3546, 3530, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2221, 2222, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3534, 3535, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3534, 3535, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3534, 3535, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3534, 3535, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3534, 3535, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2221, 2222, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3532, 3533, 98 },
   { 3534, 3535, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3539, 3540, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3539, 3540, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3539, 3540, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3539, 3540, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3539, 3540, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4536, 4508, 0 },
   { 4589, 4561, 0 },
   { 4641, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4534, 4508, 0 },
   { 4587, 4561, 0 },
   { 4639, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4511, 4508, 0 },
   { 4564, 4561, 0 },
   { 4616, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1180, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3184, 3186, 0 },
   { 3536, 3537, 98 },
   { 3539, 3540, 98 },
   { 4507, 4508, 0 },
   { 4560, 4561, 0 },
   { 4613, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3161, 3159, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3164, 3162, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1023, 0 },
   { 1202, 1031, 0 },
   { 1203, 1031, 0 },
   { 2697, 3, 0 },
   { 3167, 3165, 0 },
   { 3536, 3537, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3342, 3340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3345, 3340, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1460, 1459, 0 },
   { 3394, 3397, 78 },
   { 4504, 11, 0 },
   { 4557, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4554, 1961, 0 },
   { 4607, 1965, 0 },
   { 4659, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4553, 1961, 0 },
   { 4606, 1965, 0 },
   { 4658, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4529, 1961, 0 },
   { 4582, 1965, 0 },
   { 4634, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4528, 1961, 0 },
   { 4581, 1965, 0 },
   { 4633, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 2382, 32, 0 },
   { 4554, 1961, 0 },
   { 4607, 1965, 0 },
   { 4659, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 2382, 32, 0 },
   { 4553, 1961, 0 },
   { 4606, 1965, 0 },
   { 4658, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 2382, 32, 0 },
   { 4529, 1961, 0 },
   { 4582, 1965, 0 },
   { 4634, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 2382, 32, 0 },
   { 4528, 1961, 0 },
   { 4581, 1965, 0 },
   { 4633, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4530, 1961, 0 },
   { 4554, 1961, 0 },
   { 4583, 1965, 0 },
   { 4607, 1965, 0 },
   { 4659, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4530, 1961, 0 },
   { 4553, 1961, 0 },
   { 4583, 1965, 0 },
   { 4606, 1965, 0 },
   { 4658, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4529, 1961, 0 },
   { 4530, 1961, 0 },
   { 4582, 1965, 0 },
   { 4583, 1965, 0 },
   { 4634, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4528, 1961, 0 },
   { 4530, 1961, 0 },
   { 4581, 1965, 0 },
   { 4583, 1965, 0 },
   { 4633, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4554, 1961, 0 },
   { 4555, 1961, 0 },
   { 4607, 1965, 0 },
   { 4608, 1965, 0 },
   { 4659, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4553, 1961, 0 },
   { 4555, 1961, 0 },
   { 4606, 1965, 0 },
   { 4608, 1965, 0 },
   { 4658, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4529, 1961, 0 },
   { 4555, 1961, 0 },
   { 4582, 1965, 0 },
   { 4608, 1965, 0 },
   { 4634, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4528, 1961, 0 },
   { 4555, 1961, 0 },
   { 4581, 1965, 0 },
   { 4608, 1965, 0 },
   { 4633, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4554, 1961, 0 },
   { 4607, 1965, 0 },
   { 4659, 1965, 0 },
   { 4660, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4553, 1961, 0 },
   { 4606, 1965, 0 },
   { 4658, 1965, 0 },
   { 4660, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4529, 1961, 0 },
   { 4582, 1965, 0 },
   { 4634, 1965, 0 },
   { 4660, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4528, 1961, 0 },
   { 4581, 1965, 0 },
   { 4633, 1965, 0 },
   { 4660, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4554, 1961, 0 },
   { 4607, 1965, 0 },
   { 4635, 1965, 0 },
   { 4659, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4553, 1961, 0 },
   { 4606, 1965, 0 },
   { 4635, 1965, 0 },
   { 4658, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4529, 1961, 0 },
   { 4582, 1965, 0 },
   { 4634, 1965, 0 },
   { 4635, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4528, 1961, 0 },
   { 4581, 1965, 0 },
   { 4633, 1965, 0 },
   { 4635, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4553, 1961, 0 },
   { 4554, 1961, 0 },
   { 4606, 1965, 0 },
   { 4607, 1965, 0 },
   { 4658, 1965, 0 },
   { 4659, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4529, 1961, 0 },
   { 4554, 1961, 0 },
   { 4582, 1965, 0 },
   { 4607, 1965, 0 },
   { 4634, 1965, 0 },
   { 4659, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4528, 1961, 0 },
   { 4554, 1961, 0 },
   { 4581, 1965, 0 },
   { 4607, 1965, 0 },
   { 4633, 1965, 0 },
   { 4659, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4529, 1961, 0 },
   { 4553, 1961, 0 },
   { 4582, 1965, 0 },
   { 4606, 1965, 0 },
   { 4634, 1965, 0 },
   { 4658, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4528, 1961, 0 },
   { 4553, 1961, 0 },
   { 4581, 1965, 0 },
   { 4606, 1965, 0 },
   { 4633, 1965, 0 },
   { 4658, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4528, 1961, 0 },
   { 4529, 1961, 0 },
   { 4581, 1965, 0 },
   { 4582, 1965, 0 },
   { 4633, 1965, 0 },
   { 4634, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 61, 0 },
   { 4528, 1961, 0 },
   { 4581, 1965, 0 },
   { 4633, 1965, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1674, 11, 0 },
   { 1697, 11, 0 },
   { 1781, 16, 0 },
   { 1890, 1887, 0 },
   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { 3680, 3678, 0 },
   { 3686, 3678, 0 },
   { 3692, 3678, 0 },
   { 3698, 3678, 0 },
   { 3701, 3702, 0 },
   { 3706, 3676, 0 },
   { 3710, 3676, 0 },
   { 3714, 3676, 0 },
   { 3717, 3718, 0 },
   { 3720, 3718, 0 },
   { 3723, 3724, 0 },
   { 3728, 3683, 0 },
   { 3732, 3683, 0 },
   { 3735, 3736, 0 },
   { 3738, 3736, 0 },
   { 3741, 2891, 0 },
   { 3743, 3736, 0 },
   { 3745, 2891, 0 },
   { 3747, 1673, 0 },
   { 3751, 3689, 0 },
   { 3754, 3755, 0 },
   { 3757, 3755, 0 },
   { 3760, 3761, 0 },
   { 3763, 3755, 0 },
   { 3765, 3761, 0 },
   { 3767, 1696, 0 },
   { 3769, 3755, 0 },
   { 3771, 3761, 0 },
   { 3773, 1696, 0 },
   { 3775, 1780, 0 },
   { 4503, 11, 0 },
   { 4556, 16, 0 },
   { 4609, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1674, 11, 0 },
   { 1697, 11, 0 },
   { 1781, 16, 0 },
   { 2869, 2870, 0 },
   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { 3680, 3678, 0 },
   { 3686, 3678, 0 },
   { 3692, 3678, 0 },
   { 3698, 3678, 0 },
   { 3701, 3702, 0 },
   { 3706, 3676, 0 },
   { 3710, 3676, 0 },
   { 3714, 3676, 0 },
   { 3717, 3718, 0 },
   { 3720, 3718, 0 },
   { 3723, 3724, 0 },
   { 3728, 3683, 0 },
   { 3732, 3683, 0 },
   { 3735, 3736, 0 },
   { 3738, 3736, 0 },
   { 3741, 2891, 0 },
   { 3743, 3736, 0 },
   { 3745, 2891, 0 },
   { 3747, 1673, 0 },
   { 3751, 3689, 0 },
   { 3754, 3755, 0 },
   { 3757, 3755, 0 },
   { 3760, 3761, 0 },
   { 3763, 3755, 0 },
   { 3765, 3761, 0 },
   { 3767, 1696, 0 },
   { 3769, 3755, 0 },
   { 3771, 3761, 0 },
   { 3773, 1696, 0 },
   { 3775, 1780, 0 },
   { 4503, 11, 0 },
   { 4556, 16, 0 },
   { 4609, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2866, 2868, 0 },
   { 3656, 650, 0 },
   { 3657, 6, 0 },
   { 3658, 11, 0 },
   { 3659, 16, 0 },
   { 3660, 21, 0 },
   { 3677, 3678, 0 },
   { 3684, 3678, 0 },
   { 3690, 3678, 0 },
   { 3696, 3678, 0 },
   { 3704, 3676, 0 },
   { 3708, 3676, 0 },
   { 3712, 3676, 0 },
   { 3726, 3683, 0 },
   { 3730, 3683, 0 },
   { 3749, 3689, 0 },
   { 4531, 11, 0 },
   { 4584, 16, 0 },
   { 4636, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2002, 6, 0 },
   { 2028, 11, 0 },
   { 2054, 16, 0 },
   { 2079, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2405, 2406, 43 },
   { 2412, 2413, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2418, 2419, 43 },
   { 2423, 2424, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2405, 2406, 43 },
   { 2412, 2413, 43 },
   { 2421, 2419, 43 },
   { 2426, 2424, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2409, 2406, 43 },
   { 2416, 2413, 43 },
   { 2418, 2419, 43 },
   { 2423, 2424, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2405, 2406, 43 },
   { 2412, 2413, 43 },
   { 2418, 2419, 43 },
   { 2423, 2424, 43 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 838, 839, 0 },
   { 885, 884, 0 },
   { 892, 891, 0 },
   { 899, 897, 0 },
   { 907, 905, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 887, 886, 0 },
   { 894, 893, 0 },
   { 901, 900, 0 },
   { 909, 908, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1936, 1938, 0 },
   { 1940, 1942, 0 },
   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1894, 1896, 0 },
   { 1902, 1904, 0 },
   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1960, 1962, 0 },
   { 1964, 1966, 0 },
   { 3661, 650, 0 },
   { 3662, 6, 0 },
   { 3663, 11, 0 },
   { 3664, 16, 0 },
   { 3665, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 883, 884, 0 },
   { 890, 891, 0 },
   { 896, 897, 0 },
   { 904, 905, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 411, 14 },
   { 494, 484, 16 },
   { 567, 557, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 411, 14 },
   { 431, 429, 13 },
   { 494, 484, 16 },
   { 503, 501, 15 },
   { 567, 557, 18 },
   { 576, 574, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 421, 411, 14 },
   { 494, 484, 16 },
   { 567, 557, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 421, 411, 14 },
   { 431, 429, 13 },
   { 494, 484, 16 },
   { 503, 501, 15 },
   { 567, 557, 18 },
   { 576, 574, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 170, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { 421, 411, 14 },
   { 494, 484, 16 },
   { 567, 557, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { 421, 411, 14 },
   { 431, 429, 13 },
   { 494, 484, 16 },
   { 503, 501, 15 },
   { 567, 557, 18 },
   { 576, 574, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 411, 14 },
   { 494, 484, 16 },
   { 567, 557, 18 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 421, 411, 14 },
   { 431, 429, 13 },
   { 494, 484, 16 },
   { 503, 501, 15 },
   { 567, 557, 18 },
   { 576, 574, 17 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 421, 411, 14 },
   { 494, 484, 16 },
   { 567, 557, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 410, 411, 14 },
   { 421, 411, 14 },
   { 483, 484, 16 },
   { 494, 484, 16 },
   { 556, 557, 18 },
   { 567, 557, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 421, 411, 14 },
   { 431, 429, 13 },
   { 494, 484, 16 },
   { 503, 501, 15 },
   { 567, 557, 18 },
   { 576, 574, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 410, 411, 14 },
   { 421, 411, 14 },
   { 431, 429, 13 },
   { 483, 484, 16 },
   { 494, 484, 16 },
   { 503, 501, 15 },
   { 556, 557, 18 },
   { 567, 557, 18 },
   { 576, 574, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 149, 0 },
   { 421, 411, 14 },
   { 494, 484, 16 },
   { 567, 557, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 149, 0 },
   { 421, 411, 14 },
   { 431, 429, 13 },
   { 494, 484, 16 },
   { 503, 501, 15 },
   { 567, 557, 18 },
   { 576, 574, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { 421, 411, 14 },
   { 494, 484, 16 },
   { 567, 557, 18 },
   { 622, 618, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { 421, 411, 14 },
   { 431, 429, 13 },
   { 494, 484, 16 },
   { 503, 501, 15 },
   { 567, 557, 18 },
   { 576, 574, 17 },
   { 622, 618, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 3, 0 },
   { 421, 411, 14 },
   { 494, 484, 16 },
   { 567, 557, 18 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 3, 0 },
   { 421, 411, 14 },
   { 431, 429, 13 },
   { 494, 484, 16 },
   { 503, 501, 15 },
   { 567, 557, 18 },
   { 576, 574, 17 },
   { 3156, 3104, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 421, 411, 14 },
   { 494, 484, 16 },
   { 567, 557, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 410, 411, 14 },
   { 421, 411, 14 },
   { 483, 484, 16 },
   { 494, 484, 16 },
   { 556, 557, 18 },
   { 567, 557, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 113, 0 },
   { 1660, 1661, 36 },
   { 1767, 1768, 36 },
   { 1850, 1851, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1423, 1424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1423, 1424, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1390, 182, 33 },
   { 1394, 1395, 33 },
   { 1423, 1424, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 2772, 182, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1423, 1424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1380, 32, 0 },
   { 1423, 1424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1380, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1423, 1424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1375, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1378, 1140, 0 },
   { 1423, 1424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1378, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1423, 1424, 0 },
   { 1449, 1451, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1449, 1451, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1247, 1249, 0 },
   { 1423, 1424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1223, 1169, 0 },
   { 1247, 1249, 0 },
   { 1375, 1140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 32, 0 },
   { 1375, 1140, 0 },
   { 1423, 1424, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3175, 3176, 0 },
   { 3178, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3077, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 434, 429, 0 },
   { 506, 501, 0 },
   { 579, 574, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 206, 3, 0 },
   { 208, 207, 5 },
   { 209, 36, 6 },
   { 217, 218, 0 },
   { 220, 221, 0 },
   { 434, 429, 0 },
   { 506, 501, 0 },
   { 579, 574, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 434, 429, 0 },
   { 506, 501, 0 },
   { 579, 574, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 152, 154, 0 },
   { 434, 429, 0 },
   { 506, 501, 0 },
   { 579, 574, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 140, 0 },
   { 434, 429, 0 },
   { 444, 445, 0 },
   { 506, 501, 0 },
   { 515, 516, 0 },
   { 579, 574, 0 },
   { 588, 589, 0 },
   { 627, 629, 24 },
   { 630, 632, 25 },
   { 633, 635, 26 },
   { 636, 629, 27 },
   { 637, 632, 28 },
   { 638, 635, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1046, 1047, 0 },
   { 1075, 1076, 0 },
   { 2373, 1121, 0 },
   { 2788, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1036, 0 },
   { 1077, 1078, 0 },
   { 2374, 968, 0 },
   { 2787, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2444, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 986, 987, 0 },
   { 1052, 1023, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 990, 991, 0 },
   { 1054, 1040, 0 },
   { 2372, 1121, 0 },
   { 2791, 1121, 0 },
   { 2794, 968, 0 },
   { 2797, 968, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1428, 1429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1428, 1429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1428, 1429, 0 },
   { 3478, 3476, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1376, 1377, 0 },
   { 1428, 1429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1381, 32, 0 },
   { 1428, 1429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { 1428, 1429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1376, 1377, 0 },
   { 1379, 1377, 0 },
   { 1428, 1429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 32, 0 },
   { 1228, 1229, 0 },
   { 1257, 1259, 0 },
   { 1428, 1429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1433, 1434, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1209, 61, 0 },
   { 1210, 32, 0 },
   { 1433, 1434, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1225, 1226, 0 },
   { 1433, 1434, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 32, 0 },
   { 1225, 1226, 0 },
   { 1252, 1254, 0 },
   { 1433, 1434, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 61, 0 },
   { 1667, 1668, 36 },
   { 1774, 1775, 36 },
   { 1857, 1858, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 2386, 2167, 0 },
   { 2902, 2904, 54 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 169, 0 },
   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2113, 2116, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2121, 2125, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2113, 2116, 0 },
   { 2121, 2125, 0 },
   { 2375, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 113, 0 },
   { 187, 115, 5 },
   { 188, 117, 6 },
   { 193, 32, 0 },
   { 194, 32, 0 },
   { 197, 98, 0 },
   { 649, 657, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1072, 0 },
   { 1080, 1083, 0 },
   { 2370, 968, 0 },
   { 2776, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1072, 0 },
   { 1080, 1083, 0 },
   { 1163, 940, 0 },
   { 2370, 968, 0 },
   { 2780, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1067, 1070, 0 },
   { 2130, 969, 0 },
   { 2370, 968, 0 },
   { 2799, 968, 0 },
   { 2802, 1121, 0 },
   { 2805, 1121, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 2783, 2775, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1205, 32, 0 },
   { 1455, 1456, 33 },
   { 2785, 2779, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 170, 113, 0 },
   { 458, 459, 14 },
   { 529, 530, 16 },
   { 602, 603, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 416, 417, 14 },
   { 489, 490, 16 },
   { 562, 563, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 416, 417, 14 },
   { 421, 411, 14 },
   { 489, 490, 16 },
   { 494, 484, 16 },
   { 562, 563, 18 },
   { 567, 557, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 410, 411, 14 },
   { 416, 417, 14 },
   { 421, 411, 14 },
   { 483, 484, 16 },
   { 489, 490, 16 },
   { 494, 484, 16 },
   { 556, 557, 18 },
   { 562, 563, 18 },
   { 567, 557, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 410, 411, 14 },
   { 421, 411, 14 },
   { 428, 429, 13 },
   { 483, 484, 16 },
   { 494, 484, 16 },
   { 500, 501, 15 },
   { 556, 557, 18 },
   { 567, 557, 18 },
   { 573, 574, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 410, 411, 14 },
   { 421, 411, 14 },
   { 428, 429, 13 },
   { 431, 429, 13 },
   { 483, 484, 16 },
   { 494, 484, 16 },
   { 500, 501, 15 },
   { 503, 501, 15 },
   { 556, 557, 18 },
   { 567, 557, 18 },
   { 573, 574, 17 },
   { 576, 574, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 410, 411, 14 },
   { 416, 417, 14 },
   { 421, 411, 14 },
   { 428, 429, 13 },
   { 483, 484, 16 },
   { 489, 490, 16 },
   { 494, 484, 16 },
   { 500, 501, 15 },
   { 556, 557, 18 },
   { 562, 563, 18 },
   { 567, 557, 18 },
   { 573, 574, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 416, 417, 14 },
   { 489, 490, 16 },
   { 562, 563, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 410, 411, 14 },
   { 421, 411, 14 },
   { 428, 429, 13 },
   { 483, 484, 16 },
   { 494, 484, 16 },
   { 500, 501, 15 },
   { 556, 557, 18 },
   { 567, 557, 18 },
   { 573, 574, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2387, 3, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1023, 0 },
   { 1201, 1023, 0 },
   { 1203, 1031, 0 },
   { 1635, 1642, 0 },
   { 1742, 1749, 0 },
   { 1825, 1832, 0 },
   { 2697, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 838, 839, 0 },
   { 885, 884, 0 },
   { 892, 891, 0 },
   { 899, 897, 0 },
   { 907, 905, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 887, 886, 0 },
   { 894, 893, 0 },
   { 901, 900, 0 },
   { 909, 908, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 883, 884, 0 },
   { 890, 891, 0 },
   { 896, 897, 0 },
   { 904, 905, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 169, 0 },
   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2387, 3, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 838, 839, 0 },
   { 885, 884, 0 },
   { 892, 891, 0 },
   { 899, 897, 0 },
   { 907, 905, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 887, 886, 0 },
   { 894, 893, 0 },
   { 901, 900, 0 },
   { 909, 908, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 883, 884, 0 },
   { 890, 891, 0 },
   { 896, 897, 0 },
   { 904, 905, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 169, 0 },
   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2387, 3, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 838, 839, 0 },
   { 885, 884, 0 },
   { 892, 891, 0 },
   { 899, 897, 0 },
   { 907, 905, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 887, 886, 0 },
   { 894, 893, 0 },
   { 901, 900, 0 },
   { 909, 908, 0 },
   { 2358, 2359, 0 },
   { 2361, 2362, 0 },
   { 2375, 32, 0 },
   { 2376, 32, 0 },
   { 2377, 61, 0 },
   { 2854, 2855, 52 },
   { 2885, 2886, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 883, 884, 0 },
   { 890, 891, 0 },
   { 896, 897, 0 },
   { 904, 905, 0 },
   { 2397, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 32, 0 },
   { 2843, 2844, 52 },
   { 908, 342, 52 },
   { 2846, 2848, 52 },
   { 900, 367, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 169, 0 },
   { 2378, 32, 0 },
   { 2385, 3, 0 },
   { 4904, 4829, 103 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2378, 32, 0 },
   { 4828, 4829, 103 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_pass_op_table[nir_num_search_ops] = {
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         5,
         13,
         5,
         5,
         5,
         5,
         0,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         15,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         2,
         3,
         2,
         2,
         332,
         2,
         2,
         2,
         333,
         334,
         335,
         336,
         2,
         2,
         2244,
         2245,
         2246,
         2247,
         3,
         3,
         337,
         338,
         339,
         340,
         3,
         341,
         342,
         343,
         344,
         345,
         2248,
         2249,
         2250,
         2251,
         2252,
         2253,
         2,
         337,
         2,
         2,
         332,
         2,
         2,
         2,
         333,
         334,
         335,
         336,
         2,
         2,
         2244,
         2245,
         2246,
         2247,
         2,
         338,
         2,
         2,
         332,
         2,
         2,
         2,
         333,
         334,
         335,
         336,
         2,
         2,
         2244,
         2245,
         2246,
         2247,
         332,
         339,
         332,
         332,
         332,
         332,
         332,
         332,
         346,
         347,
         348,
         349,
         332,
         332,
         2254,
         2255,
         2256,
         2257,
         2,
         340,
         2,
         2,
         332,
         2,
         2,
         2,
         333,
         334,
         335,
         336,
         2,
         2,
         2244,
         2245,
         2246,
         2247,
         2,
         3,
         2,
         2,
         332,
         2,
         350,
         2,
         333,
         334,
         335,
         336,
         2,
         2,
         2244,
         2245,
         2246,
         2247,
         2,
         341,
         2,
         2,
         332,
         2,
         2,
         2,
         333,
         334,
         335,
         336,
         2,
         2,
         2244,
         2245,
         2246,
         2247,
         333,
         342,
         333,
         333,
         346,
         333,
         333,
         333,
         333,
         351,
         352,
         353,
         333,
         333,
         2258,
         2259,
         2260,
         2261,
         334,
         343,
         334,
         334,
         347,
         334,
         334,
         334,
         351,
         334,
         354,
         355,
         334,
         334,
         2262,
         2263,
         2264,
         2265,
         335,
         344,
         335,
         335,
         348,
         335,
         335,
         335,
         352,
         354,
         335,
         356,
         335,
         335,
         2266,
         2267,
         2268,
         2269,
         336,
         345,
         336,
         336,
         349,
         336,
         336,
         336,
         353,
         355,
         356,
         336,
         336,
         336,
         2270,
         2271,
         2272,
         2273,
         2,
         2248,
         2,
         2,
         332,
         2,
         2,
         2,
         333,
         334,
         335,
         336,
         2,
         2,
         2244,
         2245,
         2246,
         2247,
         2,
         2249,
         2,
         2,
         332,
         2,
         2,
         2,
         333,
         334,
         335,
         336,
         2,
         2,
         2244,
         2245,
         2246,
         2247,
         2244,
         2250,
         2244,
         2244,
         2254,
         2244,
         2244,
         2244,
         2258,
         2262,
         2266,
         2270,
         2244,
         2244,
         2244,
         2274,
         2275,
         2276,
         2245,
         2251,
         2245,
         2245,
         2255,
         2245,
         2245,
         2245,
         2259,
         2263,
         2267,
         2271,
         2245,
         2245,
         2274,
         2245,
         2277,
         2278,
         2246,
         2252,
         2246,
         2246,
         2256,
         2246,
         2246,
         2246,
         2260,
         2264,
         2268,
         2272,
         2246,
         2246,
         2275,
         2277,
         2246,
         2279,
         2247,
         2253,
         2247,
         2247,
         2257,
         2247,
         2247,
         2247,
         2261,
         2265,
         2269,
         2273,
         2247,
         2247,
         2276,
         2278,
         2279,
         2247,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         4,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         4,
         14,
         4,
         4,
         4,
         4,
         0,
         11,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         8,
         8,
         8,
         0,
         0,
         0,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         19,
         0,
         5,
         5,
         3,
         6,
         20,
         15,
         3,
         6,
         21,
         5,
         5,
         3,
         6,
         22,
         15,
         3,
         6,
         23,
         5,
         5,
         3,
         6,
         0,
         15,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         4,
         5,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         6,
         7,
         6,
         6,
         6,
         1311,
         6,
         6,
         6,
         1312,
         6,
         6,
         6,
         2281,
         6,
         6,
         6,
         1311,
         6,
         1311,
         6,
         1311,
         6,
         1311,
         4,
         1313,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1314,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1315,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1316,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         1317,
         1318,
         1317,
         1317,
         1317,
         1319,
         1317,
         1317,
         1317,
         1320,
         1317,
         1317,
         1317,
         2282,
         1317,
         1317,
         1317,
         1319,
         1317,
         1319,
         1317,
         1319,
         1317,
         1319,
         1321,
         1322,
         1321,
         1321,
         1321,
         1323,
         1321,
         1321,
         1321,
         1324,
         1321,
         1321,
         1321,
         2283,
         1321,
         1321,
         1321,
         1323,
         1321,
         1323,
         1321,
         1323,
         1321,
         1323,
         4,
         1325,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         5,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1326,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         2284,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         2285,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1315,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         2286,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         2287,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         2288,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         2901,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         3014,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         3020,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         3024,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         3029,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         3033,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         3038,
         4,
         4,
         4,
         1309,
         4,
         4,
         4,
         1310,
         4,
         4,
         4,
         2280,
         4,
         4,
         4,
         1309,
         4,
         1309,
         4,
         1309,
         4,
         1309,
      },
   },
   [nir_op_unpack_64_2x32_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         8,
         1536,
         1537,
         1538,
         1539,
      },
   },
   [nir_op_imul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_umul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_udiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         11,
         0,
         11,
      },
   },
   [nir_op_idiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         12,
         0,
         0,
         12,
         0,
         357,
         358,
         357,
      },
   },
   [nir_op_umod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         13,
         0,
         13,
      },
   },
   [nir_op_imod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         14,
         0,
         14,
      },
   },
   [nir_op_irem] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         15,
         0,
         15,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         5,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         12,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         8,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         7,
         7,
         7,
         7,
         7,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         5,
         5,
         5,
         5,
         5,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         11,
         11,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         16,
         1540,
         1541,
         1542,
         1543,
         1544,
         1545,
         1546,
         1547,
         1548,
         1549,
         1550,
         2576,
         2577,
         2578,
         2976,
      },
   },
   [nir_op_ineg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         6,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         17,
         1769,
         1770,
         1771,
         1772,
         1773,
         2886,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         18,
         1551,
         1552,
         1553,
         1554,
         1555,
         1556,
         1557,
         1558,
      },
   },
   [nir_search_op_u2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         19,
         2009,
         2010,
         2011,
      },
   },
   [nir_op_iabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         20,
         1774,
         1775,
         1776,
         2460,
      },
   },
   [nir_search_op_f2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         21,
         1559,
         1560,
      },
   },
   [nir_search_op_i2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         22,
         1777,
         1778,
         1779,
         1780,
         1781,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         5,
         6,
         7,
         6,
         7,
         6,
         7,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         11,
         2,
         12,
         13,
         14,
         15,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         3,
         17,
         4,
         4,
         4,
         4,
         4,
         16,
         3,
         3,
         3,
         5,
         18,
         5,
         19,
         5,
         20,
         5,
         5,
         5,
         18,
         5,
         19,
         5,
         5,
         20,
         18,
         5,
         19,
         5,
         20,
         5,
         18,
         18,
         21,
         18,
         22,
         19,
         5,
         20,
         19,
         19,
         23,
         20,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         7,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         6,
         6,
         6,
         7,
         6,
         6,
         6,
         7,
         6,
         6,
         6,
         7,
         6,
         6,
         6,
         6,
         7,
         6,
         6,
         24,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         25,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         24,
         8,
         8,
         8,
         16,
         3,
         17,
         17,
         17,
         17,
         17,
         4,
         4,
         16,
         16,
         3,
         16,
         16,
         3,
         27,
         28,
         5,
         27,
         28,
         5,
         5,
         27,
         28,
         5,
         29,
         30,
         31,
         18,
         27,
         28,
         5,
         32,
         33,
         19,
         27,
         28,
         5,
         34,
         35,
         20,
         27,
         28,
         28,
         0,
         6,
         6,
         6,
         6,
         7,
         6,
         6,
         6,
         6,
         2,
         36,
         37,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         17,
         16,
         16,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         16,
         16,
         3,
         3,
         3,
         3,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         38,
         39,
         38,
         39,
         38,
         39,
         38,
         40,
         38,
         39,
         41,
         42,
         38,
         39,
         43,
         44,
         45,
         46,
         47,
         39,
         38,
         39,
         48,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         49,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         17,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 50,
      .table = (const uint16_t []) {
      
         23,
         24,
         1561,
         1562,
         1562,
         23,
         23,
         23,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2903,
         2903,
         23,
         2903,
         2903,
         2904,
         2904,
         2903,
         2903,
         1561,
         1561,
         23,
         2903,
         2903,
         23,
         2904,
         23,
         2903,
         23,
         2903,
         2903,
         2903,
         1561,
         24,
         24,
         1563,
         1564,
         1565,
         24,
         1566,
         1567,
         24,
         24,
         1568,
         2524,
         2525,
         2526,
         2527,
         2528,
         2529,
         2530,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2905,
         2906,
         2906,
         2907,
         2906,
         2906,
         2908,
         2908,
         2906,
         2906,
         2909,
         2527,
         24,
         2906,
         2906,
         24,
         2908,
         24,
         2906,
         2907,
         2906,
         2906,
         2906,
         3004,
         1561,
         1563,
         1561,
         1569,
         1569,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2522,
         2531,
         2531,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2910,
         2910,
         2911,
         2911,
         2910,
         2910,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2911,
         1561,
         2910,
         1561,
         2910,
         2910,
         2910,
         1561,
         1562,
         1564,
         1569,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1569,
         1569,
         1569,
         1569,
         2532,
         2523,
         2523,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         2912,
         2912,
         1562,
         2912,
         2912,
         2913,
         2913,
         2912,
         2912,
         1569,
         1569,
         1562,
         2912,
         2912,
         1562,
         2913,
         1562,
         2912,
         1562,
         2912,
         2912,
         2912,
         1569,
         1562,
         1565,
         1569,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1569,
         1569,
         1569,
         1569,
         2532,
         2523,
         2523,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         1562,
         2912,
         2912,
         1562,
         2912,
         2912,
         2913,
         2913,
         2912,
         2912,
         1569,
         1569,
         1562,
         2912,
         2912,
         1562,
         2913,
         1562,
         2912,
         1562,
         2912,
         2912,
         2912,
         1569,
         23,
         24,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         1570,
         1570,
         1570,
         1570,
         1570,
         1570,
         23,
         23,
         23,
         2914,
         2915,
         1570,
         2914,
         2915,
         2916,
         2917,
         2914,
         2915,
         1561,
         1561,
         1570,
         2915,
         2915,
         1570,
         2917,
         1570,
         2915,
         1570,
         2914,
         2915,
         2915,
         1561,
         23,
         1566,
         1561,
         1562,
         1562,
         1571,
         23,
         23,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         1571,
         1571,
         1571,
         1571,
         1571,
         1571,
         23,
         23,
         23,
         2918,
         2918,
         1571,
         2918,
         2918,
         2919,
         2919,
         2918,
         2918,
         1561,
         1561,
         1571,
         2918,
         2918,
         1571,
         2919,
         1571,
         2918,
         1571,
         2918,
         2918,
         2918,
         1561,
         23,
         1567,
         1561,
         1562,
         1562,
         1571,
         23,
         23,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         1571,
         1571,
         1571,
         1571,
         1571,
         1571,
         23,
         23,
         23,
         2918,
         2918,
         1571,
         2918,
         2918,
         2919,
         2919,
         2918,
         2918,
         1561,
         1561,
         1571,
         2918,
         2918,
         1571,
         2919,
         1571,
         2918,
         1571,
         2918,
         2918,
         2918,
         1561,
         23,
         24,
         1561,
         1562,
         1562,
         23,
         23,
         23,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         23,
         23,
         23,
         23,
         23,
         23,
         2533,
         23,
         23,
         2903,
         2903,
         23,
         2903,
         2903,
         2904,
         2904,
         2903,
         2903,
         1561,
         1561,
         23,
         2903,
         2903,
         23,
         2904,
         23,
         2903,
         23,
         2903,
         2903,
         2903,
         1561,
         23,
         24,
         1561,
         1562,
         1562,
         23,
         23,
         23,
         23,
         1572,
         23,
         1561,
         1561,
         1561,
         2534,
         2522,
         2523,
         2523,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1572,
         23,
         2903,
         2903,
         23,
         2903,
         2903,
         2904,
         2904,
         2903,
         2903,
         1561,
         2534,
         23,
         2903,
         2903,
         23,
         2904,
         23,
         2903,
         23,
         2903,
         2903,
         2903,
         1561,
         23,
         1568,
         1561,
         1562,
         1562,
         23,
         23,
         23,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2903,
         2903,
         23,
         2903,
         2903,
         2904,
         2904,
         2903,
         2903,
         1561,
         1561,
         23,
         2903,
         2903,
         23,
         2904,
         23,
         2903,
         23,
         2903,
         2903,
         2903,
         1561,
         1561,
         2524,
         1561,
         1569,
         1569,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2522,
         2531,
         2531,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2910,
         2910,
         2911,
         2911,
         2910,
         2910,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2911,
         1561,
         2910,
         1561,
         2910,
         2910,
         2910,
         1561,
         1561,
         2525,
         1561,
         1569,
         1569,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2522,
         2531,
         2531,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2910,
         2910,
         2911,
         2911,
         2910,
         2910,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2911,
         1561,
         2910,
         1561,
         2910,
         2910,
         2910,
         1561,
         1561,
         2526,
         1561,
         1569,
         1569,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2522,
         2531,
         2531,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2910,
         2910,
         2911,
         2911,
         2910,
         2910,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2911,
         1561,
         2910,
         1561,
         2910,
         2910,
         2910,
         1561,
         1561,
         2527,
         1561,
         1569,
         1569,
         1561,
         1561,
         1561,
         1561,
         2534,
         1561,
         1561,
         1561,
         1561,
         1561,
         2522,
         2531,
         2531,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2534,
         1561,
         2910,
         2910,
         1561,
         2910,
         2910,
         2911,
         2911,
         2910,
         2910,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2911,
         1561,
         2910,
         1561,
         2910,
         2910,
         2910,
         1561,
         2522,
         2528,
         2522,
         2532,
         2532,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2535,
         2535,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2920,
         2920,
         2522,
         2920,
         2920,
         2921,
         2921,
         2920,
         2920,
         2522,
         2522,
         2522,
         2920,
         2920,
         2522,
         2921,
         2522,
         2920,
         2522,
         2920,
         2920,
         2920,
         2522,
         2523,
         2529,
         2531,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2531,
         2531,
         2531,
         2531,
         2535,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2922,
         2922,
         2523,
         2922,
         2922,
         2923,
         2923,
         2922,
         2922,
         2531,
         2531,
         2523,
         2922,
         2922,
         2523,
         2923,
         2523,
         2922,
         2523,
         2922,
         2922,
         2922,
         2531,
         2523,
         2530,
         2531,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2531,
         2531,
         2531,
         2531,
         2535,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2922,
         2922,
         2523,
         2922,
         2922,
         2923,
         2923,
         2922,
         2922,
         2531,
         2531,
         2523,
         2922,
         2922,
         2523,
         2923,
         2523,
         2922,
         2523,
         2922,
         2922,
         2922,
         2531,
         23,
         24,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         1570,
         1570,
         1570,
         1570,
         1570,
         1570,
         23,
         23,
         23,
         2914,
         2915,
         1570,
         2914,
         2915,
         2916,
         2917,
         2914,
         2915,
         1561,
         1561,
         3005,
         2915,
         2915,
         3005,
         2917,
         3005,
         2915,
         3005,
         3006,
         3007,
         3007,
         1561,
         23,
         24,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         1570,
         1570,
         1570,
         1570,
         1570,
         1570,
         23,
         23,
         23,
         2914,
         2915,
         1570,
         2914,
         2915,
         2916,
         2917,
         2914,
         2915,
         1561,
         1561,
         1570,
         3008,
         3008,
         1570,
         3009,
         1570,
         3008,
         1570,
         2914,
         2915,
         3008,
         1561,
         23,
         24,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         1570,
         1570,
         2536,
         1570,
         2536,
         2536,
         23,
         23,
         23,
         2914,
         2915,
         1570,
         2914,
         2915,
         2916,
         2917,
         2924,
         2925,
         1561,
         1561,
         1570,
         2915,
         2915,
         1570,
         2917,
         2536,
         2925,
         1570,
         2914,
         2915,
         2915,
         1561,
         23,
         24,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         1570,
         1570,
         1570,
         1570,
         1570,
         1570,
         23,
         23,
         23,
         2914,
         2915,
         1570,
         2914,
         2915,
         2916,
         2917,
         2914,
         2915,
         1561,
         1561,
         3005,
         3008,
         3008,
         3005,
         3009,
         3005,
         3008,
         3005,
         3006,
         3007,
         3010,
         1561,
         23,
         24,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         1570,
         1570,
         2536,
         1570,
         2536,
         2536,
         23,
         23,
         23,
         2914,
         2915,
         1570,
         2914,
         2915,
         2916,
         2917,
         2924,
         2925,
         1561,
         1561,
         3005,
         2915,
         2915,
         3005,
         2917,
         3011,
         2925,
         3005,
         3006,
         3007,
         3007,
         1561,
         23,
         24,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         1570,
         1570,
         2536,
         1570,
         2536,
         2536,
         23,
         23,
         23,
         2914,
         2915,
         1570,
         2914,
         2915,
         2916,
         2917,
         2924,
         2925,
         1561,
         1561,
         1570,
         3008,
         3008,
         1570,
         3009,
         2536,
         3012,
         1570,
         2914,
         2915,
         3008,
         1561,
         23,
         24,
         1561,
         1562,
         1562,
         23,
         23,
         23,
         2533,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         23,
         23,
         23,
         23,
         23,
         23,
         2533,
         23,
         23,
         2903,
         2903,
         23,
         2903,
         2903,
         2904,
         2904,
         2903,
         2903,
         1561,
         1561,
         23,
         2903,
         2903,
         23,
         2904,
         23,
         2903,
         23,
         2903,
         2903,
         2903,
         1561,
         23,
         24,
         1561,
         1562,
         1562,
         23,
         23,
         23,
         23,
         1572,
         23,
         1561,
         1561,
         1561,
         2534,
         2522,
         2523,
         2523,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1572,
         23,
         2903,
         2903,
         23,
         2903,
         2903,
         2904,
         2904,
         2903,
         2903,
         1561,
         2926,
         23,
         2903,
         2903,
         23,
         2904,
         23,
         2903,
         23,
         2903,
         2903,
         2903,
         1561,
         23,
         2905,
         1561,
         1562,
         1562,
         23,
         23,
         23,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2903,
         2903,
         23,
         2903,
         2903,
         2904,
         2904,
         2903,
         2903,
         1561,
         1561,
         23,
         2903,
         2903,
         23,
         2904,
         23,
         2903,
         23,
         2903,
         2903,
         2903,
         1561,
         2903,
         2906,
         2910,
         2912,
         2912,
         2914,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2903,
         2903,
         2903,
         2914,
         2915,
         2914,
         2914,
         2915,
         2916,
         2917,
         2914,
         2915,
         2910,
         2910,
         2914,
         2915,
         2915,
         2914,
         2917,
         2914,
         2915,
         2914,
         2914,
         2915,
         2915,
         2910,
         2903,
         2906,
         2910,
         2912,
         2912,
         2915,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         2915,
         2915,
         2915,
         2915,
         2915,
         2915,
         2903,
         2903,
         2903,
         2915,
         2915,
         2915,
         2915,
         2915,
         2917,
         2917,
         2915,
         2915,
         2910,
         2910,
         2915,
         2915,
         2915,
         2915,
         2917,
         2915,
         2915,
         2915,
         2915,
         2915,
         2915,
         2910,
         23,
         2907,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         1570,
         1570,
         1570,
         1570,
         1570,
         1570,
         23,
         23,
         23,
         2914,
         2915,
         1570,
         2914,
         2915,
         2916,
         2917,
         2914,
         2915,
         1561,
         1561,
         3005,
         2915,
         2915,
         3005,
         2917,
         3005,
         2915,
         3005,
         3006,
         3007,
         3007,
         1561,
         2903,
         2906,
         2910,
         2912,
         2912,
         2914,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2903,
         2903,
         2903,
         2914,
         2915,
         2914,
         2914,
         2915,
         2916,
         2917,
         2914,
         2915,
         2910,
         2910,
         3006,
         2915,
         2915,
         3006,
         2917,
         3006,
         2915,
         3006,
         3006,
         3007,
         3007,
         2910,
         2903,
         2906,
         2910,
         2912,
         2912,
         2915,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         2915,
         2915,
         2915,
         2915,
         2915,
         2915,
         2903,
         2903,
         2903,
         2915,
         2915,
         2915,
         2915,
         2915,
         2917,
         2917,
         2915,
         2915,
         2910,
         2910,
         3007,
         2915,
         2915,
         3007,
         2917,
         3007,
         2915,
         3007,
         3007,
         3007,
         3007,
         2910,
         2904,
         2908,
         2911,
         2913,
         2913,
         2916,
         2919,
         2919,
         2904,
         2904,
         2904,
         2911,
         2911,
         2911,
         2911,
         2921,
         2923,
         2923,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2904,
         2904,
         2904,
         2916,
         2917,
         2916,
         2916,
         2917,
         2916,
         2917,
         2916,
         2917,
         2911,
         2911,
         2916,
         3009,
         3009,
         2916,
         3009,
         2916,
         3009,
         2916,
         2916,
         2917,
         3009,
         2911,
         2904,
         2908,
         2911,
         2913,
         2913,
         2917,
         2919,
         2919,
         2904,
         2904,
         2904,
         2911,
         2911,
         2911,
         2911,
         2921,
         2923,
         2923,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2904,
         2904,
         2904,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2911,
         2911,
         2917,
         3009,
         3009,
         2917,
         3009,
         2917,
         3009,
         2917,
         2917,
         2917,
         3009,
         2911,
         2903,
         2906,
         2910,
         2912,
         2912,
         2914,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         2914,
         2914,
         2924,
         2914,
         2924,
         2924,
         2903,
         2903,
         2903,
         2914,
         2915,
         2914,
         2914,
         2915,
         2916,
         2917,
         2924,
         2925,
         2910,
         2910,
         2914,
         2915,
         2915,
         2914,
         2917,
         2924,
         2925,
         2914,
         2914,
         2915,
         2915,
         2910,
         2903,
         2906,
         2910,
         2912,
         2912,
         2915,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         2915,
         2915,
         2925,
         2915,
         2925,
         2925,
         2903,
         2903,
         2903,
         2915,
         2915,
         2915,
         2915,
         2915,
         2917,
         2917,
         2925,
         2925,
         2910,
         2910,
         2915,
         2915,
         2915,
         2915,
         2917,
         2925,
         2925,
         2915,
         2915,
         2915,
         2915,
         2910,
         1561,
         2909,
         1561,
         1569,
         1569,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2522,
         2531,
         2531,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2910,
         2910,
         2911,
         2911,
         2910,
         2910,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2911,
         1561,
         2910,
         1561,
         2910,
         2910,
         2910,
         1561,
         1561,
         2527,
         1561,
         1569,
         1569,
         1561,
         1561,
         1561,
         1561,
         2534,
         1561,
         1561,
         1561,
         1561,
         1561,
         2522,
         2531,
         2531,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2926,
         1561,
         2910,
         2910,
         1561,
         2910,
         2910,
         2911,
         2911,
         2910,
         2910,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2911,
         1561,
         2910,
         1561,
         2910,
         2910,
         2910,
         1561,
         23,
         24,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         3005,
         1570,
         1570,
         3005,
         3005,
         1570,
         23,
         23,
         23,
         2914,
         2915,
         3005,
         3006,
         3007,
         2916,
         2917,
         2914,
         2915,
         1561,
         1561,
         3005,
         2915,
         3007,
         3005,
         2917,
         3005,
         2915,
         3005,
         3006,
         3007,
         3007,
         1561,
         2903,
         2906,
         2910,
         2912,
         2912,
         2915,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         2915,
         3008,
         2915,
         3008,
         2915,
         3008,
         2903,
         2903,
         2903,
         2915,
         2915,
         2915,
         2915,
         2915,
         3009,
         3009,
         2915,
         2915,
         2910,
         2910,
         2915,
         2915,
         2915,
         3008,
         3009,
         2915,
         2915,
         2915,
         2915,
         2915,
         2915,
         2910,
         2903,
         2906,
         2910,
         2912,
         2912,
         2915,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         2915,
         3008,
         2915,
         3008,
         2915,
         3008,
         2903,
         2903,
         2903,
         2915,
         2915,
         2915,
         2915,
         2915,
         3009,
         3009,
         2915,
         2915,
         2910,
         2910,
         3007,
         2915,
         2915,
         3010,
         3009,
         3007,
         2915,
         3007,
         3007,
         3007,
         3007,
         2910,
         23,
         24,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         3005,
         1570,
         1570,
         3005,
         3005,
         1570,
         23,
         23,
         23,
         2914,
         2915,
         3005,
         3006,
         3007,
         2916,
         2917,
         2914,
         2915,
         1561,
         1561,
         3005,
         3008,
         3010,
         3005,
         3009,
         3005,
         3008,
         3005,
         3006,
         3007,
         3010,
         1561,
         2904,
         2908,
         2911,
         2913,
         2913,
         2917,
         2919,
         2919,
         2904,
         2904,
         2904,
         2911,
         2911,
         2911,
         2911,
         2921,
         2923,
         2923,
         2917,
         3009,
         2917,
         3009,
         2917,
         3009,
         2904,
         2904,
         2904,
         2917,
         2917,
         2917,
         2917,
         2917,
         3009,
         3009,
         2917,
         2917,
         2911,
         2911,
         2917,
         3009,
         3009,
         3009,
         3009,
         2917,
         3009,
         2917,
         2917,
         2917,
         3009,
         2911,
         23,
         24,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         3005,
         1570,
         2536,
         3005,
         3011,
         2536,
         23,
         23,
         23,
         2914,
         2915,
         3005,
         3006,
         3007,
         2916,
         2917,
         2924,
         2925,
         1561,
         1561,
         3005,
         2915,
         3007,
         3005,
         2917,
         3011,
         2925,
         3005,
         3006,
         3007,
         3007,
         1561,
         2903,
         2906,
         2910,
         2912,
         2912,
         2915,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         2915,
         3008,
         2925,
         3008,
         2925,
         3012,
         2903,
         2903,
         2903,
         2915,
         2915,
         2915,
         2915,
         2915,
         3009,
         3009,
         2925,
         2925,
         2910,
         2910,
         2915,
         2915,
         2915,
         3008,
         3009,
         2925,
         2925,
         2915,
         2915,
         2915,
         2915,
         2910,
         23,
         2907,
         1561,
         1562,
         1562,
         1570,
         1571,
         1571,
         23,
         23,
         23,
         1561,
         1561,
         1561,
         1561,
         2522,
         2523,
         2523,
         3005,
         1570,
         1570,
         3005,
         3005,
         1570,
         23,
         23,
         23,
         2914,
         2915,
         3005,
         3006,
         3007,
         2916,
         2917,
         2914,
         2915,
         1561,
         1561,
         3005,
         2915,
         3007,
         3005,
         2917,
         3005,
         2915,
         3005,
         3006,
         3007,
         3007,
         1561,
         2903,
         2906,
         2910,
         2912,
         2912,
         2914,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         3006,
         2914,
         2914,
         3006,
         3006,
         2914,
         2903,
         2903,
         2903,
         2914,
         2915,
         3006,
         3006,
         3007,
         2916,
         2917,
         2914,
         2915,
         2910,
         2910,
         3006,
         2915,
         3007,
         3006,
         2917,
         3006,
         2915,
         3006,
         3006,
         3007,
         3007,
         2910,
         2903,
         2906,
         2910,
         2912,
         2912,
         2915,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         3007,
         2915,
         2915,
         3007,
         3007,
         2915,
         2903,
         2903,
         2903,
         2915,
         2915,
         3007,
         3007,
         3007,
         2917,
         2917,
         2915,
         2915,
         2910,
         2910,
         3007,
         2915,
         3007,
         3007,
         2917,
         3007,
         2915,
         3007,
         3007,
         3007,
         3007,
         2910,
         2903,
         2906,
         2910,
         2912,
         2912,
         2915,
         2918,
         2918,
         2903,
         2903,
         2903,
         2910,
         2910,
         2910,
         2910,
         2920,
         2922,
         2922,
         3007,
         3008,
         2915,
         3010,
         3007,
         3008,
         2903,
         2903,
         2903,
         2915,
         2915,
         3007,
         3007,
         3007,
         3009,
         3009,
         2915,
         2915,
         2910,
         2910,
         3007,
         2915,
         3007,
         3010,
         3009,
         3007,
         2915,
         3007,
         3007,
         3007,
         3007,
         2910,
         1561,
         3004,
         1561,
         1569,
         1569,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2522,
         2531,
         2531,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2910,
         2910,
         2911,
         2911,
         2910,
         2910,
         1561,
         1561,
         1561,
         2910,
         2910,
         1561,
         2911,
         1561,
         2910,
         1561,
         2910,
         2910,
         2910,
         1561,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         15,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         21,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         22,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         27,
         28,
         0,
         0,
         0,
         0,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         20,
         20,
         20,
         20,
         20,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         25,
         25,
         23,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 31,
      .table = (const uint16_t []) {
      
         25,
         26,
         25,
         25,
         359,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         25,
         25,
         25,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         25,
         25,
         25,
         25,
         359,
         26,
         26,
         26,
         370,
         371,
         372,
         373,
         374,
         375,
         376,
         377,
         378,
         379,
         380,
         381,
         382,
         383,
         26,
         26,
         26,
         2159,
         2160,
         2161,
         2162,
         2163,
         2164,
         26,
         26,
         26,
         26,
         371,
         25,
         26,
         384,
         384,
         359,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         25,
         25,
         25,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         25,
         25,
         25,
         25,
         359,
         25,
         370,
         384,
         384,
         359,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         25,
         25,
         25,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         25,
         25,
         25,
         25,
         359,
         359,
         371,
         359,
         359,
         359,
         385,
         386,
         387,
         388,
         389,
         390,
         391,
         359,
         392,
         393,
         394,
         395,
         359,
         359,
         359,
         2165,
         2166,
         2167,
         2168,
         2169,
         2170,
         359,
         359,
         359,
         359,
         359,
         25,
         372,
         25,
         25,
         385,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         25,
         25,
         25,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         25,
         25,
         25,
         25,
         385,
         360,
         373,
         360,
         360,
         386,
         360,
         360,
         396,
         397,
         398,
         399,
         400,
         360,
         401,
         402,
         403,
         404,
         360,
         360,
         360,
         2154,
         2154,
         2171,
         2172,
         2173,
         2174,
         360,
         360,
         360,
         360,
         386,
         361,
         374,
         361,
         361,
         387,
         361,
         396,
         361,
         405,
         406,
         407,
         408,
         361,
         409,
         410,
         411,
         412,
         361,
         361,
         361,
         2175,
         2176,
         2177,
         2178,
         2179,
         2180,
         361,
         361,
         361,
         361,
         387,
         362,
         375,
         362,
         362,
         388,
         362,
         397,
         405,
         362,
         413,
         414,
         415,
         362,
         416,
         417,
         418,
         419,
         362,
         362,
         362,
         2181,
         2182,
         2183,
         2184,
         2185,
         2186,
         362,
         362,
         362,
         362,
         388,
         363,
         376,
         363,
         363,
         389,
         363,
         398,
         406,
         413,
         363,
         420,
         421,
         363,
         422,
         423,
         424,
         425,
         363,
         363,
         363,
         2187,
         2188,
         2189,
         2190,
         2191,
         2192,
         363,
         363,
         363,
         363,
         389,
         364,
         377,
         364,
         364,
         390,
         364,
         399,
         407,
         414,
         420,
         364,
         426,
         364,
         427,
         428,
         429,
         430,
         364,
         364,
         364,
         2193,
         2194,
         2195,
         2196,
         2197,
         2198,
         364,
         364,
         364,
         364,
         390,
         365,
         378,
         365,
         365,
         391,
         365,
         400,
         408,
         415,
         421,
         426,
         365,
         365,
         431,
         432,
         433,
         434,
         365,
         365,
         365,
         2199,
         2200,
         2201,
         2202,
         2203,
         2204,
         365,
         365,
         365,
         365,
         391,
         25,
         379,
         25,
         25,
         359,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         25,
         25,
         25,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         25,
         25,
         25,
         25,
         359,
         366,
         380,
         366,
         366,
         392,
         366,
         401,
         409,
         416,
         422,
         427,
         431,
         366,
         366,
         435,
         436,
         437,
         366,
         366,
         366,
         2205,
         2206,
         2207,
         2208,
         2209,
         2210,
         366,
         366,
         366,
         366,
         392,
         367,
         381,
         367,
         367,
         393,
         367,
         402,
         410,
         417,
         423,
         428,
         432,
         367,
         435,
         367,
         438,
         439,
         367,
         367,
         367,
         2211,
         2212,
         2213,
         2214,
         2215,
         2216,
         367,
         367,
         367,
         367,
         393,
         368,
         382,
         368,
         368,
         394,
         368,
         403,
         411,
         418,
         424,
         429,
         433,
         368,
         436,
         438,
         368,
         440,
         368,
         368,
         368,
         2217,
         2218,
         2219,
         2220,
         2221,
         2222,
         368,
         368,
         368,
         368,
         394,
         369,
         383,
         369,
         369,
         395,
         369,
         404,
         412,
         419,
         425,
         430,
         434,
         369,
         437,
         439,
         440,
         369,
         369,
         369,
         369,
         2223,
         2224,
         2225,
         2226,
         2227,
         2228,
         369,
         369,
         369,
         369,
         395,
         25,
         26,
         25,
         25,
         359,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         25,
         441,
         441,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         25,
         25,
         25,
         25,
         359,
         25,
         26,
         25,
         25,
         359,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         441,
         25,
         441,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         25,
         25,
         25,
         25,
         359,
         25,
         26,
         25,
         25,
         359,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         441,
         441,
         441,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         25,
         25,
         25,
         25,
         359,
         2153,
         2159,
         2153,
         2153,
         2165,
         2153,
         2154,
         2175,
         2181,
         2187,
         2193,
         2199,
         2153,
         2205,
         2211,
         2217,
         2223,
         2153,
         2153,
         2153,
         2153,
         2154,
         2229,
         2230,
         2231,
         2232,
         2153,
         2153,
         2153,
         2153,
         2165,
         2154,
         2160,
         2154,
         2154,
         2166,
         2154,
         2154,
         2176,
         2182,
         2188,
         2194,
         2200,
         2154,
         2206,
         2212,
         2218,
         2224,
         2154,
         2154,
         2154,
         2154,
         2154,
         2233,
         2234,
         2235,
         2236,
         2154,
         2154,
         2154,
         2154,
         2166,
         2155,
         2161,
         2155,
         2155,
         2167,
         2155,
         2171,
         2177,
         2183,
         2189,
         2195,
         2201,
         2155,
         2207,
         2213,
         2219,
         2225,
         2155,
         2155,
         2155,
         2229,
         2233,
         2155,
         2237,
         2238,
         2239,
         2155,
         2155,
         2155,
         2155,
         2167,
         2156,
         2162,
         2156,
         2156,
         2168,
         2156,
         2172,
         2178,
         2184,
         2190,
         2196,
         2202,
         2156,
         2208,
         2214,
         2220,
         2226,
         2156,
         2156,
         2156,
         2230,
         2234,
         2237,
         2156,
         2240,
         2241,
         2156,
         2156,
         2156,
         2156,
         2168,
         2157,
         2163,
         2157,
         2157,
         2169,
         2157,
         2173,
         2179,
         2185,
         2191,
         2197,
         2203,
         2157,
         2209,
         2215,
         2221,
         2227,
         2157,
         2157,
         2157,
         2231,
         2235,
         2238,
         2240,
         2157,
         2242,
         2157,
         2157,
         2157,
         2157,
         2169,
         2158,
         2164,
         2158,
         2158,
         2170,
         2158,
         2174,
         2180,
         2186,
         2192,
         2198,
         2204,
         2158,
         2210,
         2216,
         2222,
         2228,
         2158,
         2158,
         2158,
         2232,
         2236,
         2239,
         2241,
         2242,
         2158,
         2158,
         2158,
         2158,
         2158,
         2170,
         25,
         26,
         25,
         25,
         359,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         25,
         25,
         25,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         25,
         2243,
         2243,
         25,
         359,
         25,
         26,
         25,
         25,
         359,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         25,
         25,
         25,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         2243,
         25,
         2243,
         25,
         359,
         25,
         26,
         25,
         25,
         359,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         25,
         25,
         25,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         2243,
         2243,
         2243,
         25,
         359,
         25,
         26,
         25,
         25,
         359,
         25,
         360,
         361,
         362,
         363,
         364,
         365,
         25,
         366,
         367,
         368,
         369,
         25,
         25,
         25,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
         25,
         25,
         25,
         25,
         2991,
         359,
         371,
         359,
         359,
         359,
         385,
         386,
         387,
         388,
         389,
         390,
         391,
         359,
         392,
         393,
         394,
         395,
         359,
         359,
         359,
         2165,
         2166,
         2167,
         2168,
         2169,
         2170,
         359,
         359,
         359,
         2991,
         359,
      },
   },
   [nir_op_usadd_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         27,
         27,
         27,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         13,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         3,
         3,
         16,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         17,
         4,
         4,
         4,
         4,
         3,
         16,
         3,
         3,
         3,
         16,
         3,
         16,
         3,
         3,
         3,
         16,
         16,
         16,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         18,
         5,
         14,
         0,
         15,
         15,
         15,
         19,
         15,
         0,
         0,
         14,
         14,
         0,
         14,
         14,
         0,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         16,
         16,
         16,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         15,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         16,
         16,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 21,
      .table = (const uint16_t []) {
      
         28,
         29,
         1573,
         28,
         28,
         1574,
         1575,
         1576,
         28,
         1577,
         28,
         1578,
         28,
         1573,
         2537,
         2538,
         2539,
         2539,
         2945,
         2946,
         28,
         29,
         29,
         1579,
         1580,
         1581,
         1582,
         1583,
         1584,
         1585,
         1586,
         29,
         1587,
         29,
         1579,
         2540,
         2541,
         2542,
         2543,
         2947,
         2948,
         2998,
         1573,
         1579,
         1573,
         1573,
         1573,
         1588,
         1589,
         1590,
         1573,
         1591,
         1573,
         1592,
         1573,
         1573,
         2544,
         2545,
         2546,
         2546,
         2949,
         2950,
         1573,
         28,
         1580,
         1573,
         28,
         28,
         1574,
         1593,
         1576,
         28,
         1577,
         28,
         1578,
         28,
         1573,
         2537,
         2538,
         2539,
         2539,
         2945,
         2946,
         28,
         28,
         1581,
         1573,
         28,
         28,
         1574,
         1593,
         1576,
         28,
         1577,
         28,
         1578,
         28,
         1573,
         2537,
         2538,
         2539,
         2539,
         2945,
         2946,
         28,
         1574,
         1582,
         1588,
         1574,
         1574,
         1594,
         1595,
         1596,
         1574,
         1597,
         1574,
         1598,
         1574,
         2547,
         2548,
         2549,
         2550,
         2550,
         2951,
         2952,
         1574,
         1575,
         1583,
         1589,
         1593,
         1593,
         1595,
         1575,
         1599,
         1575,
         1600,
         1575,
         1601,
         1575,
         1589,
         2551,
         2552,
         2553,
         2553,
         2953,
         2954,
         1575,
         1576,
         1584,
         1590,
         1576,
         1576,
         1596,
         1599,
         1602,
         1576,
         1603,
         1576,
         1604,
         1576,
         1590,
         2554,
         2555,
         2556,
         2556,
         2955,
         2956,
         1576,
         28,
         1585,
         1573,
         28,
         28,
         1574,
         1575,
         1576,
         28,
         1577,
         28,
         1578,
         28,
         1573,
         2537,
         2538,
         2539,
         2539,
         2945,
         2946,
         28,
         1577,
         1586,
         1591,
         1577,
         1577,
         1597,
         1600,
         1603,
         1577,
         1577,
         1577,
         1605,
         1577,
         1591,
         2557,
         2558,
         2559,
         2559,
         2957,
         2958,
         1577,
         28,
         29,
         1573,
         28,
         28,
         1574,
         1575,
         1576,
         28,
         1577,
         1606,
         1578,
         28,
         1573,
         2537,
         2538,
         2539,
         2539,
         2945,
         2946,
         28,
         1578,
         1587,
         1592,
         1578,
         1578,
         1598,
         1601,
         1604,
         1578,
         1605,
         1578,
         1578,
         1578,
         1592,
         2560,
         2561,
         2562,
         2562,
         2959,
         2960,
         1578,
         28,
         29,
         1573,
         28,
         28,
         1574,
         1575,
         1576,
         28,
         1577,
         28,
         1578,
         1607,
         1573,
         2537,
         2538,
         2539,
         2539,
         2945,
         2946,
         28,
         1573,
         1579,
         1573,
         1573,
         1573,
         2547,
         1589,
         1590,
         1573,
         1591,
         1573,
         1592,
         1573,
         1573,
         2544,
         2545,
         2546,
         2546,
         2961,
         2950,
         1573,
         2537,
         2540,
         2544,
         2537,
         2537,
         2548,
         2551,
         2554,
         2537,
         2557,
         2537,
         2560,
         2537,
         2544,
         2537,
         2538,
         2563,
         2563,
         2962,
         2946,
         2537,
         2538,
         2541,
         2545,
         2538,
         2538,
         2549,
         2552,
         2555,
         2538,
         2558,
         2538,
         2561,
         2538,
         2545,
         2538,
         2564,
         2565,
         2565,
         2963,
         2964,
         2538,
         2539,
         2542,
         2546,
         2539,
         2539,
         2550,
         2553,
         2556,
         2539,
         2559,
         2539,
         2562,
         2539,
         2546,
         2563,
         2565,
         2539,
         2539,
         2965,
         2966,
         2539,
         2539,
         2543,
         2546,
         2539,
         2539,
         2550,
         2553,
         2556,
         2539,
         2559,
         2539,
         2562,
         2539,
         2546,
         2563,
         2565,
         2539,
         2539,
         2965,
         2966,
         2539,
         2945,
         2947,
         2949,
         2945,
         2945,
         2951,
         2953,
         2955,
         2945,
         2957,
         2945,
         2959,
         2945,
         2961,
         2962,
         2963,
         2965,
         2965,
         2951,
         2967,
         2945,
         2946,
         2948,
         2950,
         2946,
         2946,
         2952,
         2954,
         2956,
         2946,
         2958,
         2946,
         2960,
         2946,
         2950,
         2946,
         2964,
         2966,
         2966,
         2967,
         2964,
         2946,
         28,
         2998,
         1573,
         28,
         28,
         1574,
         1575,
         1576,
         28,
         1577,
         28,
         1578,
         28,
         1573,
         2537,
         2538,
         2539,
         2539,
         2945,
         2946,
         28,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         3,
         3,
         3,
         8,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         9,
         4,
         4,
         4,
         3,
         3,
         8,
         3,
         3,
         3,
         3,
         3,
         8,
         3,
         3,
         8,
         3,
         3,
         8,
         8,
         8,
         3,
         3,
         3,
         5,
         5,
         5,
         5,
         10,
         10,
         10,
         10,
         5,
         5,
         5,
         10,
         10,
         10,
         10,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         10,
         10,
         10,
         10,
         10,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         7,
         7,
         7,
         12,
         7,
         0,
         0,
         7,
         7,
         0,
         7,
         7,
         0,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         8,
         8,
         8,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         5,
         5,
         11,
         5,
         5,
         5,
         5,
         5,
         5,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         8,
         8,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         10,
         5,
         5,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         1611,
         32,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         1614,
         1614,
         1615,
         1615,
         1612,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         2968,
         2968,
         1609,
         1609,
         30,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         1611,
         32,
         34,
         35,
         34,
         1617,
         1617,
         1618,
         34,
         34,
         1617,
         1617,
         1618,
         1618,
         34,
         1619,
         1620,
         1619,
         1621,
         1621,
         1622,
         1619,
         1619,
         1621,
         1621,
         1622,
         1622,
         1619,
         1623,
         1624,
         1623,
         1625,
         1625,
         1626,
         1623,
         1623,
         1625,
         1625,
         1626,
         1626,
         1623,
         1627,
         1628,
         1627,
         1629,
         1629,
         1630,
         1627,
         1627,
         1629,
         1629,
         1630,
         1630,
         1627,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         1611,
         32,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         2568,
         32,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         1611,
         32,
         1623,
         1624,
         1623,
         1625,
         1625,
         1626,
         1623,
         1623,
         1625,
         1625,
         1626,
         1626,
         1623,
         1627,
         1628,
         1627,
         1629,
         1629,
         1630,
         1627,
         1627,
         1629,
         1629,
         1630,
         1630,
         1627,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         1611,
         32,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         1611,
         32,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         2969,
         2969,
         1611,
         1611,
         32,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         1614,
         1614,
         1615,
         1615,
         1612,
         1619,
         1620,
         1619,
         1621,
         1621,
         1622,
         1619,
         1619,
         1621,
         1621,
         1622,
         1622,
         1619,
         1631,
         1632,
         1631,
         1633,
         1633,
         1634,
         1631,
         1631,
         1633,
         1633,
         1634,
         1634,
         1631,
         1612,
         1613,
         1612,
         1635,
         1635,
         1615,
         1612,
         1612,
         1635,
         1635,
         1615,
         1615,
         1612,
         1612,
         1613,
         1612,
         1635,
         1635,
         1615,
         1612,
         1612,
         1635,
         1635,
         1615,
         1615,
         1612,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         1614,
         1614,
         1615,
         1615,
         1612,
         1636,
         1637,
         1636,
         1638,
         1638,
         1639,
         1636,
         1636,
         1638,
         1638,
         1639,
         2569,
         1636,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         1614,
         1614,
         1615,
         1615,
         1612,
         1612,
         1613,
         1612,
         1635,
         1635,
         1615,
         1612,
         1612,
         1635,
         1635,
         1615,
         1615,
         1612,
         1612,
         1613,
         1612,
         1635,
         1635,
         1615,
         1612,
         1612,
         1635,
         1635,
         1615,
         1615,
         1612,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         1614,
         1614,
         1615,
         1615,
         1612,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         1614,
         1614,
         1615,
         1615,
         1612,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         2970,
         2970,
         1615,
         1615,
         1612,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         1623,
         1624,
         1623,
         1625,
         1625,
         1626,
         1623,
         1623,
         1625,
         1625,
         1626,
         1626,
         1623,
         1612,
         1613,
         1612,
         1635,
         1635,
         1615,
         1612,
         1612,
         1635,
         1635,
         1615,
         1615,
         1612,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         2971,
         2971,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         1627,
         1628,
         1627,
         1629,
         1629,
         1630,
         1627,
         1627,
         1629,
         1629,
         1630,
         1630,
         1627,
         1612,
         1613,
         1612,
         1635,
         1635,
         1615,
         1612,
         1612,
         1635,
         1635,
         1615,
         1615,
         1612,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         2971,
         2971,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         1611,
         32,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         1614,
         1614,
         1615,
         1615,
         1612,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         2968,
         2968,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         2567,
         30,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         2568,
         32,
         1636,
         1637,
         1636,
         1638,
         1638,
         1639,
         1636,
         1636,
         1638,
         1638,
         1639,
         2569,
         1636,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         2567,
         30,
         2570,
         2571,
         2570,
         2572,
         2572,
         2573,
         2570,
         2570,
         2572,
         2572,
         2573,
         2574,
         2570,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         2567,
         30,
         30,
         31,
         30,
         2575,
         2575,
         1609,
         30,
         30,
         2575,
         2575,
         1609,
         2567,
         30,
         30,
         31,
         30,
         2575,
         2575,
         1609,
         30,
         30,
         2575,
         2575,
         1609,
         2567,
         30,
         2570,
         2571,
         2570,
         2572,
         2572,
         2573,
         2570,
         2570,
         2972,
         2972,
         2573,
         2574,
         2570,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         1611,
         32,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         1614,
         1614,
         1615,
         1615,
         1612,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         2570,
         2571,
         2570,
         2572,
         2572,
         2573,
         2570,
         2570,
         2572,
         2572,
         2573,
         2574,
         2570,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         2968,
         2968,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         1623,
         1624,
         1623,
         1625,
         1625,
         1626,
         1623,
         1623,
         1625,
         1625,
         1626,
         1626,
         1623,
         1612,
         1613,
         1612,
         1635,
         1635,
         1615,
         1612,
         1612,
         1635,
         1635,
         1615,
         1615,
         1612,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         2971,
         2971,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         1627,
         1628,
         1627,
         1629,
         1629,
         1630,
         1627,
         1627,
         1629,
         1629,
         1630,
         1630,
         1627,
         1612,
         1613,
         1612,
         1635,
         1635,
         1615,
         1612,
         1612,
         1635,
         1635,
         1615,
         1615,
         1612,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         2971,
         2971,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         1611,
         32,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         1614,
         1614,
         1615,
         1615,
         1612,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         2575,
         2575,
         1609,
         30,
         30,
         2575,
         2575,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         2968,
         2968,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         1610,
         1610,
         1611,
         1611,
         32,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         1614,
         1614,
         1615,
         1615,
         1612,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         2575,
         2575,
         1609,
         30,
         30,
         2575,
         2575,
         1609,
         2567,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         1616,
         1616,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         1608,
         1608,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         2968,
         2968,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         2968,
         2968,
         1609,
         1609,
         30,
         32,
         33,
         32,
         1610,
         1610,
         1611,
         32,
         32,
         2969,
         2969,
         1611,
         1611,
         32,
         1612,
         1613,
         1612,
         1614,
         1614,
         1615,
         1612,
         1612,
         2970,
         2970,
         1615,
         1615,
         1612,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         2971,
         2971,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         2971,
         2971,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         2968,
         2968,
         1609,
         1609,
         30,
         2570,
         2571,
         2570,
         2572,
         2572,
         2573,
         2570,
         2570,
         2972,
         2972,
         2573,
         2574,
         2570,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         2968,
         2968,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         2971,
         2971,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1616,
         1616,
         1609,
         30,
         30,
         2971,
         2971,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         2968,
         2968,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         2968,
         2968,
         1609,
         1609,
         30,
         30,
         31,
         30,
         1608,
         1608,
         1609,
         30,
         30,
         2968,
         2968,
         1609,
         1609,
         30,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         4,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         11,
         12,
         13,
         14,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         24,
         25,
         25,
         26,
         27,
         26,
         27,
         28,
         28,
         28,
         28,
         29,
         29,
         29,
         29,
         30,
         30,
         31,
         32,
         33,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         35,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         38,
         39,
         40,
         41,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         3,
         4,
         3,
         3,
         3,
         4,
         3,
         3,
         4,
         4,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         44,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         12,
         11,
         11,
         12,
         12,
         13,
         13,
         14,
         13,
         14,
         13,
         14,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         17,
         16,
         17,
         16,
         17,
         16,
         16,
         16,
         17,
         17,
         16,
         17,
         16,
         16,
         16,
         17,
         16,
         17,
         16,
         16,
         16,
         16,
         20,
         20,
         20,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         21,
         20,
         21,
         20,
         21,
         20,
         20,
         20,
         21,
         21,
         21,
         20,
         21,
         20,
         20,
         20,
         21,
         20,
         21,
         20,
         20,
         20,
         20,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         46,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         47,
         32,
         32,
         48,
         49,
         32,
         32,
         31,
         31,
         31,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         33,
         33,
         33,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         27,
         26,
         27,
         26,
         26,
         27,
         26,
         27,
         26,
         26,
         27,
         27,
         26,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         42,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         54,
         4,
         11,
         11,
         11,
         55,
         12,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         15,
         15,
         15,
         15,
         15,
         15,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         18,
         17,
         17,
         17,
         17,
         17,
         22,
         21,
         21,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         28,
         29,
         32,
         34,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         53,
         53,
         51,
         45,
         9,
         9,
         9,
         9,
         9,
         9,
         8,
         8,
         0,
         0,
         0,
         56,
         57,
         58,
         4,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         24,
         25,
         0,
         0,
         17,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         59,
         7,
         7,
         7,
         6,
         17,
         17,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         60,
         61,
         8,
         0,
         8,
         8,
         4,
         12,
         9,
         62,
         63,
         64,
         8,
         8,
         8,
         4,
         12,
         9,
         65,
         66,
         67,
         8,
         8,
         8,
         4,
         12,
         9,
         65,
      },
      
      .num_filtered_states = 68,
      .table = (const uint16_t []) {
      
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         37,
         37,
         1333,
         37,
         1334,
         1335,
         37,
         1336,
         1337,
         1338,
         37,
         37,
         1339,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         1340,
         37,
         1341,
         37,
         1342,
         37,
         1343,
         2381,
         2382,
         2383,
         2384,
         2385,
         37,
         37,
         2386,
         2387,
         2388,
         2389,
         2893,
         2894,
         37,
         37,
         37,
         3016,
         3018,
         3019,
         3026,
         3027,
         3028,
         3035,
         3036,
         3037,
         36,
         1333,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         1344,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         1344,
         36,
         36,
         36,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         36,
         1334,
         36,
         1344,
         1344,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         1344,
         36,
         36,
         36,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         36,
         1335,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         2390,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1327,
         1336,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1345,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1346,
         1327,
         1347,
         1327,
         1348,
         1327,
         1349,
         2391,
         1345,
         1327,
         2392,
         2393,
         1327,
         1327,
         2394,
         2395,
         2396,
         2397,
         1327,
         1327,
         1327,
         1327,
         1327,
         1345,
         1327,
         1327,
         1345,
         1327,
         1327,
         1345,
         1327,
         1327,
         1327,
         1337,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1345,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1327,
         1346,
         1327,
         1347,
         1327,
         1348,
         1327,
         1349,
         2391,
         1345,
         1327,
         2392,
         2393,
         1327,
         1327,
         2394,
         2395,
         2396,
         2397,
         1327,
         1327,
         1327,
         1327,
         1327,
         1345,
         1327,
         1327,
         1345,
         1327,
         1327,
         1345,
         1327,
         1327,
         1328,
         1338,
         1328,
         1328,
         1328,
         1328,
         1328,
         1345,
         1345,
         1350,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1351,
         1328,
         1352,
         1328,
         1353,
         1328,
         1354,
         2398,
         1350,
         1328,
         2399,
         2400,
         1328,
         1328,
         2401,
         2402,
         2403,
         2404,
         1328,
         1328,
         1328,
         1328,
         1328,
         1350,
         1328,
         1328,
         1350,
         1328,
         1328,
         1350,
         1328,
         1328,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         1355,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         1356,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         1356,
         36,
         36,
         36,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
         36,
         1339,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         1356,
         1356,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         1356,
         36,
         36,
         36,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         1357,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         1357,
         1357,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         1358,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2405,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         1358,
         1358,
         1358,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         1359,
         1359,
         1359,
         1359,
         36,
         36,
         36,
         36,
         1360,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         1359,
         1361,
         1362,
         1363,
         36,
         36,
         36,
         36,
         1360,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         1359,
         1362,
         1364,
         1365,
         36,
         36,
         36,
         36,
         1360,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         1359,
         1363,
         1365,
         1366,
         36,
         36,
         36,
         36,
         1360,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1367,
         1367,
         1367,
         1367,
         1368,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1367,
         1369,
         1370,
         1371,
         1368,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1367,
         1370,
         1372,
         1373,
         1368,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1367,
         1371,
         1373,
         1374,
         1368,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         1360,
         1360,
         1360,
         1360,
         1368,
         1368,
         1368,
         1368,
         1375,
         1376,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1376,
         1377,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1378,
         1378,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1378,
         1378,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         2995,
         2996,
         2997,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1379,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1380,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1381,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1382,
         1382,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1383,
         1382,
         1382,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2406,
         1383,
         1383,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1382,
         1382,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2407,
         1382,
         1382,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1382,
         1382,
         36,
         1384,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2407,
         1382,
         1382,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1385,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1329,
         1340,
         1329,
         1329,
         1329,
         1329,
         1329,
         1346,
         1346,
         1351,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1329,
         1385,
         1385,
         1329,
         1386,
         1329,
         1387,
         1329,
         1388,
         2408,
         1351,
         1329,
         2409,
         2410,
         1329,
         1329,
         2411,
         2412,
         2413,
         2414,
         1329,
         1329,
         1329,
         1329,
         1329,
         1351,
         1329,
         1329,
         1351,
         1329,
         1329,
         1351,
         1329,
         1329,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1389,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1330,
         1341,
         1330,
         1330,
         1330,
         1330,
         1330,
         1347,
         1347,
         1352,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1330,
         1386,
         1389,
         1389,
         1330,
         1390,
         1330,
         1391,
         2415,
         1352,
         1330,
         2416,
         2417,
         1330,
         1330,
         2418,
         2419,
         2420,
         2421,
         1330,
         1330,
         1330,
         1330,
         1330,
         1352,
         1330,
         1330,
         1352,
         1330,
         1330,
         1352,
         1330,
         1330,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1392,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1331,
         1342,
         1331,
         1331,
         1331,
         1331,
         1331,
         1348,
         1348,
         1353,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1331,
         1387,
         1331,
         1390,
         1392,
         1392,
         1331,
         1393,
         2422,
         1353,
         1331,
         2423,
         2424,
         1331,
         1331,
         2425,
         2426,
         2427,
         2428,
         1331,
         1331,
         1331,
         1331,
         1331,
         1353,
         1331,
         1331,
         1353,
         1331,
         1331,
         1353,
         1331,
         1331,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1394,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1332,
         1343,
         1332,
         1332,
         1332,
         1332,
         1332,
         1349,
         1349,
         1354,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1332,
         1388,
         1332,
         1391,
         1332,
         1393,
         1394,
         1394,
         2429,
         1354,
         1332,
         2430,
         2431,
         1332,
         1332,
         2432,
         2433,
         2434,
         2435,
         1332,
         1332,
         1332,
         1332,
         1332,
         1354,
         1332,
         1332,
         1354,
         1332,
         1332,
         1354,
         1332,
         1332,
         2374,
         2381,
         2374,
         2374,
         2374,
         2374,
         2374,
         2391,
         2391,
         2398,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2374,
         2408,
         2374,
         2415,
         2374,
         2422,
         2374,
         2429,
         2398,
         2398,
         2374,
         2436,
         2437,
         2374,
         2374,
         2438,
         2439,
         2440,
         2441,
         2374,
         2374,
         2374,
         2374,
         2374,
         2398,
         2374,
         2374,
         2398,
         2374,
         2374,
         2398,
         2374,
         2374,
         1328,
         2382,
         1328,
         1328,
         1328,
         1328,
         1328,
         1345,
         1345,
         1350,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1351,
         1328,
         1352,
         1328,
         1353,
         1328,
         1354,
         2398,
         1350,
         1328,
         2399,
         2400,
         1328,
         1328,
         2401,
         2402,
         2403,
         2404,
         1328,
         1328,
         1328,
         1328,
         1328,
         1350,
         1328,
         1328,
         1350,
         1328,
         1328,
         1350,
         1328,
         1328,
         36,
         2383,
         36,
         36,
         36,
         36,
         2390,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         2442,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         2375,
         2384,
         2375,
         2375,
         2375,
         2375,
         2375,
         2392,
         2392,
         2399,
         2375,
         2375,
         2375,
         2375,
         2375,
         2405,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2375,
         2409,
         2375,
         2416,
         2375,
         2423,
         2375,
         2430,
         2436,
         2399,
         2375,
         2405,
         2443,
         2375,
         2375,
         2444,
         2445,
         2446,
         2447,
         2375,
         2375,
         2405,
         2405,
         2405,
         2399,
         2375,
         2375,
         2399,
         2375,
         2375,
         2399,
         2375,
         2375,
         2376,
         2385,
         2376,
         2376,
         2376,
         2376,
         2376,
         2393,
         2393,
         2400,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2406,
         2407,
         2407,
         2376,
         2410,
         2376,
         2417,
         2376,
         2424,
         2376,
         2431,
         2437,
         2400,
         2376,
         2443,
         2406,
         2406,
         2406,
         2448,
         2449,
         2450,
         2451,
         2376,
         2376,
         2376,
         2376,
         2376,
         2400,
         2376,
         2376,
         2400,
         2376,
         2376,
         2400,
         2376,
         2376,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1383,
         1382,
         1382,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2406,
         1383,
         2452,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1383,
         1382,
         1382,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2406,
         2452,
         1383,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         36,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         2377,
         2386,
         2377,
         2377,
         2377,
         2377,
         2377,
         2394,
         2394,
         2401,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2411,
         2377,
         2418,
         2377,
         2425,
         2377,
         2432,
         2438,
         2401,
         2377,
         2444,
         2448,
         2377,
         2377,
         2377,
         2453,
         2454,
         2455,
         2377,
         2377,
         2377,
         2377,
         2377,
         2401,
         2377,
         2377,
         2401,
         2377,
         2377,
         2401,
         2377,
         2377,
         2378,
         2387,
         2378,
         2378,
         2378,
         2378,
         2378,
         2395,
         2395,
         2402,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2412,
         2378,
         2419,
         2378,
         2426,
         2378,
         2433,
         2439,
         2402,
         2378,
         2445,
         2449,
         2378,
         2378,
         2453,
         2378,
         2456,
         2457,
         2378,
         2378,
         2378,
         2378,
         2378,
         2402,
         2378,
         2378,
         2402,
         2378,
         2378,
         2402,
         2378,
         2378,
         2379,
         2388,
         2379,
         2379,
         2379,
         2379,
         2379,
         2396,
         2396,
         2403,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2413,
         2379,
         2420,
         2379,
         2427,
         2379,
         2434,
         2440,
         2403,
         2379,
         2446,
         2450,
         2379,
         2379,
         2454,
         2456,
         2379,
         2458,
         2379,
         2379,
         2379,
         2379,
         2379,
         2403,
         2379,
         2379,
         2403,
         2379,
         2379,
         2403,
         2379,
         2379,
         2380,
         2389,
         2380,
         2380,
         2380,
         2380,
         2380,
         2397,
         2397,
         2404,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2380,
         2414,
         2380,
         2421,
         2380,
         2428,
         2380,
         2435,
         2441,
         2404,
         2380,
         2447,
         2451,
         2380,
         2380,
         2455,
         2457,
         2458,
         2459,
         2380,
         2380,
         2380,
         2380,
         2380,
         2404,
         2380,
         2380,
         2404,
         2380,
         2380,
         2404,
         2380,
         2380,
         36,
         2893,
         36,
         1344,
         1344,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         1344,
         36,
         36,
         36,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         36,
         2894,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         1356,
         1356,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         1356,
         36,
         36,
         36,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         1358,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         2995,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2405,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         1358,
         1358,
         1358,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         1358,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         2996,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2405,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         1358,
         1358,
         1358,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         1358,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         2997,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2405,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         36,
         1358,
         1358,
         1358,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         36,
         36,
         1328,
         3016,
         1328,
         1328,
         1328,
         1328,
         1328,
         1345,
         1345,
         1350,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1351,
         1328,
         1352,
         1328,
         1353,
         1328,
         1354,
         2398,
         1350,
         1328,
         2399,
         2400,
         1328,
         1328,
         2401,
         2402,
         2403,
         2404,
         1328,
         1328,
         1328,
         1328,
         1328,
         1350,
         1328,
         1328,
         1350,
         1328,
         1328,
         1350,
         1328,
         1328,
         36,
         3018,
         36,
         1344,
         1344,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         1344,
         36,
         36,
         36,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         36,
         3019,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         1356,
         1356,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         1356,
         36,
         36,
         36,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
         1328,
         3026,
         1328,
         1328,
         1328,
         1328,
         1328,
         1345,
         1345,
         1350,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1351,
         1328,
         1352,
         1328,
         1353,
         1328,
         1354,
         2398,
         1350,
         1328,
         2399,
         2400,
         1328,
         1328,
         2401,
         2402,
         2403,
         2404,
         1328,
         1328,
         1328,
         1328,
         1328,
         1350,
         1328,
         1328,
         1350,
         1328,
         1328,
         1350,
         1328,
         1328,
         36,
         3027,
         36,
         1344,
         1344,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         1344,
         36,
         36,
         36,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         36,
         3028,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         1356,
         1356,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         1356,
         36,
         36,
         36,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
         1328,
         3035,
         1328,
         1328,
         1328,
         1328,
         1328,
         1345,
         1345,
         1350,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1328,
         1351,
         1328,
         1352,
         1328,
         1353,
         1328,
         1354,
         2398,
         1350,
         1328,
         2399,
         2400,
         1328,
         1328,
         2401,
         2402,
         2403,
         2404,
         1328,
         1328,
         1328,
         1328,
         1328,
         1350,
         1328,
         1328,
         1350,
         1328,
         1328,
         1350,
         1328,
         1328,
         36,
         3036,
         36,
         1344,
         1344,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         1344,
         36,
         36,
         36,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         1328,
         1344,
         36,
         36,
         3037,
         36,
         36,
         36,
         36,
         36,
         1327,
         1327,
         1328,
         36,
         1356,
         1356,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         1329,
         36,
         1330,
         36,
         1331,
         36,
         1332,
         2374,
         1328,
         36,
         2375,
         2376,
         36,
         36,
         2377,
         2378,
         2379,
         2380,
         36,
         1356,
         36,
         36,
         36,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
         1328,
         36,
         1356,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         9,
         10,
         11,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         21,
         22,
         22,
         23,
         23,
         23,
         23,
         24,
         24,
         24,
         24,
         25,
         25,
         25,
         25,
         26,
         27,
         0,
         28,
         0,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         31,
         0,
         0,
         0,
         0,
         32,
         0,
         0,
         33,
         34,
         35,
         36,
         37,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         42,
         2,
         42,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         42,
         2,
         3,
         2,
         42,
         43,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         45,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         46,
         8,
         46,
         8,
         9,
         8,
         46,
         9,
         9,
         10,
         10,
         11,
         10,
         11,
         10,
         11,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         14,
         13,
         14,
         13,
         14,
         13,
         13,
         13,
         14,
         14,
         13,
         14,
         13,
         13,
         13,
         14,
         13,
         14,
         13,
         13,
         13,
         13,
         17,
         17,
         17,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         18,
         17,
         18,
         17,
         18,
         17,
         17,
         17,
         18,
         18,
         18,
         17,
         18,
         17,
         17,
         17,
         18,
         17,
         18,
         17,
         17,
         17,
         17,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         47,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         0,
         0,
         0,
         0,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         26,
         26,
         26,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         48,
         49,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         50,
         51,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         54,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         38,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         55,
         55,
         55,
         55,
         3,
         3,
         3,
         3,
         3,
         56,
         56,
         56,
         9,
         9,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         57,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         12,
         12,
         12,
         12,
         12,
         12,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         15,
         14,
         14,
         14,
         14,
         14,
         19,
         18,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         24,
         25,
         28,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         51,
         51,
         49,
         47,
         5,
         5,
         5,
         58,
         5,
         5,
         59,
         60,
         32,
         32,
         32,
         12,
         12,
         12,
         61,
         62,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         21,
         22,
         0,
         0,
         14,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         4,
         4,
         4,
         0,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         9,
         4,
         0,
         63,
         64,
         65,
         66,
         5,
         5,
         3,
         9,
         4,
         67,
         68,
         69,
         70,
         5,
         5,
         3,
         9,
         4,
         71,
         72,
         73,
         74,
         5,
         5,
      },
      
      .num_filtered_states = 75,
      .table = (const uint16_t []) {
      
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         39,
         39,
         39,
         39,
         1404,
         1405,
         1406,
         39,
         39,
         39,
         39,
         39,
         1407,
         1408,
         1408,
         1408,
         1408,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         1409,
         39,
         39,
         1410,
         39,
         39,
         1411,
         39,
         1412,
         39,
         1413,
         39,
         39,
         39,
         39,
         39,
         1405,
         1406,
         39,
         39,
         2312,
         2313,
         2314,
         2315,
         39,
         39,
         39,
         39,
         39,
         1405,
         1405,
         1404,
         1404,
         39,
         39,
         1404,
         1404,
         39,
         39,
         1404,
         1404,
         39,
         39,
         1404,
         1404,
         39,
         39,
         38,
         39,
         38,
         1414,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         1414,
         1396,
         1396,
         2316,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         2887,
         1396,
         1396,
         1395,
         1395,
         1414,
         38,
         1395,
         1395,
         1414,
         38,
         1395,
         1395,
         1414,
         38,
         1395,
         1395,
         1414,
         38,
         38,
         39,
         1414,
         1414,
         1395,
         1396,
         1396,
         38,
         38,
         1415,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         1414,
         1414,
         1396,
         1396,
         2316,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         1414,
         2887,
         1396,
         1396,
         1395,
         1395,
         1414,
         1415,
         1395,
         1395,
         1414,
         1415,
         1395,
         1395,
         1414,
         1415,
         1395,
         1395,
         1414,
         1415,
         1395,
         1404,
         1395,
         1395,
         1416,
         1417,
         1417,
         1395,
         1395,
         1395,
         1395,
         1395,
         1418,
         1419,
         1419,
         1419,
         1419,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1420,
         1395,
         1395,
         1421,
         1395,
         1395,
         1422,
         1395,
         1423,
         1395,
         1424,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1395,
         1395,
         2317,
         2318,
         2319,
         2320,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1396,
         1405,
         1396,
         1396,
         1417,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1425,
         1426,
         1426,
         1426,
         1426,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1427,
         1396,
         1396,
         1428,
         1396,
         1396,
         1429,
         1396,
         1430,
         1396,
         1431,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         2321,
         2322,
         2323,
         2324,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1396,
         1406,
         1396,
         1396,
         1417,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1425,
         1426,
         1426,
         1426,
         1426,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1427,
         1396,
         1396,
         1428,
         1396,
         1396,
         1429,
         1396,
         1430,
         1396,
         1431,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         2321,
         2322,
         2323,
         2324,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         1432,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         1433,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         2325,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         2888,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         1433,
         1395,
         1395,
         38,
         1433,
         1395,
         1395,
         38,
         1433,
         1395,
         1395,
         38,
         1433,
         38,
         39,
         38,
         1415,
         1395,
         1396,
         1396,
         38,
         1433,
         1433,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         2325,
         1415,
         1396,
         1396,
         1433,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         2888,
         1433,
         1396,
         1396,
         1395,
         1395,
         1415,
         1433,
         1395,
         1395,
         1415,
         1433,
         1395,
         1395,
         1415,
         1433,
         1395,
         1395,
         1415,
         1433,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         1434,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         1434,
         1434,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1397,
         1407,
         1397,
         1397,
         1418,
         1425,
         1425,
         1397,
         1397,
         1397,
         1397,
         1397,
         1435,
         1436,
         1436,
         1436,
         1436,
         1397,
         1397,
         1397,
         1397,
         1397,
         1397,
         1397,
         1397,
         1397,
         1397,
         1397,
         1437,
         1397,
         1397,
         1438,
         1397,
         1397,
         1439,
         1397,
         1440,
         1397,
         1441,
         1397,
         1397,
         1397,
         1397,
         1397,
         1425,
         1425,
         1397,
         1397,
         2326,
         2327,
         2328,
         2329,
         1397,
         1397,
         1397,
         1397,
         1397,
         1425,
         1425,
         1418,
         1418,
         1397,
         1397,
         1418,
         1418,
         1397,
         1397,
         1418,
         1418,
         1397,
         1397,
         1418,
         1418,
         1397,
         1397,
         1398,
         1408,
         1398,
         1398,
         1419,
         1426,
         1426,
         1398,
         1398,
         1398,
         1398,
         1398,
         1436,
         1442,
         1442,
         1442,
         1442,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1443,
         1398,
         1398,
         1444,
         1398,
         1398,
         1445,
         1398,
         1446,
         1398,
         1447,
         1398,
         1398,
         1398,
         1398,
         1398,
         2330,
         2330,
         1398,
         1398,
         2331,
         2332,
         2333,
         2334,
         1398,
         1398,
         1398,
         1398,
         1398,
         1426,
         1426,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         1398,
         1408,
         1398,
         1398,
         1419,
         1426,
         1426,
         1398,
         1398,
         1398,
         1398,
         1398,
         1436,
         1442,
         1448,
         1449,
         1450,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1443,
         1398,
         1398,
         1444,
         1398,
         1398,
         1445,
         1398,
         1446,
         1398,
         1447,
         1398,
         1398,
         1398,
         1398,
         1398,
         2330,
         2330,
         1398,
         1398,
         2331,
         2332,
         2333,
         2334,
         1398,
         1398,
         1398,
         1398,
         1398,
         1426,
         1426,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         1398,
         1408,
         1398,
         1398,
         1419,
         1426,
         1426,
         1398,
         1398,
         1398,
         1398,
         1398,
         1436,
         1442,
         1449,
         1451,
         1452,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1443,
         1398,
         1398,
         1444,
         1398,
         1398,
         1445,
         1398,
         1446,
         1398,
         1447,
         1398,
         1398,
         1398,
         1398,
         1398,
         2330,
         2330,
         1398,
         1398,
         2331,
         2332,
         2333,
         2334,
         1398,
         1398,
         1398,
         1398,
         1398,
         1426,
         1426,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         1398,
         1408,
         1398,
         1398,
         1419,
         1426,
         1426,
         1398,
         1398,
         1398,
         1398,
         1398,
         1436,
         1442,
         1450,
         1452,
         1453,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1398,
         1443,
         1398,
         1398,
         1444,
         1398,
         1398,
         1445,
         1398,
         1446,
         1398,
         1447,
         1398,
         1398,
         1398,
         1398,
         1398,
         2330,
         2330,
         1398,
         1398,
         2331,
         2332,
         2333,
         2334,
         1398,
         1398,
         1398,
         1398,
         1398,
         1426,
         1426,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         1419,
         1419,
         1398,
         1398,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         1454,
         1454,
         1454,
         1454,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         1454,
         1455,
         1456,
         1457,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         1454,
         1456,
         1458,
         1459,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         1454,
         1457,
         1459,
         1460,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         1461,
         1462,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         1462,
         1463,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         1464,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1465,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1466,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1467,
         1467,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1467,
         1467,
         1468,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1399,
         1409,
         1399,
         1399,
         1420,
         1427,
         1427,
         1399,
         1399,
         1399,
         1399,
         1399,
         1437,
         1443,
         1443,
         1443,
         1443,
         1399,
         1399,
         1399,
         1399,
         1399,
         1399,
         1399,
         1399,
         1399,
         1399,
         1468,
         1469,
         1399,
         1399,
         1470,
         1399,
         1399,
         1471,
         1399,
         1472,
         1399,
         1473,
         1399,
         1399,
         1399,
         1399,
         1399,
         1427,
         1427,
         1399,
         1399,
         2335,
         2336,
         2337,
         2338,
         1399,
         1399,
         1399,
         1399,
         1399,
         1427,
         1427,
         1420,
         1420,
         1399,
         1399,
         1420,
         1420,
         1399,
         1399,
         1420,
         1420,
         1399,
         1399,
         1420,
         1420,
         1399,
         1399,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         1474,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1475,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1400,
         1410,
         1400,
         1400,
         1421,
         1428,
         1428,
         1400,
         1400,
         1400,
         1400,
         1400,
         1438,
         1444,
         1444,
         1444,
         1444,
         1400,
         1400,
         1400,
         1400,
         1400,
         1400,
         1400,
         1400,
         1400,
         1400,
         1400,
         1470,
         1400,
         1475,
         1475,
         1400,
         1400,
         1476,
         1400,
         1477,
         1400,
         1478,
         1400,
         1400,
         1400,
         1400,
         1400,
         1428,
         1428,
         1400,
         1400,
         2339,
         2340,
         2341,
         2342,
         1400,
         1400,
         1400,
         1400,
         1400,
         1428,
         1428,
         1421,
         1421,
         1400,
         1400,
         1421,
         1421,
         1400,
         1400,
         1421,
         1421,
         1400,
         1400,
         1421,
         1421,
         1400,
         1400,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         2343,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1479,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1401,
         1411,
         1401,
         1401,
         1422,
         1429,
         1429,
         1401,
         1401,
         1401,
         1401,
         1401,
         1439,
         1445,
         1445,
         1445,
         1445,
         1401,
         1401,
         1401,
         1401,
         1401,
         1401,
         1401,
         1401,
         1401,
         1401,
         1401,
         1471,
         1401,
         1401,
         1476,
         1401,
         1479,
         1479,
         1401,
         1480,
         1401,
         1481,
         1401,
         1401,
         1401,
         1401,
         1401,
         1429,
         1429,
         1401,
         1401,
         2344,
         2345,
         2346,
         2347,
         1401,
         1401,
         1401,
         1401,
         1401,
         1429,
         1429,
         1422,
         1422,
         1401,
         1401,
         1422,
         1422,
         1401,
         1401,
         1422,
         1422,
         1401,
         1401,
         1422,
         1422,
         1401,
         1401,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1482,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1402,
         1412,
         1402,
         1402,
         1423,
         1430,
         1430,
         1402,
         1402,
         1402,
         1402,
         1402,
         1440,
         1446,
         1446,
         1446,
         1446,
         1402,
         1402,
         1402,
         1402,
         1402,
         1402,
         1402,
         1402,
         1402,
         1402,
         1402,
         1472,
         1402,
         1402,
         1477,
         1402,
         1402,
         1480,
         1482,
         1482,
         1402,
         1483,
         1402,
         1402,
         1402,
         1402,
         1402,
         1430,
         1430,
         1402,
         1402,
         2348,
         2349,
         2350,
         2351,
         1402,
         1402,
         1402,
         1402,
         1402,
         1430,
         1430,
         1423,
         1423,
         1402,
         1402,
         1423,
         1423,
         1402,
         1402,
         1423,
         1423,
         1402,
         1402,
         1423,
         1423,
         1402,
         1402,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1484,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1403,
         1413,
         1403,
         1403,
         1424,
         1431,
         1431,
         1403,
         1403,
         1403,
         1403,
         1403,
         1441,
         1447,
         1447,
         1447,
         1447,
         1403,
         1403,
         1403,
         1403,
         1403,
         1403,
         1403,
         1403,
         1403,
         1403,
         1403,
         1473,
         1403,
         1403,
         1478,
         1403,
         1403,
         1481,
         1403,
         1483,
         1484,
         1484,
         1403,
         1403,
         1403,
         1403,
         1403,
         1431,
         1431,
         1403,
         1403,
         2352,
         2353,
         2354,
         2355,
         1403,
         1403,
         1403,
         1403,
         1403,
         1431,
         1431,
         1424,
         1424,
         1403,
         1403,
         1424,
         1424,
         1403,
         1403,
         1424,
         1424,
         1403,
         1403,
         1424,
         1424,
         1403,
         1403,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         1485,
         1485,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         1485,
         38,
         1485,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         1485,
         1485,
         1485,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         1414,
         1395,
         1396,
         1396,
         38,
         2325,
         2325,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         1414,
         1396,
         1396,
         2356,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         2889,
         1396,
         1396,
         1395,
         1395,
         1414,
         2325,
         1395,
         1395,
         1414,
         2325,
         1395,
         1395,
         1414,
         2325,
         1395,
         1395,
         1414,
         2325,
         38,
         39,
         1414,
         1414,
         1395,
         1396,
         1396,
         38,
         38,
         1415,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         2343,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         1414,
         1414,
         1396,
         1396,
         2316,
         38,
         2308,
         2309,
         2357,
         2358,
         38,
         38,
         38,
         1414,
         2887,
         2890,
         2992,
         1395,
         1395,
         1414,
         1415,
         1395,
         1395,
         1414,
         1415,
         1395,
         1395,
         1414,
         1415,
         1395,
         1395,
         1414,
         1415,
         1396,
         1405,
         1396,
         1396,
         1417,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1425,
         2330,
         2330,
         2330,
         2330,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1427,
         1396,
         1396,
         1428,
         1396,
         1396,
         1429,
         1396,
         1430,
         1396,
         1431,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         2321,
         2322,
         2323,
         2324,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1396,
         1406,
         1396,
         1396,
         1417,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1425,
         2330,
         2330,
         2330,
         2330,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1427,
         1396,
         1396,
         1428,
         1396,
         1396,
         1429,
         1396,
         1430,
         1396,
         1431,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         2321,
         2322,
         2323,
         2324,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         38,
         39,
         2316,
         2316,
         1395,
         1396,
         1396,
         38,
         38,
         1433,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         2356,
         2316,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         2891,
         38,
         1396,
         1396,
         1395,
         1395,
         2316,
         1433,
         1395,
         1395,
         2316,
         1433,
         1395,
         1395,
         2316,
         1433,
         1395,
         1395,
         2316,
         1433,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         2359,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         2308,
         2312,
         2308,
         2308,
         2317,
         2321,
         2321,
         2308,
         2308,
         2308,
         2308,
         2308,
         2326,
         2331,
         2331,
         2331,
         2331,
         2308,
         2308,
         2308,
         2308,
         2308,
         2308,
         2308,
         2308,
         2308,
         2308,
         2308,
         2335,
         2308,
         2308,
         2339,
         2308,
         2308,
         2344,
         2308,
         2348,
         2308,
         2352,
         2308,
         2308,
         2308,
         2308,
         2308,
         2321,
         2321,
         2308,
         2308,
         2308,
         2360,
         2361,
         2362,
         2308,
         2308,
         2308,
         2308,
         2308,
         2321,
         2321,
         2317,
         2317,
         2308,
         2308,
         2317,
         2317,
         2308,
         2308,
         2317,
         2317,
         2308,
         2308,
         2317,
         2317,
         2308,
         2308,
         2309,
         2313,
         2309,
         2309,
         2318,
         2322,
         2322,
         2309,
         2309,
         2309,
         2309,
         2309,
         2327,
         2332,
         2332,
         2332,
         2332,
         2309,
         2309,
         2309,
         2309,
         2309,
         2309,
         2309,
         2309,
         2309,
         2309,
         2309,
         2336,
         2309,
         2309,
         2340,
         2309,
         2309,
         2345,
         2309,
         2349,
         2309,
         2353,
         2309,
         2309,
         2309,
         2309,
         2309,
         2322,
         2322,
         2309,
         2309,
         2360,
         2309,
         2363,
         2364,
         2309,
         2309,
         2309,
         2309,
         2309,
         2322,
         2322,
         2318,
         2318,
         2309,
         2309,
         2318,
         2318,
         2309,
         2309,
         2318,
         2318,
         2309,
         2309,
         2318,
         2318,
         2309,
         2309,
         2310,
         2314,
         2310,
         2310,
         2319,
         2323,
         2323,
         2310,
         2310,
         2310,
         2310,
         2310,
         2328,
         2333,
         2333,
         2333,
         2333,
         2310,
         2310,
         2310,
         2310,
         2310,
         2310,
         2310,
         2310,
         2310,
         2310,
         2310,
         2337,
         2310,
         2310,
         2341,
         2310,
         2310,
         2346,
         2310,
         2350,
         2310,
         2354,
         2310,
         2310,
         2310,
         2310,
         2357,
         2323,
         2323,
         2310,
         2310,
         2361,
         2363,
         2310,
         2365,
         2310,
         2310,
         2310,
         2310,
         2310,
         2323,
         2323,
         2319,
         2319,
         2310,
         2310,
         2319,
         2319,
         2310,
         2310,
         2319,
         2319,
         2310,
         2310,
         2319,
         2319,
         2310,
         2310,
         2311,
         2315,
         2311,
         2311,
         2320,
         2324,
         2324,
         2311,
         2311,
         2311,
         2311,
         2311,
         2329,
         2334,
         2334,
         2334,
         2334,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2311,
         2338,
         2311,
         2311,
         2342,
         2311,
         2311,
         2347,
         2311,
         2351,
         2311,
         2355,
         2311,
         2311,
         2311,
         2311,
         2358,
         2324,
         2324,
         2311,
         2311,
         2362,
         2364,
         2365,
         2366,
         2311,
         2311,
         2311,
         2311,
         2311,
         2324,
         2324,
         2320,
         2320,
         2311,
         2311,
         2320,
         2320,
         2311,
         2311,
         2320,
         2320,
         2311,
         2311,
         2320,
         2320,
         2311,
         2311,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         2367,
         2367,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         2367,
         38,
         2367,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         38,
         1395,
         1396,
         1396,
         38,
         38,
         38,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         38,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         2367,
         2367,
         2367,
         38,
         38,
         1396,
         1396,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         1395,
         1395,
         38,
         38,
         38,
         39,
         38,
         1414,
         1395,
         1396,
         1396,
         38,
         2888,
         2888,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         38,
         1414,
         1396,
         1396,
         2891,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         38,
         2892,
         1396,
         1396,
         1395,
         1395,
         1414,
         2888,
         1395,
         1395,
         1414,
         2888,
         1395,
         1395,
         1414,
         2888,
         1395,
         1395,
         1414,
         2888,
         38,
         39,
         2887,
         2887,
         1395,
         1396,
         1396,
         38,
         38,
         1433,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         2889,
         2887,
         1396,
         1396,
         38,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         2892,
         38,
         1396,
         1396,
         1395,
         1395,
         2887,
         1433,
         1395,
         1395,
         2887,
         1433,
         1395,
         1395,
         2887,
         1433,
         1395,
         1395,
         2887,
         1433,
         1396,
         1405,
         1396,
         1396,
         1417,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1425,
         1426,
         1426,
         1426,
         1426,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1427,
         1396,
         1396,
         1428,
         1396,
         1396,
         1429,
         1396,
         1430,
         1396,
         1431,
         1396,
         1396,
         1396,
         1396,
         2890,
         1396,
         1396,
         1396,
         1396,
         2321,
         2322,
         2323,
         2324,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1396,
         1405,
         1396,
         1396,
         1417,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1425,
         1426,
         1426,
         1426,
         1426,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1427,
         1396,
         1396,
         1428,
         1396,
         1396,
         1429,
         1396,
         1430,
         1396,
         1431,
         1396,
         1396,
         1396,
         1396,
         2992,
         1396,
         1396,
         1396,
         1396,
         2321,
         2322,
         2323,
         2324,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1417,
         1417,
         1396,
         1396,
         1395,
         1404,
         1395,
         1395,
         1416,
         1417,
         1417,
         1395,
         1395,
         1395,
         1395,
         1395,
         1418,
         1419,
         1419,
         1419,
         1419,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1420,
         1395,
         1395,
         1421,
         1395,
         1395,
         1422,
         1395,
         1423,
         1395,
         1424,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1395,
         1395,
         2317,
         2318,
         2319,
         2320,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1416,
         2993,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1395,
         1404,
         1395,
         1395,
         1416,
         1417,
         1417,
         1395,
         1395,
         1395,
         1395,
         1395,
         1418,
         1419,
         1419,
         1419,
         1419,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1420,
         1395,
         1395,
         1421,
         1395,
         1395,
         1422,
         1395,
         1423,
         1395,
         1424,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1395,
         1395,
         2317,
         2318,
         2319,
         2320,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         2993,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         38,
         39,
         1414,
         1414,
         1395,
         1396,
         1396,
         38,
         38,
         1415,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         1414,
         1414,
         1396,
         1396,
         2316,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         1414,
         2887,
         1396,
         1396,
         1395,
         1395,
         1414,
         2994,
         1395,
         1395,
         1414,
         2994,
         1395,
         1395,
         1414,
         2994,
         1395,
         1395,
         1414,
         2994,
         38,
         39,
         38,
         1415,
         1395,
         1396,
         1396,
         38,
         1433,
         1433,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         2325,
         1415,
         1396,
         1396,
         1433,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         2888,
         1433,
         1396,
         1396,
         1395,
         1395,
         2994,
         1433,
         1395,
         1395,
         2994,
         1433,
         1395,
         1395,
         2994,
         1433,
         1395,
         1395,
         2994,
         1433,
         1395,
         1404,
         1395,
         1395,
         1416,
         1417,
         1417,
         1395,
         1395,
         1395,
         1395,
         1395,
         1418,
         1419,
         1419,
         1419,
         1419,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1420,
         1395,
         1395,
         1421,
         1395,
         1395,
         1422,
         1395,
         1423,
         1395,
         1424,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1395,
         1395,
         2317,
         2318,
         2319,
         2320,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1416,
         1416,
         1395,
         1395,
         1416,
         3022,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1395,
         1404,
         1395,
         1395,
         1416,
         1417,
         1417,
         1395,
         1395,
         1395,
         1395,
         1395,
         1418,
         1419,
         1419,
         1419,
         1419,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1420,
         1395,
         1395,
         1421,
         1395,
         1395,
         1422,
         1395,
         1423,
         1395,
         1424,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1395,
         1395,
         2317,
         2318,
         2319,
         2320,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1416,
         1416,
         1395,
         1395,
         3022,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         38,
         39,
         1414,
         1414,
         1395,
         1396,
         1396,
         38,
         38,
         1415,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         1414,
         1414,
         1396,
         1396,
         2316,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         1414,
         2887,
         1396,
         1396,
         1395,
         1395,
         1414,
         2994,
         1395,
         1395,
         1414,
         3023,
         1395,
         1395,
         1414,
         3023,
         1395,
         1395,
         1414,
         3023,
         38,
         39,
         38,
         1415,
         1395,
         1396,
         1396,
         38,
         1433,
         1433,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         2325,
         1415,
         1396,
         1396,
         1433,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         2888,
         1433,
         1396,
         1396,
         1395,
         1395,
         2994,
         1433,
         1395,
         1395,
         3023,
         1433,
         1395,
         1395,
         3023,
         1433,
         1395,
         1395,
         3023,
         1433,
         1395,
         1404,
         1395,
         1395,
         1416,
         1417,
         1417,
         1395,
         1395,
         1395,
         1395,
         1395,
         1418,
         1419,
         1419,
         1419,
         1419,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1420,
         1395,
         1395,
         1421,
         1395,
         1395,
         1422,
         1395,
         1423,
         1395,
         1424,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1395,
         1395,
         2317,
         2318,
         2319,
         2320,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         3031,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1395,
         1404,
         1395,
         1395,
         1416,
         1417,
         1417,
         1395,
         1395,
         1395,
         1395,
         1395,
         1418,
         1419,
         1419,
         1419,
         1419,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1420,
         1395,
         1395,
         1421,
         1395,
         1395,
         1422,
         1395,
         1423,
         1395,
         1424,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1395,
         1395,
         2317,
         2318,
         2319,
         2320,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         3031,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         38,
         39,
         1414,
         1414,
         1395,
         1396,
         1396,
         38,
         38,
         1415,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         1414,
         1414,
         1396,
         1396,
         2316,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         1414,
         2887,
         1396,
         1396,
         1395,
         1395,
         1414,
         2994,
         1395,
         1395,
         1414,
         3023,
         1395,
         1395,
         1414,
         3032,
         1395,
         1395,
         1414,
         3032,
         38,
         39,
         38,
         1415,
         1395,
         1396,
         1396,
         38,
         1433,
         1433,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         2325,
         1415,
         1396,
         1396,
         1433,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         2888,
         1433,
         1396,
         1396,
         1395,
         1395,
         2994,
         1433,
         1395,
         1395,
         3023,
         1433,
         1395,
         1395,
         3032,
         1433,
         1395,
         1395,
         3032,
         1433,
         1395,
         1404,
         1395,
         1395,
         1416,
         1417,
         1417,
         1395,
         1395,
         1395,
         1395,
         1395,
         1418,
         1419,
         1419,
         1419,
         1419,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1420,
         1395,
         1395,
         1421,
         1395,
         1395,
         1422,
         1395,
         1423,
         1395,
         1424,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1395,
         1395,
         2317,
         2318,
         2319,
         2320,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         3040,
         1395,
         1395,
         1395,
         1404,
         1395,
         1395,
         1416,
         1417,
         1417,
         1395,
         1395,
         1395,
         1395,
         1395,
         1418,
         1419,
         1419,
         1419,
         1419,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1395,
         1420,
         1395,
         1395,
         1421,
         1395,
         1395,
         1422,
         1395,
         1423,
         1395,
         1424,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1395,
         1395,
         2317,
         2318,
         2319,
         2320,
         1395,
         1395,
         1395,
         1395,
         1395,
         1417,
         1417,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         1416,
         1416,
         1395,
         1395,
         3040,
         1416,
         1395,
         1395,
         38,
         39,
         1414,
         1414,
         1395,
         1396,
         1396,
         38,
         38,
         1415,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         1414,
         1414,
         1396,
         1396,
         2316,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         1414,
         2887,
         1396,
         1396,
         1395,
         1395,
         1414,
         2994,
         1395,
         1395,
         1414,
         3023,
         1395,
         1395,
         1414,
         3032,
         1395,
         1395,
         1414,
         3041,
         38,
         39,
         38,
         1415,
         1395,
         1396,
         1396,
         38,
         1433,
         1433,
         38,
         38,
         1397,
         1398,
         1398,
         1398,
         1398,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         1399,
         38,
         38,
         1400,
         38,
         38,
         1401,
         38,
         1402,
         38,
         1403,
         38,
         38,
         38,
         2325,
         1415,
         1396,
         1396,
         1433,
         38,
         2308,
         2309,
         2310,
         2311,
         38,
         38,
         38,
         2888,
         1433,
         1396,
         1396,
         1395,
         1395,
         2994,
         1433,
         1395,
         1395,
         3023,
         1433,
         1395,
         1395,
         3032,
         1433,
         1395,
         1395,
         3041,
         1433,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         5,
         5,
         6,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         40,
         1640,
         1641,
         1642,
         1643,
         2517,
         2518,
         2519,
         2520,
         2521,
      },
   },
   [nir_op_umul_unorm_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         41,
         41,
         41,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         42,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         43,
         44,
         43,
         43,
         1850,
         45,
         46,
         45,
         45,
         1851,
         1852,
         1853,
         1852,
         1852,
         1854,
         1855,
         1856,
         1855,
         1855,
         1857,
         43,
         44,
         43,
         43,
         1850,
         47,
         48,
         47,
         47,
         1858,
         49,
         50,
         49,
         49,
         1859,
         1860,
         1861,
         1860,
         1860,
         1862,
         1863,
         1864,
         1863,
         1863,
         1865,
         47,
         48,
         47,
         47,
         1858,
         43,
         44,
         43,
         43,
         1850,
         45,
         46,
         45,
         45,
         1851,
         1866,
         1867,
         1866,
         1866,
         1868,
         1855,
         1856,
         1855,
         1855,
         1857,
         43,
         44,
         43,
         43,
         1850,
         43,
         44,
         43,
         43,
         1850,
         45,
         46,
         45,
         45,
         1851,
         1852,
         1853,
         1852,
         1852,
         1854,
         1869,
         1870,
         1869,
         1869,
         1871,
         43,
         44,
         43,
         43,
         1850,
         43,
         44,
         43,
         43,
         1850,
         45,
         46,
         45,
         45,
         1851,
         1852,
         1853,
         1852,
         1852,
         1854,
         1855,
         1856,
         1855,
         1855,
         1857,
         43,
         44,
         43,
         43,
         1850,
      },
   },
   [nir_op_sdot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         51,
         52,
         53,
         54,
         53,
         54,
         55,
         56,
      },
   },
   [nir_op_udot_4x8_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         57,
         58,
         59,
         60,
         59,
         60,
         61,
         62,
      },
   },
   [nir_op_sdot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         63,
         63,
         64,
         64,
         64,
         64,
         65,
         65,
      },
   },
   [nir_op_udot_4x8_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         66,
         67,
         68,
         69,
         68,
         69,
         70,
         71,
      },
   },
   [nir_op_sdot_2x16_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         72,
         73,
         74,
         75,
         74,
         75,
         76,
         77,
      },
   },
   [nir_op_udot_2x16_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         78,
         79,
         80,
         81,
         80,
         81,
         82,
         83,
      },
   },
   [nir_op_sdot_2x16_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         84,
         84,
         85,
         85,
         85,
         85,
         86,
         86,
      },
   },
   [nir_op_udot_2x16_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         87,
         87,
         88,
         88,
         88,
         88,
         89,
         89,
      },
   },
   [nir_op_sudot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         90,
         91,
         92,
         93,
         94,
         95,
         96,
         97,
      },
   },
   [nir_op_sudot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         98,
         98,
         99,
         99,
         100,
         100,
         101,
         101,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         102,
         2038,
         2039,
         2040,
      },
   },
   [nir_op_ftrunc] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         103,
      },
   },
   [nir_op_ffloor] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         104,
      },
   },
   [nir_op_ffract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         105,
      },
   },
   [nir_op_fceil] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         106,
      },
   },
   [nir_search_op_b2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         107,
         2041,
         2042,
         2043,
         2044,
         2849,
         2850,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         108,
      },
   },
   [nir_op_fdot4] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         109,
         2028,
         2029,
         2030,
         2028,
         2028,
         2029,
         2030,
         2029,
         2029,
         2029,
         2030,
         2030,
         2030,
         2030,
         2030,
      },
   },
   [nir_op_vec4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         110,
         111,
         110,
         112,
         110,
         111,
         110,
         113,
         110,
         111,
         110,
         112,
         110,
         111,
         110,
         113,
      },
   },
   [nir_op_fdot3] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         114,
         2031,
         2032,
         2031,
         2031,
         2032,
         2032,
         2032,
         2032,
      },
   },
   [nir_op_vec3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         115,
         116,
         115,
         117,
         115,
         116,
         115,
         117,
      },
   },
   [nir_op_fdot2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         118,
         119,
         2033,
         119,
         119,
         2034,
         2033,
         2034,
         2033,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         120,
         121,
         120,
         120,
         122,
         123,
         122,
         122,
         120,
         121,
         120,
         1534,
         120,
         121,
         120,
         120,
      },
   },
   [nir_op_fsum2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         124,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         10,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         12,
         0,
         3,
         3,
         2,
         4,
         13,
         8,
         2,
         4,
         14,
         3,
         3,
         2,
         4,
         15,
         8,
         2,
         4,
         16,
         3,
         3,
         2,
         4,
         0,
         8,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         125,
         126,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         127,
         128,
         127,
         1510,
         127,
         1511,
         127,
         2290,
         127,
         127,
         1510,
         127,
         1510,
         127,
         1510,
         127,
         1510,
         1512,
         1513,
         1512,
         1514,
         1512,
         1515,
         1512,
         2291,
         1512,
         1512,
         1514,
         1512,
         1514,
         1512,
         1514,
         1512,
         1514,
         125,
         126,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1516,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         126,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1517,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         126,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         2292,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         2293,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         2902,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         3015,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         3021,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         3025,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         3030,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         3034,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         3039,
         125,
         1508,
         125,
         1509,
         125,
         2289,
         125,
         125,
         1508,
         125,
         1508,
         125,
         1508,
         125,
         1508,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         4,
         0,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         129,
         130,
         129,
         129,
         1518,
         129,
         131,
         132,
         131,
         131,
         1519,
         131,
         129,
         1520,
         129,
         129,
         1518,
         129,
         1521,
         1522,
         1521,
         1521,
         1523,
         1521,
         129,
         130,
         129,
         129,
         1518,
         129,
         129,
         1524,
         129,
         129,
         1518,
         129,
      },
   },
   [nir_op_inot] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         3,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         6,
         6,
         7,
         7,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         11,
         11,
         12,
         12,
         13,
         13,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         0,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         22,
         22,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         23,
         21,
         21,
         21,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         12,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         133,
         1836,
         1837,
         1838,
         1839,
         1840,
         1841,
         1842,
         1843,
         1844,
         1845,
         1846,
         1847,
         1848,
         1849,
         2368,
         2369,
         2370,
         2371,
         2372,
         2373,
         2898,
         2899,
         2900,
      },
   },
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         9,
         9,
         10,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         13,
         2,
         14,
         2,
         2,
         2,
         15,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         16,
         5,
         17,
         6,
         6,
         6,
         6,
         6,
         16,
         5,
         5,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         7,
         7,
         7,
         7,
         7,
         16,
         5,
         17,
         17,
         17,
         17,
         17,
         6,
         6,
         16,
         16,
         5,
         16,
         16,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         2,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         20,
         6,
         21,
         16,
         16,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         16,
         16,
         5,
         5,
         5,
         5,
         16,
         9,
         22,
         9,
         9,
         22,
         9,
         9,
         22,
         9,
         22,
         22,
         9,
         22,
         9,
         22,
         9,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 23,
      .table = (const uint16_t []) {
      
         134,
         135,
         1644,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         134,
         1644,
         1644,
         1644,
         134,
         134,
         134,
         1644,
         134,
         134,
         1645,
         136,
         137,
         1647,
         1648,
         1649,
         136,
         136,
         1650,
         1651,
         1652,
         1653,
         1654,
         136,
         1647,
         1647,
         1647,
         136,
         136,
         2462,
         1647,
         136,
         136,
         1652,
         134,
         1655,
         1656,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         134,
         1656,
         1656,
         1656,
         134,
         134,
         134,
         1656,
         134,
         134,
         1645,
         134,
         135,
         1644,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         134,
         1644,
         1644,
         1644,
         134,
         134,
         134,
         1644,
         134,
         134,
         1645,
         134,
         1657,
         1644,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         134,
         1644,
         1644,
         1644,
         134,
         134,
         134,
         1644,
         134,
         134,
         1645,
         1658,
         1659,
         1660,
         1658,
         1658,
         1658,
         1658,
         1658,
         1658,
         1661,
         1658,
         1662,
         1658,
         1660,
         1660,
         1660,
         1658,
         1658,
         1658,
         1660,
         1658,
         1658,
         1661,
         1658,
         1663,
         1660,
         1658,
         1658,
         1658,
         1658,
         1658,
         1658,
         1661,
         1658,
         1662,
         1658,
         1660,
         1660,
         1660,
         1658,
         1658,
         1658,
         1660,
         1658,
         1658,
         1661,
         134,
         135,
         1644,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         134,
         1644,
         1644,
         1644,
         134,
         134,
         134,
         1644,
         134,
         134,
         1645,
         134,
         1664,
         1644,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         134,
         1644,
         1644,
         1644,
         134,
         134,
         134,
         1644,
         134,
         134,
         1645,
         1665,
         1666,
         1667,
         1665,
         1665,
         1665,
         1665,
         1665,
         1665,
         1668,
         1665,
         1669,
         1665,
         1667,
         1667,
         1667,
         1665,
         1665,
         1665,
         1667,
         1665,
         1665,
         1668,
         134,
         1670,
         1644,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         134,
         1644,
         1644,
         1644,
         134,
         134,
         134,
         1644,
         134,
         134,
         1645,
         1671,
         1672,
         1673,
         1671,
         1671,
         1671,
         1671,
         1671,
         1671,
         1674,
         1671,
         1675,
         1671,
         1673,
         1673,
         1673,
         1671,
         1671,
         1671,
         1673,
         1671,
         1671,
         1674,
         134,
         135,
         1644,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         1676,
         1644,
         1644,
         1644,
         134,
         134,
         134,
         1644,
         134,
         134,
         1645,
         134,
         2463,
         1656,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         134,
         1656,
         1656,
         1656,
         134,
         134,
         134,
         1656,
         134,
         134,
         1645,
         134,
         2464,
         1656,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         134,
         1656,
         1656,
         1656,
         134,
         134,
         134,
         1656,
         134,
         134,
         1645,
         134,
         2465,
         1656,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         134,
         1656,
         1656,
         1656,
         134,
         134,
         134,
         1656,
         134,
         134,
         1645,
         1658,
         2466,
         1660,
         1658,
         1658,
         1658,
         1658,
         1658,
         1658,
         1661,
         1658,
         1662,
         1658,
         1660,
         1660,
         1660,
         1658,
         1658,
         1658,
         1660,
         1658,
         1658,
         1661,
         1658,
         2467,
         1660,
         1658,
         1658,
         1658,
         1658,
         1658,
         1658,
         1661,
         1658,
         1662,
         1658,
         1660,
         1660,
         1660,
         1658,
         1658,
         1658,
         1660,
         1658,
         1658,
         1661,
         1658,
         1659,
         1660,
         1658,
         1658,
         1658,
         1658,
         1658,
         1658,
         1661,
         1658,
         1662,
         1658,
         1660,
         1660,
         1660,
         1658,
         1658,
         1658,
         1660,
         1658,
         1658,
         1661,
         134,
         2977,
         1656,
         134,
         134,
         134,
         134,
         134,
         134,
         1645,
         134,
         1646,
         134,
         1656,
         1656,
         1656,
         134,
         134,
         134,
         1656,
         134,
         134,
         1645,
         1658,
         2999,
         1660,
         1658,
         1658,
         1658,
         1658,
         1658,
         1658,
         1661,
         1658,
         1662,
         1658,
         1660,
         1660,
         1660,
         1658,
         1658,
         1658,
         1660,
         1658,
         1658,
         1661,
         1658,
         3000,
         1660,
         1658,
         1658,
         1658,
         1658,
         1658,
         1658,
         1661,
         1658,
         1662,
         1658,
         1660,
         1660,
         1660,
         1658,
         1658,
         1658,
         1660,
         1658,
         1658,
         1661,
         1665,
         3001,
         1667,
         1665,
         1665,
         1665,
         1665,
         1665,
         1665,
         1668,
         1665,
         1669,
         1665,
         1667,
         1667,
         1667,
         1665,
         1665,
         1665,
         1667,
         1665,
         1665,
         1668,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         10,
         10,
         11,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         14,
         2,
         15,
         2,
         2,
         2,
         16,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         7,
         7,
         7,
         7,
         7,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         2,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         138,
         139,
         1677,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1677,
         1677,
         1677,
         138,
         1677,
         140,
         141,
         1680,
         1681,
         1682,
         140,
         140,
         140,
         1683,
         1684,
         1685,
         1686,
         1687,
         140,
         1680,
         1680,
         1680,
         2468,
         1680,
         138,
         1688,
         1689,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1689,
         1689,
         1689,
         138,
         1689,
         138,
         139,
         1677,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1677,
         1677,
         1677,
         138,
         1677,
         138,
         1690,
         1677,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1677,
         1677,
         1677,
         138,
         1677,
         1691,
         1692,
         1693,
         1691,
         1691,
         1691,
         1691,
         1691,
         1691,
         1691,
         1694,
         1691,
         1695,
         1691,
         1693,
         1693,
         1693,
         1691,
         1693,
         1691,
         1696,
         1693,
         1691,
         1691,
         1691,
         1691,
         1691,
         1691,
         1691,
         1694,
         1691,
         1695,
         1691,
         1693,
         1693,
         1693,
         1691,
         1693,
         138,
         1697,
         1677,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1677,
         1677,
         1677,
         138,
         1677,
         138,
         139,
         1677,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1677,
         1677,
         1677,
         138,
         1677,
         138,
         1698,
         1677,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1677,
         1677,
         1677,
         138,
         1677,
         1699,
         1700,
         1701,
         1699,
         1699,
         1699,
         1699,
         1699,
         1699,
         1699,
         1702,
         1699,
         1703,
         1699,
         1701,
         1701,
         1701,
         1699,
         1701,
         138,
         1704,
         1677,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1677,
         1677,
         1677,
         138,
         1677,
         1705,
         1706,
         1707,
         1705,
         1705,
         1705,
         1705,
         1705,
         1705,
         1705,
         1708,
         1705,
         1709,
         1705,
         1707,
         1707,
         1707,
         1705,
         1707,
         138,
         139,
         1677,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         1710,
         1677,
         1677,
         1677,
         138,
         1677,
         138,
         2469,
         1689,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1689,
         1689,
         1689,
         138,
         1689,
         138,
         2470,
         1689,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1689,
         1689,
         1689,
         138,
         1689,
         138,
         2471,
         1689,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1689,
         1689,
         1689,
         138,
         1689,
         1691,
         1692,
         1693,
         1691,
         1691,
         1691,
         1691,
         1691,
         1691,
         1691,
         1694,
         1691,
         1695,
         1691,
         1693,
         1693,
         1693,
         1691,
         1693,
         138,
         2978,
         1689,
         138,
         138,
         138,
         138,
         138,
         138,
         138,
         1678,
         138,
         1679,
         138,
         1689,
         1689,
         1689,
         138,
         1689,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         13,
         2,
         2,
         2,
         14,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         17,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         142,
         143,
         1711,
         142,
         1712,
         1712,
         142,
         142,
         142,
         142,
         142,
         142,
         142,
         1711,
         1711,
         1712,
         142,
         1712,
         143,
         143,
         1713,
         1714,
         1715,
         1716,
         1717,
         1718,
         1719,
         1720,
         143,
         2294,
         2295,
         2296,
         1713,
         2297,
         2298,
         2973,
         1711,
         1713,
         1721,
         1711,
         1722,
         1722,
         1711,
         1711,
         1711,
         1711,
         1711,
         1711,
         1711,
         1721,
         1721,
         1722,
         1711,
         1722,
         142,
         1714,
         1711,
         142,
         1712,
         1712,
         142,
         142,
         142,
         142,
         142,
         142,
         142,
         1711,
         1711,
         1712,
         142,
         1712,
         1712,
         1715,
         1722,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1722,
         1722,
         1712,
         1712,
         1712,
         1712,
         1716,
         1722,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1722,
         1722,
         1712,
         1712,
         1712,
         142,
         1717,
         1711,
         142,
         1712,
         1712,
         142,
         142,
         142,
         142,
         142,
         142,
         142,
         1711,
         1711,
         1712,
         142,
         1712,
         142,
         1718,
         1711,
         142,
         1712,
         1712,
         142,
         1723,
         142,
         142,
         142,
         142,
         142,
         1711,
         2299,
         1712,
         142,
         1712,
         142,
         1719,
         1711,
         142,
         1712,
         1712,
         142,
         142,
         142,
         142,
         142,
         142,
         142,
         1711,
         1711,
         1712,
         142,
         1712,
         142,
         1720,
         1711,
         142,
         1712,
         1712,
         142,
         142,
         142,
         142,
         142,
         142,
         142,
         1711,
         1711,
         1712,
         142,
         1712,
         142,
         143,
         1711,
         142,
         1712,
         1712,
         142,
         142,
         142,
         142,
         1724,
         142,
         142,
         1711,
         1711,
         1712,
         142,
         1712,
         142,
         2294,
         1711,
         142,
         1712,
         1712,
         142,
         142,
         142,
         142,
         142,
         142,
         142,
         1711,
         1711,
         1712,
         142,
         1712,
         142,
         2295,
         1711,
         142,
         1712,
         1712,
         142,
         142,
         142,
         142,
         142,
         142,
         142,
         1711,
         1711,
         1712,
         142,
         1712,
         1711,
         2296,
         1721,
         1711,
         1722,
         1722,
         1711,
         1711,
         1711,
         1711,
         1711,
         1711,
         1711,
         1721,
         1721,
         1722,
         1711,
         1722,
         1711,
         1713,
         1721,
         1711,
         1722,
         1722,
         1711,
         2299,
         1711,
         1711,
         1711,
         1711,
         1711,
         1721,
         2300,
         1722,
         1711,
         1722,
         1712,
         2297,
         1722,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1722,
         1722,
         1712,
         1712,
         1712,
         142,
         2298,
         1711,
         142,
         1712,
         1712,
         142,
         142,
         142,
         142,
         142,
         142,
         142,
         1711,
         1711,
         1712,
         142,
         1712,
         1712,
         2973,
         1722,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1712,
         1722,
         1722,
         1712,
         1712,
         1712,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         13,
         2,
         2,
         2,
         14,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         17,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         144,
         145,
         1725,
         144,
         1726,
         1726,
         144,
         144,
         144,
         144,
         144,
         144,
         144,
         1725,
         1725,
         1726,
         144,
         1726,
         145,
         145,
         1727,
         1728,
         1729,
         1730,
         1731,
         1732,
         1733,
         1734,
         145,
         2301,
         2302,
         2303,
         1727,
         2304,
         2305,
         2974,
         1725,
         1727,
         1735,
         1725,
         1736,
         1736,
         1725,
         1725,
         1725,
         1725,
         1725,
         1725,
         1725,
         1735,
         1735,
         1736,
         1725,
         1736,
         144,
         1728,
         1725,
         144,
         1726,
         1726,
         144,
         144,
         144,
         144,
         144,
         144,
         144,
         1725,
         1725,
         1726,
         144,
         1726,
         1726,
         1729,
         1736,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1736,
         1736,
         1726,
         1726,
         1726,
         1726,
         1730,
         1736,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1736,
         1736,
         1726,
         1726,
         1726,
         144,
         1731,
         1725,
         144,
         1726,
         1726,
         144,
         144,
         144,
         144,
         144,
         144,
         144,
         1725,
         1725,
         1726,
         144,
         1726,
         144,
         1732,
         1725,
         144,
         1726,
         1726,
         144,
         1737,
         144,
         144,
         144,
         144,
         144,
         1725,
         2306,
         1726,
         144,
         1726,
         144,
         1733,
         1725,
         144,
         1726,
         1726,
         144,
         144,
         144,
         144,
         144,
         144,
         144,
         1725,
         1725,
         1726,
         144,
         1726,
         144,
         1734,
         1725,
         144,
         1726,
         1726,
         144,
         144,
         144,
         144,
         144,
         144,
         144,
         1725,
         1725,
         1726,
         144,
         1726,
         144,
         145,
         1725,
         144,
         1726,
         1726,
         144,
         144,
         144,
         144,
         1738,
         144,
         144,
         1725,
         1725,
         1726,
         144,
         1726,
         144,
         2301,
         1725,
         144,
         1726,
         1726,
         144,
         144,
         144,
         144,
         144,
         144,
         144,
         1725,
         1725,
         1726,
         144,
         1726,
         144,
         2302,
         1725,
         144,
         1726,
         1726,
         144,
         144,
         144,
         144,
         144,
         144,
         144,
         1725,
         1725,
         1726,
         144,
         1726,
         1725,
         2303,
         1735,
         1725,
         1736,
         1736,
         1725,
         1725,
         1725,
         1725,
         1725,
         1725,
         1725,
         1735,
         1735,
         1736,
         1725,
         1736,
         1725,
         1727,
         1735,
         1725,
         1736,
         1736,
         1725,
         2306,
         1725,
         1725,
         1725,
         1725,
         1725,
         1735,
         2307,
         1736,
         1725,
         1736,
         1726,
         2304,
         1736,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1736,
         1736,
         1726,
         1726,
         1726,
         144,
         2305,
         1725,
         144,
         1726,
         1726,
         144,
         144,
         144,
         144,
         144,
         144,
         144,
         1725,
         1725,
         1726,
         144,
         1726,
         1726,
         2974,
         1736,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1726,
         1736,
         1736,
         1726,
         1726,
         1726,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         146,
         147,
         146,
         2065,
         2065,
         2066,
         2066,
         146,
         146,
         148,
         149,
         2067,
         2068,
         2069,
         2070,
         2071,
         2072,
         148,
         146,
         2073,
         146,
         2065,
         2065,
         2066,
         2066,
         146,
         146,
         2074,
         2075,
         2074,
         2076,
         2076,
         2077,
         2077,
         2074,
         2074,
         2074,
         2078,
         2074,
         2076,
         2076,
         2077,
         2077,
         2074,
         2074,
         2079,
         2080,
         2079,
         2081,
         2081,
         2082,
         2082,
         2079,
         2079,
         2079,
         2083,
         2079,
         2081,
         2081,
         2082,
         2082,
         2079,
         2079,
         146,
         2084,
         146,
         2065,
         2065,
         2066,
         2066,
         2085,
         146,
         146,
         2611,
         146,
         2065,
         2065,
         2066,
         2066,
         146,
         146,
      },
   },
   [nir_op_ult] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         10,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         3,
         3,
         3,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         150,
         151,
         1903,
         150,
         150,
         1904,
         1904,
         1905,
         1905,
         150,
         150,
         152,
         153,
         1906,
         152,
         1907,
         1908,
         1909,
         1910,
         1911,
         1912,
         2612,
         150,
         151,
         1903,
         150,
         150,
         1904,
         1904,
         1905,
         1905,
         150,
         150,
         1913,
         1914,
         1915,
         1913,
         1913,
         1916,
         1916,
         1917,
         1917,
         1913,
         1913,
         150,
         1918,
         1903,
         150,
         150,
         1904,
         1904,
         1905,
         1905,
         150,
         150,
         1919,
         1920,
         1921,
         1919,
         1919,
         1922,
         1922,
         1923,
         1923,
         1919,
         1919,
         1919,
         1924,
         1921,
         1919,
         1919,
         1922,
         1922,
         1923,
         1923,
         1919,
         1919,
         1925,
         1926,
         1927,
         1925,
         1925,
         1928,
         1928,
         1929,
         1929,
         1925,
         1925,
         1925,
         1930,
         1927,
         1925,
         1925,
         1928,
         1928,
         1929,
         1929,
         1925,
         1925,
         150,
         1931,
         1903,
         150,
         150,
         1904,
         1904,
         1905,
         1905,
         1932,
         150,
         150,
         151,
         1903,
         150,
         150,
         1904,
         1904,
         1905,
         1905,
         150,
         150,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         154,
         155,
         154,
         2086,
         2086,
         2087,
         2087,
         154,
         154,
         154,
         154,
         154,
         156,
         157,
         2088,
         2089,
         2090,
         2091,
         2092,
         2093,
         156,
         156,
         156,
         156,
         154,
         2094,
         154,
         2086,
         2086,
         2087,
         2087,
         154,
         154,
         154,
         154,
         154,
         2095,
         2096,
         2095,
         2097,
         2097,
         2098,
         2098,
         2095,
         2095,
         2095,
         2095,
         2095,
         2095,
         2099,
         2095,
         2097,
         2097,
         2098,
         2098,
         2095,
         2095,
         2095,
         2095,
         2095,
         2100,
         2101,
         2100,
         2102,
         2102,
         2103,
         2103,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2104,
         2100,
         2102,
         2102,
         2103,
         2103,
         2100,
         2100,
         2100,
         2100,
         2100,
         154,
         2105,
         154,
         2086,
         2086,
         2087,
         2087,
         2106,
         154,
         154,
         154,
         154,
         154,
         2107,
         154,
         2086,
         2086,
         2087,
         2087,
         154,
         154,
         154,
         154,
         154,
         154,
         2108,
         154,
         2086,
         2086,
         2087,
         2087,
         154,
         154,
         154,
         154,
         154,
         154,
         2109,
         154,
         2086,
         2086,
         2087,
         2087,
         154,
         154,
         154,
         154,
         154,
         154,
         2613,
         154,
         2086,
         2086,
         2087,
         2087,
         154,
         154,
         154,
         154,
         154,
      },
   },
   [nir_op_uge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         3,
         3,
         3,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         158,
         158,
         1933,
         158,
         158,
         1934,
         1934,
         1935,
         1935,
         158,
         159,
         159,
         1936,
         159,
         1937,
         1938,
         1939,
         1940,
         1941,
         1942,
         158,
         158,
         1933,
         158,
         158,
         1934,
         1934,
         1935,
         1935,
         158,
         1943,
         1943,
         1944,
         1943,
         1943,
         1945,
         1945,
         1946,
         1946,
         1943,
         158,
         1947,
         1933,
         158,
         158,
         1934,
         1934,
         1935,
         1935,
         158,
         1948,
         1948,
         1949,
         1948,
         1948,
         1950,
         1950,
         1951,
         1951,
         1948,
         1948,
         1952,
         1949,
         1948,
         1948,
         1950,
         1950,
         1951,
         1951,
         1948,
         1953,
         1953,
         1954,
         1953,
         1953,
         1955,
         1955,
         1956,
         1956,
         1953,
         1953,
         1957,
         1954,
         1953,
         1953,
         1955,
         1955,
         1956,
         1956,
         1953,
         158,
         1958,
         1933,
         158,
         158,
         1934,
         1934,
         1935,
         1935,
         1959,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         0,
         13,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         5,
         5,
         0,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         11,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         9,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         3,
         0,
         3,
         3,
         0,
         5,
         0,
         0,
         0,
         5,
         3,
         3,
         3,
         0,
         5,
         0,
         0,
         0,
         5,
         3,
         3,
         3,
         0,
         5,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         160,
         161,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         161,
         161,
         1873,
         1874,
         1875,
         1876,
         1877,
         1878,
         1879,
         1880,
         1881,
         1882,
         1883,
         1884,
         1885,
         2614,
         1872,
         1873,
         1872,
         1872,
         1872,
         1872,
         1872,
         1872,
         1872,
         1872,
         1872,
         1872,
         1872,
         1872,
         1872,
         1872,
         160,
         1874,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1875,
         1872,
         160,
         1886,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1876,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1877,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1878,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1879,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1880,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         1887,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1881,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1888,
         160,
         160,
         160,
         160,
         160,
         160,
         1882,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1883,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1884,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         1885,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         2614,
         1872,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
         160,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         5,
         5,
         0,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         8,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         3,
         0,
         3,
         3,
         0,
         5,
         0,
         0,
         0,
         5,
         3,
         3,
         3,
         0,
         5,
         0,
         0,
         0,
         5,
         3,
         3,
         3,
         0,
         5,
         0,
         0,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         162,
         163,
         1889,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         163,
         163,
         1890,
         1891,
         1892,
         1893,
         1894,
         1895,
         1896,
         1897,
         1898,
         1899,
         2615,
         1889,
         1890,
         1889,
         1889,
         1889,
         1889,
         1889,
         1889,
         1889,
         1889,
         1889,
         1889,
         1889,
         162,
         1891,
         1889,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         1892,
         1889,
         162,
         1900,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         1893,
         1889,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         1894,
         1889,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         1895,
         1889,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         1896,
         1889,
         162,
         162,
         162,
         162,
         162,
         1901,
         162,
         162,
         162,
         162,
         162,
         1897,
         1889,
         162,
         162,
         162,
         162,
         162,
         162,
         1902,
         162,
         162,
         162,
         162,
         1898,
         1889,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         1899,
         1889,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         2615,
         1889,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         162,
         2616,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         6,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         9,
         9,
         0,
         0,
         10,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         0,
         23,
         0,
         0,
         0,
         24,
         25,
         26,
         0,
         0,
         0,
         0,
         0,
         27,
         28,
         29,
         0,
         0,
         0,
         0,
         0,
         30,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         32,
         32,
         0,
         33,
         33,
         34,
         34,
         35,
         35,
         36,
         36,
         37,
         37,
         0,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         0,
         40,
         0,
         41,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         43,
         44,
         45,
         45,
         45,
         45,
         46,
         47,
         48,
         0,
         0,
         49,
         50,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         51,
         52,
         53,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         39,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         16,
         15,
         16,
         15,
         16,
         15,
         15,
         15,
         16,
         16,
         15,
         16,
         15,
         15,
         15,
         16,
         15,
         16,
         15,
         15,
         15,
         15,
         19,
         19,
         19,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         20,
         19,
         20,
         19,
         20,
         19,
         19,
         19,
         20,
         20,
         20,
         19,
         20,
         19,
         19,
         19,
         20,
         19,
         20,
         19,
         19,
         19,
         19,
         0,
         0,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         0,
         0,
         0,
         54,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         55,
         56,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         57,
         58,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         25,
         25,
         25,
         25,
         25,
         25,
         24,
         0,
         24,
         0,
         0,
         24,
         0,
         24,
         0,
         0,
         24,
         24,
         0,
         0,
         0,
         28,
         28,
         28,
         28,
         28,
         28,
         27,
         0,
         27,
         0,
         0,
         27,
         0,
         27,
         0,
         0,
         27,
         27,
         0,
         59,
         60,
         61,
         0,
         36,
         36,
         36,
         36,
         36,
         37,
         37,
         41,
         41,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         44,
         44,
         44,
         44,
         44,
         46,
         47,
         47,
         47,
         47,
         48,
         43,
         45,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         23,
         23,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         14,
         14,
         14,
         14,
         14,
         14,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         17,
         16,
         16,
         16,
         16,
         16,
         21,
         20,
         20,
         20,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         43,
         43,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         24,
         0,
         27,
         0,
         30,
         0,
         36,
         36,
         36,
         36,
         37,
         37,
         37,
         37,
         37,
         37,
         37,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         0,
         0,
         38,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         58,
         58,
         56,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         8,
         8,
         0,
         0,
         0,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         23,
         0,
         43,
         3,
         16,
         20,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         36,
         36,
         36,
         36,
         6,
         9,
         9,
         9,
         8,
         8,
         8,
         7,
         16,
         16,
         16,
         33,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         62,
         0,
         0,
         8,
         31,
         8,
         8,
         0,
         0,
         9,
         9,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         9,
         9,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         9,
         9,
      },
      
      .num_filtered_states = 63,
      .table = (const uint16_t []) {
      
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         170,
         171,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         487,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         488,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         170,
         168,
         169,
         489,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         490,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         491,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         492,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         493,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         494,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         495,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         496,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         497,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         498,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         499,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         500,
         501,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         502,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         500,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         503,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         504,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         505,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         506,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         507,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         508,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         509,
         510,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         513,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         514,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         512,
         515,
         516,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         517,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         515,
         518,
         519,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         520,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         518,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         521,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         522,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         523,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         524,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         525,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         526,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         527,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         528,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         529,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         2640,
         2641,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2642,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2640,
         2643,
         2644,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2645,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2646,
         2647,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2648,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2646,
         2649,
         2650,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2651,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         2649,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         169,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         486,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         533,
         534,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         535,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         536,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         533,
         530,
         531,
         537,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         538,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         539,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         540,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         541,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         542,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         543,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         544,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         545,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         546,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         547,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         548,
         549,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         550,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         548,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         551,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         552,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         553,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         554,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         555,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         556,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         557,
         558,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         559,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         557,
         560,
         561,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         562,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         560,
         563,
         564,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         565,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         566,
         567,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         568,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         569,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         570,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         571,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         572,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         573,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         574,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         575,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         576,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         577,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         2652,
         2653,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2654,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2652,
         2655,
         2656,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2657,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2658,
         2659,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2660,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2658,
         2661,
         2662,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2663,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         2661,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         531,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         581,
         582,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         583,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         584,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         581,
         578,
         579,
         585,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         586,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         587,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         588,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         589,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         590,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         591,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         592,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         593,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         594,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         595,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         596,
         597,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         598,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         596,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         599,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         600,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         601,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         602,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         603,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         604,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         605,
         606,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         607,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         605,
         608,
         609,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         610,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         608,
         611,
         612,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         613,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         614,
         615,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         616,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         614,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         617,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         618,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         619,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         620,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         621,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         622,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         623,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         624,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         625,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         2664,
         2665,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2666,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2667,
         2668,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2669,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2670,
         2671,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2672,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2670,
         2673,
         2674,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2675,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         2673,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         629,
         630,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         631,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         632,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         629,
         626,
         627,
         633,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         634,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         635,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         636,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         637,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         638,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         639,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         640,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         641,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         642,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         643,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         644,
         645,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         646,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         644,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         647,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         648,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         649,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         650,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         651,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         652,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         653,
         654,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         655,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         653,
         656,
         657,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         658,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         659,
         660,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         661,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         659,
         662,
         663,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         664,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         665,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         666,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         667,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         668,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         669,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         670,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         671,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         672,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         673,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         2676,
         2677,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2680,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2681,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2679,
         2682,
         2683,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2684,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2682,
         2685,
         2686,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2687,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         2685,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         627,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         677,
         678,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         679,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         680,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         681,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         674,
         675,
         682,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         683,
         684,
         683,
         685,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         686,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         683,
         674,
         675,
         674,
         674,
         687,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         688,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         689,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         690,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         691,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         692,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         693,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         694,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         695,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         696,
         697,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         698,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         696,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         699,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         700,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         701,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         702,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         703,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         704,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         705,
         706,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         707,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         705,
         708,
         709,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         710,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         708,
         711,
         712,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         713,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         711,
         714,
         715,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         716,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         717,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         718,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         719,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         720,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         721,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         722,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         723,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         724,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         725,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         2688,
         2689,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2692,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2693,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2694,
         2695,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2696,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2694,
         2697,
         2698,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2699,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         2697,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         729,
         730,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         731,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         732,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         729,
         726,
         727,
         733,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         734,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         735,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         736,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         737,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         738,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         739,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         740,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         741,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         742,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         743,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         744,
         745,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         746,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         744,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         747,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         748,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         749,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         750,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         751,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         752,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         753,
         754,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         755,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         756,
         757,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         758,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         756,
         759,
         760,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         761,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         762,
         763,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         764,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         765,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         766,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         767,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         768,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         769,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         770,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         771,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         772,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         773,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         2700,
         2701,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2702,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2703,
         2704,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2705,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2703,
         2706,
         2707,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2708,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2706,
         2709,
         2710,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2711,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         2709,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         727,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         728,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         726,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         777,
         778,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         779,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         780,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         781,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         777,
         774,
         775,
         782,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         783,
         784,
         783,
         785,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         786,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         774,
         775,
         774,
         774,
         787,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         788,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         789,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         790,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         791,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         792,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         793,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         794,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         795,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         796,
         797,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         798,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         796,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         799,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         800,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         801,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         802,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         803,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         804,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         805,
         806,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         807,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         805,
         808,
         809,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         810,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         808,
         811,
         812,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         813,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         811,
         814,
         815,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         816,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         817,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         818,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         819,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         820,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         821,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         822,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         823,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         824,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         825,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         2712,
         2713,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2714,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2712,
         2715,
         2716,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2717,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2715,
         2718,
         2719,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2720,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2721,
         2722,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2723,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         2721,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         775,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         829,
         830,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         831,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         832,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         826,
         827,
         833,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         834,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         835,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         836,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         837,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         838,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         839,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         840,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         841,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         842,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         843,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         844,
         845,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         846,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         847,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         848,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         849,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         850,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         851,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         852,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         853,
         854,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         855,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         853,
         856,
         857,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         858,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         856,
         859,
         860,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         861,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         859,
         862,
         863,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         864,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         865,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         866,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         867,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         868,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         869,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         870,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         871,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         872,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         873,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         2724,
         2725,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2726,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2724,
         2727,
         2728,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2729,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2727,
         2730,
         2731,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2732,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2730,
         2733,
         2734,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2735,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         2733,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         877,
         878,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         879,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         880,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         877,
         874,
         875,
         881,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         882,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         883,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         884,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         885,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         886,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         887,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         888,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         889,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         890,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         891,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         892,
         893,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         894,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         892,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         895,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         896,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         897,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         898,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         899,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         900,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         901,
         902,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         905,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         906,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         907,
         908,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         909,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         907,
         910,
         911,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         912,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         913,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         914,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         915,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         916,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         917,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         918,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         919,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         920,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         921,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         2736,
         2737,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2738,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2736,
         2739,
         2740,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2741,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2739,
         2742,
         2743,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2744,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2742,
         2745,
         2746,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2747,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         2745,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         875,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         926,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         927,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         928,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         925,
         922,
         923,
         929,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         930,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         931,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         932,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         933,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         934,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         935,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         936,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         937,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         938,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         939,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         940,
         941,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         942,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         943,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         944,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         945,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         946,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         947,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         948,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         949,
         950,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         951,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         949,
         952,
         953,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         954,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         952,
         955,
         956,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         957,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         955,
         958,
         959,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         960,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         958,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         961,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         962,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         963,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         964,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         965,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         966,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         967,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         968,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         969,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         2748,
         2749,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2750,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2748,
         2751,
         2752,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2753,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2751,
         2754,
         2755,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2756,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2754,
         2757,
         2758,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2759,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         2757,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         923,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         973,
         974,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         975,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         976,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         970,
         971,
         977,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         978,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         979,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         980,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         981,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         982,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         983,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         984,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         985,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         986,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         987,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         988,
         989,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         990,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         988,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         991,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         992,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         993,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         994,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         995,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         996,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         997,
         998,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         999,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         1000,
         1001,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1004,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1005,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1003,
         1006,
         1007,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1008,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         1006,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         1009,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         1010,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         1011,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         1012,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         1013,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         1014,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         1015,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         1016,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         1017,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         2760,
         2761,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2762,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2760,
         2763,
         2764,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2765,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2763,
         2766,
         2767,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2768,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2766,
         2769,
         2770,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2771,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         2769,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         971,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         972,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         970,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         3017,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1021,
         1022,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1023,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1024,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1021,
         1018,
         1019,
         1025,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1026,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1027,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1028,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1029,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1030,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1031,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1032,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1033,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1034,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1035,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1036,
         1037,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1038,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1036,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1039,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1040,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1041,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1042,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1043,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1044,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1045,
         1046,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1047,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1048,
         1049,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1050,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1051,
         1052,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1053,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1054,
         1055,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1056,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1054,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1057,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1058,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1059,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1060,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1061,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1062,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1063,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1064,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1065,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         2772,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         2773,
         2774,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2775,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2776,
         2777,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2778,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2779,
         2780,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2781,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2782,
         2783,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2784,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1019,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1020,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1018,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1069,
         1070,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1071,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1072,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1066,
         1067,
         1073,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1074,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1075,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1076,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1077,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1078,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1079,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1080,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1081,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1082,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1083,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1084,
         1085,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1086,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1084,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1087,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1088,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1089,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1090,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1091,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1092,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1093,
         1094,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1095,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1093,
         1096,
         1097,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1098,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1096,
         1099,
         1100,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1101,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1099,
         1102,
         1103,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1104,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1105,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1106,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1107,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1108,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1109,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1110,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1111,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1112,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1113,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         2785,
         2786,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2787,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2788,
         2789,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2790,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2791,
         2792,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2793,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2794,
         2795,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2796,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1067,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1068,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1066,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1117,
         1118,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1119,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1120,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1117,
         1114,
         1115,
         1121,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1122,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1123,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1124,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1125,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1126,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1127,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1128,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1129,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1130,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1131,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1132,
         1133,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1134,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1132,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1135,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1136,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1137,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1138,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1139,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1140,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1144,
         1145,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1146,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1147,
         1148,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1149,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1147,
         1150,
         1151,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1152,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1150,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1153,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1154,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1155,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1156,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1157,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1158,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1159,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1160,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1161,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         2797,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         2798,
         2799,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2800,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2801,
         2802,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2803,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2804,
         2805,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2806,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2807,
         2808,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2809,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1115,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1116,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1114,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1165,
         1166,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1167,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1168,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1162,
         1163,
         1169,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1170,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1171,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1172,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1173,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1174,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1175,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1176,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1177,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1178,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1179,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1180,
         1181,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1182,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1183,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1184,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1185,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1186,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1187,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1188,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1192,
         1193,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1194,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1195,
         1196,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1197,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1198,
         1199,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1200,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1201,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1202,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1203,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1204,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1205,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1206,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1207,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1208,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1209,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         2810,
         2811,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2812,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2813,
         2814,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2815,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2816,
         2817,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2818,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2819,
         2820,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2821,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1213,
         1214,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1215,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1216,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1213,
         1210,
         1211,
         1217,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1218,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1219,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1220,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1221,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1222,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1223,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1224,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1225,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1226,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1227,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1228,
         1229,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1230,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1228,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1231,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1232,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1233,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1234,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1235,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1236,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1237,
         1238,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1239,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1237,
         1240,
         1241,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1242,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1240,
         1243,
         1244,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1245,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1243,
         1246,
         1247,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1248,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1246,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1249,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1250,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1251,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1252,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1253,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1254,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1255,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1256,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1257,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         2822,
         2823,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2824,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2825,
         2826,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2827,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2828,
         2829,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2830,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2831,
         2832,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2833,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1211,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1212,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1210,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1261,
         1262,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1263,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1264,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1261,
         1258,
         1259,
         1265,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1266,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1267,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1268,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1269,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1270,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1271,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1272,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1273,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1274,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1275,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1276,
         1277,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1278,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1279,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1280,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1281,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1282,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1283,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1284,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1285,
         1286,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1287,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1285,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1291,
         1292,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1293,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1294,
         1295,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1296,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1294,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1297,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1298,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1299,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1300,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1301,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1302,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1303,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1304,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1305,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         2834,
         2835,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2836,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2837,
         2838,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2839,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2840,
         2841,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2842,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2843,
         2844,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2845,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1259,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1260,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         1258,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         1306,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         1307,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         1308,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1165,
         1166,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1167,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1168,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1162,
         1163,
         1169,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1170,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1171,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1172,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1173,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1174,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1175,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1176,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1177,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1178,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1179,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1180,
         1181,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1182,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1183,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1184,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1185,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1186,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1187,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1188,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1192,
         1193,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1194,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1195,
         1196,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1197,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1198,
         1199,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1200,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1201,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1202,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1203,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1204,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1205,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1206,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1207,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1208,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1209,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         2846,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         2810,
         2811,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2812,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2813,
         2814,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2815,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2816,
         2817,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2818,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2819,
         2820,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2821,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1165,
         1166,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1167,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1168,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1162,
         1163,
         1169,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1170,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1171,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1172,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1173,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1174,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1175,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1176,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1177,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1178,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1179,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1180,
         1181,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1182,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1183,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1184,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1185,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1186,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1187,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1188,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1192,
         1193,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1194,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1195,
         1196,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1197,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1198,
         1199,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1200,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1201,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1202,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1203,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1204,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1205,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1206,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1207,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1208,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1209,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         2847,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         2810,
         2811,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2812,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2813,
         2814,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2815,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2816,
         2817,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2818,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2819,
         2820,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2821,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1165,
         1166,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1167,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1168,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1165,
         1162,
         1163,
         1169,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1170,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1171,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1172,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1173,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1174,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1175,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1176,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1177,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1178,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1179,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1180,
         1181,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1182,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1183,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1184,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1185,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1186,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1187,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1188,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1189,
         1190,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1191,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1189,
         1192,
         1193,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1194,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1192,
         1195,
         1196,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1197,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1195,
         1198,
         1199,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1200,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1198,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1201,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1202,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1203,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1204,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1205,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1206,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1207,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1208,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1209,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         2848,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         2810,
         2811,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2812,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2813,
         2814,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2815,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2816,
         2817,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2818,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2819,
         2820,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2821,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1163,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1164,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         1162,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         166,
         167,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         443,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         444,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         166,
         164,
         165,
         445,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         446,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         447,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         448,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         449,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         450,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         451,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         452,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         453,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         454,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         455,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         456,
         457,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         458,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         456,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         459,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         460,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         461,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         462,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         463,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         464,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         465,
         466,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         467,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         465,
         468,
         469,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         470,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         468,
         471,
         472,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         473,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         471,
         474,
         475,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         476,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         474,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         477,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         478,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         479,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         480,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         481,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         482,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         483,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         484,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         485,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         2628,
         2629,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2630,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2628,
         2631,
         2632,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2635,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2636,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2634,
         2637,
         2638,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2639,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         2637,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         165,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         442,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
         164,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         9,
         2,
         2,
         2,
         2,
         2,
         10,
         2,
         2,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         6,
         6,
         6,
         12,
         6,
         12,
         6,
         6,
         12,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         12,
         12,
         6,
         6,
         12,
         12,
         12,
         6,
         6,
         12,
         6,
         12,
         6,
         12,
         7,
         7,
         13,
         7,
         8,
         8,
         8,
         14,
         14,
         8,
         13,
         7,
         7,
         7,
         13,
         7,
         7,
         7,
         13,
         7,
         13,
         7,
         7,
         13,
         7,
         13,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         2,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         172,
         173,
         1739,
         1740,
         172,
         172,
         1741,
         1742,
         1742,
         2472,
         1739,
         2473,
         2474,
         2927,
         2927,
         2928,
         173,
         173,
         1743,
         1744,
         1745,
         1746,
         1747,
         1748,
         1749,
         2475,
         1743,
         2476,
         2477,
         2929,
         2930,
         2931,
         1739,
         1743,
         1739,
         1750,
         1739,
         1739,
         1751,
         1752,
         1752,
         2472,
         1739,
         2473,
         2478,
         2932,
         2932,
         2928,
         1740,
         1744,
         1750,
         1740,
         1740,
         1740,
         1753,
         1754,
         1754,
         2479,
         1750,
         2480,
         2481,
         2933,
         2933,
         2934,
         172,
         1745,
         1739,
         1740,
         172,
         172,
         1741,
         1742,
         1742,
         2472,
         1739,
         2473,
         2474,
         2927,
         2927,
         2928,
         172,
         1746,
         1739,
         1740,
         172,
         1755,
         1741,
         1742,
         1742,
         2472,
         1739,
         2473,
         2474,
         2927,
         2927,
         2928,
         1741,
         1747,
         1751,
         1753,
         1741,
         1741,
         1741,
         1756,
         1756,
         2482,
         1751,
         2483,
         2474,
         2935,
         2935,
         2936,
         1742,
         1748,
         1752,
         1754,
         1742,
         1742,
         1756,
         1742,
         1742,
         2484,
         1752,
         2485,
         2486,
         2927,
         2927,
         2937,
         1742,
         1749,
         1752,
         1754,
         1742,
         1742,
         1756,
         1742,
         1742,
         2484,
         1752,
         2485,
         2486,
         2927,
         2927,
         2937,
         2472,
         2475,
         2472,
         2479,
         2472,
         2472,
         2482,
         2484,
         2484,
         2472,
         2472,
         2487,
         2488,
         2938,
         2938,
         2939,
         1739,
         1743,
         1739,
         1750,
         1739,
         1739,
         1751,
         1752,
         1752,
         2472,
         2489,
         2473,
         2478,
         2932,
         2932,
         2928,
         2473,
         2476,
         2473,
         2480,
         2473,
         2473,
         2483,
         2485,
         2485,
         2487,
         2473,
         2473,
         2490,
         2940,
         2940,
         2941,
         2474,
         2477,
         2478,
         2481,
         2474,
         2474,
         2474,
         2486,
         2486,
         2488,
         2478,
         2490,
         2474,
         2942,
         2942,
         2943,
         2927,
         2929,
         2932,
         2933,
         2927,
         2927,
         2935,
         2927,
         2927,
         2938,
         2932,
         2940,
         2942,
         2927,
         2927,
         2944,
         2927,
         2930,
         2932,
         2933,
         2927,
         2927,
         2935,
         2927,
         2927,
         2938,
         2932,
         2940,
         2942,
         2927,
         2927,
         2944,
         2928,
         2931,
         2928,
         2934,
         2928,
         2928,
         2936,
         2937,
         2937,
         2939,
         2928,
         2941,
         2943,
         2944,
         2944,
         2928,
      },
   },
   [nir_search_op_i2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         174,
         2012,
         2013,
         2014,
         2015,
         3013,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         8,
         2,
         2,
         2,
         2,
         2,
         9,
         2,
         10,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         14,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         7,
         7,
         7,
         14,
         14,
         14,
         14,
         7,
         7,
         14,
         7,
         7,
         14,
         14,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         13,
         13,
         6,
         12,
         12,
         0,
         12,
         0,
         12,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         175,
         176,
         1757,
         1758,
         175,
         175,
         175,
         1759,
         2491,
         1757,
         2492,
         175,
         2493,
         2493,
         2494,
         175,
         175,
         176,
         176,
         1760,
         1761,
         1762,
         176,
         1763,
         1764,
         2495,
         1760,
         2496,
         2497,
         2498,
         2499,
         2500,
         3002,
         3003,
         1757,
         1760,
         1757,
         1765,
         1757,
         1757,
         1757,
         1766,
         2491,
         1757,
         2492,
         1757,
         2501,
         2501,
         2502,
         1757,
         1757,
         1758,
         1761,
         1765,
         1758,
         1758,
         1758,
         1758,
         1767,
         2503,
         1765,
         2504,
         1758,
         2505,
         2505,
         2506,
         1758,
         1758,
         175,
         1762,
         1757,
         1758,
         175,
         175,
         175,
         1759,
         2491,
         1757,
         2492,
         175,
         2493,
         2493,
         2494,
         175,
         175,
         175,
         176,
         1757,
         1758,
         175,
         1768,
         175,
         1759,
         2491,
         1757,
         2492,
         175,
         2493,
         2493,
         2494,
         175,
         175,
         175,
         1763,
         1757,
         1758,
         175,
         175,
         175,
         1759,
         2491,
         1757,
         2492,
         175,
         2493,
         2493,
         2494,
         175,
         175,
         1759,
         1764,
         1766,
         1767,
         1759,
         1759,
         1759,
         1759,
         2507,
         1766,
         2508,
         1759,
         2509,
         2509,
         2494,
         1759,
         1759,
         2491,
         2495,
         2491,
         2503,
         2491,
         2491,
         2491,
         2507,
         2491,
         2491,
         2510,
         2491,
         2511,
         2511,
         2512,
         2491,
         2491,
         1757,
         1760,
         1757,
         1765,
         1757,
         1757,
         1757,
         1766,
         2491,
         2513,
         2492,
         1757,
         2501,
         2501,
         2502,
         1757,
         1757,
         2492,
         2496,
         2492,
         2504,
         2492,
         2492,
         2492,
         2508,
         2510,
         2492,
         2492,
         2492,
         2514,
         2514,
         2515,
         2492,
         2492,
         175,
         2497,
         1757,
         1758,
         175,
         175,
         175,
         1759,
         2491,
         1757,
         2492,
         175,
         2493,
         2493,
         2494,
         175,
         175,
         2493,
         2498,
         2501,
         2505,
         2493,
         2493,
         2493,
         2509,
         2511,
         2501,
         2514,
         2493,
         2493,
         2493,
         2516,
         2493,
         2493,
         2493,
         2499,
         2501,
         2505,
         2493,
         2493,
         2493,
         2509,
         2511,
         2501,
         2514,
         2493,
         2493,
         2493,
         2516,
         2493,
         2493,
         2494,
         2500,
         2502,
         2506,
         2494,
         2494,
         2494,
         2494,
         2512,
         2502,
         2515,
         2494,
         2516,
         2516,
         2494,
         2494,
         2494,
         175,
         3002,
         1757,
         1758,
         175,
         175,
         175,
         1759,
         2491,
         1757,
         2492,
         175,
         2493,
         2493,
         2494,
         175,
         175,
         175,
         3003,
         1757,
         1758,
         175,
         175,
         175,
         1759,
         2491,
         1757,
         2492,
         175,
         2493,
         2493,
         2494,
         175,
         175,
      },
   },
   [nir_op_imin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         7,
         8,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         9,
         4,
         9,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         5,
         10,
         5,
         6,
         11,
         11,
         6,
         10,
         5,
         5,
         10,
         5,
         5,
         10,
         10,
         5,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         9,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         177,
         178,
         1782,
         1783,
         1784,
         1785,
         1785,
         2581,
         1782,
         2582,
         2979,
         2979,
         178,
         178,
         1786,
         1787,
         1788,
         1789,
         1790,
         2583,
         1786,
         2584,
         2980,
         2981,
         1782,
         1786,
         1782,
         1791,
         1792,
         1793,
         1793,
         2581,
         1782,
         2585,
         2982,
         2982,
         1783,
         1787,
         1791,
         1783,
         1794,
         1795,
         1795,
         2586,
         1791,
         2587,
         2983,
         2983,
         1784,
         1788,
         1792,
         1794,
         1784,
         1796,
         1796,
         2588,
         1792,
         2582,
         2984,
         2984,
         1785,
         1789,
         1793,
         1795,
         1796,
         1785,
         1785,
         2589,
         1793,
         2590,
         2979,
         2979,
         1785,
         1790,
         1793,
         1795,
         1796,
         1785,
         1785,
         2589,
         1793,
         2590,
         2979,
         2979,
         2581,
         2583,
         2581,
         2586,
         2588,
         2589,
         2589,
         2581,
         2581,
         2591,
         2985,
         2985,
         1782,
         1786,
         1782,
         1791,
         1792,
         1793,
         1793,
         2581,
         2592,
         2585,
         2982,
         2982,
         2582,
         2584,
         2585,
         2587,
         2582,
         2590,
         2590,
         2591,
         2585,
         2582,
         2986,
         2986,
         2979,
         2980,
         2982,
         2983,
         2984,
         2979,
         2979,
         2985,
         2982,
         2986,
         2979,
         2979,
         2979,
         2981,
         2982,
         2983,
         2984,
         2979,
         2979,
         2985,
         2982,
         2986,
         2979,
         2979,
      },
   },
   [nir_op_imax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         6,
         7,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         4,
         4,
         4,
         9,
         9,
         0,
         0,
         8,
         0,
         8,
         8,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         5,
         5,
         10,
         10,
         10,
         5,
         10,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         179,
         180,
         1797,
         1798,
         179,
         1799,
         2593,
         1797,
         2594,
         2594,
         2595,
         180,
         180,
         1800,
         1801,
         1802,
         1803,
         2596,
         1800,
         2597,
         2598,
         2599,
         1797,
         1800,
         1797,
         1804,
         1797,
         1805,
         2593,
         1797,
         2600,
         2600,
         2601,
         1798,
         1801,
         1804,
         1798,
         1798,
         1806,
         2602,
         1804,
         2603,
         2603,
         2604,
         179,
         1802,
         1797,
         1798,
         179,
         1799,
         2593,
         1797,
         2594,
         2594,
         2595,
         1799,
         1803,
         1805,
         1806,
         1799,
         1799,
         2605,
         1805,
         2606,
         2606,
         2595,
         2593,
         2596,
         2593,
         2602,
         2593,
         2605,
         2593,
         2593,
         2607,
         2607,
         2608,
         1797,
         1800,
         1797,
         1804,
         1797,
         1805,
         2593,
         2609,
         2600,
         2600,
         2601,
         2594,
         2597,
         2600,
         2603,
         2594,
         2606,
         2607,
         2600,
         2594,
         2594,
         2610,
         2594,
         2598,
         2600,
         2603,
         2594,
         2606,
         2607,
         2600,
         2594,
         2594,
         2610,
         2595,
         2599,
         2601,
         2604,
         2595,
         2595,
         2608,
         2601,
         2610,
         2610,
         2595,
      },
   },
   [nir_op_umin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         5,
         2,
         5,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         2,
         6,
         3,
         6,
         3,
         6,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         181,
         182,
         2111,
         2112,
         181,
         2617,
         2987,
         182,
         182,
         2113,
         2114,
         182,
         2618,
         2988,
         2111,
         2113,
         2111,
         2115,
         2111,
         2617,
         2989,
         2112,
         2114,
         2115,
         2112,
         2112,
         2619,
         2987,
         181,
         182,
         2111,
         2112,
         2620,
         2617,
         2987,
         2617,
         2618,
         2617,
         2619,
         2617,
         2617,
         2990,
         2987,
         2988,
         2989,
         2987,
         2987,
         2990,
         2987,
      },
   },
   [nir_op_umax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         2,
         5,
         2,
         5,
         5,
         2,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         183,
         184,
         2116,
         183,
         2621,
         2622,
         184,
         184,
         2117,
         184,
         2623,
         2624,
         2116,
         2117,
         2116,
         2116,
         2625,
         2622,
         183,
         184,
         2116,
         2626,
         2621,
         2622,
         2621,
         2623,
         2625,
         2621,
         2621,
         2627,
         2622,
         2624,
         2622,
         2622,
         2627,
         2622,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         4,
         0,
         4,
         0,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         185,
         186,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         186,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         1525,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         1526,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         1527,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         1528,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         1529,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         1530,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         1531,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         2851,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
         185,
      },
   },
   [nir_search_op_f2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         187,
         1807,
         1808,
         1809,
         1810,
         1811,
         1812,
      },
   },
   [nir_search_op_f2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         188,
         1813,
         1814,
         1815,
         1816,
         1817,
         1818,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         189,
         1819,
         1820,
         1821,
         1822,
         1823,
         1824,
         1825,
         1826,
         1827,
         1828,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         190,
         1962,
         1963,
         1964,
         1965,
         1966,
         1967,
         1968,
         1969,
         1970,
         1971,
         2885,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         8,
         9,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         5,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         14,
         9,
         9,
         9,
         9,
         9,
         15,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         9,
         9,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         1,
         0,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         191,
         1972,
         1973,
         1974,
         1975,
         1976,
         1977,
         1978,
         1979,
         1980,
         1981,
         1982,
         1983,
         1984,
         2883,
         2884,
         2895,
         2896,
         2897,
      },
   },
   [nir_op_f2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         192,
         1829,
         1830,
         1831,
         1832,
         1833,
         1834,
         1835,
      },
   },
   [nir_op_i2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         193,
         2016,
         2017,
         2018,
         2019,
         2020,
         2021,
         2022,
         2023,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         194,
         195,
         194,
         194,
         194,
         195,
         194,
         194,
         194,
         1532,
         194,
         194,
         194,
         1533,
         194,
         194,
      },
   },
   [nir_op_extract_i16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         196,
         197,
         196,
         197,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         198,
         199,
         198,
         198,
         198,
         198,
         199,
         198,
         198,
         198,
         198,
         2118,
         198,
         198,
         198,
         198,
         2119,
         198,
         198,
         198,
         198,
         2120,
         198,
         198,
         198,
      },
   },
   [nir_op_ixor] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         4,
         5,
         6,
         7,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         12,
         13,
         14,
         15,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         2,
         2,
         3,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         5,
         4,
         4,
         5,
         5,
         6,
         6,
         7,
         6,
         7,
         6,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         20,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
      },
      
      .num_filtered_states = 21,
      .table = (const uint16_t []) {
      
         200,
         201,
         200,
         200,
         200,
         200,
         200,
         200,
         200,
         1486,
         200,
         1487,
         200,
         1488,
         200,
         1489,
         200,
         2852,
         2853,
         2854,
         2855,
         201,
         201,
         201,
         201,
         201,
         201,
         201,
         201,
         201,
         1490,
         201,
         1491,
         201,
         1492,
         201,
         1493,
         1494,
         2856,
         2857,
         2858,
         2859,
         200,
         201,
         200,
         1495,
         200,
         200,
         200,
         200,
         200,
         1486,
         200,
         1487,
         200,
         1488,
         200,
         1489,
         200,
         2852,
         2853,
         2854,
         2855,
         200,
         201,
         1495,
         1495,
         200,
         200,
         200,
         200,
         200,
         1486,
         200,
         1487,
         200,
         1488,
         200,
         1489,
         200,
         2852,
         2853,
         2854,
         2855,
         200,
         201,
         200,
         200,
         200,
         1496,
         200,
         200,
         200,
         1486,
         200,
         1487,
         200,
         1488,
         200,
         1489,
         200,
         2852,
         2853,
         2854,
         2855,
         200,
         201,
         200,
         200,
         1496,
         1496,
         200,
         200,
         200,
         1486,
         200,
         1487,
         200,
         1488,
         200,
         1489,
         200,
         2852,
         2853,
         2854,
         2855,
         200,
         201,
         200,
         200,
         200,
         200,
         200,
         1497,
         200,
         1486,
         200,
         1487,
         200,
         1488,
         200,
         1489,
         200,
         2852,
         2853,
         2854,
         2855,
         200,
         201,
         200,
         200,
         200,
         200,
         1497,
         1497,
         200,
         1486,
         200,
         1487,
         200,
         1488,
         200,
         1489,
         200,
         2852,
         2853,
         2854,
         2855,
         200,
         201,
         200,
         200,
         200,
         200,
         200,
         200,
         200,
         1498,
         200,
         1487,
         200,
         1488,
         200,
         1489,
         200,
         2852,
         2853,
         2854,
         2855,
         1486,
         1490,
         1486,
         1486,
         1486,
         1486,
         1486,
         1486,
         1498,
         1498,
         1486,
         1499,
         1486,
         1500,
         1486,
         1501,
         1486,
         2860,
         2861,
         2862,
         2863,
         200,
         201,
         200,
         200,
         200,
         200,
         200,
         200,
         200,
         1486,
         200,
         1502,
         200,
         1488,
         200,
         1489,
         200,
         2852,
         2853,
         2854,
         2855,
         1487,
         1491,
         1487,
         1487,
         1487,
         1487,
         1487,
         1487,
         1487,
         1499,
         1502,
         1502,
         1487,
         1503,
         1487,
         1504,
         1487,
         2864,
         2865,
         2866,
         2867,
         200,
         201,
         200,
         200,
         200,
         200,
         200,
         200,
         200,
         1486,
         200,
         1487,
         200,
         1505,
         200,
         1489,
         200,
         2852,
         2853,
         2854,
         2855,
         1488,
         1492,
         1488,
         1488,
         1488,
         1488,
         1488,
         1488,
         1488,
         1500,
         1488,
         1503,
         1505,
         1505,
         1488,
         1506,
         1488,
         2868,
         2869,
         2870,
         2871,
         200,
         201,
         200,
         200,
         200,
         200,
         200,
         200,
         200,
         1486,
         200,
         1487,
         200,
         1488,
         200,
         1507,
         200,
         2852,
         2853,
         2854,
         2855,
         1489,
         1493,
         1489,
         1489,
         1489,
         1489,
         1489,
         1489,
         1489,
         1501,
         1489,
         1504,
         1489,
         1506,
         1507,
         1507,
         1489,
         2872,
         2873,
         2874,
         2875,
         200,
         1494,
         200,
         200,
         200,
         200,
         200,
         200,
         200,
         1486,
         200,
         1487,
         200,
         1488,
         200,
         1489,
         200,
         2852,
         2853,
         2854,
         2855,
         2852,
         2856,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2860,
         2852,
         2864,
         2852,
         2868,
         2852,
         2872,
         2852,
         2852,
         2876,
         2877,
         2878,
         2853,
         2857,
         2853,
         2853,
         2853,
         2853,
         2853,
         2853,
         2853,
         2861,
         2853,
         2865,
         2853,
         2869,
         2853,
         2873,
         2853,
         2876,
         2853,
         2879,
         2880,
         2854,
         2858,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2862,
         2854,
         2866,
         2854,
         2870,
         2854,
         2874,
         2854,
         2877,
         2879,
         2854,
         2881,
         2855,
         2859,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2863,
         2855,
         2867,
         2855,
         2871,
         2855,
         2875,
         2855,
         2878,
         2880,
         2881,
         2882,
      },
   },
   [nir_op_slt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         202,
         203,
         204,
         205,
      },
   },
   [nir_op_sge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         206,
         207,
         208,
         209,
      },
   },
   [nir_op_seq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         210,
         210,
         210,
         210,
         210,
         210,
         210,
         210,
         2121,
         2122,
         2123,
         2124,
         210,
         2121,
         210,
         210,
         210,
         210,
         210,
         2122,
         210,
         210,
         210,
         210,
         210,
         2123,
         210,
         210,
         210,
         210,
         210,
         2124,
         210,
         210,
         210,
         210,
      },
   },
   [nir_op_sne] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         211,
         211,
         211,
         211,
         211,
         211,
         211,
         211,
         2125,
         2126,
         2127,
         2128,
         211,
         2125,
         211,
         211,
         211,
         211,
         211,
         2126,
         211,
         211,
         211,
         211,
         211,
         2127,
         211,
         211,
         211,
         211,
         211,
         2128,
         211,
         211,
         211,
         211,
      },
   },
   [nir_op_fall_equal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         212,
      },
   },
   [nir_op_fall_equal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         213,
      },
   },
   [nir_op_fall_equal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         214,
      },
   },
   [nir_op_fany_nequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         215,
      },
   },
   [nir_op_fany_nequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         216,
      },
   },
   [nir_op_fany_nequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         217,
      },
   },
   [nir_op_ball_iequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         218,
         218,
         218,
         218,
         218,
         218,
         2045,
         2046,
         218,
         2045,
         218,
         218,
         218,
         2046,
         218,
         218,
      },
   },
   [nir_op_ball_iequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         219,
         219,
         219,
         219,
         219,
         219,
         2047,
         2048,
         219,
         2047,
         219,
         219,
         219,
         2048,
         219,
         219,
      },
   },
   [nir_op_ball_iequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         220,
         220,
         220,
         220,
         220,
         220,
         2049,
         2050,
         220,
         2049,
         220,
         220,
         220,
         2050,
         220,
         220,
      },
   },
   [nir_op_bany_inequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         221,
         221,
         221,
         221,
         221,
         221,
         2055,
         2056,
         221,
         2055,
         221,
         221,
         221,
         2056,
         221,
         221,
      },
   },
   [nir_op_bany_inequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         222,
         222,
         222,
         222,
         222,
         222,
         2057,
         2058,
         222,
         2057,
         222,
         222,
         222,
         2058,
         222,
         222,
      },
   },
   [nir_op_bany_inequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         223,
         223,
         223,
         223,
         223,
         223,
         2059,
         2060,
         223,
         2059,
         223,
         223,
         223,
         2060,
         223,
         223,
      },
   },
   [nir_op_ball_fequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         224,
      },
   },
   [nir_op_ball_fequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         225,
      },
   },
   [nir_op_ball_fequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         226,
      },
   },
   [nir_op_bany_fnequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         227,
      },
   },
   [nir_op_bany_fnequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         228,
      },
   },
   [nir_op_bany_fnequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         229,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         230,
         230,
         231,
         231,
      },
   },
   [nir_op_urol] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         232,
      },
   },
   [nir_op_uror] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         233,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         234,
         2146,
         2579,
         2580,
         2975,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         2,
         2,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         4,
         4,
         5,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         235,
         2135,
         2136,
         2137,
         2138,
         2139,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         236,
         237,
         236,
         236,
         238,
         239,
         238,
         238,
         236,
         2147,
         236,
         236,
         236,
         2566,
         236,
         236,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         240,
         2140,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         4,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         241,
         2141,
         2142,
         2143,
         2144,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         242,
         2145,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         243,
         243,
         244,
         244,
      },
   },
   [nir_op_fsin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         245,
      },
   },
   [nir_op_fcos] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         246,
      },
   },
   [nir_op_fcsel] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         247,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2130,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2131,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2132,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
         2134,
      },
   },
   [nir_op_f2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         248,
         2005,
         2006,
      },
   },
   [nir_op_f2ump] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         249,
         2007,
         2008,
      },
   },
   [nir_op_i2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         250,
         2024,
         2025,
      },
   },
   [nir_op_u2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         251,
         2026,
         2027,
      },
   },
   [nir_op_pack_64_2x32_split] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         252,
         252,
         252,
         252,
         252,
         1535,
         252,
         252,
         252,
      },
   },
   [nir_op_unpack_64_2x32_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         253,
         1985,
         1986,
      },
   },
   [nir_op_unpack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         254,
         2148,
         2149,
      },
   },
   [nir_op_pack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         255,
         2150,
         2461,
      },
   },
   [nir_op_unpack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         256,
         2152,
      },
   },
   [nir_op_pack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         257,
         2151,
      },
   },
   [nir_op_unpack_32_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         258,
         1987,
         1988,
      },
   },
   [nir_op_unpack_32_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         259,
         1989,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         260,
         1990,
         0,
         261,
         1990,
         1991,
         1992,
         1993,
         0,
         260,
         1990,
         0,
         261,
         1990,
         1991,
         1992,
         1993,
         0,
         260,
         1990,
         0,
         261,
         1990,
         1991,
         1992,
         1993,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         262,
         1994,
         0,
         263,
         1994,
         1995,
         1996,
         1997,
         0,
         262,
         1994,
         0,
         263,
         1994,
         1995,
         1996,
         1997,
         0,
         262,
         1994,
         0,
         263,
         1994,
         1995,
         1996,
         1997,
      },
   },
   [nir_op_pack_32_2x16_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         264,
      },
   },
   [nir_op_unpack_half_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         0,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         265,
         1998,
         1999,
         2000,
      },
   },
   [nir_op_unpack_half_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         266,
         2001,
      },
   },
   [nir_op_pack_half_2x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         2035,
         2036,
         2037,
      },
   },
   [nir_op_pack_half_2x16_split] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         267,
         268,
         269,
         270,
      },
   },
   [nir_op_pack_32_4x8_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         271,
      },
   },
   [nir_op_ussub_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         272,
         0,
         272,
      },
   },
   [nir_op_fsub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         273,
      },
   },
   [nir_op_uabs_usub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         274,
      },
   },
   [nir_op_uabs_isub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         275,
      },
   },
   [nir_op_find_lsb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         276,
      },
   },
   [nir_op_ifind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         277,
      },
   },
   [nir_op_ufind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         278,
      },
   },
   [nir_op_fmod] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         279,
      },
   },
   [nir_op_frem] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         280,
      },
   },
   [nir_op_uadd_carry] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         281,
      },
   },
   [nir_op_usub_borrow] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         282,
      },
   },
   [nir_op_bitfield_insert] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         283,
      },
   },
   [nir_op_ihadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         284,
      },
   },
   [nir_op_uhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         285,
      },
   },
   [nir_op_irhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         286,
      },
   },
   [nir_op_urhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         287,
      },
   },
   [nir_op_uadd_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         288,
      },
   },
   [nir_op_usub_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         289,
      },
   },
   [nir_op_iadd_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         290,
      },
   },
   [nir_op_isub_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         291,
      },
   },
   [nir_op_ibitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         292,
      },
   },
   [nir_op_ubitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         293,
      },
   },
   [nir_op_bitfield_select] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         294,
         0,
         0,
         294,
         0,
         1960,
         1961,
         1960,
         0,
         294,
         0,
         0,
         294,
         0,
         1960,
         1961,
         1960,
         0,
         294,
         0,
         0,
         294,
         0,
         1960,
         1961,
         1960,
      },
   },
   [nir_op_bfm] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         2002,
         2003,
         2004,
      },
   },
   [nir_op_pack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         295,
      },
   },
   [nir_op_pack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         296,
      },
   },
   [nir_op_pack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         297,
      },
   },
   [nir_op_pack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         298,
      },
   },
   [nir_op_unpack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         299,
      },
   },
   [nir_op_unpack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         300,
      },
   },
   [nir_op_unpack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         301,
      },
   },
   [nir_op_unpack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         302,
      },
   },
   [nir_op_isign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         303,
         2110,
      },
   },
   [nir_op_amul] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         304,
      },
   },
   [nir_op_umul24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         305,
      },
   },
   [nir_op_umad24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         306,
      },
   },
   [nir_op_imul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         307,
      },
   },
   [nir_op_umad24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         308,
      },
   },
   [nir_op_umul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         309,
      },
   },
   [nir_op_imad24_ir3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         310,
         311,
         312,
         311,
         312,
         313,
         314,
      },
   },
   [nir_op_imul24] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         315,
         315,
         315,
      },
   },
   [nir_op_b2b1] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         316,
      },
   },
   [nir_op_b2b8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         317,
      },
   },
   [nir_op_b2b16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         318,
      },
   },
   [nir_op_b2b32] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         319,
      },
   },
   [nir_op_ldexp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         320,
      },
   },
   [nir_op_ball_iequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2051,
         2052,
         0,
         2051,
         0,
         0,
         0,
         2052,
         0,
         0,
      },
   },
   [nir_op_bany_inequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2061,
         2062,
         0,
         2061,
         0,
         0,
         0,
         2062,
         0,
         0,
      },
   },
   [nir_op_ball_iequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2053,
         2054,
         0,
         2053,
         0,
         0,
         0,
         2054,
         0,
         0,
      },
   },
   [nir_op_bany_inequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2063,
         2064,
         0,
         2063,
         0,
         0,
         0,
         2064,
         0,
         0,
      },
   },
   [nir_op_fddx] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         321,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         322,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         323,
      },
   },
   [nir_op_fddy] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         324,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         325,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         326,
      },
   },
   [nir_op_umul_low] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         327,
         327,
         327,
      },
   },
   [nir_op_imadsh_mix16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         328,
         328,
         329,
         329,
         330,
         330,
      },
   },
   [nir_op_fisnormal] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         331,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_transform_offsets[] = {
   0,
   0,
   0,
   1,
   0,
   12,
   15,
   17,
   21,
   23,
   25,
   27,
   30,
   34,
   37,
   42,
   0,
   0,
   47,
   0,
   49,
   0,
   51,
   0,
   55,
   0,
   59,
   61,
   0,
   64,
   71,
   78,
   88,
   100,
   115,
   128,
   144,
   146,
   154,
   156,
   160,
   163,
   166,
   168,
   170,
   174,
   177,
   182,
   185,
   190,
   194,
   200,
   202,
   204,
   207,
   210,
   214,
   218,
   220,
   222,
   225,
   228,
   232,
   236,
   238,
   241,
   245,
   247,
   250,
   253,
   257,
   261,
   266,
   268,
   270,
   273,
   276,
   280,
   284,
   286,
   288,
   291,
   294,
   298,
   302,
   304,
   307,
   311,
   313,
   316,
   320,
   322,
   324,
   327,
   330,
   333,
   336,
   341,
   346,
   348,
   351,
   354,
   0,
   359,
   362,
   365,
   368,
   0,
   371,
   373,
   0,
   0,
   0,
   0,
   375,
   0,
   0,
   0,
   377,
   379,
   0,
   0,
   0,
   0,
   382,
   0,
   384,
   390,
   392,
   0,
   399,
   405,
   407,
   0,
   414,
   419,
   424,
   429,
   434,
   439,
   444,
   449,
   454,
   456,
   459,
   461,
   464,
   469,
   475,
   480,
   486,
   488,
   491,
   495,
   500,
   505,
   511,
   516,
   522,
   524,
   526,
   528,
   534,
   536,
   542,
   546,
   551,
   556,
   580,
   586,
   593,
   600,
   626,
   628,
   0,
   631,
   633,
   635,
   637,
   639,
   641,
   643,
   645,
   649,
   651,
   655,
   657,
   0,
   0,
   661,
   665,
   671,
   0,
   0,
   677,
   679,
   683,
   685,
   688,
   690,
   693,
   695,
   698,
   700,
   702,
   704,
   706,
   708,
   710,
   712,
   714,
   716,
   718,
   720,
   722,
   724,
   726,
   728,
   730,
   732,
   734,
   736,
   738,
   740,
   742,
   744,
   746,
   748,
   750,
   752,
   754,
   756,
   758,
   761,
   0,
   0,
   764,
   766,
   771,
   774,
   780,
   0,
   0,
   782,
   784,
   787,
   789,
   791,
   0,
   0,
   0,
   0,
   793,
   795,
   0,
   0,
   0,
   0,
   797,
   800,
   803,
   805,
   814,
   816,
   824,
   827,
   829,
   831,
   833,
   835,
   837,
   0,
   839,
   842,
   844,
   846,
   848,
   850,
   853,
   855,
   857,
   859,
   861,
   863,
   867,
   870,
   873,
   876,
   879,
   882,
   885,
   891,
   897,
   900,
   903,
   905,
   907,
   909,
   911,
   913,
   915,
   917,
   919,
   921,
   923,
   925,
   927,
   929,
   932,
   935,
   938,
   940,
   943,
   947,
   951,
   956,
   960,
   962,
   964,
   966,
   968,
   972,
   974,
   976,
   978,
   980,
   982,
   984,
   986,
   988,
   990,
   993,
   995,
   997,
   1000,
   1003,
   1005,
   1007,
   1019,
   1032,
   1044,
   1056,
   1068,
   1081,
   1094,
   1106,
   1118,
   1122,
   1126,
   1129,
   1132,
   1134,
   1139,
   1143,
   1147,
   1151,
   1155,
   1158,
   1160,
   1165,
   0,
   1167,
   1169,
   1171,
   1173,
   1175,
   1178,
   1181,
   1184,
   1186,
   1188,
   1190,
   1193,
   1196,
   1200,
   1204,
   1208,
   1212,
   1216,
   1221,
   1224,
   1228,
   1232,
   1235,
   1238,
   1240,
   1243,
   1246,
   1249,
   1252,
   1255,
   1258,
   1262,
   1266,
   1270,
   1273,
   1276,
   1278,
   1280,
   1282,
   1284,
   1287,
   1290,
   1293,
   1295,
   1297,
   1300,
   1303,
   1306,
   1310,
   1314,
   1318,
   1321,
   1324,
   1327,
   1330,
   1334,
   1338,
   1342,
   1345,
   1348,
   1351,
   1355,
   1359,
   1363,
   1366,
   1369,
   1373,
   1377,
   1381,
   1384,
   1387,
   1392,
   1397,
   1401,
   1405,
   1410,
   1414,
   1418,
   1422,
   1426,
   1429,
   1431,
   1437,
   1442,
   1449,
   1457,
   1462,
   1467,
   1475,
   1483,
   1491,
   1499,
   1505,
   1515,
   1520,
   1527,
   1533,
   1540,
   1552,
   1560,
   1568,
   1576,
   1584,
   1592,
   1600,
   1606,
   1613,
   1621,
   1627,
   1634,
   1642,
   1647,
   1653,
   1660,
   1665,
   1671,
   1678,
   1686,
   1691,
   1696,
   1704,
   1709,
   1714,
   1719,
   1724,
   1729,
   1737,
   1744,
   1753,
   1763,
   1770,
   1777,
   1787,
   1797,
   1807,
   1817,
   1825,
   1837,
   1844,
   1853,
   1861,
   1870,
   1884,
   1894,
   1904,
   1914,
   1924,
   1934,
   1944,
   1952,
   1961,
   1971,
   1979,
   1988,
   1998,
   2005,
   2013,
   2022,
   2029,
   2037,
   2046,
   2056,
   2063,
   2070,
   2080,
   2087,
   2094,
   2101,
   2108,
   2115,
   2120,
   2126,
   2133,
   2139,
   2164,
   2170,
   2178,
   2187,
   2193,
   2199,
   2208,
   2217,
   2226,
   2235,
   2242,
   2253,
   2259,
   2267,
   2274,
   2282,
   2295,
   2304,
   2313,
   2322,
   2331,
   2340,
   2349,
   2356,
   2364,
   2373,
   2380,
   2388,
   2397,
   2403,
   2410,
   2418,
   2424,
   2431,
   2439,
   2448,
   2454,
   2460,
   2469,
   2475,
   2481,
   2487,
   2493,
   2499,
   2504,
   2510,
   2517,
   2523,
   2548,
   2554,
   2562,
   2571,
   2577,
   2583,
   2592,
   2601,
   2610,
   2619,
   2626,
   2637,
   2643,
   2651,
   2658,
   2666,
   2679,
   2688,
   2697,
   2706,
   2715,
   2724,
   2733,
   2740,
   2748,
   2757,
   2764,
   2772,
   2781,
   2787,
   2794,
   2802,
   2808,
   2815,
   2823,
   2832,
   2838,
   2844,
   2853,
   2859,
   2865,
   2871,
   2877,
   2883,
   2889,
   2896,
   2904,
   2911,
   2937,
   2944,
   2953,
   2963,
   2970,
   2977,
   2987,
   2997,
   3007,
   3017,
   3025,
   3037,
   3044,
   3053,
   3061,
   3070,
   3084,
   3094,
   3104,
   3114,
   3124,
   3134,
   3144,
   3152,
   3161,
   3171,
   3179,
   3188,
   3198,
   3205,
   3213,
   3222,
   3229,
   3237,
   3246,
   3256,
   3263,
   3270,
   3280,
   3287,
   3294,
   3301,
   3308,
   3315,
   3322,
   3330,
   3339,
   3347,
   3374,
   3382,
   3392,
   3401,
   3412,
   3420,
   3429,
   3438,
   3448,
   3456,
   3467,
   3478,
   3489,
   3500,
   3509,
   3522,
   3530,
   3540,
   3549,
   3559,
   3574,
   3585,
   3596,
   3607,
   3618,
   3629,
   3640,
   3649,
   3659,
   3670,
   3679,
   3689,
   3700,
   3708,
   3717,
   3727,
   3735,
   3744,
   3754,
   3765,
   3773,
   3781,
   3792,
   3800,
   3808,
   3816,
   3824,
   3832,
   3839,
   3847,
   3856,
   3864,
   3891,
   3899,
   3909,
   3920,
   3928,
   3936,
   3947,
   3958,
   3969,
   3980,
   3989,
   4002,
   4010,
   4020,
   4029,
   4039,
   4054,
   4065,
   4076,
   4087,
   4098,
   4109,
   4120,
   4129,
   4139,
   4150,
   4159,
   4169,
   4180,
   4188,
   4197,
   4207,
   4215,
   4224,
   4234,
   4245,
   4253,
   4261,
   4272,
   4280,
   4288,
   4296,
   4304,
   4312,
   4320,
   4329,
   4339,
   4348,
   4376,
   4385,
   4396,
   4406,
   4418,
   4427,
   4437,
   4447,
   4458,
   4467,
   4479,
   4491,
   4503,
   4515,
   4525,
   4539,
   4548,
   4559,
   4569,
   4580,
   4596,
   4608,
   4620,
   4632,
   4644,
   4656,
   4668,
   4678,
   4689,
   4701,
   4711,
   4722,
   4734,
   4743,
   4753,
   4764,
   4773,
   4783,
   4794,
   4806,
   4815,
   4824,
   4836,
   4845,
   4854,
   4863,
   4872,
   4881,
   4887,
   4894,
   4902,
   4909,
   4935,
   4942,
   4951,
   4961,
   4968,
   4975,
   4985,
   4995,
   5005,
   5015,
   5023,
   5035,
   5042,
   5051,
   5059,
   5068,
   5082,
   5092,
   5102,
   5112,
   5122,
   5132,
   5142,
   5150,
   5159,
   5169,
   5177,
   5186,
   5196,
   5203,
   5211,
   5220,
   5227,
   5235,
   5244,
   5254,
   5261,
   5268,
   5278,
   5285,
   5292,
   5299,
   5306,
   5313,
   5320,
   5328,
   5337,
   5345,
   5372,
   5380,
   5390,
   5401,
   5409,
   5417,
   5428,
   5439,
   5450,
   5461,
   5470,
   5483,
   5491,
   5501,
   5510,
   5520,
   5535,
   5546,
   5557,
   5568,
   5579,
   5590,
   5601,
   5610,
   5620,
   5631,
   5640,
   5650,
   5661,
   5669,
   5678,
   5688,
   5696,
   5705,
   5715,
   5726,
   5734,
   5742,
   5753,
   5761,
   5769,
   5777,
   5785,
   5793,
   5800,
   5808,
   5817,
   5825,
   5852,
   5860,
   5870,
   5881,
   5889,
   5897,
   5908,
   5919,
   5930,
   5941,
   5950,
   5963,
   5971,
   5981,
   5990,
   6000,
   6015,
   6026,
   6037,
   6048,
   6059,
   6070,
   6081,
   6090,
   6100,
   6111,
   6120,
   6130,
   6141,
   6149,
   6158,
   6168,
   6176,
   6185,
   6195,
   6206,
   6214,
   6222,
   6233,
   6241,
   6249,
   6257,
   6265,
   6273,
   6281,
   6290,
   6300,
   6309,
   6337,
   6346,
   6357,
   6369,
   6378,
   6387,
   6399,
   6411,
   6423,
   6435,
   6445,
   6459,
   6468,
   6479,
   6489,
   6500,
   6516,
   6528,
   6540,
   6552,
   6564,
   6576,
   6588,
   6598,
   6609,
   6621,
   6631,
   6642,
   6654,
   6663,
   6673,
   6684,
   6693,
   6703,
   6714,
   6726,
   6735,
   6744,
   6756,
   6765,
   6774,
   6783,
   6792,
   6801,
   6806,
   6812,
   6819,
   6825,
   6850,
   6856,
   6864,
   6873,
   6879,
   6885,
   6894,
   6903,
   6912,
   6921,
   6928,
   6939,
   6945,
   6953,
   6960,
   6968,
   6981,
   6990,
   6999,
   7008,
   7017,
   7026,
   7035,
   7042,
   7050,
   7059,
   7066,
   7074,
   7083,
   7089,
   7096,
   7104,
   7110,
   7117,
   7125,
   7134,
   7140,
   7146,
   7155,
   7161,
   7167,
   7173,
   7179,
   7185,
   7190,
   7196,
   7203,
   7209,
   7234,
   7240,
   7248,
   7257,
   7263,
   7269,
   7278,
   7287,
   7296,
   7305,
   7312,
   7323,
   7329,
   7337,
   7344,
   7352,
   7365,
   7374,
   7383,
   7392,
   7401,
   7410,
   7419,
   7426,
   7434,
   7443,
   7450,
   7458,
   7467,
   7473,
   7480,
   7488,
   7494,
   7501,
   7509,
   7518,
   7524,
   7530,
   7539,
   7545,
   7551,
   7557,
   7563,
   7569,
   7575,
   7582,
   7590,
   7597,
   7623,
   7630,
   7639,
   7649,
   7656,
   7663,
   7673,
   7683,
   7693,
   7703,
   7711,
   7723,
   7730,
   7739,
   7747,
   7756,
   7770,
   7780,
   7790,
   7800,
   7810,
   7820,
   7830,
   7838,
   7847,
   7857,
   7865,
   7874,
   7884,
   7891,
   7899,
   7908,
   7915,
   7923,
   7932,
   7942,
   7949,
   7956,
   7966,
   7973,
   7980,
   7987,
   7994,
   8001,
   8006,
   8012,
   8019,
   8025,
   8050,
   8056,
   8064,
   8073,
   8079,
   8085,
   8094,
   8103,
   8112,
   8121,
   8128,
   8139,
   8145,
   8153,
   8160,
   8168,
   8181,
   8190,
   8199,
   8208,
   8217,
   8226,
   8235,
   8242,
   8250,
   8259,
   8266,
   8274,
   8283,
   8289,
   8296,
   8304,
   8310,
   8317,
   8325,
   8334,
   8340,
   8346,
   8355,
   8361,
   8367,
   8373,
   8379,
   8385,
   8390,
   8396,
   8403,
   8409,
   8434,
   8440,
   8448,
   8457,
   8463,
   8469,
   8478,
   8487,
   8496,
   8505,
   8512,
   8523,
   8529,
   8537,
   8544,
   8552,
   8565,
   8574,
   8583,
   8592,
   8601,
   8610,
   8619,
   8626,
   8634,
   8643,
   8650,
   8658,
   8667,
   8673,
   8680,
   8688,
   8694,
   8701,
   8709,
   8718,
   8724,
   8730,
   8739,
   8745,
   8751,
   8757,
   8763,
   8769,
   8775,
   8782,
   8790,
   8797,
   8823,
   8830,
   8839,
   8849,
   8856,
   8863,
   8873,
   8883,
   8893,
   8903,
   8911,
   8923,
   8930,
   8939,
   8947,
   8956,
   8970,
   8980,
   8990,
   9000,
   9010,
   9020,
   9030,
   9038,
   9047,
   9057,
   9065,
   9074,
   9084,
   9091,
   9099,
   9108,
   9115,
   9123,
   9132,
   9142,
   9149,
   9156,
   9166,
   9173,
   9180,
   9187,
   9194,
   9201,
   9207,
   9214,
   9220,
   0,
   9225,
   9231,
   9233,
   9237,
   9244,
   9248,
   9255,
   9260,
   9267,
   9276,
   9281,
   9286,
   9293,
   9302,
   9307,
   9310,
   9314,
   9317,
   9320,
   9324,
   9328,
   9331,
   9334,
   9343,
   9356,
   9370,
   9379,
   9389,
   9398,
   9410,
   9420,
   9430,
   9439,
   9448,
   9451,
   9455,
   9460,
   9465,
   9469,
   9473,
   9477,
   9482,
   9487,
   9491,
   9495,
   9498,
   9501,
   9504,
   9507,
   9512,
   9516,
   9522,
   9533,
   9545,
   9551,
   9563,
   9576,
   9580,
   9584,
   9589,
   9600,
   9612,
   9617,
   9629,
   9642,
   9646,
   9649,
   9651,
   9656,
   9661,
   9665,
   9669,
   9672,
   9682,
   9688,
   9693,
   9699,
   9704,
   9709,
   9714,
   9719,
   9724,
   9728,
   9732,
   9736,
   9739,
   9742,
   9745,
   9747,
   9750,
   9754,
   9758,
   9761,
   9764,
   9769,
   9774,
   9780,
   9785,
   9789,
   9794,
   9800,
   9806,
   9811,
   9816,
   9819,
   9821,
   9825,
   9829,
   9833,
   9836,
   9840,
   9845,
   9850,
   9854,
   9858,
   9862,
   9865,
   9869,
   9874,
   9879,
   9883,
   9887,
   9890,
   9893,
   9896,
   9900,
   9903,
   9907,
   9912,
   9917,
   9921,
   9925,
   9930,
   9933,
   9937,
   9941,
   9944,
   9947,
   9953,
   9964,
   9976,
   9982,
   9994,
   10007,
   10011,
   10016,
   10026,
   10037,
   10042,
   10053,
   10065,
   10067,
   10069,
   10071,
   10075,
   10079,
   10083,
   10087,
   10092,
   10100,
   10105,
   10110,
   10114,
   10118,
   10128,
   10133,
   10139,
   10144,
   10149,
   10154,
   10159,
   10164,
   10168,
   10172,
   10176,
   10179,
   10183,
   10187,
   10190,
   10193,
   10198,
   10203,
   10207,
   10211,
   10215,
   10218,
   10221,
   10224,
   10229,
   10235,
   10240,
   10245,
   10250,
   10255,
   10260,
   10264,
   10268,
   10272,
   0,
   10277,
   10283,
   10285,
   10290,
   10301,
   10310,
   10315,
   10325,
   10332,
   10337,
   10343,
   0,
   10350,
   10356,
   10361,
   10371,
   10386,
   10401,
   10416,
   10421,
   10426,
   10431,
   10439,
   10454,
   0,
   10462,
   10465,
   10468,
   10471,
   10474,
   10477,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   10479,
   10482,
   10485,
   10487,
   10490,
   10493,
   10496,
   10499,
   10501,
   10503,
   10508,
   10510,
   10512,
   10517,
   10524,
   10532,
   10537,
   10543,
   10548,
   10552,
   10554,
   0,
   10556,
   0,
   0,
   0,
   10558,
   0,
   10561,
   10569,
   10577,
   10586,
   10593,
   10600,
   10607,
   10615,
   10625,
   10632,
   10634,
   10636,
   10638,
   10642,
   10644,
   0,
   0,
   0,
   10646,
   0,
   0,
   10649,
   0,
   10652,
   10654,
   0,
   10657,
   10660,
   10662,
   10664,
   10672,
   10680,
   10693,
   10706,
   10713,
   10723,
   10731,
   10739,
   10748,
   10762,
   10776,
   10788,
   10803,
   10816,
   10829,
   10842,
   10858,
   10873,
   10887,
   10901,
   10918,
   10934,
   10949,
   10957,
   10968,
   10977,
   10986,
   10995,
   11002,
   11012,
   11020,
   11028,
   11031,
   11035,
   11039,
   11043,
   11049,
   11055,
   11061,
   11068,
   11074,
   11080,
   11087,
   11093,
   11099,
   11105,
   11111,
   11117,
   11124,
   11130,
   11136,
   11142,
   11149,
   11156,
   11163,
   11170,
   11176,
   11182,
   11188,
   11195,
   11202,
   11209,
   11215,
   11221,
   11227,
   11234,
   11241,
   11248,
   11261,
   11267,
   11273,
   11279,
   11286,
   11292,
   11298,
   11304,
   11310,
   11316,
   11322,
   11328,
   11334,
   11341,
   11347,
   11353,
   11359,
   11366,
   11373,
   11380,
   11387,
   11394,
   11400,
   11406,
   11412,
   11419,
   11426,
   11433,
   11439,
   11445,
   11451,
   11458,
   11465,
   11472,
   11485,
   11488,
   11491,
   11496,
   11500,
   11504,
   11509,
   11513,
   11517,
   11521,
   11525,
   11529,
   11533,
   11539,
   11545,
   11548,
   11551,
   11556,
   11560,
   11564,
   11569,
   11573,
   11577,
   11581,
   11585,
   11589,
   11593,
   11599,
   11605,
   11608,
   11611,
   11614,
   11616,
   11620,
   11624,
   11628,
   11632,
   11636,
   11639,
   11644,
   11648,
   11652,
   11655,
   11659,
   11662,
   11665,
   11668,
   11671,
   11674,
   11677,
   11680,
   11684,
   11687,
   11691,
   11694,
   11698,
   11702,
   11706,
   11709,
   0,
   11711,
   0,
   11716,
   11718,
   11721,
   11724,
   11727,
   11733,
   11738,
   11748,
   11752,
   11756,
   11759,
   11762,
   11765,
   11767,
   11770,
   11773,
   11776,
   11778,
   11781,
   11785,
   11789,
   11792,
   11796,
   11799,
   11802,
   11805,
   11808,
   11811,
   11814,
   11817,
   11820,
   11823,
   11827,
   11831,
   11835,
   11839,
   11841,
   11843,
   11847,
   11851,
   11853,
   11857,
   11859,
   11861,
   11865,
   11869,
   11871,
   11878,
   11886,
   11891,
   11896,
   11901,
   11908,
   11916,
   11921,
   11926,
   11931,
   11933,
   11935,
   11937,
   11939,
   11941,
   11943,
   11945,
   0,
   11947,
   11949,
   11951,
   11953,
   11955,
   11957,
   11959,
   11961,
   11963,
   11965,
   11967,
   11969,
   11971,
   11976,
   11982,
   11988,
   11996,
   12005,
   12010,
   12017,
   12025,
   12031,
   12038,
   12045,
   12054,
   12064,
   12070,
   12078,
   12087,
   12096,
   12107,
   12119,
   12125,
   12133,
   12142,
   12145,
   12152,
   12166,
   12173,
   12187,
   12201,
   12208,
   12214,
   12226,
   12238,
   12244,
   12250,
   12257,
   12264,
   12270,
   12282,
   12294,
   12297,
   12304,
   12318,
   12325,
   12339,
   12353,
   12360,
   12372,
   12384,
   12391,
   12398,
   12404,
   12416,
   12428,
   12431,
   12434,
   12437,
   12442,
   12447,
   12452,
   12458,
   12463,
   12469,
   12479,
   12482,
   12486,
   12490,
   12494,
   12498,
   12502,
   12505,
   12509,
   12513,
   12517,
   12521,
   12526,
   12529,
   12533,
   12537,
   12541,
   12545,
   12550,
   12559,
   12581,
   12584,
   12587,
   12590,
   12593,
   12596,
   12599,
   12603,
   12606,
   12610,
   12618,
   12621,
   12625,
   12629,
   12633,
   12636,
   12639,
   12643,
   12647,
   12651,
   12655,
   12658,
   12662,
   12666,
   12670,
   12674,
   12682,
   12704,
   12706,
   12709,
   12721,
   12731,
   12738,
   12745,
   12752,
   12791,
   12810,
   12817,
   12824,
   12836,
   12842,
   12852,
   12859,
   12866,
   12873,
   12880,
   12886,
   12902,
   12944,
   12951,
   12958,
   12965,
   12977,
   12980,
   12983,
   12987,
   12992,
   12996,
   12998,
   13000,
   13003,
   13006,
   13008,
   13010,
   13013,
   13016,
   13019,
   13022,
   13026,
   13029,
   13031,
   13033,
   13036,
   13038,
   13040,
   13042,
   13044,
   13046,
   13050,
   13052,
   13054,
   13058,
   13062,
   13064,
   13067,
   13069,
   13071,
   13073,
   13075,
   13077,
   13079,
   13081,
   13083,
   13085,
   13087,
   13089,
   13093,
   13098,
   13104,
   13107,
   13111,
   13114,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   13118,
   13120,
   13123,
   13126,
   13129,
   13132,
   13135,
   13138,
   13140,
   13142,
   13144,
   13146,
   13149,
   13152,
   13155,
   13158,
   13161,
   13164,
   13166,
   13168,
   13170,
   13172,
   13178,
   13184,
   13190,
   13196,
   13203,
   13209,
   13216,
   13227,
   13234,
   13240,
   13248,
   13255,
   13262,
   13271,
   13277,
   13285,
   13292,
   13299,
   13308,
   13320,
   13345,
   13351,
   13357,
   13363,
   13369,
   13376,
   13382,
   13389,
   13400,
   13407,
   13413,
   13421,
   13428,
   13435,
   13444,
   13450,
   13458,
   13465,
   13472,
   13481,
   13493,
   13518,
   13524,
   13530,
   13536,
   13539,
   13542,
   13544,
   13549,
   13553,
   13556,
   13559,
   13564,
   13568,
   13572,
   13576,
   13580,
   13584,
   13588,
   13592,
   13596,
   13600,
   13604,
   13608,
   13611,
   13614,
   13618,
   13621,
   13624,
   13628,
   13630,
   13632,
   13634,
   13636,
   13638,
   13641,
   13643,
   13645,
   13647,
   13649,
   13651,
   13653,
   13659,
   13661,
   13663,
   13665,
   13667,
   13669,
   13671,
   13673,
   13677,
   13681,
   13685,
   13689,
   13693,
   13698,
   13703,
   13708,
   13713,
   13718,
   13722,
   13726,
   13731,
   13736,
   13741,
   13746,
   13750,
   13754,
   13758,
   13762,
   13765,
   13768,
   13773,
   13778,
   13783,
   13788,
   13791,
   13794,
   13799,
   13804,
   13809,
   13814,
   13817,
   13820,
   13825,
   13830,
   13835,
   13840,
   13843,
   13846,
   13851,
   13856,
   13861,
   13866,
   13870,
   13874,
   13880,
   13886,
   13892,
   13898,
   13902,
   13906,
   13912,
   13918,
   13924,
   13930,
   13934,
   13938,
   13944,
   13950,
   13956,
   13962,
   13965,
   13968,
   13973,
   13978,
   13983,
   13988,
   13991,
   13994,
   13999,
   14004,
   14009,
   14014,
   14019,
   14024,
   14029,
   14034,
   14039,
   14044,
   14049,
   14054,
   14061,
   14068,
   14075,
   14082,
   14089,
   14096,
   14098,
   14102,
   14106,
   14110,
   14114,
   14126,
   14139,
   14153,
   14167,
   14181,
   14195,
   14200,
   14205,
   14210,
   14215,
   14221,
   14227,
   14233,
   14239,
   14245,
   14251,
   14257,
   14263,
   14268,
   14273,
   14278,
   14283,
   14288,
   14293,
   14298,
   14303,
   14310,
   14317,
   14324,
   14331,
   14338,
   0,
   14345,
   14347,
   14352,
   14357,
   14361,
   14366,
   14371,
   14374,
   0,
   14378,
   14380,
   14385,
   14391,
   14398,
   14402,
   14406,
   14412,
   14417,
   14421,
   14425,
   14430,
   14434,
   14438,
   14444,
   14449,
   14453,
   14457,
   14462,
   14467,
   14472,
   14477,
   14482,
   14489,
   14496,
   14503,
   14510,
   14514,
   14520,
   14526,
   14532,
   14538,
   14544,
   14550,
   14556,
   14562,
   14566,
   14572,
   14578,
   14584,
   14590,
   14597,
   14602,
   14607,
   14612,
   14617,
   14623,
   14629,
   14635,
   14641,
   14648,
   14655,
   14662,
   14669,
   14671,
   14678,
   14685,
   14692,
   14699,
   14705,
   14711,
   14717,
   14723,
   14729,
   14735,
   14741,
   14747,
   14753,
   14758,
   14763,
   14766,
   14774,
   14782,
   14790,
   14798,
   14806,
   14814,
   14819,
   14822,
   14824,
   14826,
   14828,
   14830,
   14832,
   14834,
   14837,
   14843,
   14845,
   14850,
   14855,
   14860,
   14865,
   14874,
   14883,
   14893,
   14905,
   14913,
   14924,
   14935,
   14946,
   14958,
   14960,
   14964,
   14971,
   14974,
   14980,
   14986,
   14992,
   14998,
   15002,
   15009,
   15012,
   15018,
   15024,
   15030,
   15036,
   15043,
   15053,
   15056,
   15061,
   15069,
   15073,
   15080,
   15087,
   15094,
   15101,
   15106,
   15114,
   15118,
   15125,
   15132,
   15139,
   15146,
   15150,
   15157,
   15160,
   15166,
   15172,
   15178,
   15184,
   15188,
   15195,
   15198,
   15204,
   15210,
   15216,
   15222,
   15229,
   15232,
   15238,
   15244,
   15250,
   15256,
   15259,
   15265,
   15274,
   15283,
   15292,
   15301,
   15306,
   15311,
   15316,
   15321,
   15332,
   15340,
   15348,
   15356,
   15364,
   15372,
   15380,
   15385,
   15388,
   15390,
   15396,
   15403,
   15410,
   15417,
   15424,
   15432,
   15438,
   15446,
   15453,
   15460,
   15464,
   15468,
   15472,
   15477,
   15482,
   15487,
   15492,
   15497,
   15502,
   15507,
   15512,
   15517,
   15521,
   15525,
   15529,
   15534,
   15540,
   15544,
   15550,
   15554,
   15558,
   15560,
   15564,
   15568,
   15572,
   15575,
   15577,
   15581,
   15585,
   15588,
   15593,
   15598,
   15603,
   15606,
   15611,
   15616,
   15621,
   15624,
   15629,
   15633,
   15639,
   15643,
   15647,
   15653,
   15657,
   15661,
   15665,
   15669,
   15672,
   15676,
   15679,
   15682,
   15688,
   15694,
   15700,
   15705,
   15711,
   15719,
   15728,
   15733,
   15738,
   15740,
   15742,
   15748,
   0,
   0,
   15750,
   15752,
   15759,
   15766,
   15775,
   15785,
   15787,
   15789,
   15792,
   0,
   0,
   15794,
   0,
   0,
   15796,
   0,
   0,
   15799,
   15801,
   15804,
   15807,
   0,
   0,
   15811,
   15813,
   0,
   15815,
   15817,
   15823,
   15834,
   15850,
   15861,
   15871,
   15884,
   15895,
   15906,
   15920,
   0,
   0,
   0,
   15931,
   15933,
   15938,
   15942,
   15946,
   15950,
   15954,
   15959,
   15964,
   15969,
   15974,
   15978,
   15982,
   15988,
   15992,
   15996,
   15998,
   16002,
   16006,
   16008,
   16011,
   16015,
   16018,
   16023,
   16028,
   16031,
   16036,
   16041,
   16044,
   16048,
   16054,
   16058,
   16062,
   16069,
   16074,
   16081,
   16089,
   16097,
   16100,
   16104,
   16110,
   16114,
   16117,
   16119,
   16123,
   16127,
   16133,
   16136,
   16139,
   16143,
   16150,
   16158,
   16167,
   16174,
   16182,
   16191,
   16198,
   16206,
   16215,
   16222,
   16230,
   16239,
   16248,
   16258,
   16269,
   16278,
   16288,
   16299,
   16308,
   16318,
   16329,
   16338,
   16348,
   16359,
   16367,
   16376,
   16386,
   16394,
   16403,
   16413,
   16421,
   16430,
   16440,
   16448,
   16457,
   16467,
   16475,
   16484,
   16494,
   16502,
   16511,
   16521,
   16529,
   16538,
   16548,
   16556,
   16565,
   16575,
   16584,
   16594,
   16605,
   16614,
   16624,
   16635,
   16644,
   16654,
   16665,
   16674,
   16684,
   16695,
   16705,
   16716,
   16728,
   16738,
   16749,
   16761,
   16771,
   16782,
   16794,
   16804,
   16815,
   16827,
   16837,
   16848,
   16860,
   16870,
   16881,
   16893,
   16903,
   16914,
   16926,
   16936,
   16947,
   16959,
   16970,
   16982,
   16995,
   17006,
   17018,
   17031,
   17042,
   17054,
   17067,
   17078,
   17090,
   17103,
   17112,
   17122,
   17133,
   17142,
   17152,
   17163,
   17172,
   17182,
   17193,
   17202,
   17212,
   17223,
   17233,
   17244,
   17256,
   17266,
   17277,
   17289,
   17299,
   17310,
   17322,
   17332,
   17343,
   17355,
   17365,
   17376,
   17388,
   17398,
   17409,
   17421,
   17431,
   17442,
   17454,
   17464,
   17475,
   17487,
   17498,
   17510,
   17523,
   17534,
   17546,
   17559,
   17570,
   17582,
   17595,
   17606,
   17618,
   17631,
   17637,
   17645,
   17654,
   17664,
   17672,
   17681,
   17691,
   17699,
   17708,
   17718,
   17726,
   17735,
   17745,
   17753,
   17762,
   17772,
   17780,
   17789,
   17799,
   17807,
   17816,
   17826,
   17834,
   17843,
   17853,
   17860,
   17869,
   17879,
   17890,
   17899,
   17909,
   17920,
   17929,
   17939,
   17950,
   17959,
   17969,
   17980,
   17988,
   17997,
   18007,
   18015,
   18024,
   18034,
   18042,
   18051,
   18061,
   18069,
   18078,
   18088,
   18096,
   18105,
   18115,
   18123,
   18132,
   18142,
   18150,
   18159,
   18169,
   18177,
   18186,
   18196,
   18205,
   18215,
   18226,
   18235,
   18245,
   18256,
   18265,
   18275,
   18286,
   18295,
   18305,
   18316,
   18323,
   18330,
   18337,
   18339,
   18341,
   18346,
   18351,
   18356,
   18361,
   18366,
   18372,
   18378,
   18384,
   18390,
   18397,
   18404,
   18411,
   18418,
   18425,
   18432,
   18439,
   18446,
   18452,
   18458,
   18464,
   18470,
   18476,
   18482,
   18488,
   18494,
   18502,
   18510,
   18518,
   18526,
   18534,
   18542,
   18547,
   18590,
   18633,
   18653,
   18658,
   18662,
   18666,
   18672,
   18675,
   18681,
   18687,
   18700,
   18712,
   18720,
   18728,
   0,
   0,
   0,
   18736,
   18743,
   18749,
   18753,
   18760,
   18764,
   18771,
   18775,
   18785,
   18790,
   18795,
   18803,
   18808,
   18816,
   18821,
   18829,
   18837,
   18848,
   18853,
   18861,
   18867,
   18876,
   18882,
   18891,
   18896,
   18904,
   18909,
   18912,
   18915,
   18919,
   18925,
   18929,
   18933,
   18937,
   18941,
   18945,
   18949,
   18952,
   18957,
   18961,
   18966,
   18970,
   18975,
   18980,
   0,
   0,
   18984,
   18991,
   18998,
   19000,
   0,
   0,
   0,
   0,
   0,
   0,
   19002,
   19005,
   0,
   0,
   19008,
   0,
   0,
   0,
   19010,
   19012,
   0,
   19014,
   19025,
   19041,
   19052,
   19064,
   19078,
   19083,
   19088,
   0,
   19090,
   19097,
   19104,
   19107,
   19110,
   19114,
   19118,
   19122,
   19126,
   19131,
   19136,
   19139,
   19144,
   19148,
   19153,
   19158,
   19162,
   19166,
   19168,
   19171,
   19174,
   19178,
   19186,
   19194,
   19203,
   19210,
   19213,
   19217,
   19225,
   19230,
   19238,
   19249,
   19260,
   19274,
   19288,
   19293,
   0,
   19304,
   19307,
   19313,
   19322,
   19330,
   19343,
   19355,
   19362,
   19368,
   19372,
   19374,
   19377,
   19383,
   19392,
   19405,
   19417,
   19424,
   19430,
   19434,
   19436,
   19439,
   19445,
   19454,
   19467,
   19479,
   19486,
   19492,
   19497,
};

static const nir_algebraic_table nir_opt_algebraic_table = {
   .transforms = nir_opt_algebraic_transforms,
   .transform_offsets = nir_opt_algebraic_transform_offsets,
   .pass_op_table = nir_opt_algebraic_pass_op_table,
   .values = nir_opt_algebraic_values,
   .expression_cond = nir_opt_algebraic_expression_cond,
   .variable_cond = nir_opt_algebraic_variable_cond,
};

bool
nir_opt_algebraic(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[107];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(5356 == ARRAY_SIZE(nir_opt_algebraic_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = !options->has_sdot_4x8;
   condition_flags[10] = !options->has_udot_4x8;
   condition_flags[11] = !options->has_sudot_4x8;
   condition_flags[12] = !options->has_dot_2x16;
   condition_flags[13] = options->lower_flrp16;
   condition_flags[14] = !options->lower_flrp16;
   condition_flags[15] = options->lower_flrp32;
   condition_flags[16] = !options->lower_flrp32;
   condition_flags[17] = options->lower_flrp64;
   condition_flags[18] = !options->lower_flrp64;
   condition_flags[19] = options->lower_ftrunc;
   condition_flags[20] = options->lower_ffloor;
   condition_flags[21] = !options->lower_ffloor;
   condition_flags[22] = options->lower_ffract;
   condition_flags[23] = options->lower_fceil;
   condition_flags[24] = options->lower_ffma16;
   condition_flags[25] = options->lower_ffma32;
   condition_flags[26] = options->lower_ffma64;
   condition_flags[27] = options->fuse_ffma16;
   condition_flags[28] = options->fuse_ffma32;
   condition_flags[29] = options->fuse_ffma64;
   condition_flags[30] = options->lower_fdph;
   condition_flags[31] = !options->lower_fdph;
   condition_flags[32] = options->lower_fdot;
   condition_flags[33] = !options->lower_fsat;
   condition_flags[34] = !options->lower_iabs;
   condition_flags[35] = options->lower_fsat;
   condition_flags[36] = !options->lower_fsign;
   condition_flags[37] = options->lower_umax;
   condition_flags[38] = options->lower_umin;
   condition_flags[39] = !options->lower_umax;
   condition_flags[40] = !options->lower_umin;
   condition_flags[41] = options->lower_scmp;
   condition_flags[42] = options->lower_vector_cmp;
   condition_flags[43] = !options->lower_rotate;
   condition_flags[44] = options->lower_rotate;
   condition_flags[45] = options->lower_fpow;
   condition_flags[46] = !options->lower_fpow;
   condition_flags[47] = options->lower_fdiv;
   condition_flags[48] = options->lower_fsqrt;
   condition_flags[49] = !options->lower_fsqrt;
   condition_flags[50] = options->lower_sincos;
   condition_flags[51] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[52] = !options->lower_extract_byte;
   condition_flags[53] = !options->lower_extract_word;
   condition_flags[54] = options->has_pack_32_4x8;
   condition_flags[55] = options->lower_pack_64_2x32_split;
   condition_flags[56] = options->lower_pack_32_2x16_split;
   condition_flags[57] = options->lower_unpack_64_2x32_split;
   condition_flags[58] = options->lower_unpack_32_2x16_split;
   condition_flags[59] = options->lower_fmod;
   condition_flags[60] = options->lower_uadd_carry;
   condition_flags[61] = options->lower_usub_borrow;
   condition_flags[62] = options->lower_bitfield_insert;
   condition_flags[63] = options->lower_hadd;
   condition_flags[64] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[65] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[66] = options->lower_uadd_sat;
   condition_flags[67] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[70] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[71] = options->lower_bitfield_insert_to_shifts;
   condition_flags[72] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[73] = options->lower_bitfield_extract;
   condition_flags[74] = options->lower_bitfield_extract_to_shifts;
   condition_flags[75] = options->lower_ifind_msb;
   condition_flags[76] = options->lower_find_msb_to_reverse;
   condition_flags[77] = options->lower_find_lsb;
   condition_flags[78] = options->lower_extract_byte;
   condition_flags[79] = options->lower_extract_word;
   condition_flags[80] = options->lower_pack_unorm_2x16;
   condition_flags[81] = options->lower_pack_unorm_4x8;
   condition_flags[82] = options->lower_pack_snorm_2x16;
   condition_flags[83] = options->lower_pack_snorm_4x8;
   condition_flags[84] = options->lower_unpack_unorm_2x16;
   condition_flags[85] = options->lower_unpack_unorm_4x8;
   condition_flags[86] = options->lower_unpack_snorm_2x16;
   condition_flags[87] = options->lower_unpack_snorm_4x8;
   condition_flags[88] = options->lower_pack_split;
   condition_flags[89] = options->lower_isign;
   condition_flags[90] = !options->lower_isign;
   condition_flags[91] = options->lower_fsign;
   condition_flags[92] = !options->has_imul24;
   condition_flags[93] = !options->has_umul24;
   condition_flags[94] = !options->has_umad24;
   condition_flags[95] = options->has_imul24;
   condition_flags[96] = options->has_umad24;
   condition_flags[97] = options->has_umul24;
   condition_flags[98] = options->has_fused_comp_and_csel;
   condition_flags[99] = options->lower_iadd_sat;
   condition_flags[100] = options->support_8bit_alu;
   condition_flags[101] = options->support_16bit_alu;
   condition_flags[102] = options->lower_ldexp;
   condition_flags[103] = !options->lower_bitfield_reverse;
   condition_flags[104] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[105] = options->lower_fisnormal;
   condition_flags[106] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 15
 * transforms:
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b'))
 */


static const nir_search_value_union nir_opt_algebraic_before_ffma_values[] = {
   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 0, 1 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_fmul,
      0, 2,
      { 2, 3 },
      0,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      0, 2,
      { 7, 8 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1866_0_0 -> 0 in the cache */
   /* search1866_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1866_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      0, 2,
      { 10, 3 },
      0,
   } },

   /* replace1866_0_0 -> 5 in the cache */
   /* replace1866_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1866_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      0, 2,
      { 12, 8 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1867_0_0 -> 0 in the cache */
   /* search1867_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1867_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 14, 3 },
      0,
   } },

   /* replace1867_0_0 -> 5 in the cache */
   /* replace1867_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1867_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 16, 8 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1868_0_0 -> 0 in the cache */
   /* search1868_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1868_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 18, 3 },
      0,
   } },

   /* replace1868_0_0 -> 5 in the cache */
   /* replace1868_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1868_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 20, 8 },
      -1,
   } },

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search1869_0_0 -> 5 in the cache */
   /* search1869_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search1869_1_0 -> 5 in the cache */
   /* search1869_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 22, 23 },
      -1,
   } },

   /* replace1869_0 -> 5 in the cache */
   /* replace1869_1_0 -> 8 in the cache */
   /* replace1869_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmul,
      0, 2,
      { 5, 25 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search1870_0_0 -> 5 in the cache */
   /* search1870_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search1870_1_0 -> 5 in the cache */
   /* search1870_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 3,
      { 27, 28 },
      -1,
   } },

   /* replace1870_0 -> 5 in the cache */
   /* replace1870_1_0 -> 8 in the cache */
   /* replace1870_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_imul,
      0, 2,
      { 5, 30 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1871_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fadd,
      0, 1,
      { 33, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search1872_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1872_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 36, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search1873_1_0 -> 39 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 40, 42 },
      -1,
   } },

   /* replace1873 -> 41 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search1874_0 -> 39 in the cache */
   /* search1874_1_0_0 -> 39 in the cache */
   /* search1874_1_0 -> 40 in the cache */
   /* search1874_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 40, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 39, 44 },
      -1,
   } },

   /* replace1874 -> 41 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search1875_0_0 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search1875_1_0 -> 39 in the cache */
   /* search1875_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 46, 47 },
      -1,
   } },

   /* replace1875 -> 41 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search1876_0 -> 39 in the cache */
   /* search1876_1_0_0 -> 39 in the cache */
   /* search1876_1_0 -> 46 in the cache */
   /* search1876_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 46, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 39, 49 },
      -1,
   } },

   /* replace1876 -> 41 in the cache */

   /* ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a') */
   /* search1877_0_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 39, 51 },
      0,
   } },
   /* search1877_1_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 39, 53 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_flrp,
      -1, 2,
      { 52, 54, 55 },
      -1,
   } },

   /* replace1877_0_0 -> 51 in the cache */
   /* replace1877_0_1 -> 53 in the cache */
   /* replace1877_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 51, 53, 55 },
      -1,
   } },
   /* replace1877_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 57, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a') */
   /* search1878_0_0 -> 39 in the cache */
   /* search1878_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 39, 53 },
      0,
   } },
   /* search1878_1_0 -> 39 in the cache */
   /* search1878_1_1 -> 51 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 39, 51 },
      0,
   } },
   /* search1878_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true, false,
      nir_op_flrp,
      -1, 2,
      { 59, 60, 55 },
      -1,
   } },

   /* replace1878_0_0 -> 53 in the cache */
   /* replace1878_0_1 -> 51 in the cache */
   /* replace1878_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 53, 51, 55 },
      -1,
   } },
   /* replace1878_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 62, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 64, 65 },
      0,
   } },
   /* search1879_1_0 -> 64 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 64, 67 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_flrp,
      -1, 2,
      { 66, 68, 69 },
      -1,
   } },

   /* replace1879_0_0 -> 69 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 71, 73 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 69, 74 },
      -1,
   } },
   /* replace1879_1_0 -> 64 in the cache */
   /* replace1879_1_1 -> 72 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      3, 1,
      { 64, 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      0, 4,
      { 75, 76 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_before_ffma_expression_cond[] = {
   (is_used_once),
};

static const nir_search_variable_cond nir_opt_algebraic_before_ffma_variable_cond[] = {
   (is_not_const),
};

static const struct transform nir_opt_algebraic_before_ffma_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 24, 26, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 29, 31, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 56, 58, 0 },
   { 61, 63, 0 },
   { 70, 77, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_before_ffma_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         2,
         3,
         19,
         3,
         3,
         20,
         19,
         20,
         19,
      },
   },
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         4,
         5,
         28,
         5,
         5,
         29,
         28,
         29,
         28,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         0,
         5,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         6,
         7,
         6,
         6,
         12,
         13,
         31,
         32,
         7,
         7,
         7,
         7,
         14,
         15,
         33,
         34,
         6,
         7,
         16,
         6,
         12,
         13,
         31,
         32,
         6,
         7,
         6,
         6,
         12,
         17,
         31,
         32,
         12,
         14,
         12,
         12,
         12,
         18,
         32,
         32,
         13,
         15,
         13,
         17,
         18,
         13,
         35,
         36,
         31,
         33,
         31,
         31,
         32,
         35,
         31,
         32,
         32,
         34,
         32,
         32,
         32,
         36,
         32,
         32,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         8,
         9,
         8,
         8,
         21,
         22,
         37,
         38,
         9,
         9,
         9,
         9,
         23,
         24,
         39,
         40,
         8,
         9,
         25,
         8,
         21,
         22,
         37,
         38,
         8,
         9,
         8,
         8,
         21,
         26,
         37,
         38,
         21,
         23,
         21,
         21,
         21,
         27,
         38,
         38,
         22,
         24,
         22,
         26,
         27,
         22,
         41,
         42,
         37,
         39,
         37,
         37,
         38,
         41,
         37,
         38,
         38,
         40,
         38,
         38,
         38,
         42,
         38,
         38,
      },
   },
   [nir_op_fneg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_before_ffma_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   14,
   18,
   20,
   22,
   24,
   26,
   28,
   30,
   32,
   35,
   39,
   41,
   43,
   47,
   49,
   52,
   54,
   57,
   61,
   66,
   68,
   71,
   73,
   76,
   80,
};

static const nir_algebraic_table nir_opt_algebraic_before_ffma_table = {
   .transforms = nir_opt_algebraic_before_ffma_transforms,
   .transform_offsets = nir_opt_algebraic_before_ffma_transform_offsets,
   .pass_op_table = nir_opt_algebraic_before_ffma_pass_op_table,
   .values = nir_opt_algebraic_before_ffma_values,
   .expression_cond = nir_opt_algebraic_before_ffma_expression_cond,
   .variable_cond = nir_opt_algebraic_before_ffma_variable_cond,
};

bool
nir_opt_algebraic_before_ffma(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[107];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(78 == ARRAY_SIZE(nir_opt_algebraic_before_ffma_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = !options->has_sdot_4x8;
   condition_flags[10] = !options->has_udot_4x8;
   condition_flags[11] = !options->has_sudot_4x8;
   condition_flags[12] = !options->has_dot_2x16;
   condition_flags[13] = options->lower_flrp16;
   condition_flags[14] = !options->lower_flrp16;
   condition_flags[15] = options->lower_flrp32;
   condition_flags[16] = !options->lower_flrp32;
   condition_flags[17] = options->lower_flrp64;
   condition_flags[18] = !options->lower_flrp64;
   condition_flags[19] = options->lower_ftrunc;
   condition_flags[20] = options->lower_ffloor;
   condition_flags[21] = !options->lower_ffloor;
   condition_flags[22] = options->lower_ffract;
   condition_flags[23] = options->lower_fceil;
   condition_flags[24] = options->lower_ffma16;
   condition_flags[25] = options->lower_ffma32;
   condition_flags[26] = options->lower_ffma64;
   condition_flags[27] = options->fuse_ffma16;
   condition_flags[28] = options->fuse_ffma32;
   condition_flags[29] = options->fuse_ffma64;
   condition_flags[30] = options->lower_fdph;
   condition_flags[31] = !options->lower_fdph;
   condition_flags[32] = options->lower_fdot;
   condition_flags[33] = !options->lower_fsat;
   condition_flags[34] = !options->lower_iabs;
   condition_flags[35] = options->lower_fsat;
   condition_flags[36] = !options->lower_fsign;
   condition_flags[37] = options->lower_umax;
   condition_flags[38] = options->lower_umin;
   condition_flags[39] = !options->lower_umax;
   condition_flags[40] = !options->lower_umin;
   condition_flags[41] = options->lower_scmp;
   condition_flags[42] = options->lower_vector_cmp;
   condition_flags[43] = !options->lower_rotate;
   condition_flags[44] = options->lower_rotate;
   condition_flags[45] = options->lower_fpow;
   condition_flags[46] = !options->lower_fpow;
   condition_flags[47] = options->lower_fdiv;
   condition_flags[48] = options->lower_fsqrt;
   condition_flags[49] = !options->lower_fsqrt;
   condition_flags[50] = options->lower_sincos;
   condition_flags[51] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[52] = !options->lower_extract_byte;
   condition_flags[53] = !options->lower_extract_word;
   condition_flags[54] = options->has_pack_32_4x8;
   condition_flags[55] = options->lower_pack_64_2x32_split;
   condition_flags[56] = options->lower_pack_32_2x16_split;
   condition_flags[57] = options->lower_unpack_64_2x32_split;
   condition_flags[58] = options->lower_unpack_32_2x16_split;
   condition_flags[59] = options->lower_fmod;
   condition_flags[60] = options->lower_uadd_carry;
   condition_flags[61] = options->lower_usub_borrow;
   condition_flags[62] = options->lower_bitfield_insert;
   condition_flags[63] = options->lower_hadd;
   condition_flags[64] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[65] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[66] = options->lower_uadd_sat;
   condition_flags[67] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[70] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[71] = options->lower_bitfield_insert_to_shifts;
   condition_flags[72] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[73] = options->lower_bitfield_extract;
   condition_flags[74] = options->lower_bitfield_extract_to_shifts;
   condition_flags[75] = options->lower_ifind_msb;
   condition_flags[76] = options->lower_find_msb_to_reverse;
   condition_flags[77] = options->lower_find_lsb;
   condition_flags[78] = options->lower_extract_byte;
   condition_flags[79] = options->lower_extract_word;
   condition_flags[80] = options->lower_pack_unorm_2x16;
   condition_flags[81] = options->lower_pack_unorm_4x8;
   condition_flags[82] = options->lower_pack_snorm_2x16;
   condition_flags[83] = options->lower_pack_snorm_4x8;
   condition_flags[84] = options->lower_unpack_unorm_2x16;
   condition_flags[85] = options->lower_unpack_unorm_4x8;
   condition_flags[86] = options->lower_unpack_snorm_2x16;
   condition_flags[87] = options->lower_unpack_snorm_4x8;
   condition_flags[88] = options->lower_pack_split;
   condition_flags[89] = options->lower_isign;
   condition_flags[90] = !options->lower_isign;
   condition_flags[91] = options->lower_fsign;
   condition_flags[92] = !options->has_imul24;
   condition_flags[93] = !options->has_umul24;
   condition_flags[94] = !options->has_umad24;
   condition_flags[95] = options->has_imul24;
   condition_flags[96] = options->has_umad24;
   condition_flags[97] = options->has_umul24;
   condition_flags[98] = options->has_fused_comp_and_csel;
   condition_flags[99] = options->lower_iadd_sat;
   condition_flags[100] = options->support_8bit_alu;
   condition_flags[101] = options->support_16bit_alu;
   condition_flags[102] = options->lower_ldexp;
   condition_flags[103] = !options->lower_bitfield_reverse;
   condition_flags[104] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[105] = options->lower_fisnormal;
   condition_flags[106] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_before_ffma_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 175
 * transforms:
 *    ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b'))
 *    ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b'))
 *    ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))
 *    ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a'))
 *    ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')))
 *    ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a')))
 *    ('fneg', ('fneg', 'a')) => a
 *    ('fadd', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fneg', 'a') => ('fmul', 'a', -1.0)
 *    ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b')
 *    ('ineg', 'a') => ('isub', 0, 'a')
 *    ('iabs', 'a') => ('imax', 'a', ('ineg', 'a'))
 *    ('~fadd@16', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c')
 *    ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c'))
 *    ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0))
 *    ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0))
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd')))
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('ior', 'a', 'a') => a
 *    ('iand', 'a', 'a') => a
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b')
 *    ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a')
 *    ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b'))
 *    ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b'))
 *    ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38)
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g')))
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g')))
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b'))
 *    ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c'))
 *    ('ishl', 'a', 0) => a
 *    ('ishl', 'a', -32) => a
 *    ('ishr', 'a', 0) => a
 *    ('ishr', 'a', -32) => a
 *    ('ushr', 'a', 0) => a
 *    ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1)
 *    ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2)
 *    ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3)
 *    ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1)
 *    ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b')
 *    ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b')
 *    ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b')))
 *    ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a')
 *    ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a')
 *    ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a')
 *    ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a')
 *    ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a')
 *    ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a')
 *    ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a')
 *    ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a')
 *    ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a')
 *    ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a')
 *    ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a')
 *    ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a')
 *    ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a')
 *    ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a')
 *    ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a')
 *    ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a')
 *    ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a')
 *    ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a')
 *    ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a')
 *    ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a')
 *    ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a')
 *    ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b')
 *    ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b')
 *    ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b')
 *    ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b')
 *    ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b')
 *    ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b')
 *    ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b')
 *    ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b')
 *    ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c')
 *    ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c')
 *    ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b')
 *    ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b')
 *    ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b')
 *    ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b')
 *    ('f2fmp', 'a') => ('f2f16', 'a')
 *    ('f2imp', 'a') => ('f2i16', 'a')
 *    ('f2ump', 'a') => ('f2u16', 'a')
 *    ('i2imp', 'a') => ('i2i16', 'a')
 *    ('i2fmp', 'a') => ('i2f16', 'a')
 *    ('i2imp', 'a') => ('u2u16', 'a')
 *    ('u2fmp', 'a') => ('u2f16', 'a')
 *    ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf)
 */


static const nir_search_value_union nir_opt_algebraic_late_values[] = {
   /* ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace1880_0 -> 0 in the cache */
   /* replace1880_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b') */
   /* search1881_0_0_0 -> 0 in the cache */
   /* search1881_0_0_1 -> 1 in the cache */
   /* search1881_0_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 2 },
      0,
   } },
   /* search1881_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace1881_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace1881_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b') */
   /* search1882_0 -> 3 in the cache */
   /* search1882_1_0 -> 0 in the cache */
   /* search1882_1_1 -> 1 in the cache */
   /* search1882_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace1882_0_0 -> 0 in the cache */
   /* replace1882_0 -> 9 in the cache */
   /* replace1882_1 -> 1 in the cache */
   /* replace1882 -> 10 in the cache */

   /* ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b')) */
   /* search1883_0 -> 3 in the cache */
   /* search1883_1_0_0 -> 0 in the cache */
   /* search1883_1_0_1 -> 1 in the cache */
   /* search1883_1_0 -> 2 in the cache */
   /* search1883_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace1883_0 -> 0 in the cache */
   /* replace1883_1_0 -> 1 in the cache */
   /* replace1883_1 -> 5 in the cache */
   /* replace1883 -> 6 in the cache */

   /* ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   /* search1884_0_0 -> 0 in the cache */
   /* search1884_0_1 -> 1 in the cache */
   /* search1884_0 -> 2 in the cache */
   /* search1884_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace1884_0 -> 0 in the cache */
   /* replace1884_1_0 -> 1 in the cache */
   /* replace1884_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search1885_0_0_0 -> 0 in the cache */
   /* search1885_0_0_1 -> 1 in the cache */
   /* search1885_0_0 -> 2 in the cache */
   /* search1885_0 -> 7 in the cache */
   /* search1885_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace1885_0_0 -> 0 in the cache */
   /* replace1885_0 -> 9 in the cache */
   /* replace1885_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search1886_0 -> 3 in the cache */
   /* search1886_1_0 -> 0 in the cache */
   /* search1886_1_1 -> 1 in the cache */
   /* search1886_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace1886_0_0 -> 0 in the cache */
   /* replace1886_0 -> 9 in the cache */
   /* replace1886_1 -> 1 in the cache */
   /* replace1886 -> 16 in the cache */

   /* ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search1887_0 -> 3 in the cache */
   /* search1887_1_0_0 -> 0 in the cache */
   /* search1887_1_0_1 -> 1 in the cache */
   /* search1887_1_0 -> 2 in the cache */
   /* search1887_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace1887_0 -> 0 in the cache */
   /* replace1887_1_0 -> 1 in the cache */
   /* replace1887_1 -> 5 in the cache */
   /* replace1887 -> 14 in the cache */

   /* ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search1888_0_0 -> 0 in the cache */
   /* search1888_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1888_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_feq,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace1888_0 -> 0 in the cache */
   /* replace1888_1_0 -> 1 in the cache */
   /* replace1888_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search1889_0_0 -> 0 in the cache */
   /* search1889_0_1 -> 1 in the cache */
   /* search1889_0 -> 19 in the cache */
   /* search1889_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fneu,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace1889_0 -> 0 in the cache */
   /* replace1889_1_0 -> 1 in the cache */
   /* replace1889_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1890_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 24, 1 },
      0,
   } },
   /* search1890_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 25, 3 },
      -1,
   } },

   /* replace1890_0 -> 0 in the cache */
   /* replace1890_1_0 -> 1 in the cache */
   /* replace1890_1 -> 5 in the cache */
   /* replace1890 -> 14 in the cache */

   /* ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search1891_0_0_0 -> 24 in the cache */
   /* search1891_0_0_1 -> 1 in the cache */
   /* search1891_0_0 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 25 },
      0,
   } },
   /* search1891_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 27, 3 },
      -1,
   } },

   /* replace1891_0_0 -> 0 in the cache */
   /* replace1891_0 -> 9 in the cache */
   /* replace1891_1 -> 1 in the cache */
   /* replace1891 -> 16 in the cache */

   /* ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search1892_0 -> 3 in the cache */
   /* search1892_1_0 -> 24 in the cache */
   /* search1892_1_1 -> 1 in the cache */
   /* search1892_1 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 3, 25 },
      -1,
   } },

   /* replace1892_0_0 -> 0 in the cache */
   /* replace1892_0 -> 9 in the cache */
   /* replace1892_1 -> 1 in the cache */
   /* replace1892 -> 16 in the cache */

   /* ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search1893_0 -> 3 in the cache */
   /* search1893_1_0_0 -> 24 in the cache */
   /* search1893_1_0_1 -> 1 in the cache */
   /* search1893_1_0 -> 25 in the cache */
   /* search1893_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 1,
      { 3, 27 },
      -1,
   } },

   /* replace1893_0 -> 0 in the cache */
   /* replace1893_1_0 -> 1 in the cache */
   /* replace1893_1 -> 5 in the cache */
   /* replace1893 -> 14 in the cache */

   /* ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search1894_0_0 -> 24 in the cache */
   /* search1894_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 24, 1 },
      0,
   } },
   /* search1894_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace1894_0 -> 0 in the cache */
   /* replace1894_1_0 -> 1 in the cache */
   /* replace1894_1 -> 5 in the cache */
   /* replace1894 -> 21 in the cache */

   /* ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search1895_0_0 -> 24 in the cache */
   /* search1895_0_1 -> 1 in the cache */
   /* search1895_0 -> 31 in the cache */
   /* search1895_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace1895_0 -> 0 in the cache */
   /* replace1895_1_0 -> 1 in the cache */
   /* replace1895_1 -> 5 in the cache */
   /* replace1895 -> 23 in the cache */

   /* ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')) */
   /* search1896_0_0 -> 0 in the cache */
   /* search1896_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search1896_1_0_0 -> 0 in the cache */
   /* search1896_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1896_1_1_0 -> 1 in the cache */
   /* search1896_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      2, 1,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 34, 37 },
      -1,
   } },

   /* replace1896_0_0 -> 0 in the cache */
   /* replace1896_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* replace1896_1_0 -> 1 in the cache */
   /* replace1896_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 39, 40 },
      -1,
   } },

   /* ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search1897_1_0 -> 42 in the cache */
   /* search1897_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 2,
      { 44, 45 },
      -1,
   } },

   /* replace1897_0 -> 43 in the cache */
   /* replace1897_1_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, true,
      nir_op_flt,
      -1, 0,
      { 43, 47 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))) */
   /* search1898_0_0 -> 0 in the cache */
   /* search1898_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search1898_1_0_0 -> 0 in the cache */
   /* search1898_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1898_1_1_0 -> 1 in the cache */
   /* search1898_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      2, 1,
      { 50, 51 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 49, 52 },
      -1,
   } },

   /* replace1898_0_0_0 -> 0 in the cache */
   /* replace1898_0_0_1 -> 1 in the cache */
   /* replace1898_0_0 -> 39 in the cache */
   /* replace1898_0_1_0 -> 1 in the cache */
   /* replace1898_0_1_1 -> 0 in the cache */
   /* replace1898_0_1 -> 40 in the cache */
   /* replace1898_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 1,
      { 41 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a'))) */
   /* search1899_0_0 -> 42 in the cache */
   /* search1899_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search1899_1_0 -> 42 in the cache */
   /* search1899_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 2,
      { 55, 56 },
      -1,
   } },

   /* replace1899_0_0 -> 43 in the cache */
   /* replace1899_0_1_0 -> 42 in the cache */
   /* replace1899_0_1 -> 47 in the cache */
   /* replace1899_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 48 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   /* search1900_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 59 },
      -1,
   } },

   /* replace1900 -> 42 in the cache */

   /* ('fadd', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search1901_0 -> 0 in the cache */
   /* search1901_1_0 -> 1 in the cache */
   /* search1901_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* replace1901_0 -> 0 in the cache */
   /* replace1901_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('fneg', 'a') => ('fmul', 'a', -1.0) */
   /* search1902_0 -> 42 in the cache */
   /* search1902 -> 59 in the cache */

   /* replace1902_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 42, 63 },
      -1,
   } },

   /* ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b') */
   /* search1903_0 -> 0 in the cache */
   /* search1903_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 0, 65 },
      -1,
   } },

   /* replace1903_0 -> 0 in the cache */
   /* replace1903_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('ineg', 'a') => ('isub', 0, 'a') */
   /* search1904_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 42 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace1904_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 69, 42 },
      -1,
   } },

   /* ('iabs', 'a') => ('imax', 'a', ('ineg', 'a')) */
   /* search1905_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iabs,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace1905_0 -> 42 in the cache */
   /* replace1905_1_0 -> 42 in the cache */
   /* replace1905_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_imax,
      0, 1,
      { 42, 68 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 73, 74 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 75, 76 },
      -1,
   } },

   /* replace1906_0 -> 73 in the cache */
   /* replace1906_1 -> 74 in the cache */
   /* replace1906_2 -> 76 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 73, 74, 76 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 79, 80 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 81, 82 },
      -1,
   } },

   /* replace1907_0 -> 79 in the cache */
   /* replace1907_1 -> 80 in the cache */
   /* replace1907_2 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 79, 80, 82 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 85, 86 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 87, 88 },
      -1,
   } },

   /* replace1908_0 -> 85 in the cache */
   /* replace1908_1 -> 86 in the cache */
   /* replace1908_2 -> 88 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 85, 86, 88 },
      -1,
   } },

   /* ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      1, 1,
      { 91, 92 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 2,
      { 93, 94 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd3,
      0, 1,
      { 96, 97, 98 },
      -1,
   } },

   /* ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c') */
   /* search1910_0_0 -> 91 in the cache */
   /* search1910_0_1 -> 92 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 91, 92 },
      0,
   } },
   /* search1910_1 -> 94 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 100, 94 },
      -1,
   } },

   /* replace1910_0 -> 96 in the cache */
   /* replace1910_1_0 -> 97 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 97 },
      -1,
   } },
   /* replace1910_2 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd3,
      0, 1,
      { 96, 102, 98 },
      -1,
   } },

   /* ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c')) */
   /* search1911_0_0 -> 91 in the cache */
   /* search1911_0_1 -> 92 in the cache */
   /* search1911_0 -> 100 in the cache */
   /* search1911_1 -> 94 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_isub,
      -1, 0,
      { 100, 94 },
      -1,
   } },

   /* replace1911_0 -> 96 in the cache */
   /* replace1911_1_0 -> 97 in the cache */
   /* replace1911_1 -> 102 in the cache */
   /* replace1911_2_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_iadd3,
      0, 1,
      { 96, 102, 105 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0)) */
   /* search1912_0_0 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 73 },
      -1,
   } },
   /* search1912_1 -> 74 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 107, 74 },
      1,
   } },

   /* replace1912_0_0 -> 73 in the cache */
   /* replace1912_0_1 -> 74 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 73, 74 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 110, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 109, 112 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0)) */
   /* search1913_0 -> 73 in the cache */
   /* search1913_1_0 -> 74 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 74 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 73, 114 },
      1,
   } },

   /* replace1913_0_0 -> 73 in the cache */
   /* replace1913_0_1 -> 74 in the cache */
   /* replace1913_0 -> 109 in the cache */
   /* replace1913_1_0 -> 111 in the cache */
   /* replace1913_1_1 -> 110 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_vec2,
      -1, 0,
      { 111, 110 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 109, 116 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 119 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 118, 120 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace1914_1 -> 119 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 122, 119 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search1915_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 124, 125 },
      -1,
   } },

   /* replace1915_0 -> 0 in the cache */
   /* replace1915_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search1916_0_0 -> 0 in the cache */
   /* search1916_0 -> 124 in the cache */
   /* search1916_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 124, 125 },
      -1,
   } },

   /* replace1916_0 -> 0 in the cache */
   /* replace1916_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search1917_0_0 -> 0 in the cache */
   /* search1917_0 -> 124 in the cache */
   /* search1917_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 124, 125 },
      -1,
   } },

   /* replace1917_0 -> 0 in the cache */
   /* replace1917_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search1918_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 42 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 132, 133 },
      -1,
   } },

   /* replace1918_0 -> 42 in the cache */
   /* replace1918_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 42, 133 },
      -1,
   } },

   /* ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd'))) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 136, 137 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 139, 140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fmin,
      0, 3,
      { 138, 141 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 3,
      { 142, 143 },
      -1,
   } },

   /* replace1919_0_0 -> 136 in the cache */
   /* replace1919_0_1_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 136, 145 },
      -1,
   } },
   /* replace1919_1_0 -> 139 in the cache */
   /* replace1919_1_1_0 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 139, 147 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 1,
      { 146, 148 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search1920_0_0 -> 0 in the cache */
   /* search1920_0 -> 9 in the cache */
   /* search1920_1_0 -> 1 in the cache */
   /* search1920_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace1920_0 -> 1 in the cache */
   /* replace1920_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search1921_0_0 -> 0 in the cache */
   /* search1921_0 -> 9 in the cache */
   /* search1921_1_0 -> 1 in the cache */
   /* search1921_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace1921_0 -> 1 in the cache */
   /* replace1921_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search1922_0_0 -> 0 in the cache */
   /* search1922_0 -> 9 in the cache */
   /* search1922_1_0 -> 1 in the cache */
   /* search1922_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace1922_0 -> 1 in the cache */
   /* replace1922_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search1923_0_0 -> 0 in the cache */
   /* search1923_0 -> 9 in the cache */
   /* search1923_1_0 -> 1 in the cache */
   /* search1923_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace1923_0 -> 1 in the cache */
   /* replace1923_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search1924_0_0 -> 42 in the cache */
   /* search1924_0 -> 59 in the cache */
   /* search1924_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 59, 63 },
      -1,
   } },

   /* replace1924_0 -> 133 in the cache */
   /* replace1924_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 133, 42 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search1925_0 -> 63 in the cache */
   /* search1925_1_0 -> 42 in the cache */
   /* search1925_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 63, 59 },
      -1,
   } },

   /* replace1925_0 -> 42 in the cache */
   /* replace1925_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 42, 133 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search1926_0_0 -> 42 in the cache */
   /* search1926_0 -> 59 in the cache */
   /* search1926_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 59, 63 },
      -1,
   } },

   /* replace1926_0 -> 133 in the cache */
   /* replace1926_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 133, 42 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search1927_0 -> 63 in the cache */
   /* search1927_1_0 -> 42 in the cache */
   /* search1927_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 63, 59 },
      -1,
   } },

   /* replace1927_0 -> 42 in the cache */
   /* replace1927_1 -> 133 in the cache */
   /* replace1927 -> 135 in the cache */

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search1928_0_0 -> 42 in the cache */
   /* search1928_0 -> 59 in the cache */
   /* search1928_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 59, 63 },
      -1,
   } },

   /* replace1928_0 -> 133 in the cache */
   /* replace1928_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 133, 42 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search1929_0 -> 63 in the cache */
   /* search1929_1_0 -> 42 in the cache */
   /* search1929_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 63, 59 },
      -1,
   } },

   /* replace1929_0 -> 42 in the cache */
   /* replace1929_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 42, 133 },
      -1,
   } },

   /* ('ior', 'a', 'a') => a */
   /* search1930_0 -> 42 in the cache */
   /* search1930_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ior,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace1930 -> 42 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search1931_0 -> 42 in the cache */
   /* search1931_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_iand,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace1931 -> 42 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 171 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 172 },
      0,
   } },
   /* search1932_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true, false,
      nir_op_fadd,
      0, 1,
      { 173, 133 },
      -1,
   } },

   /* replace1932_0_0 -> 133 in the cache */
   /* replace1932_0_1_0 -> 42 in the cache */
   /* replace1932_0_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 133, 59 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsat,
      -1, 1,
      { 175 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b') */
   /* search1933_0 -> 0 in the cache */
   /* search1933_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1933_0 -> 0 in the cache */
   /* replace1933_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b') */
   /* search1934_0 -> 0 in the cache */
   /* search1934_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1934_0 -> 0 in the cache */
   /* replace1934_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b') */
   /* search1935_0 -> 0 in the cache */
   /* search1935_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1935_0 -> 0 in the cache */
   /* replace1935_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b') */
   /* search1936_0 -> 0 in the cache */
   /* search1936_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdph,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1936_0 -> 0 in the cache */
   /* replace1936_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search1937_0_0 -> 136 in the cache */
   /* search1937_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 136, 137 },
      0,
   } },
   /* search1937_1_0 -> 136 in the cache */
   /* search1937_1_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 136, 139 },
      0,
   } },
   /* search1937_2 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true, false,
      nir_op_flrp,
      -1, 2,
      { 185, 186, 140 },
      -1,
   } },

   /* replace1937_0_0 -> 137 in the cache */
   /* replace1937_0_1 -> 139 in the cache */
   /* replace1937_0_2 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 137, 139, 140 },
      -1,
   } },
   /* replace1937_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 188, 136 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search1938_0 -> 79 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 1,
      { 79, 190, 191 },
      -1,
   } },

   /* replace1938_0 -> 191 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace1938_2 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 191, 193, 79 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search1939_0 -> 79 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xc000000000000000 /* -2.0 */ },
   } },
   /* search1939_2 -> 191 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 1,
      { 79, 195, 191 },
      -1,
   } },

   /* replace1939_0 -> 191 in the cache */
   /* replace1939_1 -> 193 in the cache */
   /* replace1939_2_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 191, 193, 197 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search1940_0 -> 79 in the cache */
   /* search1940_1 -> 195 in the cache */
   /* search1940_2 -> 193 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 1,
      { 79, 195, 193 },
      -1,
   } },

   /* replace1940_0 -> 193 in the cache */
   /* replace1940_1 -> 191 in the cache */
   /* replace1940_2 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 193, 191, 79 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search1941_0 -> 79 in the cache */
   /* search1941_1 -> 190 in the cache */
   /* search1941_2 -> 193 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 1,
      { 79, 190, 193 },
      -1,
   } },

   /* replace1941_0 -> 193 in the cache */
   /* replace1941_1 -> 191 in the cache */
   /* replace1941_2_0 -> 79 in the cache */
   /* replace1941_2 -> 197 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 193, 191, 197 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search1942_0_0 -> 190 in the cache */
   /* search1942_0_1 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 190, 79 },
      0,
   } },
   /* search1942_1 -> 191 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 203, 191 },
      -1,
   } },

   /* replace1942_0 -> 191 in the cache */
   /* replace1942_1 -> 193 in the cache */
   /* replace1942_2 -> 79 in the cache */
   /* replace1942 -> 194 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search1943_0_0 -> 195 in the cache */
   /* search1943_0_1 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 195, 79 },
      0,
   } },
   /* search1943_1 -> 191 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 205, 191 },
      -1,
   } },

   /* replace1943_0 -> 191 in the cache */
   /* replace1943_1 -> 193 in the cache */
   /* replace1943_2_0 -> 79 in the cache */
   /* replace1943_2 -> 197 in the cache */
   /* replace1943 -> 198 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search1944_0_0 -> 195 in the cache */
   /* search1944_0_1 -> 79 in the cache */
   /* search1944_0 -> 205 in the cache */
   /* search1944_1 -> 193 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 205, 193 },
      -1,
   } },

   /* replace1944_0 -> 193 in the cache */
   /* replace1944_1 -> 191 in the cache */
   /* replace1944_2 -> 79 in the cache */
   /* replace1944 -> 200 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search1945_0_0 -> 190 in the cache */
   /* search1945_0_1 -> 79 in the cache */
   /* search1945_0 -> 203 in the cache */
   /* search1945_1 -> 193 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 2,
      { 203, 193 },
      -1,
   } },

   /* replace1945_0 -> 193 in the cache */
   /* replace1945_1 -> 191 in the cache */
   /* replace1945_2_0 -> 79 in the cache */
   /* replace1945_2 -> 197 in the cache */
   /* replace1945 -> 202 in the cache */

   /* ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 210 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 209, 211 },
      -1,
   } },
   /* search1946_1 -> 210 in the cache */
   /* search1946_2 -> 210 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 212, 210, 210 },
      -1,
   } },

   /* replace1946_0 -> 210 in the cache */
   /* replace1946_1 -> 209 in the cache */
   /* replace1946_2 -> 210 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 210, 209, 210 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search1947_0 -> 79 in the cache */
   /* search1947_1 -> 190 in the cache */
   /* search1947_2_0_0 -> 79 in the cache */
   /* search1947_2_0_1 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      -1, 0,
      { 79, 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 215 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 1,
      { 79, 190, 216 },
      -1,
   } },

   /* replace1947_0 -> 79 in the cache */
   /* replace1947_1 -> 193 in the cache */
   /* replace1947_2 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 79, 193, 79 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search1948_0 -> 79 in the cache */
   /* search1948_1 -> 190 in the cache */
   /* search1948_2_0_0 -> 79 in the cache */
   /* search1948_2_0 -> 197 in the cache */
   /* search1948_2_1 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 197, 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 79, 190, 219 },
      -1,
   } },

   /* replace1948_0 -> 79 in the cache */
   /* replace1948_1 -> 193 in the cache */
   /* replace1948_2 -> 79 in the cache */
   /* replace1948 -> 218 in the cache */

   /* ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search1949_0 -> 79 in the cache */
   /* search1949_1_0 -> 79 in the cache */
   /* search1949_1 -> 197 in the cache */
   /* search1949_2_0 -> 190 in the cache */
   /* search1949_2_1 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 1,
      { 190, 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_ffma,
      0, 2,
      { 79, 197, 221 },
      -1,
   } },

   /* replace1949_0 -> 79 in the cache */
   /* replace1949_1 -> 193 in the cache */
   /* replace1949_2 -> 79 in the cache */
   /* replace1949 -> 218 in the cache */

   /* ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search1950_0 -> 79 in the cache */
   /* search1950_1_0 -> 190 in the cache */
   /* search1950_1_1_0 -> 79 in the cache */
   /* search1950_1_1 -> 197 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 190, 197 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fmul,
      0, 2,
      { 79, 223 },
      -1,
   } },

   /* replace1950_0 -> 79 in the cache */
   /* replace1950_1 -> 193 in the cache */
   /* replace1950_2 -> 79 in the cache */
   /* replace1950 -> 218 in the cache */

   /* ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 225, 226 },
      0,
   } },
   /* search1951_1_0 -> 225 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 225, 228 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmin,
      0, 3,
      { 227, 229 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace1951_1_0 -> 226 in the cache */
   /* replace1951_1_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmin,
      1, 1,
      { 226, 228 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 231, 232 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b')) */
   /* search1952_0_0 -> 225 in the cache */
   /* search1952_0_1 -> 226 in the cache */
   /* search1952_0 -> 227 in the cache */
   /* search1952_1_0 -> 225 in the cache */
   /* search1952_1_1 -> 228 in the cache */
   /* search1952_1 -> 229 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmax,
      0, 3,
      { 227, 229 },
      -1,
   } },

   /* replace1952_0 -> 231 in the cache */
   /* replace1952_1_0 -> 226 in the cache */
   /* replace1952_1_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fmax,
      1, 1,
      { 226, 228 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fadd,
      0, 2,
      { 231, 235 },
      -1,
   } },

   /* ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsqrt,
      -1, 0,
      { 237 },
      -1,
   } },
   /* search1953_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 238, 43 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x47efffffe0000000 /* 3.4028234663852886e+38 */ },
   } },
   /* search1953_2_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_frsq,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_bcsel,
      -1, 1,
      { 239, 240, 241 },
      -1,
   } },

   /* replace1953_0_0 -> 42 in the cache */
   /* replace1953_0 -> 241 in the cache */
   /* replace1953_1 -> 240 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 241, 240 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g'))) */
   { .variable = {
      { nir_search_value_variable, -7 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_fmul,
      3, 1,
      { 248, 249 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_ffma,
      2, 2,
      { 246, 247, 250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_ffma,
      1, 3,
      { 244, 245, 251 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 252, 253 },
      -1,
   } },

   /* replace1954_0 -> 244 in the cache */
   /* replace1954_1 -> 245 in the cache */
   /* replace1954_2_0 -> 246 in the cache */
   /* replace1954_2_1 -> 247 in the cache */
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_ffma,
      2, 1,
      { 255, 256, 257 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_ffma,
      1, 2,
      { 246, 247, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_ffma,
      0, 3,
      { 244, 245, 259 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, -5 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 263, 264 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ffma,
      1, 2,
      { 261, 262, 265 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 266, 267 },
      -1,
   } },

   /* replace1955_0 -> 261 in the cache */
   /* replace1955_1 -> 262 in the cache */
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 269, 270, 271 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ffma,
      0, 2,
      { 261, 262, 272 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g'))) */
   /* search1956_0_0_0 -> 244 in the cache */
   /* search1956_0_0_1 -> 245 in the cache */
   /* search1956_0_0_2_0 -> 246 in the cache */
   /* search1956_0_0_2_1 -> 247 in the cache */
   /* search1956_0_0_2_2_0 -> 248 in the cache */
   /* search1956_0_0_2_2_1 -> 249 in the cache */
   /* search1956_0_0_2_2 -> 250 in the cache */
   /* search1956_0_0_2 -> 251 in the cache */
   /* search1956_0_0 -> 252 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_fneg,
      -1, 3,
      { 252 },
      -1,
   } },
   /* search1956_1 -> 253 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      true, false,
      nir_op_fadd,
      0, 4,
      { 274, 253 },
      -1,
   } },

   /* replace1956_0_0 -> 244 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 244 },
      -1,
   } },
   /* replace1956_1 -> 245 in the cache */
   /* replace1956_2_0_0 -> 246 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 246 },
      -1,
   } },
   /* replace1956_2_1 -> 247 in the cache */
   /* replace1956_2_2_0_0 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 255 },
      -1,
   } },
   /* replace1956_2_2_1 -> 256 in the cache */
   /* replace1956_2_2_2 -> 257 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_ffma,
      2, 1,
      { 278, 256, 257 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_ffma,
      1, 2,
      { 277, 247, 279 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false, false,
      nir_op_ffma,
      0, 3,
      { 276, 245, 280 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search1957_0 -> 79 in the cache */
   /* search1957_1 -> 80 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 79, 80, 282 },
      -1,
   } },

   /* replace1957 -> 282 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search1958_0 -> 79 in the cache */
   /* search1958_1 -> 80 in the cache */
   /* search1958_2 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 79, 80, 282 },
      -1,
   } },

   /* replace1958 -> 282 in the cache */

   /* ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b')) */
   /* search1959_0 -> 79 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ubfe,
      -1, 0,
      { 79, 285, 286 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   /* replace1959_0_1_0 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ineg,
      -1, 0,
      { 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 288, 289 },
      -1,
   } },
   /* replace1959_1_0 -> 79 in the cache */
   /* replace1959_1_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 79, 80 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 290, 291 },
      -1,
   } },

   /* ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c')) */
   /* search1960_0 -> 79 in the cache */
   /* search1960_1 -> 285 in the cache */
   /* search1960_2 -> 286 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ibfe,
      -1, 0,
      { 79, 285, 286 },
      -1,
   } },

   /* replace1960_0_0 -> 79 in the cache */
   /* replace1960_0_1_0_0 -> 80 in the cache */
   /* replace1960_0_1_0_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iadd,
      0, 1,
      { 80, 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ineg,
      -1, 1,
      { 294 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 1,
      { 79, 295 },
      -1,
   } },
   /* replace1960_1_0 -> 82 in the cache */
   /* replace1960_1 -> 289 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishr,
      -1, 1,
      { 296, 289 },
      -1,
   } },

   /* ('ishl', 'a', 0) => a */
   /* search1961_0 -> 42 in the cache */
   /* search1961_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 42, 282 },
      -1,
   } },

   /* replace1961 -> 42 in the cache */

   /* ('ishl', 'a', -32) => a */
   /* search1962_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x20 /* -32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 42, 299 },
      -1,
   } },

   /* replace1962 -> 42 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search1963_0 -> 42 in the cache */
   /* search1963_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 42, 282 },
      -1,
   } },

   /* replace1963 -> 42 in the cache */

   /* ('ishr', 'a', -32) => a */
   /* search1964_0 -> 42 in the cache */
   /* search1964_1 -> 299 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ishr,
      -1, 0,
      { 42, 299 },
      -1,
   } },

   /* replace1964 -> 42 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search1965_0 -> 42 in the cache */
   /* search1965_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_ushr,
      -1, 0,
      { 42, 282 },
      -1,
   } },

   /* replace1965 -> 42 in the cache */

   /* ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search1966_0_0 -> 0 in the cache */
   /* search1966_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 304, 305 },
      -1,
   } },

   /* replace1966_0 -> 0 in the cache */
   /* replace1966_1 -> 1 in the cache */
   /* replace1966 -> 304 in the cache */

   /* ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search1967_0_0 -> 0 in the cache */
   /* search1967_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* search1967_1 -> 305 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 307, 305 },
      -1,
   } },

   /* replace1967_0 -> 0 in the cache */
   /* replace1967_1 -> 1 in the cache */
   /* replace1967 -> 304 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1968_0_0 -> 0 in the cache */
   /* search1968_0_1 -> 1 in the cache */
   /* search1968_0 -> 304 in the cache */
   /* search1968_1 -> 305 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 304, 305 },
      -1,
   } },

   /* replace1968_0 -> 0 in the cache */
   /* replace1968_1 -> 1 in the cache */
   /* replace1968 -> 307 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1969_0_0 -> 0 in the cache */
   /* search1969_0_1 -> 1 in the cache */
   /* search1969_0 -> 307 in the cache */
   /* search1969_1 -> 305 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 307, 305 },
      -1,
   } },

   /* replace1969_0 -> 0 in the cache */
   /* replace1969_1 -> 1 in the cache */
   /* replace1969 -> 307 in the cache */

   /* ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search1970_0_0 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 73 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 311 },
      -1,
   } },

   /* replace1970_0 -> 73 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 73, 313 },
      -1,
   } },

   /* ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search1971_0_0 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 73 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 315 },
      -1,
   } },

   /* replace1971_0 -> 73 in the cache */
   /* replace1971_1 -> 313 in the cache */
   /* replace1971 -> 314 in the cache */

   /* ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search1972_0_0 -> 73 in the cache */
   /* search1972_0 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 311 },
      -1,
   } },

   /* replace1972_0 -> 73 in the cache */
   /* replace1972_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 73, 313 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search1973_0_0 -> 73 in the cache */
   /* search1973_0 -> 315 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 315 },
      -1,
   } },

   /* replace1973_0 -> 73 in the cache */
   /* replace1973_1 -> 313 in the cache */
   /* replace1973 -> 318 in the cache */

   /* ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search1974_0_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_u2u8,
      -1, 0,
      { 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 320 },
      -1,
   } },

   /* replace1974_0 -> 79 in the cache */
   /* replace1974_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 79, 282 },
      -1,
   } },

   /* ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search1975_0_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_i2i8,
      -1, 0,
      { 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 323 },
      -1,
   } },

   /* replace1975_0 -> 79 in the cache */
   /* replace1975_1 -> 282 in the cache */
   /* replace1975 -> 322 in the cache */

   /* ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search1976_0_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2u16,
      -1, 0,
      { 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 325 },
      -1,
   } },

   /* replace1976_0 -> 79 in the cache */
   /* replace1976_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 79, 282 },
      -1,
   } },

   /* ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search1977_0_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2i16,
      -1, 0,
      { 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_u2u32,
      -1, 0,
      { 328 },
      -1,
   } },

   /* replace1977_0 -> 79 in the cache */
   /* replace1977_1 -> 282 in the cache */
   /* replace1977 -> 327 in the cache */

   /* ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search1978_0_0 -> 79 in the cache */
   /* search1978_0 -> 320 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 320 },
      -1,
   } },

   /* replace1978_0 -> 79 in the cache */
   /* replace1978_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i8,
      -1, 0,
      { 79, 282 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search1979_0_0 -> 79 in the cache */
   /* search1979_0 -> 323 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 323 },
      -1,
   } },

   /* replace1979_0 -> 79 in the cache */
   /* replace1979_1 -> 282 in the cache */
   /* replace1979 -> 331 in the cache */

   /* ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search1980_0_0 -> 79 in the cache */
   /* search1980_0 -> 325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 325 },
      -1,
   } },

   /* replace1980_0 -> 79 in the cache */
   /* replace1980_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_extract_i16,
      -1, 0,
      { 79, 282 },
      -1,
   } },

   /* ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search1981_0_0 -> 79 in the cache */
   /* search1981_0 -> 328 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_i2i32,
      -1, 0,
      { 328 },
      -1,
   } },

   /* replace1981_0 -> 79 in the cache */
   /* replace1981_1 -> 282 in the cache */
   /* replace1981 -> 334 in the cache */

   /* ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1) */
   /* search1982_0_0 -> 79 in the cache */
   /* search1982_0_1 -> 282 in the cache */
   /* search1982_0 -> 322 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 322, 336 },
      -1,
   } },

   /* replace1982_0 -> 79 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_insert_u8,
      -1, 0,
      { 79, 338 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2) */
   /* search1983_0_0 -> 79 in the cache */
   /* search1983_0_1 -> 282 in the cache */
   /* search1983_0 -> 322 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 322, 340 },
      -1,
   } },

   /* replace1983_0 -> 79 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_insert_u8,
      -1, 0,
      { 79, 342 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3) */
   /* search1984_0_0 -> 79 in the cache */
   /* search1984_0_1 -> 282 in the cache */
   /* search1984_0 -> 322 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 322, 344 },
      -1,
   } },

   /* replace1984_0 -> 79 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_insert_u8,
      -1, 0,
      { 79, 346 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1) */
   /* search1985_0_0 -> 79 in the cache */
   /* search1985_0_1 -> 336 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 79, 336 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00 /* 65280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 348, 349 },
      -1,
   } },

   /* replace1985_0 -> 79 in the cache */
   /* replace1985_1 -> 338 in the cache */
   /* replace1985 -> 339 in the cache */

   /* ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2) */
   /* search1986_0_0 -> 79 in the cache */
   /* search1986_0_1 -> 340 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 79, 340 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff0000 /* 16711680 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 351, 352 },
      -1,
   } },

   /* replace1986_0 -> 79 in the cache */
   /* replace1986_1 -> 342 in the cache */
   /* replace1986 -> 343 in the cache */

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3) */
   /* search1987_0_0 -> 79 in the cache */
   /* search1987_0_1 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ishl,
      -1, 0,
      { 79, 344 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_iand,
      0, 1,
      { 354, 355 },
      -1,
   } },

   /* replace1987_0 -> 79 in the cache */
   /* replace1987_1 -> 346 in the cache */
   /* replace1987 -> 347 in the cache */

   /* ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3) */
   /* search1988_0 -> 79 in the cache */
   /* search1988_1 -> 344 in the cache */
   /* search1988 -> 354 in the cache */

   /* replace1988_0 -> 79 in the cache */
   /* replace1988_1 -> 346 in the cache */
   /* replace1988 -> 347 in the cache */

   /* ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1) */
   /* search1989_0 -> 79 in the cache */
   /* search1989_1 -> 340 in the cache */
   /* search1989 -> 351 in the cache */

   /* replace1989_0 -> 79 in the cache */
   /* replace1989_1 -> 338 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_insert_u16,
      -1, 0,
      { 79, 338 },
      -1,
   } },

   /* ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b') */
   /* search1990_0_0 -> 0 in the cache */
   /* search1990_0_1 -> 305 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 305 },
      -1,
   } },
   /* search1990_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_insert_u8,
      -1, 0,
      { 358, 1 },
      -1,
   } },

   /* replace1990_0 -> 0 in the cache */
   /* replace1990_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_insert_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b') */
   /* search1991_0_0 -> 0 in the cache */
   /* search1991_0_1 -> 305 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 305 },
      -1,
   } },
   /* search1991_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_insert_u16,
      -1, 0,
      { 361, 1 },
      -1,
   } },

   /* replace1991_0 -> 0 in the cache */
   /* replace1991_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_insert_u16,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 364, 365 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1992_1_1 -> 365 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 367, 365 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 366, 368 },
      -1,
   } },

   /* replace1992_0_0 -> 364 in the cache */
   /* replace1992_0_1 -> 367 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false, false,
      nir_op_umin,
      1, 1,
      { 364, 367 },
      -1,
   } },
   /* replace1992_1 -> 365 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 370, 365 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search1993_0_0 -> 364 in the cache */
   /* search1993_0_1 -> 365 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 364, 365 },
      0,
   } },
   /* search1993_1_0 -> 367 in the cache */
   /* search1993_1_1 -> 365 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 367, 365 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 372, 373 },
      -1,
   } },

   /* replace1993_0_0 -> 364 in the cache */
   /* replace1993_0_1 -> 367 in the cache */
   /* replace1993_0 -> 370 in the cache */
   /* replace1993_1 -> 365 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 370, 365 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search1994_0_0 -> 73 in the cache */
   /* search1994_0_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 73, 313 },
      0,
   } },
   /* search1994_1_0 -> 74 in the cache */
   /* search1994_1_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 74, 313 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 376, 377 },
      -1,
   } },

   /* replace1994_0_0 -> 73 in the cache */
   /* replace1994_0_1 -> 74 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_umin,
      1, 1,
      { 73, 74 },
      -1,
   } },
   /* replace1994_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 379, 313 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search1995_0_0 -> 73 in the cache */
   /* search1995_0_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 73, 313 },
      0,
   } },
   /* search1995_1_0 -> 74 in the cache */
   /* search1995_1_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 74, 313 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 381, 382 },
      -1,
   } },

   /* replace1995_0_0 -> 73 in the cache */
   /* replace1995_0_1 -> 74 in the cache */
   /* replace1995_0 -> 379 in the cache */
   /* replace1995_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 379, 313 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search1996_0_0 -> 79 in the cache */
   /* search1996_0_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 79, 282 },
      0,
   } },
   /* search1996_1_0 -> 80 in the cache */
   /* search1996_1_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 80, 282 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 385, 386 },
      -1,
   } },

   /* replace1996_0_0 -> 79 in the cache */
   /* replace1996_0_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_umin,
      1, 1,
      { 79, 80 },
      -1,
   } },
   /* replace1996_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 388, 282 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search1997_0_0 -> 79 in the cache */
   /* search1997_0_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 79, 282 },
      0,
   } },
   /* search1997_1_0 -> 80 in the cache */
   /* search1997_1_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 80, 282 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 390, 391 },
      -1,
   } },

   /* replace1997_0_0 -> 79 in the cache */
   /* replace1997_0_1 -> 80 in the cache */
   /* replace1997_0 -> 388 in the cache */
   /* replace1997_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 388, 282 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search1998_0_0 -> 85 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      1, 1,
      { 85, 394 },
      0,
   } },
   /* search1998_1_0 -> 86 in the cache */
   /* search1998_1_1 -> 394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      2, 1,
      { 86, 394 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_iand,
      0, 3,
      { 395, 396 },
      -1,
   } },

   /* replace1998_0_0 -> 85 in the cache */
   /* replace1998_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_umin,
      1, 1,
      { 85, 86 },
      -1,
   } },
   /* replace1998_1 -> 394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ine,
      0, 2,
      { 398, 394 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search1999_0_0 -> 85 in the cache */
   /* search1999_0_1 -> 394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      1, 1,
      { 85, 394 },
      0,
   } },
   /* search1999_1_0 -> 86 in the cache */
   /* search1999_1_1 -> 394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      2, 1,
      { 86, 394 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 3,
      { 400, 401 },
      -1,
   } },

   /* replace1999_0_0 -> 85 in the cache */
   /* replace1999_0_1 -> 86 in the cache */
   /* replace1999_0 -> 398 in the cache */
   /* replace1999_1 -> 394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ieq,
      0, 2,
      { 398, 394 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2000_0 -> 111 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2000_1_1_0 -> 74 in the cache */
   /* search2000_1_1_1 -> 110 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 74, 110 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 404, 405 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 111, 406 },
      -1,
   } },

   /* replace2000_0_0 -> 111 in the cache */
   /* replace2000_0_1_0 -> 404 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 111, 408 },
      -1,
   } },
   /* replace2000_1_0 -> 74 in the cache */
   /* replace2000_1_1 -> 404 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 74, 404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      0, 3,
      { 409, 410 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b'))) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2001_1 -> 313 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 0,
      { 413 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2f16,
      -1, 0,
      { 414 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 412, 313, 415 },
      -1,
   } },

   /* replace2001_0_0_0 -> 412 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_ior,
      0, 1,
      { 412, 417 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_inot,
      -1, 1,
      { 418 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_b2f16,
      -1, 1,
      { 419 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2002_0 -> 193 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2002_1_1_0 -> 80 in the cache */
   /* search2002_1_1_1 -> 191 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 80, 191 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 421, 422 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 193, 423 },
      -1,
   } },

   /* replace2002_0_0 -> 193 in the cache */
   /* replace2002_0_1_0 -> 421 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 421 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 193, 425 },
      -1,
   } },
   /* replace2002_1_0 -> 80 in the cache */
   /* replace2002_1_1 -> 421 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 80, 421 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      0, 3,
      { 426, 427 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b'))) */
   /* search2003_0 -> 412 in the cache */
   /* search2003_1 -> 282 in the cache */
   /* search2003_2_0_0 -> 413 in the cache */
   /* search2003_2_0 -> 414 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2f32,
      -1, 0,
      { 414 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 412, 282, 429 },
      -1,
   } },

   /* replace2003_0_0_0 -> 412 in the cache */
   /* replace2003_0_0_1 -> 417 in the cache */
   /* replace2003_0_0 -> 418 in the cache */
   /* replace2003_0 -> 419 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_b2f32,
      -1, 1,
      { 419 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2004_1_1_0 -> 86 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      2, 1,
      { 86, 434 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      1, 2,
      { 433, 435 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true, false,
      nir_op_fadd,
      0, 3,
      { 432, 436 },
      -1,
   } },

   /* replace2004_0_0 -> 432 in the cache */
   /* replace2004_0_1_0 -> 433 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 433 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 432, 438 },
      -1,
   } },
   /* replace2004_1_0 -> 86 in the cache */
   /* replace2004_1_1 -> 433 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fmul,
      2, 1,
      { 86, 433 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_fadd,
      0, 3,
      { 439, 440 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b'))) */
   /* search2005_0 -> 412 in the cache */
   /* search2005_1 -> 394 in the cache */
   /* search2005_2_0_0 -> 413 in the cache */
   /* search2005_2_0 -> 414 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2f64,
      -1, 0,
      { 414 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 412, 394, 442 },
      -1,
   } },

   /* replace2005_0_0_0 -> 412 in the cache */
   /* replace2005_0_0_1 -> 417 in the cache */
   /* replace2005_0_0 -> 418 in the cache */
   /* replace2005_0 -> 419 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false, false,
      nir_op_b2f64,
      -1, 1,
      { 419 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2006_0 -> 412 in the cache */
   /* search2006_1_0 -> 137 in the cache */
   /* search2006_1_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 137, 139 },
      0,
   } },
   /* search2006_2_0 -> 137 in the cache */
   /* search2006_2_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 137, 140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 412, 445, 446 },
      -1,
   } },

   /* replace2006_0 -> 137 in the cache */
   /* replace2006_1_0 -> 412 in the cache */
   /* replace2006_1_1 -> 139 in the cache */
   /* replace2006_1_2 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 412, 139, 140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 137, 448 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2007_0 -> 412 in the cache */
   /* search2007_1_0 -> 137 in the cache */
   /* search2007_1_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 137, 139 },
      -1,
   } },
   /* search2007_2_0 -> 137 in the cache */
   /* search2007_2_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_fadd,
      1, 1,
      { 137, 140 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 412, 450, 451 },
      -1,
   } },

   /* replace2007_0 -> 137 in the cache */
   /* replace2007_1_0 -> 412 in the cache */
   /* replace2007_1_1 -> 139 in the cache */
   /* replace2007_1_2 -> 140 in the cache */
   /* replace2007_1 -> 448 in the cache */
   /* replace2007 -> 449 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2008_0 -> 412 in the cache */
   /* search2008_1_0 -> 262 in the cache */
   /* search2008_1_1 -> 269 in the cache */
   /* search2008_1_2 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 262, 269, 270 },
      0,
   } },
   /* search2008_2_0 -> 262 in the cache */
   /* search2008_2_1 -> 269 in the cache */
   /* search2008_2_2 -> 271 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 262, 269, 271 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 412, 453, 454 },
      -1,
   } },

   /* replace2008_0 -> 262 in the cache */
   /* replace2008_1 -> 269 in the cache */
   /* replace2008_2_0 -> 412 in the cache */
   /* replace2008_2_1 -> 270 in the cache */
   /* replace2008_2_2 -> 271 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 412, 270, 271 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 262, 269, 456 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2009_0 -> 412 in the cache */
   /* search2009_1_0 -> 262 in the cache */
   /* search2009_1_1 -> 269 in the cache */
   /* search2009_1_2 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 262, 269, 270 },
      -1,
   } },
   /* search2009_2_0 -> 262 in the cache */
   /* search2009_2_1 -> 269 in the cache */
   /* search2009_2_2 -> 271 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 262, 269, 271 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 412, 458, 459 },
      -1,
   } },

   /* replace2009_0 -> 262 in the cache */
   /* replace2009_1 -> 269 in the cache */
   /* replace2009_2_0 -> 412 in the cache */
   /* replace2009_2_1 -> 270 in the cache */
   /* replace2009_2_2 -> 271 in the cache */
   /* replace2009_2 -> 456 in the cache */
   /* replace2009 -> 457 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2010_0 -> 412 in the cache */
   /* search2010_1_0 -> 262 in the cache */
   /* search2010_1_1 -> 269 in the cache */
   /* search2010_1_2 -> 270 in the cache */
   /* search2010_1 -> 453 in the cache */
   /* search2010_2_0 -> 262 in the cache */
   /* search2010_2_1 -> 271 in the cache */
   /* search2010_2_2 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 262, 271, 270 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 412, 453, 461 },
      -1,
   } },

   /* replace2010_0 -> 262 in the cache */
   /* replace2010_1_0 -> 412 in the cache */
   /* replace2010_1_1 -> 269 in the cache */
   /* replace2010_1_2 -> 271 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 0,
      { 412, 269, 271 },
      -1,
   } },
   /* replace2010_2 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 262, 463, 270 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2011_0 -> 412 in the cache */
   /* search2011_1_0 -> 262 in the cache */
   /* search2011_1_1 -> 269 in the cache */
   /* search2011_1_2 -> 270 in the cache */
   /* search2011_1 -> 458 in the cache */
   /* search2011_2_0 -> 262 in the cache */
   /* search2011_2_1 -> 271 in the cache */
   /* search2011_2_2 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_ffma,
      1, 1,
      { 262, 271, 270 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false, false,
      nir_op_bcsel,
      -1, 2,
      { 412, 458, 465 },
      -1,
   } },

   /* replace2011_0 -> 262 in the cache */
   /* replace2011_1_0 -> 412 in the cache */
   /* replace2011_1_1 -> 269 in the cache */
   /* replace2011_1_2 -> 271 in the cache */
   /* replace2011_1 -> 463 in the cache */
   /* replace2011_2 -> 270 in the cache */
   /* replace2011 -> 464 in the cache */

   /* ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a') */
   /* search2012_0_0_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 468 },
      -1,
   } },

   /* replace2012_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a') */
   /* search2013_0_0_0 -> 79 in the cache */
   /* search2013_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fceil,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 471 },
      -1,
   } },

   /* replace2013_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fceil,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a') */
   /* search2014_0_0_0 -> 79 in the cache */
   /* search2014_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fcos,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 474 },
      -1,
   } },

   /* replace2014_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fcos,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a') */
   /* search2015_0_0_0 -> 79 in the cache */
   /* search2015_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fddx,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 477 },
      -1,
   } },

   /* replace2015_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fddx,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a') */
   /* search2016_0_0_0 -> 79 in the cache */
   /* search2016_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fddx_coarse,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 480 },
      -1,
   } },

   /* replace2016_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fddx_coarse,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a') */
   /* search2017_0_0_0 -> 79 in the cache */
   /* search2017_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fddx_fine,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 483 },
      -1,
   } },

   /* replace2017_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fddx_fine,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a') */
   /* search2018_0_0_0 -> 79 in the cache */
   /* search2018_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fddy,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 486 },
      -1,
   } },

   /* replace2018_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fddy,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a') */
   /* search2019_0_0_0 -> 79 in the cache */
   /* search2019_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fddy_coarse,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 489 },
      -1,
   } },

   /* replace2019_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fddy_coarse,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a') */
   /* search2020_0_0_0 -> 79 in the cache */
   /* search2020_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fddy_fine,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 492 },
      -1,
   } },

   /* replace2020_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fddy_fine,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a') */
   /* search2021_0_0_0 -> 79 in the cache */
   /* search2021_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fexp2,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 495 },
      -1,
   } },

   /* replace2021_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fexp2,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a') */
   /* search2022_0_0_0 -> 79 in the cache */
   /* search2022_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ffloor,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 498 },
      -1,
   } },

   /* replace2022_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ffloor,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a') */
   /* search2023_0_0_0 -> 79 in the cache */
   /* search2023_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ffract,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 501 },
      -1,
   } },

   /* replace2023_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_ffract,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a') */
   /* search2024_0_0_0 -> 79 in the cache */
   /* search2024_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_flog2,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 504 },
      -1,
   } },

   /* replace2024_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flog2,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a') */
   /* search2025_0_0_0 -> 79 in the cache */
   /* search2025_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 507 },
      -1,
   } },

   /* replace2025_0 -> 79 in the cache */
   /* replace2025 -> 197 in the cache */

   /* ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a') */
   /* search2026_0_0_0 -> 79 in the cache */
   /* search2026_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_frcp,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 509 },
      -1,
   } },

   /* replace2026_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_frcp,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a') */
   /* search2027_0_0_0 -> 79 in the cache */
   /* search2027_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fround_even,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 512 },
      -1,
   } },

   /* replace2027_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fround_even,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a') */
   /* search2028_0_0_0 -> 79 in the cache */
   /* search2028_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_frsq,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 515 },
      -1,
   } },

   /* replace2028_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_frsq,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a') */
   /* search2029_0_0_0 -> 79 in the cache */
   /* search2029_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 518 },
      -1,
   } },

   /* replace2029_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fsat,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a') */
   /* search2030_0_0_0 -> 79 in the cache */
   /* search2030_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 521 },
      -1,
   } },

   /* replace2030_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a') */
   /* search2031_0_0_0 -> 79 in the cache */
   /* search2031_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fsin,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 524 },
      -1,
   } },

   /* replace2031_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fsin,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a') */
   /* search2032_0_0_0 -> 79 in the cache */
   /* search2032_0_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fsqrt,
      -1, 0,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 527 },
      -1,
   } },

   /* replace2032_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fsqrt,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b') */
   /* search2033_0_0_0 -> 79 in the cache */
   /* search2033_0_0 -> 467 in the cache */
   /* search2033_0_1_0 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 80 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 467, 530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 1,
      { 531 },
      -1,
   } },

   /* replace2033_0 -> 79 in the cache */
   /* replace2033_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 79, 80 },
      -1,
   } },

   /* ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b') */
   /* search2034_0_0_0 -> 79 in the cache */
   /* search2034_0_0 -> 467 in the cache */
   /* search2034_0_1_0 -> 80 in the cache */
   /* search2034_0_1 -> 530 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fdiv,
      -1, 0,
      { 467, 530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 534 },
      -1,
   } },

   /* replace2034_0 -> 79 in the cache */
   /* replace2034_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fdiv,
      -1, 0,
      { 79, 80 },
      -1,
   } },

   /* ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b') */
   /* search2035_0_0_0 -> 79 in the cache */
   /* search2035_0_0 -> 467 in the cache */
   /* search2035_0_1_0 -> 80 in the cache */
   /* search2035_0_1 -> 530 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 467, 530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 1,
      { 537 },
      -1,
   } },

   /* replace2035_0 -> 79 in the cache */
   /* replace2035_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 79, 80 },
      -1,
   } },

   /* ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b') */
   /* search2036_0_0_0 -> 79 in the cache */
   /* search2036_0_0 -> 467 in the cache */
   /* search2036_0_1_0 -> 80 in the cache */
   /* search2036_0_1 -> 530 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 467, 530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 1,
      { 540 },
      -1,
   } },

   /* replace2036_0 -> 79 in the cache */
   /* replace2036_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 79, 80 },
      -1,
   } },

   /* ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b') */
   /* search2037_0_0_0 -> 79 in the cache */
   /* search2037_0_0 -> 467 in the cache */
   /* search2037_0_1_0 -> 80 in the cache */
   /* search2037_0_1 -> 530 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmod,
      -1, 0,
      { 467, 530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 543 },
      -1,
   } },

   /* replace2037_0 -> 79 in the cache */
   /* replace2037_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmod,
      -1, 0,
      { 79, 80 },
      -1,
   } },

   /* ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b') */
   /* search2038_0_0_0 -> 79 in the cache */
   /* search2038_0_0 -> 467 in the cache */
   /* search2038_0_1_0 -> 80 in the cache */
   /* search2038_0_1 -> 530 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 467, 530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 1,
      { 546 },
      -1,
   } },

   /* replace2038_0 -> 79 in the cache */
   /* replace2038_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 79, 80 },
      -1,
   } },

   /* ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b') */
   /* search2039_0_0_0 -> 79 in the cache */
   /* search2039_0_0 -> 467 in the cache */
   /* search2039_0_1_0 -> 80 in the cache */
   /* search2039_0_1 -> 530 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 467, 530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 549 },
      -1,
   } },

   /* replace2039_0 -> 79 in the cache */
   /* replace2039_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_fpow,
      -1, 0,
      { 79, 80 },
      -1,
   } },

   /* ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b') */
   /* search2040_0_0_0 -> 79 in the cache */
   /* search2040_0_0 -> 467 in the cache */
   /* search2040_0_1_0 -> 80 in the cache */
   /* search2040_0_1 -> 530 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_frem,
      -1, 0,
      { 467, 530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 552 },
      -1,
   } },

   /* replace2040_0 -> 79 in the cache */
   /* replace2040_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_frem,
      -1, 0,
      { 79, 80 },
      -1,
   } },

   /* ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c') */
   /* search2041_0_0_0 -> 79 in the cache */
   /* search2041_0_0 -> 467 in the cache */
   /* search2041_0_1_0 -> 80 in the cache */
   /* search2041_0_1 -> 530 in the cache */
   /* search2041_0_2_0 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2fmp,
      -1, 0,
      { 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 467, 530, 555 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 1,
      { 556 },
      -1,
   } },

   /* replace2041_0 -> 79 in the cache */
   /* replace2041_1 -> 80 in the cache */
   /* replace2041_2 -> 82 in the cache */
   /* replace2041 -> 84 in the cache */

   /* ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c') */
   /* search2042_0_0_0 -> 79 in the cache */
   /* search2042_0_0 -> 467 in the cache */
   /* search2042_0_1_0 -> 80 in the cache */
   /* search2042_0_1 -> 530 in the cache */
   /* search2042_0_2_0 -> 82 in the cache */
   /* search2042_0_2 -> 555 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 467, 530, 555 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true, false,
      nir_op_f2f32,
      -1, 0,
      { 558 },
      -1,
   } },

   /* replace2042_0 -> 79 in the cache */
   /* replace2042_1 -> 80 in the cache */
   /* replace2042_2 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 79, 80, 82 },
      -1,
   } },

   /* ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b') */
   /* search2043_0_0 -> 79 in the cache */
   /* search2043_0 -> 467 in the cache */
   /* search2043_1_0 -> 80 in the cache */
   /* search2043_1 -> 530 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_feq,
      0, 1,
      { 467, 530 },
      -1,
   } },

   /* replace2043_0 -> 79 in the cache */
   /* replace2043_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_feq,
      0, 1,
      { 79, 80 },
      -1,
   } },

   /* ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b') */
   /* search2044_0_0 -> 79 in the cache */
   /* search2044_0 -> 467 in the cache */
   /* search2044_1_0 -> 80 in the cache */
   /* search2044_1 -> 530 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fge,
      -1, 0,
      { 467, 530 },
      -1,
   } },

   /* replace2044_0 -> 79 in the cache */
   /* replace2044_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fge,
      -1, 0,
      { 79, 80 },
      -1,
   } },

   /* ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b') */
   /* search2045_0_0 -> 79 in the cache */
   /* search2045_0 -> 467 in the cache */
   /* search2045_1_0 -> 80 in the cache */
   /* search2045_1 -> 530 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_flt,
      -1, 0,
      { 467, 530 },
      -1,
   } },

   /* replace2045_0 -> 79 in the cache */
   /* replace2045_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 79, 80 },
      -1,
   } },

   /* ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b') */
   /* search2046_0_0 -> 79 in the cache */
   /* search2046_0 -> 467 in the cache */
   /* search2046_1_0 -> 80 in the cache */
   /* search2046_1 -> 530 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true, false,
      nir_op_fneu,
      0, 1,
      { 467, 530 },
      -1,
   } },

   /* replace2046_0 -> 79 in the cache */
   /* replace2046_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fneu,
      0, 1,
      { 79, 80 },
      -1,
   } },

   /* ('f2fmp', 'a') => ('f2f16', 'a') */
   /* search2047_0 -> 79 in the cache */
   /* search2047 -> 467 in the cache */

   /* replace2047_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2f16,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('f2imp', 'a') => ('f2i16', 'a') */
   /* search2048_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2imp,
      -1, 0,
      { 79 },
      -1,
   } },

   /* replace2048_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2i16,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('f2ump', 'a') => ('f2u16', 'a') */
   /* search2049_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2ump,
      -1, 0,
      { 79 },
      -1,
   } },

   /* replace2049_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_f2u16,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('i2imp', 'a') => ('i2i16', 'a') */
   /* search2050_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2imp,
      -1, 0,
      { 79 },
      -1,
   } },

   /* replace2050_0 -> 79 in the cache */
   /* replace2050 -> 328 in the cache */

   /* ('i2fmp', 'a') => ('i2f16', 'a') */
   /* search2051_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2fmp,
      -1, 0,
      { 79 },
      -1,
   } },

   /* replace2051_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_i2f16,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('i2imp', 'a') => ('u2u16', 'a') */
   /* search2052_0 -> 79 in the cache */
   /* search2052 -> 574 in the cache */

   /* replace2052_0 -> 79 in the cache */
   /* replace2052 -> 325 in the cache */

   /* ('u2fmp', 'a') => ('u2f16', 'a') */
   /* search2053_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2fmp,
      -1, 0,
      { 79 },
      -1,
   } },

   /* replace2053_0 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false, false,
      nir_op_u2f16,
      -1, 0,
      { 79 },
      -1,
   } },

   /* ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf) */
   /* search2054_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_fisfinite,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2054_0_0 -> 42 in the cache */
   /* replace2054_0 -> 47 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x7ff0000000000000 /* inf */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false, false,
      nir_op_flt,
      -1, 0,
      { 47, 580 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_late_expression_cond[] = {
   (is_used_once),
   (is_only_used_as_float),
};

static const nir_search_variable_cond nir_opt_algebraic_late_variable_cond[] = {
   (is_finite),
   (is_not_const),
   (is_gt_0_and_lt_1),
   (is_not_fmul),
   (is_not_negative),
   (is_not_const_and_not_fsign),
};

static const struct transform nir_opt_algebraic_late_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 64, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 169, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 71, 72, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 177, 178, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 179, 180, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 182, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 183, 184, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 192, 194, 16 },
   { 196, 198, 16 },
   { 199, 200, 16 },
   { 201, 202, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 282, 0 },
   { 287, 292, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 282, 0 },
   { 293, 297, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 42, 0 },
   { 300, 42, 0 },
   { 354, 347, 117 },
   { 351, 357, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 301, 42, 0 },
   { 302, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 303, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 467, 569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 571, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 572, 573, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 574, 328, 0 },
   { 574, 325, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 575, 576, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 577, 578, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 579, 581, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 10, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 160, 161, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 121, 123, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 158, 159, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 150, 151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 565, 566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 64, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 42, 0 },
   { 59, 64, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 64, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 64, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 64, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 16, 0 },
   { 29, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 164, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { 26, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 162, 163, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 152, 153, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 126, 127, 0 },
   { 134, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 563, 564, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 20, 21, 0 },
   { 32, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 128, 129, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 154, 155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 561, 562, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 22, 23, 0 },
   { 33, 23, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 165, 166, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 130, 131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 157, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 567, 568, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 230, 233, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 447, 449, 0 },
   { 452, 449, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 455, 457, 0 },
   { 460, 457, 0 },
   { 462, 464, 0 },
   { 466, 464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 61, 62, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 77, 78, 27 },
   { 83, 84, 28 },
   { 89, 90, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 61, 62, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 77, 78, 27 },
   { 83, 84, 28 },
   { 89, 90, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 77, 78, 27 },
   { 83, 84, 28 },
   { 89, 90, 29 },
   { 204, 194, 16 },
   { 206, 198, 16 },
   { 207, 200, 16 },
   { 208, 202, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 61, 62, 107 },
   { 77, 78, 27 },
   { 83, 84, 28 },
   { 89, 90, 29 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 115, 117, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 113, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 113, 113 },
   { 115, 117, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 222, 218, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 42, 0 },
   { 350, 339, 117 },
   { 353, 343, 117 },
   { 356, 347, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 48, 0 },
   { 170, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 42, 0 },
   { 369, 371, 0 },
   { 378, 380, 0 },
   { 387, 389, 0 },
   { 397, 399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 57, 58, 0 },
   { 169, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 169, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 169, 42, 0 },
   { 374, 375, 0 },
   { 383, 384, 0 },
   { 392, 393, 0 },
   { 402, 403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 95, 99, 112 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 66, 67, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 101, 103, 112 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 66, 67, 109 },
   { 95, 99, 112 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 95, 99, 112 },
   { 101, 103, 112 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 66, 67, 109 },
   { 101, 103, 112 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 104, 106, 112 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 306, 304, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 308, 304, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 309, 307, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 310, 307, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 42, 0 },
   { 300, 42, 0 },
   { 337, 339, 117 },
   { 341, 343, 117 },
   { 345, 347, 117 },
   { 354, 347, 117 },
   { 351, 357, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 359, 360, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 312, 314, 52 },
   { 321, 322, 52 },
   { 326, 327, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 314, 52 },
   { 324, 322, 52 },
   { 329, 327, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 317, 318, 52 },
   { 330, 331, 52 },
   { 333, 334, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 319, 318, 52 },
   { 332, 331, 52 },
   { 335, 334, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 362, 363, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 12, 6, 0 },
   { 160, 161, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 8, 10, 0 },
   { 158, 159, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 18, 14, 0 },
   { 30, 14, 0 },
   { 164, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { 28, 16, 0 },
   { 162, 163, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 144, 149, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 218, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 220, 218, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 214, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 214, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 214, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 220, 218, 16 },
   { 222, 218, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 192, 194, 16 },
   { 196, 198, 16 },
   { 199, 200, 16 },
   { 201, 202, 16 },
   { 213, 214, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 214, 16 },
   { 217, 218, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 214, 16 },
   { 220, 218, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 214, 16 },
   { 222, 218, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 268, 273, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 61, 62, 107 },
   { 174, 176, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 77, 78, 27 },
   { 83, 84, 28 },
   { 89, 90, 29 },
   { 407, 411, 13 },
   { 424, 428, 15 },
   { 437, 441, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 77, 78, 27 },
   { 83, 84, 28 },
   { 89, 90, 29 },
   { 204, 194, 16 },
   { 206, 198, 16 },
   { 207, 200, 16 },
   { 208, 202, 16 },
   { 407, 411, 13 },
   { 424, 428, 15 },
   { 437, 441, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 268, 273, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 61, 62, 107 },
   { 268, 273, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 77, 78, 27 },
   { 83, 84, 28 },
   { 89, 90, 29 },
   { 268, 273, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 508, 197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 541, 542, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 559, 560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 547, 548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 538, 539, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 532, 533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 557, 84, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 519, 520, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 528, 529, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 516, 517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 469, 470, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 472, 473, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 475, 476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 478, 479, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 481, 482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 484, 485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 487, 488, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 490, 491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 493, 494, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 496, 497, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 499, 500, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 502, 503, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 505, 506, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 510, 511, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 513, 514, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 522, 523, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 525, 526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 535, 536, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 544, 545, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 550, 551, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 553, 554, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 416, 420, 0 },
   { 430, 431, 0 },
   { 443, 444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 218, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 218, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 218, 16 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 38, 41, 0 },
   { 170, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 53, 54, 0 },
   { 169, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 254, 260, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 254, 260, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 61, 62, 107 },
   { 254, 260, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 77, 78, 27 },
   { 83, 84, 28 },
   { 89, 90, 29 },
   { 254, 260, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 254, 260, 115 },
   { 268, 273, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 64, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 61, 62, 107 },
   { 275, 281, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 61, 62, 107 },
   { 275, 281, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 61, 62, 107 },
   { 77, 78, 27 },
   { 83, 84, 28 },
   { 89, 90, 29 },
   { 275, 281, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 61, 62, 107 },
   { 268, 273, 115 },
   { 275, 281, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 61, 62, 107 },
   { 254, 260, 115 },
   { 275, 281, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_late_pass_op_table[nir_num_search_ops] = {
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         49,
         50,
         51,
         0,
         157,
         0,
         52,
         0,
         0,
         0,
         0,
         0,
         0,
         53,
         0,
         54,
         0,
         0,
         54,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         55,
         0,
         0,
         158,
         0,
         54,
         0,
         0,
         54,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         6,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         3,
         8,
         4,
         7,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         9,
         0,
         9,
         10,
         9,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         2,
         3,
         94,
         95,
         95,
         2,
         94,
         95,
         95,
         173,
         218,
         224,
         3,
         3,
         96,
         97,
         98,
         3,
         174,
         175,
         176,
         177,
         219,
         225,
         94,
         96,
         94,
         99,
         99,
         94,
         94,
         99,
         99,
         178,
         220,
         224,
         95,
         97,
         99,
         95,
         95,
         95,
         99,
         95,
         95,
         179,
         221,
         226,
         95,
         98,
         99,
         95,
         95,
         95,
         99,
         95,
         95,
         179,
         221,
         226,
         2,
         3,
         94,
         95,
         95,
         100,
         94,
         95,
         95,
         173,
         218,
         224,
         94,
         174,
         94,
         99,
         99,
         94,
         94,
         99,
         99,
         178,
         220,
         224,
         95,
         175,
         99,
         95,
         95,
         95,
         99,
         95,
         95,
         179,
         221,
         226,
         95,
         176,
         99,
         95,
         95,
         95,
         99,
         95,
         95,
         179,
         221,
         226,
         173,
         177,
         178,
         179,
         179,
         173,
         178,
         179,
         179,
         173,
         222,
         227,
         218,
         219,
         220,
         221,
         221,
         218,
         220,
         221,
         221,
         222,
         218,
         228,
         224,
         225,
         224,
         226,
         226,
         224,
         224,
         226,
         226,
         227,
         228,
         224,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         4,
         56,
         57,
         58,
         59,
         60,
         223,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         61,
         62,
         0,
         0,
         159,
         0,
         0,
         63,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         64,
         0,
         65,
         0,
         0,
         65,
         0,
         0,
         66,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         67,
         0,
         0,
         0,
         160,
         0,
         65,
         0,
         0,
         65,
         0,
         0,
         161,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         5,
         6,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         68,
         69,
         70,
         71,
         6,
         5,
         68,
         5,
         5,
         5,
         5,
         5,
         5,
         69,
         5,
         72,
         5,
         5,
         5,
         5,
         70,
         5,
         5,
         5,
         5,
         5,
         5,
         71,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         5,
         5,
         5,
         5,
         73,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         8,
         74,
         75,
         76,
         8,
         7,
         74,
         7,
         7,
         7,
         7,
         7,
         75,
         7,
         77,
         7,
         7,
         7,
         76,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         78,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         107,
         9,
         9,
         9,
         9,
         108,
         9,
         109,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         216,
         9,
         9,
         109,
         9,
         9,
         9,
         9,
         216,
         9,
         107,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         110,
         9,
         9,
         9,
         9,
         216,
         216,
         9,
         9,
         9,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         1,
         1,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         217,
         10,
         10,
         10,
         111,
         10,
         217,
         10,
         10,
         111,
         112,
         10,
         10,
         10,
         10,
         10,
         10,
         113,
         10,
         10,
         217,
         217,
         10,
         10,
         10,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         11,
         114,
         115,
         116,
         114,
         114,
         117,
         118,
         115,
         117,
         115,
         119,
         116,
         118,
         119,
         116,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         12,
      },
   },
   [nir_op_iabs] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         3,
         0,
         5,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         14,
         15,
         86,
         87,
         14,
         213,
         15,
         15,
         88,
         89,
         15,
         214,
         86,
         88,
         86,
         90,
         86,
         213,
         87,
         89,
         90,
         87,
         87,
         215,
         14,
         15,
         86,
         87,
         91,
         213,
         213,
         214,
         213,
         215,
         213,
         213,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         16,
         16,
         120,
         120,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         101,
         102,
         103,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         17,
         133,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         2,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         1,
         1,
         1,
         0,
         1,
         2,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         79,
         79,
         0,
         0,
         79,
         80,
         0,
         0,
         0,
         0,
         81,
      },
   },
   [nir_op_fdot2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         18,
      },
   },
   [nir_op_fdot3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         19,
      },
   },
   [nir_op_fdot4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         20,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         21,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         82,
         82,
         82,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         83,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         7,
         4,
         8,
         7,
         3,
         0,
         0,
         9,
         0,
         9,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         10,
         10,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         7,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         2,
         9,
         9,
         9,
         9,
         9,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         23,
         22,
         104,
         105,
         22,
         163,
         164,
         168,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         23,
         22,
         104,
         105,
         22,
         163,
         164,
         168,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         165,
         169,
         165,
         166,
         166,
         165,
         170,
         171,
         171,
         165,
         167,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         23,
         22,
         104,
         105,
         22,
         163,
         164,
         168,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         165,
         165,
         165,
         166,
         172,
         165,
         165,
         166,
         172,
         165,
         167,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         106,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         23,
         22,
         104,
         105,
         22,
         163,
         164,
         168,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         165,
         165,
         165,
         166,
         172,
         165,
         165,
         166,
         172,
         165,
         167,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         165,
         169,
         165,
         166,
         166,
         165,
         170,
         171,
         171,
         165,
         167,
         165,
         165,
         165,
         166,
         172,
         165,
         165,
         166,
         172,
         165,
         167,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         165,
         165,
         165,
         166,
         172,
         165,
         165,
         166,
         172,
         165,
         167,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         23,
         22,
         104,
         104,
         22,
         163,
         164,
         164,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         105,
         22,
         22,
         104,
         105,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
         165,
         165,
         165,
         166,
         166,
         165,
         165,
         166,
         166,
         165,
         167,
         22,
         22,
         22,
         104,
         104,
         22,
         22,
         104,
         104,
         22,
         162,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         92,
         0,
         0,
         0,
         93,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         211,
         0,
         0,
         84,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         211,
         0,
         0,
         84,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         211,
         0,
         0,
         84,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         211,
         0,
         0,
         84,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         211,
         0,
         0,
         84,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         212,
         0,
         211,
         0,
         0,
         84,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         211,
         0,
         0,
         84,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         24,
         134,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         25,
         135,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         26,
         0,
         27,
         0,
         26,
         0,
         27,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         28,
         0,
         29,
         0,
         28,
         0,
         29,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         30,
         0,
         0,
         30,
         0,
         0,
         125,
         0,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         31,
         0,
         31,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         32,
         0,
         32,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         121,
         33,
         33,
         33,
         122,
         33,
         33,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         34,
         35,
         34,
         34,
         34,
         35,
         34,
         34,
         34,
         123,
         34,
         34,
         34,
         124,
         34,
         34,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         36,
         127,
         128,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         37,
         129,
         130,
      },
   },
   [nir_op_insert_u8] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         126,
         126,
      },
   },
   [nir_op_insert_u16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         131,
         131,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         38,
         0,
         38,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         39,
         39,
         39,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         40,
         40,
         40,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         132,
      },
   },
   [nir_op_inot] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         41,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         29,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 32,
      .table = (const uint16_t []) {
      
         0,
         180,
         181,
         182,
         183,
         184,
         185,
         186,
         187,
         188,
         189,
         190,
         191,
         192,
         193,
         194,
         195,
         196,
         197,
         198,
         199,
         200,
         201,
         202,
         203,
         204,
         205,
         206,
         207,
         208,
         209,
         210,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         136,
      },
   },
   [nir_op_f2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         42,
      },
   },
   [nir_op_fceil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         137,
      },
   },
   [nir_op_fcos] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         138,
      },
   },
   [nir_op_fddx] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         139,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         140,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         141,
      },
   },
   [nir_op_fddy] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         142,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         143,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         144,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         145,
      },
   },
   [nir_op_ffloor] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         146,
      },
   },
   [nir_op_ffract] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         147,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         148,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         149,
      },
   },
   [nir_op_fround_even] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         150,
      },
   },
   [nir_op_fsign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         151,
      },
   },
   [nir_op_fsin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         152,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         153,
      },
   },
   [nir_op_fmod] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         154,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         155,
      },
   },
   [nir_op_frem] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         156,
      },
   },
   [nir_op_f2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         43,
      },
   },
   [nir_op_f2ump] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         44,
      },
   },
   [nir_op_i2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         45,
      },
   },
   [nir_op_i2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         46,
      },
   },
   [nir_op_u2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         47,
      },
   },
   [nir_op_fisfinite] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         48,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_late_transform_offsets[] = {
   0,
   0,
   0,
   0,
   1,
   0,
   0,
   0,
   0,
   3,
   5,
   0,
   7,
   9,
   0,
   0,
   0,
   0,
   11,
   13,
   15,
   17,
   0,
   19,
   0,
   0,
   24,
   26,
   29,
   31,
   34,
   39,
   42,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   44,
   46,
   48,
   50,
   53,
   55,
   57,
   59,
   61,
   63,
   65,
   67,
   69,
   71,
   73,
   75,
   78,
   80,
   82,
   84,
   87,
   89,
   92,
   94,
   96,
   99,
   101,
   104,
   106,
   0,
   108,
   110,
   112,
   115,
   117,
   119,
   121,
   0,
   123,
   0,
   125,
   0,
   127,
   130,
   0,
   0,
   0,
   0,
   0,
   0,
   135,
   0,
   137,
   139,
   143,
   145,
   149,
   157,
   0,
   162,
   164,
   166,
   0,
   169,
   0,
   171,
   176,
   178,
   181,
   187,
   190,
   192,
   198,
   200,
   202,
   204,
   207,
   210,
   213,
   215,
   217,
   219,
   221,
   223,
   231,
   233,
   237,
   241,
   245,
   249,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   251,
   254,
   257,
   261,
   265,
   0,
   267,
   269,
   271,
   273,
   275,
   277,
   280,
   286,
   289,
   292,
   295,
   297,
   300,
   307,
   318,
   320,
   323,
   328,
   330,
   332,
   334,
   336,
   338,
   340,
   342,
   344,
   346,
   348,
   350,
   352,
   354,
   356,
   358,
   360,
   362,
   364,
   366,
   368,
   370,
   372,
   374,
   376,
   378,
   380,
   382,
   384,
   386,
   388,
   390,
   394,
   396,
   398,
   400,
   402,
   405,
   408,
   410,
   412,
   415,
   420,
   423,
   425,
   428,
   431,
   437,
   441,
};

static const nir_algebraic_table nir_opt_algebraic_late_table = {
   .transforms = nir_opt_algebraic_late_transforms,
   .transform_offsets = nir_opt_algebraic_late_transform_offsets,
   .pass_op_table = nir_opt_algebraic_late_pass_op_table,
   .values = nir_opt_algebraic_late_values,
   .expression_cond = nir_opt_algebraic_late_expression_cond,
   .variable_cond = nir_opt_algebraic_late_variable_cond,
};

bool
nir_opt_algebraic_late(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[119];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(582 == ARRAY_SIZE(nir_opt_algebraic_late_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = !options->has_sdot_4x8;
   condition_flags[10] = !options->has_udot_4x8;
   condition_flags[11] = !options->has_sudot_4x8;
   condition_flags[12] = !options->has_dot_2x16;
   condition_flags[13] = options->lower_flrp16;
   condition_flags[14] = !options->lower_flrp16;
   condition_flags[15] = options->lower_flrp32;
   condition_flags[16] = !options->lower_flrp32;
   condition_flags[17] = options->lower_flrp64;
   condition_flags[18] = !options->lower_flrp64;
   condition_flags[19] = options->lower_ftrunc;
   condition_flags[20] = options->lower_ffloor;
   condition_flags[21] = !options->lower_ffloor;
   condition_flags[22] = options->lower_ffract;
   condition_flags[23] = options->lower_fceil;
   condition_flags[24] = options->lower_ffma16;
   condition_flags[25] = options->lower_ffma32;
   condition_flags[26] = options->lower_ffma64;
   condition_flags[27] = options->fuse_ffma16;
   condition_flags[28] = options->fuse_ffma32;
   condition_flags[29] = options->fuse_ffma64;
   condition_flags[30] = options->lower_fdph;
   condition_flags[31] = !options->lower_fdph;
   condition_flags[32] = options->lower_fdot;
   condition_flags[33] = !options->lower_fsat;
   condition_flags[34] = !options->lower_iabs;
   condition_flags[35] = options->lower_fsat;
   condition_flags[36] = !options->lower_fsign;
   condition_flags[37] = options->lower_umax;
   condition_flags[38] = options->lower_umin;
   condition_flags[39] = !options->lower_umax;
   condition_flags[40] = !options->lower_umin;
   condition_flags[41] = options->lower_scmp;
   condition_flags[42] = options->lower_vector_cmp;
   condition_flags[43] = !options->lower_rotate;
   condition_flags[44] = options->lower_rotate;
   condition_flags[45] = options->lower_fpow;
   condition_flags[46] = !options->lower_fpow;
   condition_flags[47] = options->lower_fdiv;
   condition_flags[48] = options->lower_fsqrt;
   condition_flags[49] = !options->lower_fsqrt;
   condition_flags[50] = options->lower_sincos;
   condition_flags[51] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[52] = !options->lower_extract_byte;
   condition_flags[53] = !options->lower_extract_word;
   condition_flags[54] = options->has_pack_32_4x8;
   condition_flags[55] = options->lower_pack_64_2x32_split;
   condition_flags[56] = options->lower_pack_32_2x16_split;
   condition_flags[57] = options->lower_unpack_64_2x32_split;
   condition_flags[58] = options->lower_unpack_32_2x16_split;
   condition_flags[59] = options->lower_fmod;
   condition_flags[60] = options->lower_uadd_carry;
   condition_flags[61] = options->lower_usub_borrow;
   condition_flags[62] = options->lower_bitfield_insert;
   condition_flags[63] = options->lower_hadd;
   condition_flags[64] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[65] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[66] = options->lower_uadd_sat;
   condition_flags[67] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[70] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[71] = options->lower_bitfield_insert_to_shifts;
   condition_flags[72] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[73] = options->lower_bitfield_extract;
   condition_flags[74] = options->lower_bitfield_extract_to_shifts;
   condition_flags[75] = options->lower_ifind_msb;
   condition_flags[76] = options->lower_find_msb_to_reverse;
   condition_flags[77] = options->lower_find_lsb;
   condition_flags[78] = options->lower_extract_byte;
   condition_flags[79] = options->lower_extract_word;
   condition_flags[80] = options->lower_pack_unorm_2x16;
   condition_flags[81] = options->lower_pack_unorm_4x8;
   condition_flags[82] = options->lower_pack_snorm_2x16;
   condition_flags[83] = options->lower_pack_snorm_4x8;
   condition_flags[84] = options->lower_unpack_unorm_2x16;
   condition_flags[85] = options->lower_unpack_unorm_4x8;
   condition_flags[86] = options->lower_unpack_snorm_2x16;
   condition_flags[87] = options->lower_unpack_snorm_4x8;
   condition_flags[88] = options->lower_pack_split;
   condition_flags[89] = options->lower_isign;
   condition_flags[90] = !options->lower_isign;
   condition_flags[91] = options->lower_fsign;
   condition_flags[92] = !options->has_imul24;
   condition_flags[93] = !options->has_umul24;
   condition_flags[94] = !options->has_umad24;
   condition_flags[95] = options->has_imul24;
   condition_flags[96] = options->has_umad24;
   condition_flags[97] = options->has_umul24;
   condition_flags[98] = options->has_fused_comp_and_csel;
   condition_flags[99] = options->lower_iadd_sat;
   condition_flags[100] = options->support_8bit_alu;
   condition_flags[101] = options->support_16bit_alu;
   condition_flags[102] = options->lower_ldexp;
   condition_flags[103] = !options->lower_bitfield_reverse;
   condition_flags[104] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[105] = options->lower_fisnormal;
   condition_flags[106] = !options->vectorize_vec2_16bit;
   condition_flags[107] = options->has_fsub;
   condition_flags[108] = options->lower_fneg;
   condition_flags[109] = options->has_isub || options->lower_ineg;
   condition_flags[110] = options->lower_ineg;
   condition_flags[111] = options->lower_iabs;
   condition_flags[112] = options->has_iadd3;
   condition_flags[113] = options->vectorize_vec2_16bit;
   condition_flags[114] = options->fdot_replicates;
   condition_flags[115] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[116] = options->avoid_ternary_with_two_constants;
   condition_flags[117] = !options->lower_insert_byte;
   condition_flags[118] = !options->lower_insert_word;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_late_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 19
 * transforms:
 *    ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b')
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b')
 *    ('fneg', ('fneg', 'a')) => a
 *    ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b')
 *    ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b'))
 *    ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c'))
 *    ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c')
 *    ('fneg', ('fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b'))
 *    ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a'))
 *    ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a'))
 */


static const nir_search_value_union nir_opt_algebraic_distribute_src_mods_values[] = {
   /* ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2055_0 -> 0 in the cache */
   /* replace2055_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 8 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 7, 9, 10 },
      -1,
   } },

   /* replace2056_0 -> 6 in the cache */
   /* replace2056_1 -> 8 in the cache */
   /* replace2056_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      -1,
   } },

   /* ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b') */
   /* search2057_0_0 -> 0 in the cache */
   /* search2057_0 -> 1 in the cache */
   /* search2057_1_0 -> 2 in the cache */
   /* search2057_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2057_0 -> 0 in the cache */
   /* replace2057_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b') */
   /* search2058_0_0 -> 0 in the cache */
   /* search2058_0 -> 1 in the cache */
   /* search2058_1_0 -> 2 in the cache */
   /* search2058_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2058_0 -> 0 in the cache */
   /* replace2058_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b') */
   /* search2059_0_0 -> 0 in the cache */
   /* search2059_0 -> 1 in the cache */
   /* search2059_1_0 -> 2 in the cache */
   /* search2059_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2059_0 -> 0 in the cache */
   /* replace2059_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 20 },
      -1,
   } },

   /* replace2060 -> 19 in the cache */

   /* ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b') */
   /* search2061_0_0 -> 0 in the cache */
   /* search2061_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2061_0_0 -> 0 in the cache */
   /* replace2061_0 -> 1 in the cache */
   /* replace2061_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b')) */
   /* search2062_0_0 -> 0 in the cache */
   /* search2062_0_1 -> 2 in the cache */
   /* search2062_0 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fabs,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2062_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2062_1_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmul,
      0, 1,
      { 26, 27 },
      -1,
   } },

   /* ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c')) */
   /* search2063_0_0 -> 6 in the cache */
   /* search2063_0_1 -> 8 in the cache */
   /* search2063_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 29 },
      -1,
   } },

   /* replace2063_0_0 -> 6 in the cache */
   /* replace2063_0 -> 7 in the cache */
   /* replace2063_1 -> 8 in the cache */
   /* replace2063_2_0 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 10 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_ffma,
      0, 1,
      { 7, 8, 31 },
      -1,
   } },

   /* ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c') */
   /* search2064_0_0 -> 6 in the cache */
   /* search2064_0_1 -> 8 in the cache */
   /* search2064_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 33 },
      -1,
   } },

   /* replace2064_0_0 -> 6 in the cache */
   /* replace2064_0 -> 7 in the cache */
   /* replace2064_1_0 -> 8 in the cache */
   /* replace2064_1 -> 9 in the cache */
   /* replace2064_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false, false,
      nir_op_flrp,
      -1, 0,
      { 7, 9, 10 },
      -1,
   } },

   /* ('fneg', ('fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2065_0_0 -> 0 in the cache */
   /* search2065_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 36 },
      -1,
   } },

   /* replace2065_0_0 -> 0 in the cache */
   /* replace2065_0 -> 1 in the cache */
   /* replace2065_1_0 -> 2 in the cache */
   /* replace2065_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fadd,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2066_0_0 -> 0 in the cache */
   /* search2066_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 39 },
      -1,
   } },

   /* replace2066_0_0 -> 0 in the cache */
   /* replace2066_0 -> 1 in the cache */
   /* replace2066_1_0 -> 2 in the cache */
   /* replace2066_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2067_0_0 -> 0 in the cache */
   /* search2067_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmax,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 42 },
      -1,
   } },

   /* replace2067_0_0 -> 0 in the cache */
   /* replace2067_0 -> 1 in the cache */
   /* replace2067_1_0 -> 2 in the cache */
   /* replace2067_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fmin,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b') */
   /* search2068_0_0 -> 0 in the cache */
   /* search2068_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 45 },
      -1,
   } },

   /* replace2068_0_0 -> 0 in the cache */
   /* replace2068_0 -> 1 in the cache */
   /* replace2068_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b') */
   /* search2069_0_0 -> 0 in the cache */
   /* search2069_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 48 },
      -1,
   } },

   /* replace2069_0_0 -> 0 in the cache */
   /* replace2069_0 -> 1 in the cache */
   /* replace2069_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b') */
   /* search2070_0_0 -> 0 in the cache */
   /* search2070_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 1,
      { 51 },
      -1,
   } },

   /* replace2070_0_0 -> 0 in the cache */
   /* replace2070_0 -> 1 in the cache */
   /* replace2070_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b')) */
   /* search2071_0_0 -> 0 in the cache */
   /* search2071_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 54 },
      -1,
   } },

   /* replace2071_0 -> 0 in the cache */
   /* replace2071_1_0 -> 2 in the cache */
   /* replace2071_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false, false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a')) */
   /* search2072_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 19 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fneg,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2072_0_0 -> 19 in the cache */
   /* replace2072_0 -> 20 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 20 },
      -1,
   } },

   /* ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a')) */
   /* search2073_0_0 -> 19 in the cache */
   /* search2073_0 -> 57 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2073_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fabs,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false, false,
      nir_op_fsign,
      -1, 0,
      { 61 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_distribute_src_mods_expression_cond[] = {
   (is_used_once),
};


static const struct transform nir_opt_algebraic_distribute_src_mods_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 23, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 21, 19, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 30, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 47, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 49, 50, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 53, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 40, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 43, 44, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 56, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 59, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 25, 28, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 62, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 5, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 12, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 18, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_distribute_src_mods_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         2,
         2,
         2,
         28,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         7,
         8,
         9,
         10,
         11,
         12,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         1,
         3,
         4,
         5,
         6,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         3,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         4,
         4,
         4,
         4,
         4,
         4,
         29,
         29,
      },
   },
   [nir_op_fdot2_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         5,
         5,
         5,
         30,
      },
   },
   [nir_op_fdot3_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         6,
         6,
         6,
         31,
      },
   },
   [nir_op_fdot4_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         7,
         7,
         7,
         32,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         26,
         27,
      },
   },
   [nir_op_flrp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         8,
      },
   },
   [nir_op_fadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_fmin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_fmax] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_fdph_replicated] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         12,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_distribute_src_mods_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   13,
   15,
   17,
   19,
   21,
   23,
   25,
   27,
   29,
   31,
   33,
   35,
   37,
};

static const nir_algebraic_table nir_opt_algebraic_distribute_src_mods_table = {
   .transforms = nir_opt_algebraic_distribute_src_mods_transforms,
   .transform_offsets = nir_opt_algebraic_distribute_src_mods_transform_offsets,
   .pass_op_table = nir_opt_algebraic_distribute_src_mods_pass_op_table,
   .values = nir_opt_algebraic_distribute_src_mods_values,
   .expression_cond = nir_opt_algebraic_distribute_src_mods_expression_cond,
   .variable_cond = NULL,
};

bool
nir_opt_algebraic_distribute_src_mods(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[119];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(63 == ARRAY_SIZE(nir_opt_algebraic_distribute_src_mods_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = !options->has_sdot_4x8;
   condition_flags[10] = !options->has_udot_4x8;
   condition_flags[11] = !options->has_sudot_4x8;
   condition_flags[12] = !options->has_dot_2x16;
   condition_flags[13] = options->lower_flrp16;
   condition_flags[14] = !options->lower_flrp16;
   condition_flags[15] = options->lower_flrp32;
   condition_flags[16] = !options->lower_flrp32;
   condition_flags[17] = options->lower_flrp64;
   condition_flags[18] = !options->lower_flrp64;
   condition_flags[19] = options->lower_ftrunc;
   condition_flags[20] = options->lower_ffloor;
   condition_flags[21] = !options->lower_ffloor;
   condition_flags[22] = options->lower_ffract;
   condition_flags[23] = options->lower_fceil;
   condition_flags[24] = options->lower_ffma16;
   condition_flags[25] = options->lower_ffma32;
   condition_flags[26] = options->lower_ffma64;
   condition_flags[27] = options->fuse_ffma16;
   condition_flags[28] = options->fuse_ffma32;
   condition_flags[29] = options->fuse_ffma64;
   condition_flags[30] = options->lower_fdph;
   condition_flags[31] = !options->lower_fdph;
   condition_flags[32] = options->lower_fdot;
   condition_flags[33] = !options->lower_fsat;
   condition_flags[34] = !options->lower_iabs;
   condition_flags[35] = options->lower_fsat;
   condition_flags[36] = !options->lower_fsign;
   condition_flags[37] = options->lower_umax;
   condition_flags[38] = options->lower_umin;
   condition_flags[39] = !options->lower_umax;
   condition_flags[40] = !options->lower_umin;
   condition_flags[41] = options->lower_scmp;
   condition_flags[42] = options->lower_vector_cmp;
   condition_flags[43] = !options->lower_rotate;
   condition_flags[44] = options->lower_rotate;
   condition_flags[45] = options->lower_fpow;
   condition_flags[46] = !options->lower_fpow;
   condition_flags[47] = options->lower_fdiv;
   condition_flags[48] = options->lower_fsqrt;
   condition_flags[49] = !options->lower_fsqrt;
   condition_flags[50] = options->lower_sincos;
   condition_flags[51] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[52] = !options->lower_extract_byte;
   condition_flags[53] = !options->lower_extract_word;
   condition_flags[54] = options->has_pack_32_4x8;
   condition_flags[55] = options->lower_pack_64_2x32_split;
   condition_flags[56] = options->lower_pack_32_2x16_split;
   condition_flags[57] = options->lower_unpack_64_2x32_split;
   condition_flags[58] = options->lower_unpack_32_2x16_split;
   condition_flags[59] = options->lower_fmod;
   condition_flags[60] = options->lower_uadd_carry;
   condition_flags[61] = options->lower_usub_borrow;
   condition_flags[62] = options->lower_bitfield_insert;
   condition_flags[63] = options->lower_hadd;
   condition_flags[64] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[65] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[66] = options->lower_uadd_sat;
   condition_flags[67] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[70] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[71] = options->lower_bitfield_insert_to_shifts;
   condition_flags[72] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[73] = options->lower_bitfield_extract;
   condition_flags[74] = options->lower_bitfield_extract_to_shifts;
   condition_flags[75] = options->lower_ifind_msb;
   condition_flags[76] = options->lower_find_msb_to_reverse;
   condition_flags[77] = options->lower_find_lsb;
   condition_flags[78] = options->lower_extract_byte;
   condition_flags[79] = options->lower_extract_word;
   condition_flags[80] = options->lower_pack_unorm_2x16;
   condition_flags[81] = options->lower_pack_unorm_4x8;
   condition_flags[82] = options->lower_pack_snorm_2x16;
   condition_flags[83] = options->lower_pack_snorm_4x8;
   condition_flags[84] = options->lower_unpack_unorm_2x16;
   condition_flags[85] = options->lower_unpack_unorm_4x8;
   condition_flags[86] = options->lower_unpack_snorm_2x16;
   condition_flags[87] = options->lower_unpack_snorm_4x8;
   condition_flags[88] = options->lower_pack_split;
   condition_flags[89] = options->lower_isign;
   condition_flags[90] = !options->lower_isign;
   condition_flags[91] = options->lower_fsign;
   condition_flags[92] = !options->has_imul24;
   condition_flags[93] = !options->has_umul24;
   condition_flags[94] = !options->has_umad24;
   condition_flags[95] = options->has_imul24;
   condition_flags[96] = options->has_umad24;
   condition_flags[97] = options->has_umul24;
   condition_flags[98] = options->has_fused_comp_and_csel;
   condition_flags[99] = options->lower_iadd_sat;
   condition_flags[100] = options->support_8bit_alu;
   condition_flags[101] = options->support_16bit_alu;
   condition_flags[102] = options->lower_ldexp;
   condition_flags[103] = !options->lower_bitfield_reverse;
   condition_flags[104] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[105] = options->lower_fisnormal;
   condition_flags[106] = !options->vectorize_vec2_16bit;
   condition_flags[107] = options->has_fsub;
   condition_flags[108] = options->lower_fneg;
   condition_flags[109] = options->has_isub || options->lower_ineg;
   condition_flags[110] = options->lower_ineg;
   condition_flags[111] = options->lower_iabs;
   condition_flags[112] = options->has_iadd3;
   condition_flags[113] = options->vectorize_vec2_16bit;
   condition_flags[114] = options->fdot_replicates;
   condition_flags[115] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[116] = options->avoid_ternary_with_two_constants;
   condition_flags[117] = !options->lower_insert_byte;
   condition_flags[118] = !options->lower_insert_word;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_distribute_src_mods_table);
      }
   }

   return progress;
}

